<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

/*
Plugin Name: Grand Job
Plugin URI: https://sfwebservice.com/grand-job
Description: Jobboard manager plugin
Version: 1.2.1
Author: SFThemes
Author URI: https://sfwebservice.com
License: GPLv2 or later
Text Domain: gj
*/

class GJ_Class{

    /**
     * GJ version.
     *
     * @var string
     */
    public $version = '1.2.0';

    /**
     * The single instance of the class.
     *
     */
    protected static $_instance = null;

    /**
     * Main GJ Instance.
     *
     * Ensures only one instance of GJ is loaded or can be loaded.
     *
     */
    public static function instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }
        return self::$_instance;
    }


    /**
     * GJ Constructor.
     */
    public function __construct() {

        $this->define_constants();
        $this->includes();
        $this->init_hooks();


    }

    /**
     * Define GJ Constants.
     */
    private function define_constants() {
	    $upload_dir = wp_upload_dir();
        define( 'GJ_VERSION', $this->version );
        define( 'GJ_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
        define( 'GJ_PLUGIN_URL', plugins_url( '/', __FILE__ ) );
        define( 'GJ_PREFIX', '_gj_' );
	    define( 'GJ_IMPORT_DIR', $upload_dir['basedir'] . '/jobs_import_export/imports' );
	    define( 'GJ_IMPORT_URL', $upload_dir['baseurl'] . '/jobs_import_export/imports' );
	    define( 'GJ_IMPORT_LOG', $upload_dir['basedir'] . '/jobs_import_export.log' );

        if(!defined('GJ_PREVIEW_MODE')){
            define( 'GJ_PREVIEW_MODE', false );
        }
    }

    /**
     * Load GL Files
     */
    public function includes() {

        include_once GJ_PLUGIN_DIR.'includes/helper.function.php';
	    include_once GJ_PLUGIN_DIR.'includes/tools.php';
        include_once GJ_PLUGIN_DIR.'includes/class/api.controller.php';
        include_once GJ_PLUGIN_DIR.'includes/class/controller.class.php';
        include_once GJ_PLUGIN_DIR.'includes/api.php';
        include_once GJ_PLUGIN_DIR.'includes/front.class.php';
        include_once GJ_PLUGIN_DIR.'includes/install.class.php';
        if(is_admin()){
            include_once GJ_PLUGIN_DIR.'includes/admin.class.php';
        }
        include_once GJ_PLUGIN_DIR.'includes/ajax.php';
        include_once GJ_PLUGIN_DIR.'includes/class/listing.class.php';
        include_once GJ_PLUGIN_DIR.'includes/class/listing-job.class.php';
        include_once GJ_PLUGIN_DIR.'includes/class/listing-candidate.class.php';
        include_once GJ_PLUGIN_DIR.'includes/class/listing-employer.class.php';

        //rewrite rules
        include_once GJ_PLUGIN_DIR.'includes/class/rewrite-rules.php';

        // widget
        include_once GJ_PLUGIN_DIR.'includes/widgets/job-filter.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/candidate-filter.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/employer-filter.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/job_infomation.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/job_contact_form.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/employer_infomation.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/employer_contact_form.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/candidate_infomation.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/candidate_contact_form.php';
        include_once GJ_PLUGIN_DIR.'includes/widgets/job-apply.php';

        //hook
        include_once GJ_PLUGIN_DIR.'includes/hook.php';
    }

    /**
     * Hook into actions and filters.
     */
    private function init_hooks() {

        register_activation_hook( __FILE__, array( 'GJ_Install', 'install' ) );
        register_deactivation_hook( __FILE__, array('GJ_Install', 'deactive') );

        add_action('plugins_loaded', array('GJ_Install', 'update'));
        add_action( 'plugins_loaded', array( $this, 'on_plugins_loaded' ), -1 );

        add_action( 'wpmu_new_blog', array( 'GJ_Install', 'new_blog' ), 10, 6 );
        add_action( 'delete_blog', array( 'GJ_Install', 'delete_blog' ), 10, 2 );

        add_action( 'after_setup_theme', array( $this, 'setup_environment' ) );
        add_action( 'init', array( $this, 'init' ), 0 );

        add_action( 'widgets_init', array( 'GJ_Install', 'register_widgets' ), 0 );

        add_action('wp_logout', array($this, 'end_session'));
        add_action('wp_login', array($this, 'end_session'));

        add_action( 'rest_api_init', array($this, 'create_initial_rest_routes'), 99 );

        add_action( 'wp_loaded',array('GJ_Rewrite_Rules', 'flush_rules'));
        add_filter( 'rewrite_rules_array',array('GJ_Rewrite_Rules', 'insert_rewrite_rules'));
        add_filter( 'query_vars',array('GJ_Rewrite_Rules', 'insert_query_vars'));

        add_action('activated_plugin',array($this, 'active_plugin_error'));
    }

    function on_plugins_loaded(){
        do_action( 'gj_loaded' );
    }

    function active_plugin_error()
    {
        $error = ob_get_contents();
        if($error){
            file_put_contents(dirname(__file__).'/error_activation.txt', ob_get_contents());
        }
    }

    /**
     * Ensure theme and server variable compatibility and setup image sizes.
     */
    public function setup_environment() {

        define( 'GJ_TEMPLATE_PATH', $this->template_path() );

        $this->add_thumbnail_support();
        $this->add_image_sizes();
    }

    /**
     * Ensure post thumbnail support is turned on.
     */
    private function add_thumbnail_support() {
        return false;
        if ( ! current_theme_supports( 'post-thumbnails' ) ) {
            add_theme_support( 'post-thumbnails' );
        }
        add_post_type_support( 'gj_employer', 'thumbnail' );
        add_post_type_support( 'gj_candidate', 'thumbnail' );
    }
    
    private function add_image_sizes() {
        $employer_image_size = array(100, 100, false);
        $candidate_image_size = array(100, 100, true);
        $candidate_image_size = apply_filters('gj_candidate_thumbnail_size', $candidate_image_size);
        $employer_image_size = apply_filters('gj_employer_thumbnail_size', $employer_image_size);

        add_image_size( 'gjc-thumbnail', $candidate_image_size[0], $candidate_image_size[1], $candidate_image_size[2] );
        add_image_size( 'gje-thumbnail', $employer_image_size[0], $employer_image_size[1], $employer_image_size[2] );
    }

    /**
     * Load Localisation files.
     *
     */
    public function load_plugin_textdomain() {
        $locale = apply_filters( 'plugin_locale', get_locale(), 'gj' );
        load_textdomain( 'gj', GJ_PLUGIN_DIR . '/gj-' . $locale . '.mo' );
        load_plugin_textdomain( 'gj', false, plugin_basename( dirname( __FILE__ ) ) . '/languages' );
    }
 
    /**
     * Init GJ when WordPress Initialises.
     */
    public function init() {
        // Before init action.
        do_action( 'before_gj_init' );

        // Set up localisation.
        $this->load_plugin_textdomain();
        $this->start_session();

        // Init action.

        do_action( 'gj_init' );
    }

    function start_session() {
        if(!session_id()) {
            session_start();
        }
    }

    function end_session() {
    }

    /**
     * Get the template path.
     * @return string
     */
    public function template_path() {
        return apply_filters( 'gj_template_path', 'grand-job/' );
    }

    /**
     * Get the plugin path.
     * @return string
     */
    public function plugin_path() {
        return untrailingslashit( GJ_PLUGIN_DIR );
    }

    /**
     * Auto-load in-accessible properties on demand.
     * @param mixed $key
     * @return mixed
     */
    public function __get( $key ) {
        if ( in_array( $key, array( 'payment_gateways', 'social_logins', 'applies') ) ) {
            return $this->$key();
        }

        return null;
    }

    /**
     * Get gateways class.
     * @return GJ_Payment_Gateways
     */
    public function payment_gateways() {
        return GJ_Payment_Gateways::instance();
    }

    /**
     * Get Social Login class.
     * @return GJ_Social_Logins
     */
    public function social_logins() {
        return GJ_Social_Logins::instance();
    }

    /**
     * Get Apply method class.
     * @return GJ_Applies
     */
    public function applies() {
        return GJ_Applies::instance();
    }

    /**
     * Register API
     */
    public function create_initial_rest_routes(){
        $controller = new GJ_REST_Controller;
        $controller->register_routes();
    }
}

/**
 * @return GJ_Class
 */
if(!function_exists('GJ')){
    function GJ(){
        return GJ_Class::instance();
    }
}

// Global for backwards compatibility.
$GLOBALS['gj'] = GJ();
