<?php

class GJ_Admin_Application{
    static function init(){
        add_filter('manage_posts_columns' , array(__CLASS__, 'columns_head' ));
        add_filter('manage_posts_custom_column' , array(__CLASS__, 'columns_content' ), 10, 2);

        add_action('pre_get_posts',array( __CLASS__, 'pre_get_posts' ) );

        add_action('admin_enqueue_scripts', function (){
            $fieldHelp = GJ_Fields::instance();
            $fieldHelp->enqueueTypeScripts(array(
               'user',
               'datetime',
            ));
        });

        add_action('gj_before_schema', function($postType){
            if($postType === 'gj_application'){

                $selectOptions = new stdClass();
                $selectOptions->noOptions = esc_html__('List is empty', 'gj');
                $selectOptions->fetchingOptions = esc_html__('Fetching data...', 'gj');

                $fields = array(
                    array(
                        'type' => 'user',
                        'label' => esc_html__('Applier','gj'),
                        'model' => 'author',
                        'asynchronous' => 'every',
                        'values' => array(),
                        'selectOptions' => $selectOptions,
                    ),
                    array(
                        'type' => 'post',
                        'label' => esc_html__('Job','gj'),
                        'model' => 'job',
                        'asynchronous' => 'once',
                        'placeholder' => esc_html__('Type to search', 'gj'),
                        'postType' => 'gj_job',
                        'values' => array(),
                        'selectOptions' => $selectOptions,
                    ),
                );

                $fields = apply_filters('gj_general_fields_schema', $fields, $postType);

                foreach ($fields as $field){
                    echo json_encode($field) . ",";
                }

            }
        });

        add_filter('gj_models', function($models, $postType){
            if($postType === 'gj_application') {
                $post = get_post();
                $models[] = 'author : {ID : ' . $post->post_author . ', display_name : "' . get_the_author_meta('display_name', $post->post_author) . '"}';
                $job_id = get_post_meta($post->ID, GJ_PREFIX.'job_id', true);
                $models[] = 'job : {ID : ' . $job_id . ', post_title : "' . get_the_title($job_id) . '"}';
            }
            return $models;
        }, 10, 2);

        add_action('gj_before_save_post', function($postID){
            if($postID && get_post_type($postID) == 'gj_application'){
                $model = gj_clean($_POST);
                $postID = intval($_POST['postID']);
                $author = isset($model['author']) ? $model['author']['ID'] : get_current_user_id();
                $job_id = isset($model['job']) ? $model['job']['ID'] : '';
                wp_update_post(array(
                    'ID' => $postID,
                    'post_author' => $author,
                ), true);
                update_post_meta($postID, GJ_PREFIX.'job_id', $job_id);
            }
        });
    }

    static function columns_head( $columns )
    {
        $screen = get_current_screen();
        if ($screen->post_type == 'gj_application') {
            $columns = array(
                'cb' => '<input type="checkbox" />',
                'title' => esc_html__('Title', 'gj'),
                'full_name' => esc_html__('Name', 'gj'),
                'email' => esc_html__('Email', 'gj'),
                'user' => esc_html__('Posted User', 'gj'),
                'job' => esc_html__('Job', 'gj'),
                'source' => esc_html__('Source', 'gj'),
                'date' => esc_html__('Date', 'gj'),
            );

            $columns = apply_filters('gj_admin_application_columns_head', $columns);
        }

        return $columns;
    }

    static function columns_content( $column, $post_ID ) {
        $screen = get_current_screen();
        if($screen->post_type == 'gj_application'){
            if ($column == 'user') {
                $post = get_post($post_ID);
                $user = get_userdata($post->post_author);
                if($user){
                    echo '<a target="_blank" title="'.esc_attr__('Click to view', 'gj').'" href="'.esc_url(get_edit_user_link($user->ID)).'">'.$user->display_name.'</a>';
                }
            }
            if ($column == 'full_name') {
                $application = GJ_Application::get_application($post_ID);
                echo '<a title="'.esc_attr__('Click to filter', 'gj').'" href="'.esc_url(admin_url().'edit.php?post_type=gj_application&user_id='.$application->get_author_id()).'">'.$application->get_full_name().'</a>';
            }
            if ($column == 'email') {
                $application = GJ_Application::get_application($post_ID);
                echo '<a title="'.esc_attr__('Click to filter', 'gj').'" href="'.esc_url(admin_url().'edit.php?post_type=gj_application&user_id='.$application->get_author_id()).'">'.$application->get_email().'</a>';
            }
            if ($column == 'job') {
                $application = GJ_Application::get_application($post_ID);
                $job = $application->get_job();
                if($job){
                    echo '<a title="'.esc_attr__('Click to filter', 'gj').'" href="'.esc_url(admin_url().'edit.php?post_type=gj_application&job_id='.$job->get_id()).'">'.$job->get_title().'</a>';
                }
            }
            if ($column == 'source') {
                $application = GJ_Application::get_application($post_ID);
                echo esc_html($application->get_source());
            }

            do_action('gj_admin_application_columns_content', $post_ID);
        }
    }

    static function pre_get_posts($query){
        if(is_blog_admin() && $query->get('post_type') == 'gj_application'){
            if(!isset($_GET['post_status'])){
                $query->set('post_status', array_keys(GJ_Application::get_status_array()));
            }

            if(isset($_GET['user_id']) && $_GET['user_id']){
                $query->set('author', intval($_GET['user_id']));
            }

            if(isset($_GET['job_id']) && $_GET['job_id']){
                $query->set('meta_query', array(
                    array(
                        'key' => GJ_PREFIX.'job_id',
                        'value' => intval($_GET['job_id']),
                        'compare' => '='
                    )
                ));
            }
        }
    }
}

GJ_Admin_Application::init();