<?php

class GJ_Admin_Candidate {

    static function init() {

        add_action('admin_menu', array(__CLASS__, 'register_metabox'), 99);

        add_action('save_post', array(__CLASS__, 'save_post'));
        add_action('pre_get_posts', array(__CLASS__, 'pre_get_posts'));

        add_filter('manage_posts_columns', array(__CLASS__, 'columns_head'));
        add_filter('manage_posts_custom_column', array(__CLASS__, 'columns_content'), 10, 2);

        add_filter('post_row_actions', array(__CLASS__, 'remove_quick_edit'), 10, 1);
        add_filter('page_row_actions', array(__CLASS__, 'remove_quick_edit'), 10, 1);

        add_action('admin_footer-post.php', array(__CLASS__, 'append_post_status_list'));

        add_action('gj_before_schema', function($postType){
            if($postType === 'gj_candidate'){
                $fields = array(
                    array(
                        'type' => 'switch',
                        'label' => esc_html__('Featured','gj'),
                        'model' => 'featured',
                        'default' => '',
                        'textOn' => esc_html__('Yes','gj'),
                        'textOff' => esc_html__('No','gj'),
                        'valueOn' => '1',
                        'valueOff' => '',
                    ),
                );

                $fields = apply_filters('gj_general_fields_schema', $fields, $postType);

                $fieldString =  $tabJson = json_encode($fields);
                $fieldString = str_replace(array('"beginJSFunction', 'endJSFunction"'), array('function', ""), $fieldString);
                echo "{
                    legend : '".esc_html__('General','gj')."',
                    fields : ".$fieldString.",
                },";
            }
        });

        add_filter('gj_models', function($models, $postType){
            if($postType === 'gj_candidate') {
                $post = get_post();
                $featured = get_post_meta($post->ID, GJ_PREFIX.'featured', true);
                $models[] = 'featured : "' . ($featured) . '"';
            }
            return $models;
        }, 10, 2);

        add_action('gj_before_save_post', function($postID){
            if($postID && get_post_type($postID) == 'gj_candidate'){
                $model = gj_clean($_POST);
                $postID = intval($_POST['postID']);
                $featured = isset($model['featured']) ? $model['featured'] : '';
                update_post_meta($postID, GJ_PREFIX.'featured', $featured);
            }
        });
    }

    static function remove_quick_edit($actions) {
        global $current_screen;
        if ($current_screen->post_type != 'gj_candidate')
            return $actions;
        unset($actions['inline hide-if-no-js']);
        return $actions;
    }

    static function append_post_status_list(){
        global $post;
        $complete = '';
        $label = '';
        if($post->post_type == 'gj_candidate'){
            if($post->post_status == 'gj-rejected'){
                $complete = "selected='selected'";
                $label = esc_html__('Rejected', 'gj');
            }
            echo '
                <script>
                    jQuery(document).ready(function($){
                        $("select#post_status").append("<option value=\"gj-rejected\" '.$complete.'>'.esc_html__('Rejected', 'gj').'</option>");
                        $("#post-status-display").append("'.$label.'");
                        $("select#post_status").after("<input type=\"hidden\" name=\"original_post_status\" value=\"'.$post->post_status.'\" >");
                    });
                </script>
                ';
        }
    }

    static function register_metabox() {
        remove_meta_box('gj_catdiv', 'gj_candidate', 'core');
        remove_meta_box('gj_typediv', 'gj_candidate', 'core');
        remove_meta_box('gj_leveldiv', 'gj_candidate', 'core');
        remove_meta_box('gj_skilldiv', 'gj_candidate', 'core');
        remove_meta_box('gj_locationdiv', 'gj_candidate', 'core');
        remove_meta_box('tagsdiv-gj_state', 'gj_candidate', 'core');
        remove_meta_box('tagsdiv-gj_city', 'gj_candidate', 'core');
    }

    static function save_post($post_id) {
        require_once(ABSPATH . 'wp-admin/includes/screen.php');
        if (isset($_POST) && $_POST && !defined('DOING_AJAX') && is_blog_admin()) {
            if (get_post_type($post_id) == 'gj_candidate') {
                if(isset($_POST['original_post_status'])) {
                    $old_post_status = $_POST['original_post_status'];
                    $new_post_status = $_POST['post_status'];
                    if($old_post_status != $new_post_status){
                        $candidate = GJ_Candidate::get_candidate($post_id);

                        if ($new_post_status == 'publish') {
                            GJ_Email::send_email('approved_resume', $candidate);
                        } elseif ($new_post_status == 'pending') {
                            GJ_Email::send_email('review_resume', $candidate);

                        } elseif ($new_post_status == 'gj-rejected') {
                            GJ_Email::send_email('rejected_resume', $candidate);
                        }
                    }
                }
            }
        }
    }

    static function columns_head($columns) {
        $screen = get_current_screen();
        if ($screen->post_type == 'gj_candidate') {
            $columns = array(
                'cb' => '<input type="checkbox" />',
                'avatar' => '',
                'title' => esc_html__('Name', 'gj'),
                'status' => esc_html__('Status', 'gj'),
                'email' => esc_html__('Email', 'gj'),
                'user_id' => esc_html__('User ID', 'gj'),
                'featured' => esc_html__('Featured', 'gj'),
                'actions' => esc_html__('Actions', 'gj'),
                'date' => esc_html__('Register', 'gj'),
            );
        }

        return $columns;
    }

    static function columns_content($column, $post_ID) {
        $screen = get_current_screen();
        if ($screen->post_type == 'gj_candidate') {
            if ($column == 'user_id') {
                $post = get_post($post_ID);
                $user = get_userdata($post->post_author);
                if ($user) {
                    echo '<a href="' . esc_url(get_edit_user_link($user->ID)) . '">#' . $user->ID . '</a>';
                }
            }
            if ($column == 'email') {
                $email = get_post_meta($post_ID, 'email', true);
                if(!$email){
                    $post = get_post($post_ID);
                    $user = get_userdata($post->post_author);
                    if ($user) {
                        $email = $user->user_email;
                    }
                }

                echo esc_html($email);
            }
            if ($column == 'avatar') {
                echo get_the_post_thumbnail($post_ID, 'thubnail');
            }
            if ($column == 'status') {
                $status = get_post_status($post_ID);
                echo '<span class="job-status ' . esc_attr($status) . '">' . GJ_Candidate::get_status_title($status) . '</span>';
            }
            if ($column == 'featured') {
                $candidate = GJ_Candidate::get_candidate($post_ID);
                $featured = $candidate->is_featured();
                echo '<button class="gj-candidate-featured '.($featured ? 'featured' : '').'" data-id="'.$candidate->get_id().'">'.($featured ? '<i class="fa fa-star"></i>' : '<i class="fa fa-star-o"></i>').'</button>';
            }
            if ($column == 'actions') {
                $candidate = GJ_Candidate::get_candidate($post_ID);
                $status = $candidate->get_status();
                if(!$candidate->has_status('publish')){
                    echo '<button class="gj-candidate-change-status publish" '.($status == 'publish' ? 'disabled' : '').' data-status="publish" data-id="'.$post_ID.'"><i class="fa fa-check-circle"></i>'.esc_html__(' Publish', 'gj').'</button>';
                }
                if(!$candidate->has_status('draft')){
                    echo '<button class="gj-candidate-change-status draft" data-status="draft" data-id="'.esc_attr($post_ID).'"><i class="fa fa-times"></i>'.esc_html__(' Draft', 'gj').'</button>';
                }
                if(!$candidate->has_status('pending')){
                    echo '<button class="gj-candidate-change-status pending" '.($status == 'pending' ? 'disabled' : '').' data-status="pending" data-id="'.$post_ID.'"><i class="fa fa-clock-o"></i>'.esc_html__(' Pending', 'gj').'</button>';
                }
                if(!$candidate->has_status('gj-rejected')){
                    echo '<button class="gj-candidate-change-status gj-rejected" '.($status == 'gj-rejected' ? 'disabled' : '').' 
                        data-status="gj-rejected" 
                        data-id="'.esc_attr($post_ID).'"
                        ><i class="fa fa-exclamation-triangle"></i>'.esc_html__(' Reject', 'gj').'</button>';
                }
            }
        }
    }

    static function pre_get_posts($query) {
		global $current_screen;
		
		if ($current_screen && ($current_screen->post_type != 'gj_employer'))
            return $query;
		
        if (is_blog_admin() && $query->get('post_type') == 'gj_candidate') {
            if (!isset($_GET['post_status'])) {
                $query->set('post_status', array_keys(GJ_Employer::get_status_array()));
            }
        }
    }

}

add_action('init', array('GJ_Admin_Candidate', 'init'));
