<?php

class GJ_Admin_City {
    static public function init(){
        add_action( 'gj_city_add_form_fields', array(__CLASS__, 'add_form_fields'), 10, 1 );
        add_action( 'gj_city_edit_form_fields', array(__CLASS__, 'edit_form_fields'), 10, 2 );
        add_action( 'edited_gj_city', array(__CLASS__, 'save_custom_meta'), 99, 2 );
        add_action( 'create_gj_city', array(__CLASS__, 'save_custom_meta'), 10, 2 );
        add_action('admin_print_footer_scripts', array(__CLASS__, 'admin_print_footer_scripts'), 99);
	}

    static function add_form_fields($taxonomy){
        ?>
        <div class="container" id="term-app">
            <div class="form-field form-required state-field-wrap">
                <label for="country"><?php echo esc_html__('State', 'gj'); ?></label>
                <input type="hidden" :value="country ? country.code : ''" name="country">
                <input type="hidden" :value="state ? state.term_id : ''" name="state">
                <multiselect :placeholder="placeholderCountry" :options="counties" v-model="country" :multiple="false" :label="'name'" :track-by="'code'" @input="changeCountry"
                :select-label="''"
                :selected-label="''"
                :deselect-label="''"
				:deselect-group-label="''"
                ></multiselect>
                <multiselect :loading="stateLoading" :placeholder="placeholderState" :options="states" v-model="state" :multiple="false" :label="'name'" :track-by="'term_id'"
                :select-label="''"
                :selected-label="''"
                :deselect-label="''"
				:deselect-group-label="''"
                ></multiselect>
            </div>
        </div>
        <?php
    }

    static function edit_form_fields($term, $taxonomy){
        ?>
        <tr class="form-field" id="term-app">
            <th><label for="country"><?php echo esc_html__('State', 'gj'); ?></label></th>
            <td class="state-field-wrap">
                <input type="hidden" :value="country ? country.code : ''" name="country">
                <input type="hidden" :value="state ? state.term_id : ''" name="state">
                <multiselect :placeholder="placeholderCountry"  :options="counties" v-model="country" :multiple="false" :label="'name'" :track-by="'code'" @input="changeCountry"
                :select-label="''"
                :selected-label="''"
                :deselect-label="''"
				:deselect-group-label="''"
                ></multiselect>
                <multiselect :loading="stateLoading"  :placeholder="placeholderState" :options="states" v-model="state" :multiple="false" :label="'name'" :track-by="'term_id'"
                :select-label="''"
                :selected-label="''"
                :deselect-label="''"
				:deselect-group-label="''"
                ></multiselect>
            </td>
        </tr>
        <?php
    }

    static function save_custom_meta($term_id, $taxonomy){
        if(isset($_POST['state'])){
            $state = gj_clean($_POST['state']);
            update_term_meta($term_id, 'state', $state);
        }
    }

    static function admin_print_footer_scripts(){
        global $current_screen;
        if(isset($current_screen) && $current_screen->id === 'edit-gj_city'){
            $stateID = isset($_GET['tag_ID']) ? get_term_meta(intval($_GET['tag_ID']), 'state', true) : false;
            $states = array();
            if($stateID){
                $country = isset($_GET['tag_ID']) ? get_term_meta($stateID, 'country', true) : false;
                $state = get_term($stateID, 'gj_state');
                $args = array(
                    'hide_empty' => false, // also retrieve terms which are not used yet
                    'meta_query' => array(
                        array(
                            'key'       => 'country',
                            'value'     => $country,
                            'compare'   => '='
                        )
                    ),
                    'taxonomy'  => 'gj_state',
                );
                $states = get_terms( $args );
            }else{
                $country = $state = null;
            }
        ?>
        <script type="text/javascript">
            var vm = new Vue({
                el: "#term-app",
                data: {
                    placeholderCountry : 'Select country',
                    placeholderState : 'Select state',
                    country : <?php echo ($country && $country !== null) ? "{code : '{$country}', name : '".gj_get_country_titles($country)."'}" : 'null'; ?>,
                    state : <?php echo !empty($state) ? json_encode($state) : 'null'; ?>,
                    counties : <?php echo json_encode(gj_countries_options());?>,
                    states: <?php echo json_encode($states); ?>,
                    stateLoading : false
                },
                methods: {
                    changeCountry(value){
                        this.stateLoading = true;
                        jQuery.ajax({
                            url: '<?php echo rest_url('gj/v1/states'); ?>',
                            type: 'GET',
                            data : {country : value.code},
                            dataType: 'json',
                            success: (result) => {
                                this.stateLoading = false;
                                this.states = result;
                            }
                        });
                    }
                }
            });

            jQuery('#addtag input[type="submit"], #edittag input[type="submit"]').click(function(e){
                jQuery('#term-app .state-field-wrap').removeClass('invalid');
                var form =jQuery(this).closest('form');
                var state = form.find('input[name="state"]').val();
                if(!state){
                    e.preventDefault();
                    jQuery('#term-app .state-field-wrap').addClass('invalid');
                }
            })
        </script>
        <?php
        }
    }
}

GJ_Admin_City::init();
?>
