<?php

if ( ! class_exists( 'WP_List_Table' ) ) {
	require_once(ABSPATH . 'wp-admin/includes/class-wp-list-table.php');
}

class GJ_Email_Queue_Form_List_Table extends WP_List_Table {

	public static function define_columns() {
		$columns = array(
			'cb' => '<input type="checkbox" />',
			'from_name' => esc_html__( 'From Name', 'gj' ),
			'from_address' => esc_html__( 'From Address', 'gj' ),
			'recipients' => esc_html__( 'Recipients', 'gj' ),
			'subject' => esc_html__( 'Subject', 'gj' ),
			'attemp' => esc_html__( 'Attempt', 'gj' ),
		);

		return $columns;
	}

	function __construct() {
		parent::__construct( array(
			'singular' => 'email',
			'plural' => 'emails',
			'ajax' => false,
		) );
	}

	function prepare_items() {
		$current_screen = get_current_screen();
		$per_page = $this->get_items_per_page( 'gj_email_queue_forms_per_page' );

		$this->_column_headers = $this->get_column_info();

		global $wpdb;
		$sql = "SELECT * FROM {$wpdb->prefix}gj_email_queue LIMIT 0,$per_page";
        $this->items = $wpdb->get_results($sql);

        $sql = "SELECT COUNT(1) FROM {$wpdb->prefix}gj_email_queue";
        $total_items = $wpdb->get_var($sql);
        $total_pages = ceil( $total_items / $per_page );

		$this->set_pagination_args( array(
			'total_items' => $total_items,
			'total_pages' => $total_pages,
			'per_page' => $per_page,
		) );
	}

	function get_columns() {
		return get_column_headers( get_current_screen() );
	}

	function get_bulk_actions() {
		$actions = array(
			'delete' => esc_html__( 'Delete', 'gj' ),
			'send' => esc_html__( 'Send', 'gj' ),
		);

		return $actions;
	}

	function column_default( $item, $column_name ) {
		return '';
	}

	function column_cb( $item ) {
		return sprintf(
			'<input type="checkbox" name="%1$s[]" value="%2$s" />',
			$this->_args['singular'],
			$item->ID );
	}

	function column_from_name( $item ) {
		return $item->from_name;
	}

	function column_from_address( $item ) {
		return $item->from_address;
	}

	function column_recipients( $item ) {
		return $item->recipients;
	}

	function column_subject( $item ) {
		return $item->subject;
	}

	function column_attemp( $item ) {
		return $item->attemp;
	}

}
