<?php

class GJ_Admin_Job {

    static $fields = array();

    static function init() {

        add_action('pre_get_posts', array(__CLASS__, 'pre_get_posts'));
        add_action('admin_menu', array(__CLASS__, 'register_metabox'), 99 );
        add_action('save_post', array(__CLASS__, 'save_post'));
        add_filter('manage_gj_job_posts_columns', array(__CLASS__, 'columns_head'));
        add_filter('manage_gj_job_posts_custom_column', array(__CLASS__, 'columns_content'), 10, 2);

        add_filter('post_row_actions', array(__CLASS__, 'remove_quick_edit'), 10, 2);
        add_filter('page_row_actions', array(__CLASS__, 'remove_quick_edit'), 10, 2);

        add_action('admin_footer-post.php', array(__CLASS__, 'append_post_status_list'));

        add_action('gj_before_schema', function($postType){
            global $current_screen;
            if($postType === 'gj_job'){
                $fields = array(
                        array(
                            'type' => 'switch',
                            'label' => esc_html__('Featured','gj'),
                            'model' => 'featured',
                            'default' => '',
                            'textOn' => esc_html__('Yes','gj'),
                            'textOff' => esc_html__('No','gj'),
                            'valueOn' => '1',
                            'valueOff' => '',
                        ),
                        array(
                            'type' => 'post',
                            'label' => esc_html__('Employer','gj'),
                            'model' => 'employer',
                            'postType' => 'gj_employer',
                            'asynchronous' => 'once',
                            'values' => array(),
                            'selectOptions' => array(
                                  'multiple' => false,
                                  'noOptions' => esc_html__('No List Found','gj'),
                                  'fetchingOptions' => esc_html__('Fetching data...', 'gj'),
                            ),
                        ),
                        array(
                            'type' => 'switch',
                            'label' => esc_html__('Never Expiry','gj'),
                            'model' => 'neverExpiry',
                            'default' => '',
                            'textOn' => esc_html__('Yes','gj'),
                            'textOff' => esc_html__('No','gj'),
                            'valueOn' => '1',
                            'valueOff' => '',
                        ),
                        array(
                            'type' => 'dateTime',
                            'label' => esc_html__('Expiry Date','gj'),
                            'model' => 'expiry',
                            'dateOptions' => array(
                                    'format' => 'Y/m/d',
                                    'timepicker' => false
                            ),
                            'visible' => 'beginJSFunction(model){return !model.neverExpiry;}endJSFunction'
                        )
                );

                $fields = apply_filters('gj_general_fields_schema', $fields, $postType);

                $fieldString =  $tabJson = json_encode($fields);
                $fieldString = str_replace(array('"beginJSFunction', 'endJSFunction"'), array('function', ""), $fieldString);
                echo "{
                    legend : '".esc_html__('General','gj')."',
                    fields : ".$fieldString.",
                },";
            }
        });

        add_filter('gj_models', function($models, $postType){
            if($postType === 'gj_job') {
                $post = get_post();

                $employerModel = '';
                $employer = get_post_meta($post->ID, GJ_PREFIX.'employer', true);
                $expiry = get_post_meta($post->ID, GJ_PREFIX.'expiry', true);
                $never_expiry = get_post_meta($post->ID, GJ_PREFIX.'never_expiry', true);
                $featured = get_post_meta($post->ID, GJ_PREFIX.'featured', true);
                if ($employer) {
                    $employer = get_post($employer, 'gj_employer');
                    if ($employer && !is_wp_error($employer)) {
                        $employerModel = new stdClass();
                        $employerModel->ID = $employer->ID;
                        $employerModel->post_title = $employer->post_title;
                    }
                }

                $models[] = 'employer : ' . ($employerModel ? json_encode($employerModel) : '""');
                $models[] = 'expiry : "' . ($expiry ? date('Y/m/d', $expiry) : '') . '"';
                $models[] = 'neverExpiry : "' . $never_expiry . '"';
                $models[] = 'featured : "' . ($featured) . '"';
            }
            return $models;
        }, 10, 2);

        add_action('gj_before_save_post', function($postID){
           if($postID && get_post_type($postID) == 'gj_job'){
               $model = gj_clean($_POST);
               $postID = intval($_POST['postID']);
               $employer = isset($model['employer']) ? $model['employer']['ID'] : '';
               $featured = isset($model['featured']) ? $model['featured'] : '';
               $never_expiry = isset($model['neverExpiry']) ? $model['neverExpiry'] : '';
               $expiry = isset($model['expiry']) ? strtotime(str_replace('/', '-', $model['expiry'])) : '';
               update_post_meta($postID, GJ_PREFIX.'employer', $employer);
               update_post_meta($postID, GJ_PREFIX.'expiry', $expiry);
               update_post_meta($postID, GJ_PREFIX.'featured', $featured);
               update_post_meta($postID, GJ_PREFIX.'never_expiry', $never_expiry);
           }
        });
    }

    static function append_post_status_list(){
        global $post;
        $complete = '';
        $label = '';
        if($post->post_type == 'gj_job'){
            if($post->post_status == 'gj-rejected'){
                $complete = "selected='selected'";
                $label = esc_html__('Rejected', 'gj');
            }
            echo '
                <script>
                    jQuery(document).ready(function($){
                        $("select#post_status").append("<option value=\"gj-rejected\" '.$complete.'>'.esc_html__('Rejected', 'gj').'</option>");
                        $("#post-status-display").append("'.$label.'");
                        $("select#post_status").after("<input type=\"hidden\" name=\"original_post_status\" value=\"'.$post->post_status.'\" >");
                    });
                </script>
                ';
        }
    }

    static function remove_quick_edit($actions, $post) {
        if ($post->post_type != 'gj_job')
            return $actions;
        unset($actions['inline hide-if-no-js']);
        $job = GJ_Job::get_job($post);
        if ($job->has_status('publish')) {
            $title = esc_html__('View', 'gj');
        } else {
            $title = esc_html__('Preview', 'gj');
        }
        $permalink = $job->permalink();

        $actions['view'] = '<a href="' . esc_url($permalink) . '" title="' . esc_attr($title) . '" target="_blank">' . $title . '</a>';

        return $actions;
    }

    static function register_metabox() {
        global $submenu;
        unset($submenu['edit.php?post_type=gj_job'][10]);

        remove_meta_box('gj_sizediv', 'gj_job', 'core');
        remove_meta_box('gj_locationdiv', 'gj_job', 'core');
        remove_meta_box('gj_skilldiv', 'gj_job', 'core');
        remove_meta_box('gj_salarydiv', 'gj_job', 'core');
        remove_meta_box('gj_catdiv', 'gj_job', 'core');
        remove_meta_box('gj_typediv', 'gj_job', 'core');
        remove_meta_box('gj_leveldiv', 'gj_job', 'core');
        remove_meta_box('tagsdiv-gj_state', 'gj_job', 'core');
        remove_meta_box('tagsdiv-gj_city', 'gj_job', 'core');
    }

    static function save_post($post_id) {
        if (isset($_POST) && $_POST && !defined('DOING_AJAX')) {
            if (get_post_type($post_id) == 'gj_job'){

                if(isset($_POST['original_post_status'])) {
                    $old_post_status = $_POST['original_post_status'];
                    $new_post_status = $_POST['post_status'];
                    if($old_post_status != $new_post_status){
                        $job = GJ_Job::get_job($post_id);

                        if ($new_post_status == 'publish') {
                            GJ_Email::send_email('approved_job', $job);
                        } elseif ($new_post_status == 'pending') {
                            GJ_Email::send_email('review_job', $job);
                        } elseif ($new_post_status == 'gj-rejected') {
                            GJ_Email::send_email('rejected_job', $job);
                        }
                        elseif ($new_post_status == 'gj-expired') {
                            GJ_Email::send_email('expired_job', $job);
                        }
                    }
                }
            }
        }
    }

    static function columns_head($columns) {
        $columns = array(
            'cb' => '<input type="checkbox" />',
            'title' => esc_html__('Title', 'gj'),
            'status' => esc_html__('Status', 'gj'),
            'user_id' => esc_html__('Posted by', 'gj'),
            'taxonomy-gj_cat' => esc_html__('Category', 'gj'),
            'taxonomy-gj_salary' => esc_html__('Salary', 'gj'),
            'featured' => esc_html__('Featured', 'gj'),
            'actions' => esc_html__('Actions', 'gj'),
            'date' => esc_html__('Posted date', 'gj'),
        );

        return apply_filters('gj_manage_column_header', $columns);
    }

    static function columns_content($column, $post_ID) {
        do_action('gj_manage_column_content', $column, $post_ID);
        if ($column == 'user_id') {
            $job = GJ_Job::get_job($post_ID);
            $author_id = $job->get_author_id();
            $user = get_userdata($author_id);
            if ($user) {
                echo '<a href="' . esc_url(admin_url('edit.php?post_type=gj_job&author_id=' . $user->ID)) . '" >' . $user->display_name;
            }
        }
        if ($column == 'avatar') {
            $job = GJ_Job::get_job($post_ID);
            $employer = $job->get_employer();
            if($employer){
                echo $employer->get_thumbnail('gje-thumbnail');
            }else{
                $author_id = $job->get_author_id();
                if ($author_id) {
                    echo get_avatar($author_id);
                }
            }
        }
        if ($column == 'status') {
            $job = GJ_Job::get_job($post_ID);
            echo '<span class="job-status ' . esc_attr($job->get_status()) . '">' . $job->get_status_title($job->get_status()) . '</span>';
        }
        if ($column == 'featured') {
            $job = GJ_Job::get_job($post_ID, true);
            $featured = $job->is_featured();

            echo '<button class="gj-job-featured '.($featured ? 'featured' : '').'" data-id="'.$job->get_id().'">'.($featured ? '<i class="fa fa-star"></i>' : '<i class="fa fa-star-o"></i>').'</button>';
        }

        if ($column == 'actions') {
            $job = GJ_Job::get_job($post_ID);
            $status = $job->get_status();
            if(!$job->has_status('expired')){
                echo '<button class="gj-job-change-status gj-expired" data-status="gj-expired" data-id="'.esc_attr($post_ID).'"><i class="fa fa-times"></i>'.esc_html__(' Expiry', 'gj').'</button>';
            }
            if(!$job->has_status('publish')){
                echo '<button class="gj-job-change-status publish" data-status="publish" data-id="'.esc_attr($post_ID).'"><i class="fa fa-check-circle"></i>'.esc_html__(' Publish', 'gj').'</button>';
            }
            if(!$job->has_status('pending')){
                echo '<button class="gj-job-change-status pending" data-status="pending" data-id="'.esc_attr($post_ID).'"><i class="fa fa-clock-o"></i>'.esc_html__(' Pending', 'gj').'</button>';
            }
            if(!$job->has_status('rejected')){
                echo '<button class="gj-job-change-status gj-rejected" 
                data-status="gj-rejected" 
                data-id="'.esc_attr($post_ID).'"
                ><i class="fa fa-exclamation-triangle"></i>'.esc_html__(' Reject', 'gj').'</button>';
            }
        }
    }

    static function pre_get_posts($query) {
        global $current_screen;
        if ($current_screen && ($current_screen->post_type != 'gj_job' || $current_screen->base == 'gj_job_page_gj-alerts'))
            return $query;

        if (is_blog_admin() && $query->get('post_type') == 'gj_job') {
            if (!isset($_GET['post_status'])) {
                $query->set('post_status', array_keys(GJ_Job::get_status_array()));
            }

            if (isset($_GET['user_id']) && $_GET['user_id']) {
                $query->set('author', intval($_GET['user_id']));
            }

            if (isset($_GET['employer_id']) && $_GET['employer_id']) {
                $meta_query = $query->get('meta_query');
                if(!$meta_query) $meta_query = array();
                $meta_query[] = array(
                    'key' => GJ_PREFIX.'employer',
                    'value' => intval($_GET['employer_id']),
                    'compare' => '='
                ); 
                $query->set('meta_query', $meta_query);
            }

            if (!isset($_GET['orderby'])) {
                $query->set('orderby', 'date');
                $query->set('order', 'desc');
            }

            if (isset($_GET['author_id']) && $_GET['author_id']) {
                $query->set('author', intval($_GET['author_id']));
            }
        }
    }
}

add_action('init', array('GJ_Admin_Job', 'init'));
