<?php
/**
 * Order Notes
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
 * GJ_Meta_Box_Order_Notes Class.
 */
class GJ_Meta_Box_Order_Notes {

	/**
	 * Output the metabox.
	 *
	 * @param WP_Post $post
	 */
	public static function output( $post ) {
		global $post;

		$args = array(
			'post_id'   => $post->ID,
			'orderby'   => 'comment_ID',
			'order'     => 'DESC',
			'approve'   => 'approve',
			'type'      => 'order_note',
		);

		$notes = get_comments( $args );

		echo '<ul class="gj-order-notes">';

		if ( $notes ) {

			foreach ( $notes as $note ) {

				$note_classes   = array( 'gj-note' );
				$note_classes[] = get_comment_meta( $note->comment_ID, 'is_customer_note', true ) ? 'customer-note' : '';
				$note_classes[] = ( esc_html__( 'gj', 'gj' ) === $note->comment_author ) ? 'system-note' : '';
				$note_classes   = apply_filters( 'gj_order_note_class', array_filter( $note_classes ), $note );
				?>
				<li rel="<?php echo absint( $note->comment_ID ); ?>" class="<?php echo esc_attr( implode( ' ', $note_classes ) ); ?>">
					<div class="gj-note-content">
						<?php echo wpautop( wptexturize( wp_kses_post( $note->comment_content ) ) ); ?>
					</div>
					<p class="meta">
						<abbr class="exact-date" title="<?php echo esc_attr($note->comment_date); ?>"><?php printf( esc_html__( 'added on %1$s at %2$s', 'gj' ), date_i18n( get_option('date_format'), strtotime( $note->comment_date ) ), date_i18n( get_option('time_format'), strtotime( $note->comment_date ) ) ); ?></abbr>
						<?php
						if ( esc_html__( 'gj', 'gj' ) !== $note->comment_author ) :
							/* translators: %s: note author */
							printf( ' ' . esc_html__( 'by %s', 'gj' ), $note->comment_author );
						endif;
						?>
						<a href="#" class="gj-delete-note" role="button"><?php esc_html_e( 'Delete note', 'gj' ); ?></a>
					</p>
				</li>
				<?php
			}
		} else {
			echo '<li>' . esc_html__( 'There are no notes yet.', 'gj' ) . '</li>';
		}

		echo '</ul>';
		?>
		<div class="gj-add-note">
			<p>
				<label for="gj-add-order-note"><?php esc_html_e( 'Add note', 'gj' ); ?> <?php //echo _help_tip( esc_html__( 'Add a note for your reference, or add a customer note (the user will be notified).', 'gj' ) ); ?></label>
				<textarea type="text" name="order_note" id="gj-add-order-note" class="input-text" cols="20" rows="5"></textarea>
			</p>
			<p>
                <input type="hidden" id="gj-order-note-id" value="<?php echo esc_attr($post->ID); ?>">
				<button type="button" class="gj-add-note button button-primary"><?php esc_html_e( 'Add', 'gj' ); ?></button>
			</p>
		</div>
		<?php
	}
}
