<?php

class GJ_Admin_Order{
    static $fields = array();

    static function init(){
        add_action('admin_menu', array( __CLASS__ , 'register_metabox'));

        add_action('save_post', array( __CLASS__ , 'save_post'));
        add_action('pre_get_posts',array( __CLASS__, 'pre_get_posts' ) );
        add_filter('manage_posts_columns' , array(__CLASS__, 'columns_head' ));
        add_filter('manage_posts_custom_column' , array(__CLASS__, 'columns_content' ), 10, 2);
        add_action('restrict_manage_posts', array(__CLASS__, 'restrict_manage_posts' ));

        add_filter('post_row_actions', array(__CLASS__, 'remove_quick_edit'),10,1);
        add_filter('page_row_actions', array(__CLASS__, 'remove_quick_edit'),10,1);
    }

    static function remove_quick_edit( $actions){
        global $current_screen;
        if( $current_screen->post_type != 'gj_order' ) return $actions;
        unset($actions['inline hide-if-no-js']);
        return $actions;
    }

    static function register_metabox(){
        remove_meta_box('submitdiv', 'gj_order', 'core');
        add_meta_box('gj-order-box', esc_html__('Order Metabox Info', 'gj'), array( __CLASS__, 'metabox_html'), 'gj_order', 'normal', 'high');
        add_meta_box( 'gj-order-notes', esc_html__('Order Note', 'gj'), 'GJ_Meta_Box_Order_Notes::output', 'gj_order', 'side', 'default' );
    }

    static function metabox_html(){
        global $post;
        $post_id = $post->ID;

        if($post_id) {
            $order = GJ_Order::get_order($post_id);
            $author = $order->get_author();
            $products = $order->get_products();
            ?>
            <div class="gj-metabox wp-clearfix">
                <table class="form-table">
                    <?php if($author){ ?>
                    <tr>
                        <th><label><?php echo esc_html__('User', 'gj'); ?></label></th>
                        <td><?php echo esc_html($author->get_display_name()); ?></td>
                    </tr>
                    <tr>
                        <th><label><?php echo esc_html__('Email', 'gj'); ?></label></th>
                        <td><?php echo esc_attr($author->get_email()); ?></td>
                    </tr>
                    <tr>
                        <th><label><?php echo esc_html__('Created', 'gj'); ?></label></th>
                        <td><?php echo esc_html($order->get_created(get_option('date_format'))); ?></td>
                    </tr>
                    <?php } ?>

                    <tr>
                        <th><label><?php echo esc_html__('Description', 'gj'); ?></label></th>
                        <td>
                           <?php echo $products[0]->get_title_for_order(); ?>
                        </td>
                    </tr>
                    <?php if($order->has_tax()){?>
                        <tr>
                            <th><label><?php echo sprintf(esc_html__('Tax Price - %s%%', 'gj'), $order->get_tax_value()); ?></label></th>
                            <td><?php echo gj_system_price($order->get_tax_price(), $order->get_currency()); ?></td>
                        </tr>
                    <?php } ?>
                    <tr>
                        <th><label><?php echo esc_html__('Total price', 'gj'); ?></label></th>
                        <td><?php echo gj_system_price($order->get_total_price(), $order->get_currency()); ?></td>
                    </tr>
                    <tr>
                        <th><label><?php echo esc_html__('Payment Method', 'gj'); ?></label></th>
                        <td><?php echo esc_html($order->get_payment_method_title()); ?></td>
                    </tr>
                    <?php do_action('gj_admin_order_after_payment_method', $order)?>
                    <tr>
                        <th><label><?php echo esc_html__('Status', 'gj'); ?></label></th>
                        <td>
                            <select name="status" <?php echo ($post->post_status == 'gj-completed' || $post->post_status == 'gj-cancelled') ? 'disabled' : ''?>>
                                <?php
                                $options = GJ_Order::get_status_array();
                                foreach ($options as $key=>$option){
                                    echo '<option value="'.$key.'" '.($post->post_status == $key ? 'selected' : '').'>'.$option.'</option>';
                                }
                                ?>
                            </select>
                        </td>
                    </tr>
                    <tr>
                        <th><label></label></th>
                        <td>
                            <button type="submit" class="button button-primary"><?php echo esc_html__('Update', 'gj'); ?></button>
                        </td>
                    </tr>
                </table>
            </div>
            <?php
        }
    }

    static function save_post($post_id){
        if(get_post_type($post_id) == 'gj_order'){
            if(isset($_POST['status'])){
                $new_status = sanitize_text_field($_POST['status']);
                $old_status = get_post_status($post_id);
                $order = GJ_Order::get_order($post_id);
                if($old_status != $new_status){
                    if($new_status == 'gj-completed'){
                        $order->completed_order();
                    }else{
                        $order->change_status($new_status, '', true, false);
                    }
                }
            }
        }
    }

    static function columns_head( $columns )
    {
        $screen = get_current_screen();
        if ($screen->post_type == 'gj_order') {
            $columns = array(
                'cb' => '<input type="checkbox" />',
                'title' => esc_html__('Title', 'gj'),
                'status' => esc_html__('Status', 'gj'),
                'user_id' => esc_html__('User ', 'gj'),
                'price' => esc_html__('Price ', 'gj'),
                'payment_method' => esc_html__('Payment Method ', 'gj'),
                'order_date' => esc_html__('Date (purchased/created) ', 'gj'),
            );
        }

        return $columns;
    }

    static function columns_content( $column, $post_ID ) {
        $screen = get_current_screen();
        if($screen->post_type == 'gj_order'){
            if ($column == 'user_id') {
                $post = get_post($post_ID);
                $user = get_userdata($post->post_author);
                if($user){
                    echo esc_html($user->display_name .' '.$user->user_email);
                }
            }
            if ($column == 'status') {
                $status = get_post_status($post_ID);
                echo '<span class="job-status '.esc_attr($status).'">'.GJ_Order::get_status_title($status).'</span>';
            }
            if ($column == 'price') {
                $order = GJ_Order::get_order($post_ID);
                echo gj_system_price($order->get_total_price(), $order->get_currency());
            }
            if ($column == 'payment_method') {
                $order = GJ_Order::get_order($post_ID);
                echo esc_html($order->get_payment_method_title());
            }
            if ($column == 'order_date') {
                $order = GJ_Order::get_order($post_ID);
                if($order->get_status() == 'gj-completed'){
                    $purchased_date = $order->get_purchased_date();
                    if($purchased_date){
                        echo date_i18n(get_option('date_format'), $purchased_date);
                    }
                }else{
                    echo esc_html($order->get_created());
                }
            }
        }
    }

    static function pre_get_posts($query){
        if(is_blog_admin() && $query->get('post_type') == 'gj_order'){
            if(!isset($_GET['post_status']) || $_GET['post_status'] == 'all'){
                $query->set('post_status', array_keys(GJ_Order::get_status_array()));
            }

            $email = isset($_GET['s']) ? sanitize_email($_GET['s']) : '';
            if($email && is_email($email)){
                $user = get_user_by('email', $email);
                if($user && !is_wp_error($user)){
                    $query->set('author', $user->ID);
                }else{
                    $query->set('author', -1);
                }

                $query->set('s', '');
            }

            $form_date = isset($_GET['from_date']) ? sanitize_text_field($_GET['from_date']) : '';
            $to_date = isset($_GET['to_date']) ? sanitize_text_field($_GET['to_date']) : '';
            if($form_date && $to_date){
                $query->set('date_query', array(
                        'after' => $form_date,
                        'before' => $to_date,
                ));
            }elseif($form_date){
                $query->set('date_query', array(
                    'after' => $form_date,
                ));
            }elseif($to_date){
                $query->set('date_query', array(
                    'before' => $to_date,
                ));
            }
        }
    }

    static function restrict_manage_posts($post_type) {
        if ($post_type == 'gj_order') {
            wp_enqueue_script('datetimepicker');
            wp_enqueue_style('datetimepicker');

            ?>
            <input type="text" class="gj-order-from-date" name="from_date" id="gj-order-from-date"
                   placeholder="<?php esc_html_e('From Date', 'gj'); ?>"
                   value="<?php echo isset($_REQUEST['from_date']) ? esc_attr($_REQUEST['from_date']) : ''; ?>"/>
            <input type="text" class="gj-order-to-date" name="to_date" placeholder="<?php esc_html__('To Date', 'gj'); ?>" id="gj-order-to-date"
                   value="<?php echo isset($_REQUEST['to_date']) ? esc_attr($_REQUEST['to_date']) : ''; ?>"/>
            <?php
        }
    }
}

GJ_Admin_Order::init();