<?php

class GJ_Admin_Setting {

    static function setting_page() {

        $fields = GJ_Fields::instance();
        $fields->registerScripts();
        $fields->enqueueTypeScripts(array('post'));
        $fields->enqueueScripts(true);

        wp_enqueue_script('growl');
        wp_enqueue_style('growl');
        wp_localize_script('gj-admin', 'gji18n', array(
            'saved_success' => esc_html__('Saved successfully!', 'gj'),
            'saved_error' => esc_html__('Saved error, please try refresh the page and try agian!', 'gj'),
            'reseted_success' => esc_html__('Reseted successfully!', 'gj'),
            'reseted_error' => esc_html__('Reseted error, please try refresh the page and try agian!', 'gj'),
        ));

        ?>
        <div class="wrap">
            <div class="container" id="gj-setting-page">
                <vue-form-generator :schema="schema" :model="model" :options="formOptions" @validate="validate"></vue-form-generator>
            </div>

            <p id="gj-setting-page-btn">
                <button type="button" class="button gj-save-settings button-primary"><?php echo esc_html__('Save Changes', 'gj'); ?></button>
                <button type="button" class="button gj-reset-settings"><?php echo esc_html__('Reset Default', 'gj'); ?></button>
            </p>
        </div>
        <?php
    }

    static function settings_print_footer_scripts(){
        if(!isset($_GET['page']) || $_GET['page'] != 'gj-setting-page'){
            return false;
        }

        $schema = array(
             "tabs" => array(
                 array(
                     "title" => esc_html__("Settings", 'gj'),
                     "id" => "settings",
                     "groups" => array(
                         array(
                             'legend' => esc_html__('General', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Submit job mode', 'gj' ),
                                     'model'   => 'submit_job_mode',
                                     'type' => 'select',
                                     'values' => gj_submit_job_modes(),
                                 ),
                                 array(
                                     'label' => esc_html__( 'Disable employer registration', 'gj' ),
                                     'model'   => 'disable_employer_register',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Disable candidate registration', 'gj' ),
                                     'model'   => 'disable_candidate_register',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Auto generate password', 'gj' ),
                                     'help' => esc_html__( 'Auto generate password when registration', 'gj' ),
                                     'model'   => 'registration_generate_password',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Verify Account', 'gj' ),
                                     'model'   => 'verify_account',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 /*array(
                                     'label' => esc_html__( 'Input Date Format', 'gj' ),
                                     'model'   => 'input_date_format',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'hint' => wp_kses_post(__('Click <a href="http://php.net/manual/en/function.date.php" target="_blank">here</a> to see all format', 'gj')),
                                 ),*/
                                 array(
                                     'label' => esc_html__('Dashboard items per page', 'gj'),
                                     'model' => 'dashboard_items_per_page',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'std' => '20',
                                 ),
                                 array(
                                     'label' => esc_html__('Using ReCaptcha', 'gj'),
                                     'model' => 'use_recaptcha',
                                     'type' => 'checklist',
                                     'values' => gj_recaptcha_options(),
                                     'checklistOptions' => array(
                                             'value' => 'id',
                                             'name' => 'name',
                                     )
                                 ),
                                 array(
                                     'label' => esc_html__('Captcha Secret Key', 'gj'),
                                     'model' => 'google_recaptcha_secret_key',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__('Captcha Site Key', 'gj'),
                                     'model' => 'google_recaptcha_site_key',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__('Restrict bad terms', 'gj'),
                                     'help' => esc_html__( 'Prevent user from entering bad term name when submitting job in addition to fontend, separated by commas', 'gj' ),
                                     'model' => 'restrict_bad_terms',
                                     'type' => 'textArea',
                                     ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Job Settings', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Jobs Sidebar', 'gj' ),
                                     'model'   => 'jobs_sidebar',
                                     'type' => 'select',
                                     'values' => array(
                                         array('id' => 'withoutSidebar', 'name' => esc_html__('Without Sidebar', 'gj')),
                                         array('id' => 'left', 'name' => esc_html__('Left Sidebar', 'gj')),
                                         array('id' => 'right', 'name' => esc_html__('Right Sidebar', 'gj')),
                                     ),
                                     'std' => 'left',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Job Sidebar', 'gj' ),
                                     'model'   => 'job_sidebar',
                                     'type' => 'select',
                                     'values' => array(
                                         array('id' => 'withoutSidebar', 'name' => esc_html__('Without Sidebar', 'gj')),
                                         array('id' => 'left', 'name' => esc_html__('Left Sidebar', 'gj')),
                                         array('id' => 'right', 'name' => esc_html__('Right Sidebar', 'gj')),
                                     ),
                                     'std' => 'left',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Sticky Sidebar', 'gj' ),
                                     'model'   => 'job_sidebar_sticky',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                     'std' => '1',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Sorting Jobs Default', 'gj' ),
                                     'model'   => 'sorting_jobs_default',
                                     'type' => 'select',
                                     'values' => array(
                                            array('id' => 'date', 'name' => esc_html__('Newest', 'gj')),
                                            array('id' => 'salary', 'name' => esc_html__('Salary', 'gj')),
                                            array('id' => 'name', 'name' => esc_html__('Title', 'gj')),
                                     )
                                 ),
                                 array(
                                     'label' => esc_html__( 'Show expired job', 'gj' ),
                                     'model'   => 'show_expired_job',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Jobs Per Page', 'gj' ),
                                     'model'   => 'jobs_per_page',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Limit related jobs', 'gj' ),
                                     'model'   => 'limit_item_related',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Edit Job Auto Aprroved', 'gj' ),
                                     'model'   => 'edit_job_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Edit Free Job Auto Aprroved', 'gj' ),
                                     'model'   => 'edit_free_job_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'New Job Auto Aprroved', 'gj' ),
                                     'model'   => 'new_job_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'New Free Job Auto Aprroved', 'gj' ),
                                     'model'   => 'new_free_job_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Keep Posts When Delete User', 'gj' ),
                                     'model'   => 'keep_posts_delete_user',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Move Posts from Deleting User To User ID', 'gj' ),
                                     'model'   => 'keep_posts_user_id',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Employer Settings', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Employers Per Page', 'gj' ),
                                     'model'   => 'employers_per_page',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Employers Sidebar', 'gj' ),
                                     'model'   => 'employers_sidebar',
                                     'type' => 'select',
                                     'values' => array(
                                         array('id' => 'withoutSidebar', 'name' => esc_html__('Without Sidebar', 'gj')),
                                         array('id' => 'left', 'name' => esc_html__('Left Sidebar', 'gj')),
                                         array('id' => 'right', 'name' => esc_html__('Right Sidebar', 'gj')),
                                     ),
                                     'std' => 'left',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Employer Sidebar', 'gj' ),
                                     'model'   => 'employer_sidebar',
                                     'type' => 'select',
                                     'values' => array(
                                         array('id' => 'withoutSidebar', 'name' => esc_html__('Without Sidebar', 'gj')),
                                         array('id' => 'left', 'name' => esc_html__('Left Sidebar', 'gj')),
                                         array('id' => 'right', 'name' => esc_html__('Right Sidebar', 'gj')),
                                     ),
                                     'std' => 'left',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Sticky Sidebar', 'gj' ),
                                     'model'   => 'employer_sidebar_sticky',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                     'std' => '1',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Login Redirect', 'gj' ),
                                     'model'   => 'employer_login_redirect',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []                     
                                 ),
                                 array(
                                     'label' => esc_html__( 'Auto approved', 'gj' ),
                                     'model'   => 'employer_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Edit auto approved', 'gj' ),
                                     'model'   => 'edit_employer_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                    'label' => esc_html__( 'Sorting Default', 'gj' ),
                                    'model'   => 'sorting_employers_default',
                                    'type' => 'select',
                                    'values' => array(
                                           array('id' => 'date', 'name' => esc_html__('Newest', 'gj')),
                                           array('id' => 'name', 'name' => esc_html__('Title', 'gj')),
                                    )
                                ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Candidate Settings', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Candidates Per Page', 'gj' ),
                                     'model'   => 'candidates_per_page',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Candidates Sidebar', 'gj' ),
                                     'model'   => 'candidates_sidebar',
                                     'type' => 'select',
                                     'values' => array(
                                         array('id' => 'withoutSidebar', 'name' => esc_html__('Without Sidebar', 'gj')),
                                         array('id' => 'left', 'name' => esc_html__('Left Sidebar', 'gj')),
                                         array('id' => 'right', 'name' => esc_html__('Right Sidebar', 'gj')),
                                     ),
                                     'std' => 'left',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Candidate Sidebar', 'gj' ),
                                     'model'   => 'candidate_sidebar',
                                     'type' => 'select',
                                     'values' => array(
                                         array('id' => 'withoutSidebar', 'name' => esc_html__('Without Sidebar', 'gj')),
                                         array('id' => 'left', 'name' => esc_html__('Left Sidebar', 'gj')),
                                         array('id' => 'right', 'name' => esc_html__('Right Sidebar', 'gj')),
                                     ),
                                     'std' => 'left',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Sticky Sidebar', 'gj' ),
                                     'model'   => 'candidate_sidebar_sticky',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                     'std' => '1',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Login Redirect', 'gj' ),
                                     'model'   => 'candidate_login_redirect',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => [] 
                                 ),
                                 array(
                                     'label' => esc_html__( 'Auto approved', 'gj' ),
                                     'model'   => 'candidate_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Edit auto approved', 'gj' ),
                                     'model'   => 'edit_candidate_auto_approved',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Yes", 'gj'),
                                     'textOff' => esc_html__("No", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                    'label' => esc_html__( 'Sorting Default', 'gj' ),
                                    'model'   => 'sorting_candidates_default',
                                    'type' => 'select',
                                    'values' => array(
                                           array('id' => 'date', 'name' => esc_html__('Newest', 'gj')),
                                           array('id' => 'name', 'name' => esc_html__('Title', 'gj')),
                                    )
                                ),
								array(
									'label' => esc_html__('Who can see candidates', 'iwjob'),
									'model' => 'show_candidate_public_profile',
									'type' => 'select',
									'std' => '',
									'values' => array(
										array('id' => '', 'name' => esc_html__('Anyone', 'gj')),
										array('id' => '1', 'name' => esc_html__('Only Users Registered', 'gj')),
										array('id' => '2', 'name' => esc_html__('Only Employers', 'gj')),
						
									)
								),
                             )
                         ), 
                         array(
                             'legend' => esc_html__('Map Settings', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Google API Key', 'gj' ),
                                     'model'   => 'google_api_key',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Default Latitude', 'gj' ),
                                     'model'   => 'map_latitude',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Default longitude', 'gj' ),
                                     'model'   => 'map_logtitude',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Default zoom', 'gj' ),
                                     'model'   => 'map_zoom',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                    'label' => esc_html__( 'Auto detect Country/State/City', 'gj' ),
                                    'model'   => 'auto_detect_locations',
                                    'type' => 'switch',
                                    'textOn' => esc_html__("Yes", 'gj'),
                                    'textOff' => esc_html__("No", 'gj'),
                                    'valueOn' => '1',
                                    'valueOff' => '',
                                ),
                                 array(
                                     'label' => esc_html__( 'Search unit', 'gj' ),
                                     'model'   => 'search_unit',
                                     'type' => 'select',
                                     'values' => array(
                                         array('id' => 'Km', 'name' => esc_html__('KM', 'gj')),
                                         array('id' => 'Miles', 'name' => esc_html__('MILES', 'gj')),
                                     )
                                 ),
                                 array(
                                     'label' => esc_html__( 'Default search radius', 'gj' ),
                                     'model'   => 'default_search_radius',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 /*
                                 array(
                                     'label' => esc_html__( 'Style', 'gj' ),
                                     'model'   => 'map_styles',
                                     'type' => 'textArea',
                                     'inputType' => 'text',
                                 ),*/
                             )
                         ),
                         array(
                             'legend' => esc_html__('Term and Services', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Register Terms and Services', 'gj' ),
                                     'model'   => 'terms_and_conditions',
                                     'type' => 'textArea',
                                     'hint' => esc_html__("{link_terms_and_conditions_page} Link to Terms and conditions Page, {link_privacy_policy_page} Link to Privacy Policy Page", 'gj'),
                                 ),
                                 array(
                                     'label' => esc_html__( 'Apply Job Terms and services', 'gj' ),
                                     'model'   => 'apply_terms_and_conditions',
                                     'type' => 'textArea',
                                 ),
                             )
                         ),
                     )
                 ),
                 array(
                     "title" => esc_html__("Pages + Slugs", 'gj'),
                     "id" => "pages-slugs",
                     "groups" => array(
                         array(
                             'legend' => esc_html__('Pages', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Login', 'gj' ),
                                     'model'   => 'login_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Register', 'gj' ),
                                     'model'   => 'register_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Verify account', 'gj' ),
                                     'model'   => 'verify_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Lost password', 'gj' ),
                                     'model'   => 'lostpass_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Dashboard', 'gj' ),
                                     'model'   => 'dashboard_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Jobs', 'gj' ),
                                     'model'   => 'jobs_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Employers', 'gj' ),
                                     'model'   => 'employers_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Candidates', 'gj' ),
                                     'model'   => 'candidates_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Terms & Conditions', 'gj' ),
                                     'model'   => 'terms_and_conditions_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                                 array(
                                     'label' => esc_html__( 'Privacy Policy', 'gj' ),
                                     'model'   => 'privacy_policy_page_id',
                                     'type' => 'post',
                                     'postType' => 'page',
                                     'asynchronous' => 'once',
                                     'default' => '',
                                     'values' => []
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Slugs', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Job', 'gj' ),
                                     'model'   => 'job_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'job',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Employer', 'gj' ),
                                     'model'   => 'employer_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'employer',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Candidate', 'gj' ),
                                     'model'   => 'candidate_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'candidate',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Category', 'gj' ),
                                     'model'   => 'category_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'category',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Type', 'gj' ),
                                     'model'   => 'type_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'type',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Salary', 'gj' ),
                                     'model'   => 'salary_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'sallery',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Skill', 'gj' ),
                                     'model'   => 'skill_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'sallery',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Level', 'gj' ),
                                     'model'   => 'level_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'level',
                                 ),
                                 array(
                                     'label' => esc_html__( 'City', 'gj' ),
                                     'model'   => 'city_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'level',
                                 ),
                                 array(
                                     'label' => esc_html__( 'State', 'gj' ),
                                     'model'   => 'state_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'level',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Company Size', 'gj' ),
                                     'model'   => 'size_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'size',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Expericence', 'gj' ),
                                     'model'   => 'expericence_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'size',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Gender', 'gj' ),
                                     'model'   => 'gender_slug',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => 'size',
                                 ),
                             )
                         )
                     )
                 ),
                 array(
                     "title" => esc_html__("Price", 'gj'),
                     "id" => "price",
                     "groups" => array(
                         array(
                             'legend' => esc_html__('General', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Job Currency', 'gj' ),
                                     'model'   => 'currency',
                                     'type' => 'select',
                                     'values' => gj_currency_options()
                                 ),
                                 array(
                                     'label' => esc_html__( 'System Currency', 'gj' ),
                                     'model'   => 'system_currency',
                                     'type' => 'select',
                                     'values' => gj_currency_options()
                                 ),
                                 array(
                                     'label' => esc_html__( 'Trim Zeros', 'gj' ),
                                     'model'   => 'price_trim_zeros',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
									 'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Use Tax', 'gj' ),
                                     'model'   => 'tax_used',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
									 'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Tax Value', 'gj' ),
                                     'model'   => 'tax_value',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     "visible" => "beginJSFunction(model) { return model && model.tax_used;}endJSFunction",
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Job Price', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'Job Price', 'gj' ),
                                     'model'   => 'job_price',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '5',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Featured Job Price', 'gj' ),
                                     'model'   => 'featured_job_price',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '5',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Renew Job Price', 'gj' ),
                                     'model'   => 'renew_job_price',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '5',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Job Duration', 'gj' ),
                                     'model'   => 'job_expiry',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '1',
                                     'styleWidth' => 50
                                 ),
                                 array(
                                     'label' => '',
                                     'model'   => 'job_expiry_unit',
                                     'type' => 'select',
                                     'values' => array(
                                             array('id' => 'day', 'name' => esc_html__('Day', 'gj')),
                                             array('id' => 'month', 'name' => esc_html__('Month', 'gj')),
                                             array('id' => 'year', 'name' => esc_html__('Year', 'gj')),
                                     ),
                                     'styleWidth' => 50
                                 ),
                             )
                         )
                     )
                 ),
                 array(
                     "title" => esc_html__("Emails", 'gj'),
                     "id" => "emails",
                     "groups" => array(
                         array(
                             'legend' => esc_html__('New Register', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_register_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_register_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('New Register [Admin]', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_admin_register_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_admin_register_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Verify Account', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_verify_account_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_verify_account_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Reset Password', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_resetpass_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_resetpass_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Delete Account', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_delete_account_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_delete_account_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('New Job', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_new_job_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_new_job_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Review Job[Admin]', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_review_job_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_review_job_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Approved Job', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_approved_job_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_approved_job_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Rejected Job', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_rejected_job_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_rejected_job_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                            'legend' => esc_html__('Expired Job', 'gj'),
                            'fields' => array(
                                array(
                                    'label' => null,
                                    'model'   => 'email_expired_job_enable',
                                    'type' => 'switch',
                                    'textOn' => esc_html__("Enable", 'gj'),
                                    'textOff' => esc_html__("Disable", 'gj'),
                                    'valueOn' => '1',
                                    'valueOff' => '',
                                ),
                                array(
                                    'label' => esc_html__( 'Subject', 'gj' ),
                                    'model'   => 'email_expired_job_subject',
                                    'type' => 'input',
                                    'inputType' => 'text',
                                    'default' => '',
                                ),
                            )
                        ),
                         array(
                             'legend' => esc_html__('Review Resume [Admin]', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_review_resume_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_review_resume_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Approved Resume', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_approved_resume_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_approved_resume_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Rejected Resume', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_rejected_resume_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_rejected_resume_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Review Company [Admin]', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_review_company_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_review_company_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Approved Company', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_approved_company_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_approved_company_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Rejected Company', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_rejected_company_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_rejected_company_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('New Order', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_new_order_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_new_order_enable',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('New Order[Admin]', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_admin_new_order_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_admin_new_order_enable',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Hold Order', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_hold_order_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_hold_order_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Completed Order', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_completed_order_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_completed_order_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
						 array(
                             'legend' => esc_html__('Cancelled Order', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_cancelled_order_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_cancelled_order_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('New Application[Candidate]', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_new_application_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_new_application_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('New Application[Employer]', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_new_application_employer_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_new_application_employer_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Application Contact', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_application_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Interview Subject', 'gj' ),
                                     'model'   => 'email_application_interview_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                ),
                                 array(
                                     'label' => esc_html__( 'Interview Content', 'gj' ),
                                     'model'   => 'email_application_interview_content',
                                     'type' => 'textArea',
                                     'default' => '',
                                ),
                                 array(
                                     'label' => esc_html__( 'Accept Subject', 'gj' ),
                                     'model'   => 'email_application_accept_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                ),
                                 array(
                                     'label' => esc_html__( 'Accept Content', 'gj' ),
                                     'model'   => 'email_application_accept_content',
                                     'type' => 'textArea',
                                     'default' => '',
                                ),
                                 array(
                                     'label' => esc_html__( 'Reject Subject', 'gj' ),
                                     'model'   => 'email_application_reject_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                ),
                                 array(
                                     'label' => esc_html__( 'Reject Content', 'gj' ),
                                     'model'   => 'email_application_reject_content',
                                     'type' => 'textArea',
                                     'default' => '',
                                ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Contact Email', 'gj'),
                             'id' => 'contact_email',
                             'fields' => array(
                                 array(
                                     'label' => null,
                                     'model'   => 'email_contact_enable',
                                     'type' => 'switch',
                                     'textOn' => esc_html__("Enable", 'gj'),
                                     'textOff' => esc_html__("Disable", 'gj'),
                                     'valueOn' => '1',
                                     'valueOff' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Subject', 'gj' ),
                                     'model'   => 'email_contact_subject',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                             )
                         ),
                         array(
                             'legend' => esc_html__('Email settings', 'gj'),
                             'fields' => array(
                                 array(
                                     'label' => esc_html__( 'From Name', 'gj' ),
                                     'model'   => 'email_from_name',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                 ),
                                 array(
                                     'label' => esc_html__( 'From Email', 'gj' ),
                                     'model'   => 'email_from_address',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Admin Email', 'gj' ),
                                     'model'   => 'admin_email_receiver',
                                     'type' => 'input',
                                     'inputType' => 'text',
                                     'default' => '',
                                 ),
                                 array(
                                     'label' => esc_html__( 'Email Footer Text', 'gj' ),
                                     'model'   => 'email_footer_text',
                                     'type' => 'textArea',
                                     'default' => '',
                                 ),
                             )
                         ),
                     )
                 ),
             ),
             "tabActive" => "settings"
        );

        $applies = GJ()->applies->applies();
        if ($applies) {
            $apply_settings = array();
            foreach ($applies as $apply) {
                $option_fields = $apply->admin_option_fields();
                if($option_fields){
                     $apply_settings[] = $option_fields; 
                }                            
            }
            if($apply_settings){
                $schema['tabs'][] = array(
                         "title" => esc_html__("Apply methods", 'gj'),
                         "id" => "apply-methods",
                         "groups" => $apply_settings
                );
            }
        }
        
        $payment_gateways = GJ()->payment_gateways->payment_gateways();
        if ($payment_gateways) {
            $payment_settings = array();
            foreach ($payment_gateways as $payment_gateway) {
                $admin_option_fields = $payment_gateway->admin_option_fields();
                if ($admin_option_fields) {
                    $payment_settings[] = $admin_option_fields;
                }
            }

            if($payment_settings){
                $schema['tabs'][] = array(
                         "title" => esc_html__("Payment Gateways", 'gj'),
                         "id" => "payment-gateways",
                         "groups" =>$payment_settings
                );
            }
        }

        // save socials
        $socials = GJ()->social_logins->social_logins();
        if ($socials) {
            $social_settings = array();
            foreach ($socials as $social) {
                $admin_option_fields = $social->admin_option_fields();
                if ($admin_option_fields) {
                     $social_settings[] = $admin_option_fields;
                }
            }

            if($social_settings){
                $schema['tabs'][] = array(
                         "title" => esc_html__("Socials Login", 'gj'),
                         "id" => "socials-login",
                         "groups" =>$social_settings
                );
            }
        }

        $schema = apply_filters('gj_settings_schema', $schema);

        $model = gj_option();
        $model = apply_filters('gj_settings_model', $model);

        if($model){
            foreach ($model as $key => $setting){
                if(strpos($key, '_page_id') > -1){
                    if($setting > 0){
                        $model[$key] = array(
                            'ID' => $setting['ID'],
                            'post_title' => wp_specialchars_decode(get_the_title($setting['ID'])),
                        );
                    }
                }
            }
        }

        ?>
        <script type="text/javascript">
            var gjSettings = new Vue({
                el: "#gj-setting-page",
                components: {
                    "vue-form-generator": VueFormGenerator.component,
                },
                methods: {
                    validate(isValid, errors, self){
                    }
                },
                data: {
                    model: <?php echo $model ? json_encode($model) : '{}'; ?>,
                    schema: <?php $schemajs = json_encode($schema); $schemajs = str_replace(array('"beginJSFunction', 'endJSFunction"'), array('function', ""), $schemajs); echo (string)$schemajs; ?>,
                    formOptions: {
                        validateAfterLoad: false,
                        validateAfterChanged: true
                    }
                }
            });
        </script>
        <?php
    }

    static function fields_page() {
        wp_enqueue_script('vue');
        wp_enqueue_script('sortable');
        wp_enqueue_script('vuedraggable');
        wp_enqueue_script('vfg-field-array');
        wp_enqueue_script('vfg');
        wp_enqueue_style('vfg');
        wp_enqueue_script('custom-fields');
        wp_enqueue_script('fields-manager');
        wp_enqueue_style('fields-manager');

        $field_post_type = isset($_GET['field_post_type']) ? sanitize_text_field($_GET['field_post_type']) : 'gj_job';
        $baselink = admin_url().'edit.php?post_type=gj_job&page=gj-fields-page';

        ?>
        <div class="wrap">
			<div class="gj-post-type-tab">
            <?php
            $post_types = gj_field_manager_post_types();
            if($post_types){
                foreach ($post_types as $post_type){
					$class = ($field_post_type == $post_type['post_type'])? "class='active'" : "";
                    echo "<a href=".esc_url($baselink).'&field_post_type='.$post_type['post_type']." ".$class. ">".$post_type['name']."</a>";
                }
            }
			
            $post_type = isset($post_types[$field_post_type]) ? $post_types[$field_post_type] : false;
            ?>
			</div>
            <div class="gj-field-page">
                <?php if($post_type){
                    $fieldsArr = $groupsObj = [];
                    $fields = get_posts(array(
                        'post_type' => 'gj_fields',
                        'posts_per_page' => -1,
                        'post_status' => 'any',
                        'orderby' => 'menu_order',
                        'order' => 'ASC',
                        'meta_query' => array(
                            array(
                                'key' => 'post_type',
                                'value' => $field_post_type,
                                'compare' => '=',
                            )
                        )
                    ));

                    if($fields){
                        foreach ($fields as $field){
                            $fieldObj = new stdClass();
                            $fieldObj->active = $field->post_status == 'publish' ? 'true' : '';
                            $fieldObj->name = $field->post_title;
                            $fieldObj->id = $field->ID;
                            $fieldObj->group = $field->post_parent;
                            $fieldObj->type = $field->post_excerpt;
                            $fieldObj->metakey = get_post_meta($field->ID, 'metakey', true);
                            $fieldObj->order = $field->menu_order;
                            $fieldObj->settings = json_decode($field->post_content);

                            foreach ($fieldObj->settings as $key=>$value){
                                if($key === 'schema'){
                                    $fieldObj->settings->{$key} = str_replace( array( "\n", "\r" ), array( "\\n", "\\r" ), $value );
                                }
                            }
                            $overrideSettings = new stdClass();
                            $fieldObj->overrideSettings[] = $overrideSettings;
                            $fieldsArr[] = $fieldObj;
                        }
                    }

                    if($post_type['grouped']){
                        $groups = get_posts(array(
                            'post_type' => 'gj_field_groups',
                            'posts_per_page' => -1,
                            'post_status' => 'any',
                            'orderby' => 'menu_order',
                            'order' => 'ASC',
                            'meta_query' => array(
                                array(
                                    'key' => 'post_type',
                                    'value' => $field_post_type,
                                    'compare' => '=',
                                )
                            )
                        ));
                        if($groups){
                            foreach ($groups as $group){
                                $groupObj = new stdClass();
                                $groupObj->id = $group->ID;
                                $groupObj->active = $group->post_status == 'publish' ? 'true' : '';
                                $groupObj->name = $group->post_title;
                                $groupObj->settings = $group->post_content ? (array)json_decode($group->post_content, true) : array();
                                
                                $fields = array();
                                foreach ($fieldsArr as $field){
                                    if($field->group == $groupObj->id){
                                        $fields[] = $field;
                                    }
                                }

                                $groupObj->fields = $fields;
                                $groupsObj[] = $groupObj;
                            }

                            $fieldsArr = [];
                        }
                    }
                    ?>
                     <script type="text/javascript">
                         var GJFieldGroups = <?php echo json_encode($groupsObj); ?>;
                         var GJFields = <?php echo json_encode($fieldsArr); ?>;
                         var <?php echo GJ_Field_Abstract::$JSVariableName; ?> = [
                             <?php
                             $instance = GJ_Fields::instance();
                             $JSRegister = array();
                             foreach ($instance->types() as $field){
                                 $JSRegister[] = $field->JSRegister();
                             }
                             echo implode(",\n\r", $JSRegister);
                             ?>
                         ];
                         var GJGroupSchema = <?php echo json_encode(GJ_Fields::getGroupSchema()); ?>
                     </script>
                    <div class="container" id="app">
                        <component-fields :field-types="<?php echo GJ_Field_Abstract::$JSVariableName; ?>" :groups="[]" :fields="[]" :grouped="<?php echo !empty($post_type['grouped']) ? "true" : "false"; ?>" :post-type="'<?php echo esc_attr($field_post_type); ?>'"/>
                    </div>
                <?php }else{ ?>
                    <div class="does-not-support">
                        <?php esc_html_e("Field Manager does not support this post type", "gj"); ?>
                    </div>
                <?php } ?>
            </div>
        </div>
        <?php
    }

    static function save_settings() {

        GJ_Post_Types::register_post_types();
        flush_rewrite_rules();
    }

}