<?php

class GJ_Admin_State {
    static public function init(){
        add_action( 'gj_state_add_form_fields', array(__CLASS__, 'add_form_fields'), 10, 1 );
        add_action( 'gj_state_edit_form_fields', array(__CLASS__, 'edit_form_fields'), 10, 2 );
        add_action( 'edited_gj_state', array(__CLASS__, 'save_custom_meta'), 99, 2 );
        add_action( 'create_gj_state', array(__CLASS__, 'save_custom_meta'), 10, 2 );
        add_action('admin_print_footer_scripts', array(__CLASS__, 'admin_print_footer_scripts'), 99);
	}

    static function add_form_fields($taxonomy){
        ?>
        <div class="container" id="term-app">
            <div class="form-field form-required country-field-wrap">
                <label for="country"><?php echo esc_html__('Country', 'gj'); ?></label>
                <input type="hidden" :value="getValue" name="country">
                <multiselect :id="'country'" :options="options" v-model="value" :multiple="false" :label="'name'" :track-by="'code'"
                :select-label="''"
                :selected-label="''"
                :deselect-label="''"
				:deselect-group-label="''"
                >
                    <span slot="noResult"><?php esc_html_e('No elements found. Consider changing the search query', 'gj')?></span>
                    <span slot="noOptions"><?php esc_html_e('No List Found', 'gj')?></span>
                    <span slot="fetchingOptions"><?php esc_html_e('Fetching data...', 'gj')?></span>
                </multiselect>
            </div>
        </div>
        <?php
    }

    static function edit_form_fields($term, $taxonomy){
        ?>
        <tr class="form-field" id="term-app">
            <th><label for="country"><?php echo esc_html__('Country', 'gj'); ?></label></th>
            <td class="country-field-wrap">
                <input type="hidden" :value="getValue" name="country">
                <multiselect :options="options" v-model="value" :multiple="false" :label="'name'" :track-by="'code'" :preselectFirst="true"
                :select-label="''"
                :selected-label="''"
                :deselect-label="''"
				:deselect-group-label="''"
                >
                    <span slot="noResult"><?php esc_html_e('No elements found. Consider changing the search query', 'gj')?></span>
                    <span slot="noOptions"><?php esc_html_e('No List Found', 'gj')?></span>
                    <span slot="fetchingOptions"><?php esc_html_e('Fetching data...', 'gj')?></span>
                </multiselect>
            </td>
        </tr>
        <?php
    }

    static function save_custom_meta($term_id, $taxonomy){
        if(isset($_POST['country'])){
            $country = isset($_POST['country']) ? sanitize_text_field($_POST['country']) : '';
            if(!$country){
                $country = 'US';
            }

            update_term_meta($term_id, 'country', $country);
        }
    }

    static function admin_print_footer_scripts(){
        global $current_screen;
        if(isset($current_screen) && $current_screen->id === 'edit-gj_state'){
            $country = isset($_GET['tag_ID']) ? get_term_meta(intval($_GET['tag_ID']), 'country', true) : false;
        ?>
        <script type="text/javascript">
            var vm = new Vue({
                el: "#term-app",
                data: {
                    value : <?php echo !empty($country) ? "{code : '{$country}', name : '".gj_get_country_titles($country)."'}" : 'null'; ?>,
                    options: <?php echo json_encode(gj_countries_options());?>
                },
                computed: {
                    getValue() {
                        if (!this.value) {
                           var NewValue = '';
                        }else{
                            var NewValue = this.value.code;
                        }

                        return NewValue;
                    }
                },
            });

            jQuery('#addtag input[type="submit"], #edittag input[type="submit"]').click(function(e){
                jQuery('#term-app .country-field-wrap').removeClass('invalid');
                var form =jQuery(this).closest('form');
                var country = form.find('input[name="country"]').val();
                if(!country){
                    e.preventDefault();
                    jQuery('#term-app .country-field-wrap').addClass('invalid');
                }
            })
        </script>
        <?php
        }
    }
}

GJ_Admin_State::init();
?>
