<?php
/**
 * Ajax functions
 * @author InwaveThemes
 */

add_action( 'wp_ajax_gj_send_queue_email', 'gj_send_queue_email' );
add_action( 'wp_ajax_nopriv_gj_send_queue_email', 'gj_send_queue_email' );

function gj_send_queue_email() {
    if(!defined( 'WP_CACHE' ) || !WP_CACHE){
        check_ajax_referer('gj-security');
    }

    if(GJ_Email_Queue::count_emails() > 0){
        GJ_Email_Queue::send_emails();
    }

    exit;
}

add_action( 'wp_ajax_gj_send_all_email', 'gj_send_all_email' );
add_action( 'wp_ajax_nopriv_gj_send_all_email', 'gj_send_all_email' );

function gj_send_all_email() {

    global $wpdb;
    $max_email_send_in_one = gj_option('max_email_send_in_one', 5);
    $max_attemp = gj_option('max_email_attemp', 5);

    $step = isset($_POST['step']) ? intval($_POST['step']) : 1 ;

    $current = (int)($max_email_send_in_one * $step);

    if ($step == 1) {
        $sql = "SELECT COUNT(*) AS total FROM {$wpdb->prefix}gj_email_queue WHERE attemp <= %d";
        $sql = $wpdb->prepare($sql, $max_attemp);

        $total = $wpdb->get_var($sql);

        $rest = $total;

    }else{

        $total = isset($_POST['total']) ? intval($_POST['total']) : 0;

        $rest = $total - $current;
    }

    if ($rest > 0) {
        GJ_Email_Queue::send_emails(array(), $current);
    }

    $return = array( 'status' => 1, 'total' => $total, 'step' => (int)$step);

    if ($rest > 0) {
        $return['next'] = 1;
    } else {
        $return['next'] = 0;
    }

    $return['current'] = $current;

    if ($total > 0) {
        if ($current < $total) {
            $return['percent'] = ($current/$total) * 100;
        } else {
            $return['percent'] = 100;
        }

    } else {
        $return['percent'] = 0;
    }

    $return['percent'] = ($return['percent'] > 100) ? 100 : $return['percent'];

    echo json_encode($return); die();

}

add_action( 'wp_ajax_gj_membership_expiry_notice', array( 'GJ_Controller','membership_expiry_notice') );
add_action( 'wp_ajax_gj_membership_expired', array( 'GJ_Controller','membership_expired') );

add_action( 'wp_ajax_gj_addfield', function(){

    if(!current_user_can('administrator')){
        die();
    }

    $field = gj_clean($_POST['field']);

    $postType = $_POST['postType'] ? gj_clean($_POST['postType']) : 'gj_job';

    $id = wp_insert_post(array(
        'post_title' => $field['name'],
        'post_name' => $field['metakey'],
        'post_parent' => $field['group'],
        'post_excerpt' => $field['type'],
        'post_content' => json_encode($field['settings'],JSON_UNESCAPED_UNICODE),
        'post_status' => 'publish',
        'menu_order' => intval($field['order']) + 1,
        'post_type' => 'gj_fields'
    ));

    if($id){
        update_post_meta($id, 'post_type', $postType);
        update_post_meta($id, 'metakey', $field['metakey']);

        global $wpdb;

        //update order
        $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON p.ID = pm.post_id SET p.menu_order = p.menu_order +1 
                    WHERE p.post_type = 'gj_fields' AND p.post_parent = %d AND p.menu_order >= %d AND p.ID != %d AND pm.meta_key = %s AND pm.meta_value = %s";

        $wpdb->query($wpdb->prepare($query, $field['group'], intval($field['order']) + 1, $id, 'post_type', $postType));
    }

    wp_send_json(array('id' => $id));
} );

add_action( 'wp_ajax_gj_duplicatefield', function(){

    if(!current_user_can('administrator')){
        die();
    }

    $field = gj_clean($_POST['field']);
    $newField = gj_clean($_POST['newField']);

    $newPostId = gj_clone_post($field['id'], 'publish', array(
          'post_title' => $newField['name'],
          'post_name' => $newField['metakey'],
          'post_parent' => $newField['group'],
    ));

    if($newPostId){

        update_post_meta($newPostId, 'metakey', $newField['metakey']);
        global $wpdb;

        wp_update_post(
                array(
                    'ID' => $newPostId,
                    'post_title' => $newField['name'],
                    'post_name' => $newField['metakey'],
                )
        );
        $post_type = get_post_meta($field['id'], 'post_type', true);

        //update order
        $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON p.ID = pm.post_id SET p.menu_order = p.menu_order +1 
                    WHERE p.post_type = 'gj_fields' AND p.post_parent = %d AND p.menu_order >= %d AND p.ID != %d AND pm.meta_key = %s AND pm.meta_value = %s";

        $wpdb->query($wpdb->prepare($query, $field['group'], $field['order'], $field['id'], 'post_type', $post_type));

        $newPost = get_post($newPostId);
        wp_send_json(array(
            'id' => $newField['id'],
            'newId' => $newPost->ID,
        ));
    }
} );

add_action( 'wp_ajax_gj_updatefield', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $field = gj_clean($_POST['field']);

    $post = get_post($field['id']);
	//var_dump($post); 
    if($post && $post->post_type == 'gj_fields') {
        $updatePost = wp_update_post(array(
            'ID' => $field['id'],
            'post_title' => $field['name'],
            'post_name' => $field['metakey'],
            'post_status' => $field['active'] == 'true' ? 'publish' : 'pending',
            'post_content' => json_encode($field['settings'],JSON_UNESCAPED_UNICODE),
        ));

        update_post_meta($field['id'], 'metakey', $field['metakey']);

        wp_send_json(array('success' => $updatePost));

    }

    wp_send_json(array('success' => false));
} );

add_action( 'wp_ajax_gj_deletefield', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $id = gj_clean($_POST['id']);
    if($id){
        $post = get_post($id);
        $post_type = get_post_meta($id, 'post_type', true);
        if($post && $post->post_type == 'gj_fields'){
            $deletePost = wp_delete_post($id, true);
            if($deletePost){
                //update order
                global $wpdb;
                $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON p.ID = pm.post_id SET p.menu_order = p.menu_order - 1 WHERE p.post_type = 'gj_fields' AND p.post_parent = %d 
                          AND p.menu_order >= %d AND pm.meta_key = %s AND pm.meta_value = %s";
                $wpdb->query($wpdb->prepare($query, $post->post_parent, $post->menu_order, 'post_type', $post_type));
            }

            wp_send_json(array('success' => $deletePost));
        }
    }

    wp_send_json(array('success' => false));
} );

add_action( 'wp_ajax_gj_reorderfield', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $id = gj_clean($_POST['id']);
    $oldOrder = gj_clean($_POST['oldOrder']) + 1;
    $newOrder = gj_clean($_POST['newOrder']) + 1;

    $post = get_post($id);
    if($post && $post->post_type == 'gj_fields'){
        $updatePost = wp_update_post(array(
            'ID' => $id,
            'menu_order' => $newOrder,
        ));

        $post_type = get_post_meta($id, 'post_type', true);

        if($updatePost){
            global $wpdb;
            if($newOrder > $oldOrder){
                $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON pm.post_id = p.ID SET p.menu_order = p.menu_order -1 
                          WHERE p.post_type = 'gj_fields' AND p.post_parent = %d AND p.menu_order > %d AND p.menu_order <= %d AND p.ID != %d AND pm.meta_key = %s AND pm.meta_value = %s";
                $wpdb->query($wpdb->prepare($query, $post->post_parent, $oldOrder, $newOrder, $id, 'post_type', $post_type));
            }else{
                $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON pm.post_id = p.ID SET p.menu_order = p.menu_order +1 
                WHERE p.post_type = 'gj_fields' AND p.post_parent = %d AND p.menu_order < %d AND p.menu_order >= %d AND p.ID != %d  AND pm.meta_key = %s AND pm.meta_value = %s";
                $wpdb->query($wpdb->prepare($query, $post->post_parent, $oldOrder, $newOrder, $id, 'post_type', $post_type));
            }
        }

        wp_send_json(array('success' => true));
    }

    wp_send_json(array('success' => false));
} );

add_action( 'wp_ajax_gj_changegroupfield', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $id = gj_clean($_POST['id']);
    $order = gj_clean($_POST['order']);
    $toGroup = gj_clean($_POST['to']);
    $post = get_post($id);
    if($post && $post->post_type == 'gj_fields'){
        $updatePost = wp_update_post(array(
            'ID' => $id,
            'menu_order' => $order,
            'post_parent' => $toGroup,
        ));

        if($updatePost){
            $post_type = get_post_meta($id, 'post_type', true);

            global $wpdb;

            $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON p.ID = pm.post_id SET p.menu_order = p.menu_order -1
                      WHERE p.post_type = 'gj_fields' AND p.menu_order > %d AND p.post_parent = %d AND pm.meta_key = %s AND pm.meta_value = %s";
            $wpdb->query($wpdb->prepare($query, $post->menu_order, $post->post_parent, 'post_type', $post_type));

            $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm SET p.menu_order = p.menu_order +1 
                      WHERE p.post_type = 'gj_fields' AND p.menu_order > %d AND p.post_parent = %d AND pm.meta_key = %s AND pm.meta_value = %s";
            $wpdb->query($wpdb->prepare($query, $order, $toGroup, 'post_type', $post_type));
        }

        wp_send_json(array('success' => true));
    }

    wp_send_json(array('success' => false));
});

add_action( 'wp_ajax_gj_addgroup', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $title = gj_clean($_POST['name']);
    $order = intval($_POST['order']) + 1;
    $post_type = gj_clean($_POST['postType']);

    $id = wp_insert_post(array(
            'post_title' => $title,
            'post_status' => 'publish',
            'post_type' => 'gj_field_groups',
            'menu_order' => $order
    ));

    if($id){
        update_post_meta($id, 'post_type', $post_type);

        global $wpdb;
        //update order
        if($order > 0){
            $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON p.ID = pm.post_id SET p.menu_order = p.menu_order +1 
                  WHERE p.post_type = 'gj_field_groups' AND p.menu_order >= %d AND p.ID != %d AND pm.meta_key = %s AND pm.meta_value = %s";
            $wpdb->query($wpdb->prepare($query, $order, $id, 'post_type', $post_type));
        }
    }

    wp_send_json(array('id' => $id));
});

add_action( 'wp_ajax_gj_updategroup', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $group = gj_clean($_POST['group']);

    $post = get_post($group['id']);
    if($post && $post->post_type == 'gj_field_groups') {
        $updatePost = wp_update_post(array(
            'ID' => $group['id'],
            'post_title' => $group['name'],
            'post_name' => $group['metakey'],
            'post_content' => json_encode($group['settings'],JSON_UNESCAPED_UNICODE),
        ));

        wp_send_json(array('success' => $updatePost));
    }

    wp_send_json(array('success' => false));
});

add_action( 'wp_ajax_gj_renamegroup', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $title = gj_clean($_POST['name']);
    $id = gj_clean($_POST['id']);

    $post = get_post($id);
    if($post && $post->post_type == 'gj_field_groups'){
        $update = wp_update_post(array(
            'post_title' => $title,
            'ID' => $id,
        ));

        wp_send_json(array('success' => $update));
    }

    wp_send_json(array('success' => false));
} );

add_action( 'wp_ajax_gj_deletegroup', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $id = gj_clean($_POST['id']);

    //delete fields
    $posts = get_posts(array(
        'post_type' => 'gj_fields',
        'posts_per_page' => -1,
        'post_status' => 'any',
        'post_parent' => $id,
    ));

    if($posts){
        foreach ($posts as $post){
            wp_delete_post($post, true);
        }
    }

    if($id){
        $post = get_post($id);
        if($post && $post->post_type == 'gj_field_groups'){

            $post_type = get_post_meta($id, 'post_type', true);

            $deletePost = wp_delete_post($id, true);
            if($deletePost){
                //update order
                global $wpdb;
                $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON pm.post_id = p.ID SET p.menu_order = p.menu_order - 1 
                          WHERE p.post_type = 'gj_field_groups' AND p.menu_order >= %d AND pm.meta_key = %s AND pm.meta_value = %s";
                $wpdb->query($wpdb->prepare($query, $post->menu_order, 'post_type', $post_type));
            }
            wp_send_json(array('success' => true));
        }
    }

    wp_send_json(array('success' => false));

} );

add_action( 'wp_ajax_gj_reordergroup', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $id = gj_clean($_POST['id']);
    $oldOrder = gj_clean($_POST['oldOrder']) + 1;
    $newOrder = gj_clean($_POST['newOrder']) + 1;

    $post = get_post($id);

    if($post && $post->post_type == 'gj_field_groups'){
        $updatePost = wp_update_post(array(
            'ID' => $id,
            'menu_order' => $newOrder,
        ));

        if($updatePost){
            global $wpdb;
            $post_type = get_post_meta($id, 'post_type', true);

            if($newOrder > $oldOrder){
                $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON pm.post_id = p.ID SET p.menu_order = p.menu_order -1 
                          WHERE p.post_type = 'gj_field_groups' AND p.menu_order > %d AND p.menu_order <= %d AND p.ID != %d AND pm.meta_key = %s AND pm.meta_value = %s";
                $wpdb->query($wpdb->prepare($query, $oldOrder, $newOrder, $id, 'post_type', $post_type));
            }else{

                $query = "UPDATE {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON pm.post_id = p.ID SET p.menu_order = p.menu_order +1 
                          WHERE p.post_type = 'gj_field_groups' AND p.menu_order < %d AND p.menu_order >= %d AND p.ID != %d AND pm.meta_key = %s AND pm.meta_value = %s";
                $wpdb->query($wpdb->prepare($query, $oldOrder, $newOrder, $id, 'post_type', $post_type));
            }
        }

        wp_send_json(array('success' => true));
    }

    wp_send_json(array('success' => false));
} );

add_action( 'wp_ajax_gj_field_ajax', function(){
    if(!current_user_can('administrator')){
        die();
    }

    $fieldId = gj_clean($_POST['id']);
    $fc = gj_clean($_POST['fc']);
    $post = get_post($fieldId);

    $field = GJ_Fields::instance()->getField($post);
    if($field && method_exists($field, $fc)){
        $field->$fc();
    }
    else{
        die();
    }
} );

add_action( 'wp_ajax_gj_save_post', function(){
    GJ_Fields::instance()->savePost();
} );

add_action('wp_ajax_gj_save_settings', array('GJ_Controller', 'save_settings'));
add_action('wp_ajax_gj_reset_settings', array('GJ_Controller', 'reset_settings'));

add_action('wp_ajax_gj_add_order_note', array('GJ_Controller', 'add_order_note'));
add_action('wp_ajax_gj_delete_order_note', array('GJ_Controller', 'delete_order_note'));

add_action('wp_ajax_gj_jobs_export', array('GJ_Controller', 'jobs_export'));
add_action('wp_ajax_gj_upload_csv_actions', array('GJ_Controller', 'upload_csv_actions'));
add_action('wp_ajax_gj_set_post_types', array('GJ_Controller', 'set_post_types'));
add_action('wp_ajax_gj_parse_data_to_import', array('GJ_Controller', 'parse_data_to_import'));

add_action('wp_ajax_gj_jobs_expiry_notice', array('GJ_Controller', 'jobs_expiry_notice'));
add_action('wp_ajax_nopriv_gj_jobs_expiry_notice', array('GJ_Controller', 'jobs_expiry_notice'));

add_action('wp_ajax_gj_job_expired', array('GJ_Controller', 'jobs_expired'));
add_action('wp_ajax_nopriv_gj_job_expired', array('GJ_Controller', 'jobs_expired'));

add_action('wp_ajax_gj_membership_expiry_notice', array('GJ_Controller', 'membership_expiry_notice'));
add_action('wp_ajax_nopriv_gj_membership_expiry_notice', array('GJ_Controller', 'membership_expiry_notice'));

add_action('wp_ajax_gj_membership_expired', array('GJ_Controller', 'membership_expired'));
add_action('wp_ajax_nopriv_gj_membership_expired', array('GJ_Controller', 'membership_expired'));

add_action('wp_ajax_gj_create_default_pages', array('GJ_Controller', 'create_default_products'));

add_action('wp_ajax_gj_reorder_all_fields', array('GJ_Controller', 'reorder_all_fields'));

add_action('wp_ajax_gj_export_fields', array('GJ_Install', 'export_fields'));
add_action('wp_ajax_gj_export_options', array('GJ_Install', 'export_options'));

add_filter('gj_logged_in', array('GJ_Controller', 'logged_in_fallback'));


