<?php
/**
 * @class 		GJ_REST_Controller
 * @package		GJ/Api/Classes
 * @author 		InwaveThemes
 */

class GJ_REST_Controller extends WP_REST_Controller {

    /**
     * Register the routes for the objects of the controller.
     */
    public function register_routes() {
        $version = '1';
        $namespace = 'gj/v' . $version;
        $base = '';

        register_rest_route( $namespace, '/' . $base . 'register', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'register' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'not_login_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'login', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'login' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'not_login_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'lost-password', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'lostpass' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'not_login_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'reset-password', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'resetpass' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'not_login_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'me', array(
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'edit_profile' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions'),
            ),
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'delete_account' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions'),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'me/request-verification', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'request_verification'),
                'permission_callback' => array( 'GJ_REST_Controller', 'request_verification_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'me/change-email', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'change_email'),
                'permission_callback' => array( 'GJ_REST_Controller', 'request_verification_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'countries', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array('GJ_API_Controller', 'get_countries' ),
                'permission_callback' => array('GJ_REST_Controller', 'public_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'states', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array('GJ_API_Controller', 'get_states' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'cities', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'get_cities' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
                'args'                => array(
                    'context' => array(
                        'default' => 'view',
                    ),
                ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'terms/(?P<taxonomy>[a-zA-Z0-9_-]+)', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'get_terms' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
                'args'                => array(
                    'context' => array(
                        'default' => 'view',
                    ),
                    'hide_empty' => array(
                        'default' => false,
                    ),
                    'orderby' => array(
                        'default' => 'name',
                    ),
                    'order' => array(
                        'default' => 'ASC',
                    ),
                    'query' => array(
                        'default' => '',
                    ),
                ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'posts', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'get_posts' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions' ),
                'args'                => array(
                    'context' => array(
                        'default' => 'view',
                    ),
                    'postType' => array(
                        'default' => 'post',
                    ),
                    'orderby' => array(
                        'default' => 'name',
                    ),
                    'order' => array(
                        'default' => 'ASC',
                    ),
                    'query' => array(
                        'default' => '',
                    ),
                ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'users', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'get_users' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions' ),
                'args'                => array(
                    'context' => array(
                        'default' => 'view',
                    ),
                    'orderby' => array(
                        'default' => 'display_name',
                    ),
                    'order' => array(
                        'default' => 'ASC',
                    ),
                    'query' => array(
                        'default' => '',
                    ),
                ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'image', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'upload_image' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'image/(?P<ID>[0-9]+)', array(
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'delete_file' ),
                'permission_callback' => array('GJ_REST_Controller', 'delete_file_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'cv', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'upload_cv' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'cv/(?P<ID>[0-9]+)', array(
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'delete_file' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'delete_file_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'posts/submit', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'submit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'post/(?P<ID>[0-9]+)/edit', array(
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'edit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'edit_post_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'post/(?P<ID>[0-9]+)/delete', array(
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'delete_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'delete_post_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'post/(?P<ID>[0-9]+)/contact', array(
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'contact' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'contact_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'employers', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'employers' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'submit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'employer_permissions' ),
            ),
        ));

        register_rest_route( $namespace, '/' . $base . 'employer/(?P<ID>[0-9]+)', array(
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'delete_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'delete_post_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'edit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'edit_post_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'employer/(?P<ID>[0-9]+)/publish', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'publish_employer' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'publish_post_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'employer/(?P<ID>[0-9]+)/follow', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'follow_employer' ),
                'permission_callback' => 'gj_can_follow_employer',
            ),
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'unfollow_employer' ),
                'permission_callback' => 'gj_can_follow_employer',
            ),
        ) );


        register_rest_route( $namespace, '/' . $base . 'employer/(?P<ID>[0-9]+)/featured', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'featured_employer' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'private_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'unfeatured_employer' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'employer/(?P<ID>[0-9]+)/changestatus', array(
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'change_employer_status' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'candidates', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'candidates' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'submit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'candidate_permissions' ),
            ),
        ));

        register_rest_route( $namespace, '/' . $base . 'candidate/(?P<ID>[0-9]+)', array(
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'delete_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'delete_post_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'edit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'edit_post_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'candidate/(?P<ID>[0-9]+)/publish', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'publish_candidate' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'publish_post_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'candidate/(?P<ID>[0-9]+)/save', array(
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'unsave_resume' ),
                'permission_callback' => 'gj_can_save_resume_cv',
            ),
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'save_resume' ),
                'permission_callback' => 'gj_can_save_resume_cv',
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'candidate/(?P<ID>[0-9]+)/featured', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'featured_candidate' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'private_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'unfeatured_candidate' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'candidate/(?P<ID>[0-9]+)/changestatus', array(
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'change_candidate_status' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'jobs', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'jobs' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'submit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'employer_permissions' ),
            ),
        ));

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)', array(
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'delete_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'delete_post_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'edit_post' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'edit_post_permissions' ),
            ),
        ));

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)/apply', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'apply_job' ),
                //'permission_callback' => array( 'GJ_REST_Controller', 'login_permissions' ),
                'permission_callback' => 'gj_can_apply_job',
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)/save', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'save_job' ),
                'permission_callback' => 'gj_can_save_job',
            ),
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'unsave_job' ),
                'permission_callback' => 'gj_can_save_job',
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)/draft', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'draft_job' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'job_private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)/publish', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'publish_job' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'publish_post_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)/changestatus', array(
            array(
                'methods'             => WP_REST_Server::EDITABLE,
                'callback'            => array( 'GJ_API_Controller', 'change_job_status' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)/featured', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'featured_job' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'job_private_permissions' ),
            ),
            array(
                'methods'             => WP_REST_Server::DELETABLE,
                'callback'            => array( 'GJ_API_Controller', 'unfeatured_job' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'job_private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'job/(?P<ID>[0-9]+)/renew', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'renew_job' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'job_private_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'application/(?P<ID>[0-9]+)/email', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'send_application_email' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'application_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'application/(?P<ID>[0-9]+)/note', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'application_note' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'application_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'application/(?P<ID>[0-9]+)/changestatus', array(
            array(
                'methods'             => WP_REST_Server::CREATABLE,
                'callback'            => array( 'GJ_API_Controller', 'application_change_status' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'application_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'application/(?P<ID>[0-9]+)/quickview', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'application_quick_view' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'quick_view_application_permissions' ),
            ),
        ) );

        register_rest_route( $namespace, '/' . $base . 'filter/jobs', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'filter_jobs' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
        ) );
        register_rest_route( $namespace, '/' . $base . 'filter/employers', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'filter_employers' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
        ) );
        register_rest_route( $namespace, '/' . $base . 'filter/candidates', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'filter_candidates' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
        ) );
        register_rest_route( $namespace, '/' . $base . 'filter/cities', array(
            array(
                'methods'             => WP_REST_Server::READABLE,
                'callback'            => array( 'GJ_API_Controller', 'filter_cities' ),
                'permission_callback' => array( 'GJ_REST_Controller', 'public_permissions' ),
            ),
        ) );

        do_action('gj_api', $namespace, $base);
    }

    static public function public_permissions($request){
        return true;
    }

    static public function private_permissions($request){
        return current_user_can('administrator');
    }

    static public function not_login_permissions($request){
        return !is_user_logged_in();
    }

    static public function login_permissions($request){
        return is_user_logged_in();
    }

    static public function candidate_permissions($request){
        if(is_user_logged_in()){
            $user = GJ_User::get_user();

            return $user->is_candidate();
        }

        return false;
    }

    static public function employer_permissions($request){
        if(is_user_logged_in()){
            $user = GJ_User::get_user();

            return $user->is_employer();
        }

        return false;
    }

    static public function request_verification_permissions($request){
        $user = GJ_User::get_user();
        return $user && !$user->is_verified();
    }

    static public function delete_file_permissions($request){
        $ID = $request['ID'];
        return current_user_can('delete_post', $ID);
    }

    static public function delete_post_permissions($request){
        $ID = $request['ID'];
        return current_user_can('delete_post', $ID);
    }

    static public function publish_post_permissions($request){
        $ID = $request['ID'];
        $post = get_post($ID);
        if($post){
            if($post->post_type == 'gj_job'){
                $job = GJ_Job::get_job($post);
                return $job->can_publish();
            }elseif($post->post_type == 'gj_employer'){
                $employer = GJ_Employer::get_employer($post);
                return $employer->can_publish();
            }elseif($post->post_type == 'gj_candidate'){
                $candidate = GJ_Candidate::get_candidate($post);
                return $candidate->can_publish();
            }
        }

        return false;
    }

    static public function job_private_permissions($request){
        $ID = $request['ID'];
        $job = GJ_Job::get_job($ID);
        $user_id = get_current_user_id();
        if($job && ($job->get_author_id() == $user_id || current_user_can('administrator'))){
            return true;
        }

        return false;
    }

    static public function edit_post_permissions($request){
        $ID = $request['ID'];
        if(get_post_type($ID) === 'gj_job'){
            return current_user_can('edit_post', $ID);
        }else{
            if(get_post_type($ID) === 'gj_application' && !current_user_can('administrator')){
                return false;
            }
            else
            {
                return current_user_can('edit_post', $ID);
            }
        }

        return false;
    }

    static public function contact_permissions($request){
        if(!is_user_logged_in()){
            return false;    
        }

        $ID = $request['ID'];
        if(!in_array(get_post_type($ID), array('gj_job', 'gj_employer', 'gj_candidate'))){
            return false;
        }

        return true;
    }

    static public function application_permissions($request){
        $ID = $request['ID'];
        $application = GJ_Application::get_application($ID);
        if($application && $application->is_job_author()){
            return true;
        }

        return false;
    }

    static public function quick_view_application_permissions($request){
        $ID = $request['ID'];
        $application = GJ_Application::get_application($ID);
        if($application && ($application->is_author() || $application->is_job_author())){
            return true;
        }

        return false;
    }
}