<?php

/**
 * API Functions
 *
 * @class 		GJ_API_Controller
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */
class GJ_API_Controller {

    static function get_states($request) {
        $args = array(
            'hide_empty' => isset($_REQUEST['hide_empty']) ? sanitize_text_field($_REQUEST['hide_empty']) : false,
            'orderby' => isset($_REQUEST['orderby']) ? sanitize_text_field($_REQUEST['orderby']) : 'name',
            'order' => isset($_REQUEST['order']) ? sanitize_text_field($_REQUEST['order']) : 'ASC',
            'number' => isset($_REQUEST['number']) ? sanitize_text_field($_REQUEST['number']) : false,
            'taxonomy' => 'gj_state',
        );

        if (isset($_REQUEST['country']) && $_REQUEST['country']) {
            $args['meta_query'] = array(
                array(
                    'key' => 'country',
                    'value' => sanitize_text_field($_REQUEST['country']),
                    'compare' => '='
                )
            );
        }

        $items = get_terms($args);

        return new WP_REST_Response($items, 200);
    }

    static function get_countries($request) {

        return new WP_REST_Response(gj_countries_options(), 200);
    }

    static function get_cities($request) {
        $args = array(
            'hide_empty' => isset($_REQUEST['hide_empty']) ? sanitize_text_field($_REQUEST['hide_empty']) : false,
            'orderby' => isset($_REQUEST['orderby']) ? sanitize_text_field($_REQUEST['orderby']) : 'name',
            'order' => isset($_REQUEST['order']) ? sanitize_text_field($_REQUEST['order']) : 'ASC',
            'number' => isset($_REQUEST['number']) ? sanitize_text_field($_REQUEST['number']) : false,
            'taxonomy' => 'gj_city',
        );

        if (isset($_REQUEST['state']) && $_REQUEST['state']) {
            $args['meta_query'] = array(
                array(
                    'key' => 'state',
                    'value' => intval($_REQUEST['state']),
                    'compare' => '='
                )
            );
        }

        $terms = get_terms($args);

        return new WP_REST_Response($terms, 200);
    }

    static function get_terms($request) {
        $hide_empty = isset($_GET['hide_empty']) ? (boolean) $_GET['hide_empty'] : false;
        $orderby = isset($_GET['orderby']) ? sanitize_text_field($_GET['orderby']) : 'name';
        $order = isset($_GET['order']) ? sanitize_text_field($_GET['order']) : 'ASC';
        $query = isset($_GET['query']) ? sanitize_text_field($_GET['query']) : '';

        $args = array(
            'hide_empty' => $hide_empty,
            'taxonomy' => $request['taxonomy'],
            'orderby' => $orderby,
            'order' => $order,
            'search' => $query,
        );
        $items = get_terms($args);
        $items = array_map(function($term) {
            $term->name = wp_specialchars_decode($term->name);
            return $term;
        }, $items);

        return new WP_REST_Response($items, 200);
    }

    static function get_posts($request) {
        $postType = isset($_GET['postType']) ? sanitize_text_field($_GET['postType']) : 'post';
        $orderby = isset($_GET['orderby']) ? sanitize_text_field($_GET['orderby']) : 'name';
        $order = isset($_GET['order']) ? sanitize_text_field($_GET['order']) : 'ASC';
        $query = isset($_GET['query']) ? sanitize_text_field($_GET['query']) : '';
        $args = array(
            'post_type' => $postType,
            'orderby' => $orderby,
            'order' => $order,
            's' => $query,
            'posts_per_page' => -1,
        );
        $items = get_posts($args);

        if ($items) {
            $items = array_map(function ($item) {
                $newItem = new stdClass();
                $newItem->ID = $item->ID;
                $newItem->post_title = $item->post_title;

                return $newItem;
            }, $items);
        }

        return new WP_REST_Response($items, 200);
    }

    static function get_users($request) {
        $orderby = isset($_GET['orderby']) ? sanitize_text_field($_GET['orderby']) : 'name';
        $order = isset($_GET['order']) ? sanitize_text_field($_GET['order']) : 'ASC';
        $query = isset($_GET['query']) ? sanitize_text_field($_GET['query']) : '';

        $users = get_users(array('search' => "*" . $query . "*", 'orderby' => $orderby, 'order' => $order, 'fields' => array('ID', 'display_name', 'user_email')));
        return new WP_REST_Response($users, 200);
    }

    static function upload_image() {

        if (!function_exists('wp_handle_upload')) {
            require_once(ABSPATH . 'wp-admin/includes/file.php');
        }

        $file = $_FILES['image'];
        $mimes = array(
            // Image formats.
            'jpg|jpeg|jpe' => 'image/jpeg',
            'gif' => 'image/gif',
            'png' => 'image/png',
            'bmp' => 'image/bmp',
        );
        $overides = array('test_form' => false, 'mimes' => $mimes);
        $status = wp_handle_upload($file, $overides);
        if ($status) {
            $attachment = array(
                'guid' => $status['url'],
                'post_mime_type' => $status['type'],
                'post_title' => preg_replace('/\.[^.]+$/', '', basename($file['name'])),
                'post_content' => '',
                'post_parent' => '',
                'post_status' => 'inherit',
            );

            // Adds file as attachment to WordPress

            $id = wp_insert_attachment($attachment, $status['file']);
            if (!is_wp_error($id)) {
                include_once( ABSPATH . 'wp-admin/includes/image.php' );
                wp_update_attachment_metadata($id, wp_generate_attachment_metadata($id, $status['file']));
            }

            $status['ID'] = $id;
            $status['thumbnail_url'] = wp_get_attachment_thumb_url($id);
            $status['url'] = wp_get_attachment_url($id);
            $status['sourceID'] = isset($_POST['sourceID']) ? sanitize_text_field($_POST['sourceID']): '';
            $remove_file_id = isset($_POST['remove_file_id']) ? (int) $_POST['remove_file_id'] : 0;
            if ($remove_file_id && current_user_can('delete_post', $remove_file_id)) {
                wp_delete_attachment($remove_file_id, true);
            }

            unset($status['file']);
        }

        return new WP_REST_Response($status, 200);
    }

    static function upload_cv() {
        /* $option = array();
          $option['ID'] = 19990;
          $option['url'] = 'http://ag.giz';
          $option['name'] = 'ag.giz';
          $option['date'] = ''; */

        $file = $_FILES['file'];
        $option = gj_upload_cv($file);

        return new WP_REST_Response($option, 200);
    }

    static function apply_job($request) {
        $data = apply_filters('gj_before_apply_job', null, $request);
        if ($data) {
            return new WP_REST_Response($data);
        }

        $user_captchas = (array) gj_option('use_recaptcha');
        $captcha_respon = GJ_API_Controller::check_recaptcha(in_array('apply_job', $user_captchas));

        if ($captcha_respon !== true) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Wrong captcha', 'gj')
            ));
        }

        $postTitle = isset($_POST['title']) ? sanitize_title($_POST['title']) : time();
        $jobID = isset($_POST['jobID']) ? intval($_POST['jobID']) : time();
        if (!$jobID) {
            return new WP_REST_Response(array('success' => false, 'message' => esc_html__('Invalid job', 'gj')));
        }
        $user = get_current_user_id() ? get_current_user_id() : '';
        $post_data = array(
            'post_title' => $postTitle,
            'post_content' => '',
            'post_type' => 'gj_application',
            'post_status' => 'pending',
            'post_author' => get_current_user_id() ? get_current_user_id() : '',
        );

        $postID = wp_insert_post($post_data);

        if ($postID) {
            $fieldHelper = new GJ_Fields();
            $fields = $fieldHelper->getFields($postID, 'gj_application');
            if ($fields) {
                foreach ($fields as $field) {
                    if (is_admin() && ($field->getSetting('showInput') === 'both' || $field->getSetting('showInput') === 'backend')) {
                        $field->save();
                    } elseif (!is_admin() && ($field->getSetting('showInput') === 'both' || $field->getSetting('showInput') === 'dashboard')) {
                        $field->save();
                    }
                }
            }

            update_post_meta($postID, GJ_PREFIX . 'job_id', $jobID);

            clean_post_cache($postID);

            $application = GJ_Application::get_application($postID, true);
            if (class_exists('\W3TC\DbCache_Plugin')) {
                $dbcache = new W3TC\DbCache_Plugin();
                $dbcache->on_post_change();
            }
            if (get_current_user_id()) {
                $job_applieds = get_user_meta(get_current_user_id(), 'gj_apply_job', true);
                if (!$job_applieds) {
                    $job_applieds = array($jobID);
                } else {
                    $job_applieds[] = $jobID;
                }

                update_user_meta(get_current_user_id(), 'gj_apply_job', $job_applieds);
            } else {
                setcookie('gj_apply_' . $jobID, 1, time() + 60 * 60 * 24 * 360, SITECOOKIEPATH);
            }

            GJ_Email::send_email('new_application', $application);
            GJ_Email::send_email('new_application_employer', $application);


            $data = array(
                'success' => true,
                'message' => gj_get_template_part('applies/thankyou-content', array(), true)
            );
        } else {
            $data = array(
                'success' => false,
                'message' => esc_html__('Can not delete account please reload the page and try again.', 'gj')
            );
        }
        if (get_current_user_id()) {
            $data = apply_filters('gj_after_apply_job', $data, $request);
        }

        return new WP_REST_Response($data);
    }

    static function edit_profile($request) {
        $args = array(
            "ID" => get_current_user_id(),
            "first_name" => sanitize_text_field($_POST['firstName']),
            "last_name" => sanitize_text_field($_POST['lastName']),
            "display_name" => trim(sanitize_text_field($_POST['firstName']) . ' ' . sanitize_text_field($_POST['lastName'])),
            "user_email" => sanitize_text_field($_POST['email']),
            "user_url" => esc_url_raw($_POST['url']),
        );

        $new_password = isset($_POST['new_password']) ? sanitize_text_field($_POST['new_password']) : '';
        $password_confirm = isset($_POST['password_confirm']) ? sanitize_text_field($_POST['password_confirm']) : '';

        if ($new_password) {
            if (strlen($new_password) < 6) {
                $return['message'] = esc_html__('Password must be at least 6 characters.', 'gj');
                $return['success'] = false;
                return new WP_REST_Response($return);
            }

            if ($new_password !== $password_confirm) {
                $return['message'] = esc_html__('Confirm password does not match.', 'gj');
                $return['success'] = false;
                return new WP_REST_Response($return);
            }

            $args['user_pass'] = $new_password;
        }

        $update = wp_update_user($args);

        if ($update && !is_wp_error($update)) {
            $old_avatar = get_user_meta(get_current_user_id(), GJ_PREFIX . 'avatar', true);
            if (isset($_POST['avatar']) && $_POST['avatar']['id']) {
                if ($_POST['avatar']['isNew']) {
                    update_user_meta(get_current_user_id(), GJ_PREFIX . 'avatar', intval($_POST['avatar']['id']));
                    if ($old_avatar && current_user_can('delete_post', $old_avatar)) {
                        wp_delete_attachment($old_avatar, true);
                    }
                }
            } else {
                delete_user_meta(get_current_user_id(), GJ_PREFIX . 'avatar');
                if ($old_avatar && current_user_can('delete_post', $old_avatar)) {
                    wp_delete_attachment($old_avatar, true);
                }
            }

            $return = array('success' => true, 'message' => esc_html__('Update successfully!', 'gj'));

            if ($new_password) {
                $return['redirect_url'] = gj_get_page_permalink('dashboard');
                wp_logout();
            }

            return new WP_REST_Response($return);
        } else {
            return new WP_REST_Response(array('success' => false, 'message' => $update->get_error_message()), 412);
        }
    }

    static function delete_file($request) {
        $ID = $request['ID'];
        wp_delete_attachment($ID, true);
        return new WP_REST_Response(array('success' => true), 200);
    }

    static function request_verification() {
        $user = GJ_User::get_user();

        GJ_Email::send_email('verify_account', array('user' => $user));

        return new WP_REST_Response(array(
            'success' => true,
            'message' => esc_html__('An email was sent to your email please click the activation link to verify your account!', 'gj')
                ), 200);
        exit;
    }

    static function register() {

        $data = apply_filters('gj_before_register', null);
        if ($data) {
            return new WP_REST_Response($data);
        }

        $return = array();
        $user_name = sanitize_user($_POST['username'], true);
        $email = sanitize_email($_POST['email']);
        $display_name = isset($_POST['display_name']) ? sanitize_text_field($_POST['display_name']) : '';
        $password = isset($_POST['password']) ? sanitize_text_field($_POST['password']) : '';
        $password_confirm = isset($_POST['password_confirm']) ? sanitize_text_field($_POST['password_confirm']) : '';
        $social = isset($_POST['social']) ? sanitize_text_field($_POST['social']) : '';
        $role = $_POST['role'];

        if (!$user_name) {
            $return['message'] = esc_html__('Invalid username.', 'gj');
            $return['success'] = false;
            return new WP_REST_Response($return);
        }

        $username = preg_replace('/[^a-zA-Z0-9.-_@]/', '', $user_name);
        if ($username !== $user_name) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Invalid username (do not use special characters or spaces)!', 'gj')
            ));
        }
        if (strlen($user_name) < 5) {
            $return['message'] = esc_html__('Username must be at least 5 characters.', 'gj');
            $return['success'] = false;
            return new WP_REST_Response($return);
        }

        if (username_exists($user_name)) {
            $return['message'] = esc_html__('Username already exists.', 'gj');
            $return['success'] = false;
            return new WP_REST_Response($return);
        }

        if (!$email) {
            $return['message'] = esc_html__('Invalid User Email.', 'gj');
            $return['success'] = false;
            return new WP_REST_Response($return);
        }

        /* if(gj_option('registration_generate_password')){
          $password = wp_generate_password();
          $auto_generate_password = true;
          }else{ */
        if ($password) {

            if ($password !== $password_confirm) {
                $return['message'] = esc_html__('Confirm password does not match.', 'gj');
                $return['success'] = false;
                return new WP_REST_Response($return);
            }

            if (strlen($password) < 6) {
                $return['message'] = esc_html__('Password must be at least 6 characters.', 'gj');
                $return['success'] = false;
                return new WP_REST_Response($return);
            }

            $auto_generate_password = false;
        } else {
            /* $return['message'] = esc_html__('Please enter password.', 'gj');
              $return['success'] = false;
              return new WP_REST_Response($return); */
            $password = wp_generate_password();
            $auto_generate_password = true;
        }
        //}

        if (email_exists($email)) {
            $return['message'] = esc_html__('User Email already exists.', 'gj');
            $return['success'] = false;
            return new WP_REST_Response($return);
        }

        $user_captchas = (array) gj_option('use_recaptcha');
        $captcha_respon = GJ_API_Controller::check_recaptcha(in_array('register', $user_captchas));
        if ($captcha_respon !== true) {
            return new WP_REST_Response(array(
                'loggedin' => false,
                'message' => esc_html__('Wrong captcha', 'gj')
            ));
        }

        $user_data = array();
        $user_data['user_login'] = $user_name;
        $user_data['first_name'] = $user_name;
        $user_data['display_name'] = $display_name ? $display_name : $user_name;
        $user_data['user_pass'] = $password;
        $user_data['user_email'] = $email;
        $user_data['role'] = ( $role == 'employer' ? 'gj_employer' : 'gj_candidate' );

        $user_id = wp_insert_user($user_data);
        if (!is_wp_error($user_id)) {

            do_action('gj_register_process', $user_id);

            $verified = false;
            if ($social) {
                $social_data = $_SESSION['gj_social_register_data'];
                if ($social_data && $social == $social_data['social']) {
                    $profile_image = isset($social_data['profile_image']) ? $social_data['profile_image'] : '';
                    $social_id = isset($social_data['social_id']) ? $social_data['social_id'] : '';
                    $social = isset($social_data['social']) ? $social_data['social'] : '';
                    $social_email = isset($social_data['email']) ? $social_data['email'] : '';

                    if ($profile_image) {
                        update_user_meta($user_id, GJ_PREFIX . 'avatar', $profile_image);
                    }
                    if ($social_id) {
                        update_user_meta($user_id, GJ_PREFIX . 'social_id', $social_id);
                    }
                    if ($social) {
                        update_user_meta($user_id, GJ_PREFIX . 'social', $social);
                    }

                    if ($email == $social_email) {
                        $verified = true;
                    }
                }
            }

            $activation_url = '';
            if (gj_option('verify_account') && !$verified) {
                $user = GJ_User::get_user($user_id);
                $activation_url = $user->get_activation_url();
            }

            GJ_Email::send_email('register', array(
                'user_id' => $user_id,
                'password' => $user_data['user_pass'],
                'verified' => $verified,
                'activation_url' => $activation_url,
                'auto_generate_password' => $auto_generate_password
            ));

            GJ_Email::send_email('admin_register', array(
                'user_id' => $user_id,
                'password' => $user_data['user_pass'],
                'verified' => $verified,
                'activation_url' => $activation_url,
                'auto_generate_password' => $auto_generate_password
            ));

            $info = array();
            $info['user_login'] = $user_name;
            $info['user_password'] = $password;
            $info['remember'] = true;
            $user_signon = wp_signon($info, is_ssl());

            if (gj_option('verify_account') && !$verified) {
                $redirect_url = gj_get_page_permalink('verify');
            } else {
                $login_redirect = isset($_POST['redirect_to']) ? esc_url_raw($_POST['redirect_to']) : '';
                if (!$login_redirect) {
                    if (in_array('gj_employer', $user_signon->roles)) {
                        $login_redirect = get_permalink(gj_option('employer_login_redirect')['ID']);
                    } elseif (in_array('gj_candidate', $user_signon->roles)) {
                        $login_redirect = get_permalink(gj_option('candidate_login_redirect')['ID']);
                    }
                }

                if (!$login_redirect || $login_redirect == gj_get_page_permalink('login') || $login_redirect == gj_get_page_permalink('register')) {
                    $login_redirect = gj_get_page_permalink('dashboard');
                }

                $redirect_url = add_query_arg(array('registed' => 'true'), $login_redirect);
            }

            $return = apply_filters('gj_registered', array(
                'success' => true,
                'message' => esc_html__('Registered successfully, redirecting...', 'gj'),
                'redirect_url' => $redirect_url
                    ), $user_id, $verified);

            return new WP_REST_Response($return);
        } else {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Can\'t register please refresh the page and try again.', 'gj')
            ));
        }
    }

    static function check_recaptcha($required = false) {
        if (isset($_POST['g-recaptcha-response'])) {
            $captcha = sanitize_text_field($_POST['g-recaptcha-response']);
            $response = wp_remote_get("https://www.google.com/recaptcha/api/siteverify?secret=" . gj_option('google_recaptcha_secret_key') . "&response=" . $captcha . "&remoteip=" . $_SERVER['REMOTE_ADDR'], array('decompress' => false));
            if ($response) {
                $response = wp_remote_retrieve_body($response);
                if ($response) {
                    $response = json_decode($response);
                    if (!$response->success || $response->success === false) {
                        $err = $response->{'error-codes'};
                        if (is_array($err)) {
                            return implode(', ', $err);
                        } else {
                            return $err;
                        }
                    }
                } else {
                    return false;
                }
            } else {
                return false;
            }
        } elseif ($required) {
            return false;
        }

        return true;
    }

    static function login() {
        $data = apply_filters('gj_before_login', null);
        if ($data) {
            return new WP_REST_Response($data);
        }
        $user_captchas = (array) gj_option('use_recaptcha');
        $captcha_respon = GJ_API_Controller::check_recaptcha(in_array('login', $user_captchas));

        if ($captcha_respon !== true) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Wrong captcha', 'gj')
            ));
        }

        $info = array();
        $info['user_login'] = sanitize_user($_POST['username'], true);
        $info['user_password'] = sanitize_text_field($_POST['password']);
        $info['remember'] = true;
        do_action('gj_before_login', $info['user_login']);
        if (!$info['user_login'] || !$info['user_password']) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Please input your account info.', 'gj')
            ));
        }
        $user_signon = wp_signon($info, is_ssl());
        if (is_wp_error($user_signon)) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => $user_signon->get_error_message() ? $user_signon->get_error_message() : esc_html__('Unknown error!!!', 'gj')
            ));
        } else {

            wp_set_current_user($user_signon->ID, $user_signon->user_login);

            $redirect_url = isset($_POST['redirect_to']) ? esc_url_raw($_POST['redirect_to']) : '';
            if (!$redirect_url) {
                if (in_array('gj_employer', $user_signon->roles)) {
                    $redirect_url = get_permalink(gj_option('employer_login_redirect')['ID']);
                } elseif (in_array('gj_candidate', $user_signon->roles)) {
                    $redirect_url = get_permalink(gj_option('candidate_login_redirect')['ID']);
                }
            }

            if (!$redirect_url || $redirect_url == gj_get_page_permalink('login') || $redirect_url == gj_get_page_permalink('register')) {
                $redirect_url = gj_get_page_permalink('dashboard');
            }

            $redirect_url = add_query_arg(array('loggedin' => 'true'), $redirect_url);

            if (gj_option('verify_account')) {
                $user = GJ_User::get_user();
                if (!$user->is_verified()) {
                    $redirect_url = gj_get_page_permalink('verify');
                }
            }

            $data = apply_filters('gj_logged_in', array(
                'success' => true,
                'message' => esc_html__('Login successful, redirecting...', 'gj'),
                'redirect_url' => $redirect_url
            ));

            return new WP_REST_Response($data);
        }
    }

    static function lostpass() {

        $user_login = sanitize_text_field($_POST['user_login']);
        if (!$user_login) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Please enter Email Or Username.', 'gj')
            ));
        }

        if (is_email($user_login)) {
            if (!email_exists($user_login)) {
                return new WP_REST_Response(array(
                    'success' => false,
                    'message' => esc_html__('There is no user registered with that email address.', 'gj')
                ));
            } else {
                $user = get_user_by('email', $user_login);
            }
        } else {
            if (!username_exists($user_login)) {
                return new WP_REST_Response(array(
                    'success' => false,
                    'message' => esc_html__('Invalid Username.', 'gj')
                ));
                exit;
            } else {
                $user = get_user_by('login', $user_login);
            }
        }

        $user = GJ_User::get_user($user);
        $user->generate_resetpass_code();
        GJ_Email::send_email('resetpass', $user);

        return new WP_REST_Response(array(
            'success' => true,
            'message' => esc_html__('Please Check your email for the confirmation link.', 'gj')
        ));
    }

    static function resetpass() {

        $password = sanitize_text_field($_POST['password']);
        $password_confirm = sanitize_text_field($_POST['password_confirm']);
        $user = sanitize_text_field($_POST['user']);
        $code = sanitize_text_field($_POST['code']);

        if (!GJ_User::can_reset_password($user, $code)) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('You do not have permission to change the password.', 'gj')
            ));
        }

        if (!$password) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Please enter password.', 'gj')
            ));
        }

        if (strlen($password) < 6) {
            $return['message'] = esc_html__('Password length of at least 6 characters.', 'gj');
            $return['success'] = false;
            echo json_encode($return);
        }

        if ($password !== $password_confirm) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Confirm password does not match.', 'gj')
            ));
        }

        $user = get_user_by('login', $user);
        $update_user_data = array(
            'ID' => $user->ID,
            'user_pass' => $password
        );
        wp_update_user($update_user_data);

        $user = GJ_User::get_user($user);
        $user->delete_resetpass_code();

        return new WP_REST_Response(array(
            'success' => true,
            'redirect_url' => gj_get_page_permalink('login'),
            'message' => esc_html__('You have successfully changed your password.', 'gj')
        ));
    }

    static function change_email() {
        $email = sanitize_email($_POST['email']);

        if (!$email) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Please enter your email.', 'gj')
            ));
        }

        if (email_exists($email)) {
            $return['message'] = esc_html__('This email has already been used by another user.', 'gj');
            $return['success'] = false;
            return new WP_REST_Response($return);
        }

        $update_user_data = array(
            'ID' => get_current_user_id(),
            'user_email' => $email,
        );

        wp_update_user($update_user_data);
        clean_user_cache(get_current_user_id());

        $user = GJ_User::get_user(null, true);

        GJ_Email::send_email('verify_account', array('user' => $user));

        return new WP_REST_Response(array(
            'success' => true,
            'message' => esc_html__('An email was sent to your email please click the activation link to verify your account!', 'gj')
        ));
    }

    static function delete_account() {
        $user = wp_get_current_user();
        if (GJ_PREVIEW_MODE && ($user->user_login == 'employer' || $user->user_login == 'candidate')) {
            $return['message'] = esc_html__('Sorry you cannot delete this account.', 'gj');
            $return['success'] = false;
            return new WP_REST_Response($return);
        }

        $user = GJ_User::get_user();
        $move_to_user = '';
        if (gj_option('keep_posts_delete_user')) {
            $move_to_user = gj_option('keep_posts_user_id', 1);
        }

        if (wp_delete_user(get_current_user_id(), $move_to_user)) {

            GJ_Email::send_email('delete_account', array('user' => $user));

            return new WP_REST_Response(array(
                'success' => true,
                'redirect_url' => add_query_arg(array('deleted_user' => 'true'), home_url('/')),
                'message' => esc_html__('An email was sent to your email please click the activation link to verify your account!', 'gj')
            ));
        }

        return new WP_REST_Response(array(
            'success' => false,
            'message' => esc_html__('Can not delete account please reload the page and try again.', 'gj')
        ));
    }

    static function contact($request) {

        $data = apply_filters('gj_before_contact', null, $request);

        if ($data !== null) {
            return new WP_REST_Response($data);
        }

        $item_id = $request['ID'];
        if (!$item_id) {
            $data = array(
                'success' => false,
                'message' => esc_html__('Invalid Item.', 'gj')
            );

            return new WP_REST_Response(apply_filters('gj_contact', $data, $request));
        }

        $name = isset($_POST['name']) ? stripslashes(sanitize_text_field($_POST['name'])) : '';
        $email = isset($_POST['email']) ? stripslashes(sanitize_email($_POST['email'])) : '';
        $message = isset($_POST['message']) ? stripslashes(wp_kses_post($_POST['message'])) : '';

        if (!$message) {
            $data = array(
                'success' => false,
                'message' => esc_html__('Please enter a message.', 'gj')
            );

            return new WP_REST_Response(apply_filters('gj_contact', $data, $request));
        }

        $user_captchas = (array) gj_option('use_recaptcha');
        $captcha_respon = GJ_API_Controller::check_recaptcha(in_array('contact', $user_captchas));

        if ($captcha_respon !== true) {

            $data = array(
                'success' => false,
                'message' => esc_html__('Wrong captcha', 'gj')
            );

            return new WP_REST_Response(apply_filters('gj_contact', $data, $request));
        }

        $email_data = array(
            'item_id' => $item_id,
            'name' => $name,
            'email' => $email,
            'message' => $message,
        );

        GJ_Email::send_email('contact', $email_data);

        $data = array(
            'success' => true,
            'message' => esc_html__('Sent successfully.', 'gj')
        );

        return new WP_REST_Response(apply_filters('gj_contact', $data, $request));
    }

    static function submit_post($request) {
        $data = apply_filters('gj_before_submit_post', null, $request);

        if ($data) {
            return new WP_REST_Response($data);
        }

        $postType = isset($_POST['postType']) ? sanitize_text_field($_POST['postType']) : '';
        $status = 'draft';

        if ($postType == 'gj_application') {
            $status = 'pending';
        } elseif ($postType == 'gj_candidate') {
            $status = current_user_can('administrator') ? 'publish' : (gj_option('candidate_auto_approved') ? 'publish' : 'pending');
        } elseif ($postType == 'gj_employer') {
            $status = current_user_can('administrator') ? 'publish' : (gj_option('employer_auto_approved') ? 'publish' : 'pending');
        }

        if ($postType === 'gj_application') {
            $jobID = intval($_POST['jobID']);
            if (!$jobID) {
                return new WP_REST_Response(array('success' => false, 'message' => 'Empty job ID'), 412);
            }
        }

        $postTitle = isset($_POST['title']) ? sanitize_title($_POST['title']) : time();

        $post_data = array(
            'post_title' => $postTitle,
            'post_content' => '',
            'post_type' => $postType,
            'post_status' => $status,
            'post_author' => get_current_user_id(),
        );

        $postID = wp_insert_post($post_data);

        if ($postID) {
            $fieldHelper = new GJ_Fields();
            $fields = $fieldHelper->getFields($postID, $postType);
            if ($fields) {
                foreach ($fields as $field) {
                    if (is_admin() && ($field->getSetting('showInput') === 'both' || $field->getSetting('showInput') === 'backend')) {
                        $field->save();
                    } elseif (!is_admin() && ($field->getSetting('showInput') === 'both' || $field->getSetting('showInput') === 'dashboard')) {
                        $field->save();
                    }
                }
            }

            if ($postType === 'gj_application') {
                update_post_meta($postID, GJ_PREFIX . 'job_id', $jobID);
            } else {
                if ($postType === 'gj_job') {
                    if (!isset($_POST['salary_from'])) {
                        update_post_meta($postID, 'salary_from', '');
                    }
                    if (!isset($_POST['salary_to'])) {
                        update_post_meta($postID, 'salary_to', '');
                    }
                }

                update_post_meta($postID, GJ_PREFIX . 'featured', '');
            }

            $post = GJ_Post::get_post($postID);

            if ($postType == 'gj_employer' && $status == 'pending') {
                $employer = GJ_Employer::get_employer($post);
                GJ_Email::send_email('review_company', $employer);
            } elseif ($postType == 'gj_candidate' && $status == 'pending') {
                $candidate = GJ_Candidate::get_candidate($post);
                GJ_Email::send_email('review_resume', $candidate);
            }

            $data = array('success' => true, 'postID' => $postID, 'permalink' => $post->permalink());
        } else {
            $data = array('success' => false, 'postID' => '');
        }

        return new WP_REST_Response(apply_filters('gj_after_submit_post', $data, $postID));
    }

    static function edit_post($request) {

        $data = apply_filters('gj_before_edit_post', null, $request);
        if ($data) {
            return new WP_REST_Response($data);
        }

        $postID = $request['ID'];
        $postType = get_post_type($postID);
        $fieldHelper = new GJ_Fields();
        $fields = $fieldHelper->getFields($postID, $postType);
        if ($fields) {
            foreach ($fields as $field) {
                if (is_admin() && ($field->getSetting('showInput') === 'both' || $field->getSetting('showInput') === 'backend')) {
                    $field->save();
                } elseif (!is_admin() && ($field->getSetting('showInput') === 'both' || $field->getSetting('showInput') === 'dashboard')) {
                    $field->save();
                }
            }
        }

        $result = array();
        if ($postType == 'gj_job') {
            $job = GJ_Job::get_job($postID);
            if ($job->has_status('publish')) {
                $is_free = $job->is_free();
                $auto_approved = current_user_can('administrator') ? true : ($is_free ? gj_option('edit_free_job_auto_approved') : gj_option('edit_job_auto_approved'));
                if (!$auto_approved) {
                    $job->change_status('pending');
                    $result['status'] = 'pending';
                } else {
                    $result['status'] = 'publish';
                }
            } elseif ($job->has_status('rejected')) {
                $job->change_status('pending');
                $result['status'] = 'pending';
            } else {
                $result['status'] = $job->get_status();
            }

            $result['permalink'] = $job->permalink();
        } elseif ($postType == 'gj_employer') {
            $employer = GJ_Employer::get_employer($postID);
            if ($employer->has_status('publish')) {
                $auto_approved = current_user_can('administrator') ? true : gj_option('edit_employer_auto_approved');
                if (!$auto_approved) {
                    $employer->change_status('pending');
                    $result['status'] = 'pending';
                } else {
                    $result['status'] = 'publish';
                }
            } elseif ($employer->has_status('rejected')) {
                $employer->change_status('pending');
                $result['status'] = 'pending';
            } else {
                $result['status'] = $employer->get_status();
            }
            $result['permalink'] = $employer->permalink();
        } elseif ($postType == 'gj_candidate') {
            $candidate = GJ_Candidate::get_candidate($postID);
            if ($candidate->has_status('publish')) {
                $auto_approved = current_user_can('administrator') ? true : gj_option('edit_candidate_auto_approved');
                //var_dump($auto_approved); die();
                if (!$auto_approved) {
                    $candidate->change_status('pending');
                    $result['status'] = 'pending';
                } else {
                    $result['status'] = 'publish';
                }
            } elseif ($candidate->has_status('rejected')) {
                $candidate->change_status('pending');
                $result['status'] = 'pending';
            } else {
                $result['status'] = $candidate->get_status();
            }
            $result['permalink'] = $candidate->permalink();
        }

        $result['postID'] = $postID;

        if ($result['status'] == 'publish') {
            $result['message'] = esc_html__('Your job has been updated.', 'gj');
        } elseif ($result['status'] == 'pending') {
            $result['message'] = esc_html__('Thank you for editing. We will check it asap!', 'gj');
        }

        $result = apply_filters('gj_after_edit_post', $result, $postID);

        return new WP_REST_Response($result);
    }

    static function delete_post($request) {

        $data = apply_filters('gj_before_delete_post', null, $request);
        if ($data) {
            return new WP_REST_Response($data);
        }

        $ID = $request['ID'];
        if (wp_delete_post($ID, true)) {
            $data = array(
                'success' => true,
                'message' => esc_html__('Deleted successfully.', 'gj')
            );
        } else {
            $data = array(
                'success' => false,
                'message' => esc_html__('An error occurred during the execution please reload the page and try again.', 'gj')
            );
        }

        return new WP_REST_Response(apply_filters('gj_after_delete_post', $data, $ID));
    }

    static function save_job($request) {

        $id = $request['ID'];
        $user = GJ_User::get_user();
        $user->save_job($id);

        return new WP_REST_Response(array(
            'success' => true,
            'text' => wp_kses_post('<i class="fa fa-heart"></i><span>Saved</span>', 'gj'),
            'message' => esc_html__('Saved job successfully!', 'gj')
        ));
    }

    static function unsave_job($request) {
        $id = $request['ID'];
        $user = GJ_User::get_user();
        $user->undo_save_job($id);

        return new WP_REST_Response(array(
            'success' => true,
            'text' => wp_kses_post('<i class="far fa-heart"></i><span>Save</span>'),
            'message' => esc_html__('Delete successfully!', 'gj')
        ));
    }

    static function jobs() {
        return new WP_REST_Response(array());
    }

    static function candidates() {
        return new WP_REST_Response(array());
    }

    static function employers() {
        return new WP_REST_Response(array());
    }

    static function follow_employer($request) {

        $id = $request['ID'];
        $user = GJ_User::get_user();
        if (!$user->is_followed($id)) {
            $user->follow($id);
        }

        return new WP_REST_Response(array(
            'success' => true,
            'text' => esc_html__('Followed', 'gj'),
            'message' => esc_html__('Followed successfully!', 'gj')
        ));
    }

    static function unfollow_employer($request) {
        $id = $request['ID'];
        $user = GJ_User::get_user();
        $user->unfollow($id);

        return new WP_REST_Response(array(
            'success' => true,
            'text' => esc_html__('Follow', 'gj'),
            'message' => esc_html__('UnFollowed successfully!', 'gj'),
        ));
    }

    static function save_resume($request) {
        $id = $request['ID'];
        $user = GJ_User::get_user();
        $user->save_resum($id);

        return new WP_REST_Response(array(
            'success' => true,
            'text' => wp_kses_post('<i class="fa fa-heart"></i><span>Saved</span>', 'gj'),
            'message' => esc_html__('Saved successfully!', 'gj'),
        ));
    }

    static function unsave_resume($request) {
        $id = $request['ID'];
        $user = GJ_User::get_user();
        $user->delete_save_resum($id);

        return new WP_REST_Response(array(
            'success' => true,
            'text' => wp_kses_post('<i class="far fa-heart"></i><span>Save</span>', 'gj'),
            'message' => esc_html__('Deleted successfully!', 'gj')
        ));
    }

    static function send_application_email($request) {

        $application_id = sanitize_text_field($request['ID']);
        $application = GJ_Application::get_application($application_id);

        $subject = stripslashes(sanitize_text_field($_POST['subject']));
        $content = stripslashes(wp_kses_post($_POST['content']));

        if (!$subject) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Please enter email subject', 'gj')
            ));
        }
        if (!$content) {
            return new WP_REST_Response(array(
                'success' => false,
                'message' => esc_html__('Please enter email content', 'gj')
            ));
        }

        $email_data = array(
            'application_id' => $application_id,
            'subject' => $subject,
            'content' => $content,
        );

        GJ_Email::send_email('application', $email_data);

        return new WP_REST_Response(array(
            'success' => true,
            'message' => sprintf(esc_html__('Email has been sent to %s.', 'gj'), $application->get_full_name())
        ));
    }

    static function application_note($request) {

        $application_id = sanitize_text_field($request['ID']);
        $application = GJ_Application::get_application($application_id);

        $note = stripslashes(wp_kses_post($_POST['note']));

        $application->note($note);

        return new WP_REST_Response(array(
            'success' => true,
        ));
    }

    static function application_change_status($request) {

        $application_id = sanitize_text_field($request['ID']);
        $application = GJ_Application::get_application($application_id);

        $status = stripslashes(wp_kses_post($_POST['status']));

        $application->change_status($status);

        return new WP_REST_Response(array(
            'success' => true,
        ));
    }

    static function application_quick_view($request) {
        $application_id = $request['ID'];
        $application = GJ_Application::get_application($application_id);
        $html = gj_get_template_part('dashboard/application/popup', array('application' => $application), true);

        return new WP_REST_Response(array(
            'success' => true,
            'html' => $html
        ));
    }

    static function publish_job($request) {
        ini_set('display_errors', 1);
        ini_set('display_startup_errors', 1);
        error_reporting(E_ALL);
        $job_id = $request['ID'];

        $response = apply_filters('gj_before_publish_job', null, $job_id);
        if ($response !== null) {
            return new WP_REST_Response($response);
        }

        $job = GJ_Job::get_job($job_id);
        $never_expiry = $job->is_never_expiry();
        $expiry_date = $job->get_expiry();

        $data = array(
            'success' => false,
        );

        if (current_user_can('administrator') || $never_expiry || (!$never_expiry && $expiry_date > current_time('timestamp'))) {
            $job->change_status('publish', false);

            $data = array(
                'success' => true,
                'status' => 'publish',
                'message' => esc_html__('your job has been published.', 'gj'),
                'permalink' => $job->permalink()
            );
        } elseif (gj_option('submit_job_mode') == 'single') {
            $submit_price = gj_option('job_price');
            if ((float) $submit_price > 0) {
                $cart = new GJ_Cart();
                $product = new GJ_Product('newjob', array('item_id' => $job_id));
                $cart->add($product);

                $data = array(
                    'success' => false,
                    'redirect' => $cart->checkout()
                );
            } else {
                update_post_meta($job_id, GJ_PREFIX . 'is_free', '1');
                if (gj_option('new_free_job_auto_approved')) {
                    $job->change_status('publish', false);
                    $data = array(
                        'success' => true,
                        'status' => 'publish',
                        'message' => esc_html__('your job has been published.', 'gj'),
                        'permalink' => $job->permalink()
                    );
                } else {
                    $job->change_status('pending');
                    $data = array(
                        'success' => true,
                        'status' => 'pending',
                        'message' => esc_html__('Thank you for submitting, your job is waiting approve.', 'gj'),
                        'permalink' => $job->permalink()
                    );
                }
            }
        } else {
            //is free job mode
            update_post_meta($job_id, GJ_PREFIX . 'free_job', '1');
            if (gj_option('new_free_job_auto_approved')) {
                $job->change_status('publish', false);
                $data = array(
                    'success' => true,
                    'status' => 'publish',
                    'message' => esc_html__('your job has been published.', 'gj'),
                    'permalink' => $job->permalink()
                );
            } else {
                $job->change_status('pending');
                $data = array(
                    'success' => true,
                    'status' => 'pending',
                    'message' => esc_html__('Thank you for submitting, your job is waiting approve.', 'gj'),
                    'permalink' => $job->permalink()
                );
            }
        }

        $data = apply_filters('gj_after_publish_job', $data, $job_id);

        return new WP_REST_Response($data);
    }

    static function draft_job($request) {
        $job_id = $request['ID'];
        $job = GJ_Job::get_job($job_id);
        $job->change_status('draft', false);
        $data = array(
            'success' => true,
        );

        return new WP_REST_Response($data);
    }

    static function featured_job($request) {
        $job_id = $request['ID'];

        $response = apply_filters('gj_before_featured_job', null, $job_id);
        if ($response !== null) {
            return new WP_REST_Response($response);
        }

        $job = GJ_Job::get_job($job_id);

        if (current_user_can('administrator')) {
            $job->set_featured();
            $data = array(
                'success' => true,
                'message' => esc_html__('your job has been made featured.', 'gj'),
                'permalink' => $job->permalink()
            );
        } else {
            if (gj_option('featured_job_price') > 0) {

                $cart = new GJ_Cart();
                $product = new GJ_Product('featuredjob', array('item_id' => $job_id));
                $cart->add($product);

                $data = array(
                    'success' => false,
                    'redirect' => $cart->checkout()
                );
            } else {
                $product = new GJ_Product('featuredjob', array('item_id' => $job_id));
                $product->completed_order();
                $data = array(
                    'success' => true,
                    'message' => esc_html__('your job has been made featured.', 'gj'),
                    'permalink' => $job->permalink()
                );
            }
        }

        $data = apply_filters('gj_after_featured_job', $data, $job_id);

        return new WP_REST_Response($data);
    }

    static function unfeatured_job($request) {
        $job_id = $request['ID'];

        $response = apply_filters('gj_before_unfeatured_job', null, $job_id);
        if ($response !== null) {
            return new WP_REST_Response($response);
        }

        $job = GJ_Job::get_job($job_id);
        $job->unfeatured();

        $data = apply_filters('gj_after_unfeatured_job', array(
            'success' => true,
            'message' => esc_html__('your job has been unfeatured.', 'gj'),
            'permalink' => $job->permalink()
                ), $job_id);

        return new WP_REST_Response($data);
    }

    static function renew_job($request) {

        $job_id = $request['ID'];

        $response = apply_filters('gj_before_renew_job', null, $job_id);
        if ($response !== null) {
            return new WP_REST_Response($response);
        }

        $job = GJ_Job::get_job($job_id);

        if (gj_option('renew_job_price') <= 0) {
            $product = new GJ_Product('renewjob', array('item_id' => $job_id));
            $product->completed_order();
            $data = array(
                'success' => true,
                'message' => esc_html__('Your job has been renewed.', 'gj'),
                'permalink' => $job->permalink()
            );
        } else {
            $cart = new GJ_Cart();
            $product = new GJ_Product('renewjob', array('item_id' => $job_id));
            $cart->add($product);
            $data = array(
                'success' => false,
                'redirect' => $cart->checkout()
            );
        }

        $data = apply_filters('gj_after_renew_job', $data, $job_id);

        return new WP_REST_Response($data);
    }

    static function change_job_status($request) {
        $job_id = intval($request['ID']);
        $new_status = sanitize_text_field($_POST['status']);
        $job = GJ_Job::get_job($job_id);
        if ($job) {
            if ($new_status == 'gj-rejected') {
                $reason = sanitize_textarea_field($_POST['reason']);
                update_post_meta($job_id, GJ_PREFIX . 'reason', $reason);
            }
            $send_email = $new_status == 'pending' ? false : true;
            $job->change_status($new_status, $send_email);
            return new WP_REST_Response(array(
                'success' => true,
            ));
        }
        return new WP_REST_Response(array(
            'success' => false,
        ));
    }

    static function publish_employer($request) {

        $id = $request['ID'];

        $response = apply_filters('gj_before_publish_employer', null, $id);
        if ($response !== null) {
            return new WP_REST_Response($response);
        }

        $employer = GJ_Employer::get_employer($id);

        if (current_user_can('administrator')) {
            $employer->change_status('publish', false);

            $data = array(
                'success' => true,
                'status' => 'publish',
                'message' => esc_html__('Your company has been published.', 'gj'),
                'permalink' => $employer->permalink()
            );
        } else {
            $employer->change_status('pending');
            $data = array(
                'success' => true,
                'status' => 'pending',
                'message' => esc_html__('Thank you for submitting, your company is waiting approve.', 'gj'),
                'permalink' => $employer->permalink()
            );
        }

        $data = apply_filters('gj_after_publish_employer', $data, $id);

        return new WP_REST_Response($data);
    }

    static function featured_employer($request) {
        $employer_id = $request['ID'];
        $employer = GJ_Employer::get_employer($employer_id);
        if ($employer) {
            $employer->set_featured();
            return new WP_REST_Response(array(
                'success' => true,
            ));
        }

        return new WP_REST_Response(array(
            'success' => false,
        ));
    }

    static function unfeatured_employer($request) {
        $employer_id = $request['ID'];
        $employer = GJ_Employer::get_employer($employer_id);
        if ($employer) {
            $employer->unfeatured();
            return new WP_REST_Response(array(
                'success' => true,
            ));
        }

        return new WP_REST_Response(array(
            'success' => false,
        ));
    }

    static function change_employer_status($request) {

        $id = sanitize_text_field($request['ID']);
        $employer = GJ_Employer::get_employer($id);

        $status = stripslashes(wp_kses_post($_POST['status']));
        if ($status == 'gj-rejected') {
            $reason = sanitize_textarea_field($_POST['reason']);
            update_post_meta($id, GJ_PREFIX . 'reason', $reason);
        }

        $employer->change_status($status);

        return new WP_REST_Response(array(
            'success' => true,
        ));
    }

    static function publish_candidate($request) {

        $id = $request['ID'];

        $response = apply_filters('gj_before_publish_candidate', null, $id);
        if ($response !== null) {
            return new WP_REST_Response($response);
        }

        $candidate = GJ_Candidate::get_candidate($id);

        if (current_user_can('administrator')) {
            $candidate->change_status('publish', false);

            $data = array(
                'success' => true,
                'status' => 'publish',
                'message' => esc_html__('Your resume has been published.', 'gj'),
                'permalink' => $candidate->permalink()
            );
        } else {
            $candidate->change_status('pending');
            $data = array(
                'success' => true,
                'status' => 'pending',
                'message' => esc_html__('Thank you for submitting, your resume is waiting approve.', 'gj'),
                'permalink' => $candidate->permalink()
            );
        }

        $data = apply_filters('gj_after_publish_candidate', $data, $id);

        return new WP_REST_Response($data);
    }

    static function featured_candidate($request) {
        $id = $request['ID'];
        $candidate = GJ_Candidate::get_candidate($id);
        if ($candidate) {
            $candidate->set_featured();
            return new WP_REST_Response(array(
                'success' => true,
            ));
        }

        return new WP_REST_Response(array(
            'success' => false,
        ));
    }

    static function unfeatured_candidate($request) {
        $id = $request['ID'];
        $candidate = GJ_Candidate::get_candidate($id);
        if ($candidate) {
            $candidate->unfeatured();
            return new WP_REST_Response(array(
                'success' => true,
            ));
        }

        return new WP_REST_Response(array(
            'success' => false,
        ));
    }

    static function change_candidate_status($request) {

        $id = sanitize_text_field($request['ID']);
        $candidate = GJ_Candidate::get_candidate($id);

        $status = stripslashes(wp_kses_post($_POST['status']));
        if ($status == 'gj-rejected') {
            $reason = sanitize_textarea_field($_POST['reason']);
            update_post_meta($id, GJ_PREFIX . 'reason', $reason);
        }
        $candidate->change_status($status);

        return new WP_REST_Response(array(
            'success' => true,
        ));
    }

    static function filter_cities($request) {
        $args = array(
            'hide_empty' => isset($_REQUEST['hide_empty']) ? sanitize_text_field($_REQUEST['hide_empty']) : false,
            'orderby' => isset($_REQUEST['orderby']) ? sanitize_text_field($_REQUEST['orderby']) : 'name',
            'order' => isset($_REQUEST['order']) ? sanitize_text_field($_REQUEST['order']) : 'ASC',
            'number' => isset($_REQUEST['number']) ? sanitize_text_field($_REQUEST['number']) : false,
            'taxonomy' => 'gj_city',
        );

        if (isset($_REQUEST['state']) && $_REQUEST['state']) {
            $args['meta_query'] = array(
                array(
                    'key' => 'state',
                    'value' => intval($_REQUEST['state']),
                    'compare' => '='
                )
            );
        }

        $terms = get_terms($args);

        if (isset($_REQUEST['filters']) && $_REQUEST['filters']) {

            $term_ids = wp_list_pluck($terms, 'term_id');
            $type = sanitize_text_field($_REQUEST['post_type']);
            $_filters = gj_clean($_REQUEST['filters']);

            switch ($type) {
                case 'gj_candidate':
                    $filters = GJ_Candidate_Listing::instance()->get_data_filters($_filters);
                    break;
                case 'gj_employer':
                    $filters = GJ_Employer_Listing::instance()->get_data_filters($_filters);
                    break;
                default:
                    $filters = GJ_Job_Listing::instance()->get_data_filters($_filters);
                    break;
            }

            $counts = gj_count_item_by_taxonomy($filters, $term_ids);
            gj_map_terms_with_counter($terms, $counts);
        }

        unset($args['number']);
        $count = wp_count_terms('gj_city', $args);

        return new WP_REST_Response(array('terms' => $terms, 'count' => $count), 200);
    }

    static function filter_jobs($request) {
        ini_set('display_errors', 1);
        ini_set('display_startup_errors', 1);
        error_reporting(E_ALL);

        $listings = GJ_Job_Listing::instance();
        $data_filters = $listings->get_data_filters();
        $query = $listings->get_query($data_filters);
        $html = gj_get_template_part('parts/jobs/jobs', array('query' => $query, 'paged' => $data_filters['paged']), true);
        $filtered_html = gj_get_template_part('parts/jobs/filtered', array(), true);
        $url = $listings->get_request_url($data_filters);
        $feed_url = $listings->get_feed_url($data_filters);

        $enable_job_counts = true;
        $counts = array();
        if ($enable_job_counts && isset($_REQUEST['counter_term_ids'])) {
            $counter_term_ids = gj_clean($_REQUEST['counter_term_ids']);
            if ($counter_term_ids) {
                $counts = gj_count_item_by_taxonomy($data_filters, $counter_term_ids);
            }
        }

        $data = array('html' => $html, 'filtered_html' => $filtered_html, 'total' => $query->found_posts, 'counts' => $counts, 'url' => $url, 'feed_url' => $feed_url);

        return new WP_REST_Response(apply_filters('gj_filter_jobs', $data, $data_filters));
    }

    static function filter_employers($request) {
        $listings = GJ_Employer_Listing::instance();
        $data_filters = $listings->get_data_filters();
        $query = $listings->get_query($data_filters);
        $html = gj_get_template_part('parts/employers/employers', array('query' => $query, 'paged' => $data_filters['paged']), true);
        $filtered_html = gj_get_template_part('parts/employers/filtered', array(), true);
        $url = $listings->get_request_url($data_filters);
        $feed_url = $listings->get_feed_url($data_filters);

        $enable_job_counts = true;
        $counts = array();
        if ($enable_job_counts && isset($_REQUEST['counter_term_ids'])) {
            $counter_term_ids = gj_clean($_REQUEST['counter_term_ids']);
            if ($counter_term_ids) {
                $counts = gj_count_item_by_taxonomy($data_filters, $counter_term_ids);
            }
        }

        $data = array('html' => $html, 'filtered_html' => $filtered_html, 'total' => $query->found_posts, 'counts' => $counts, 'url' => $url, 'feed_url' => $feed_url);

        return new WP_REST_Response(apply_filters('gj_filter_employers', $data, $data_filters));
    }

    static function filter_candidates($request) {
        $listings = GJ_Candidate_Listing::instance();
        $data_filters = $listings->get_data_filters();
        $query = $listings->get_query($data_filters);
        $html = gj_get_template_part('parts/candidates/candidates', array('query' => $query, 'paged' => $data_filters['paged']), true);
        $filtered_html = gj_get_template_part('parts/candidates/filtered', array(), true);
        $url = $listings->get_request_url($data_filters);
        $feed_url = $listings->get_feed_url($data_filters);

        $enable_job_counts = true;
        $counts = array();
        if ($enable_job_counts && isset($_REQUEST['counter_term_ids'])) {
            $counter_term_ids = gj_clean($_REQUEST['counter_term_ids']);
            if ($counter_term_ids) {
                $counts = gj_count_item_by_taxonomy($data_filters, $counter_term_ids);
            }
        }

        $data = array('html' => $html, 'filtered_html' => $filtered_html, 'total' => $query->found_posts, 'counts' => $counts, 'url' => $url, 'feed_url' => $feed_url);

        return new WP_REST_Response(apply_filters('gj_filter_candidates', $data, $data_filters));
    }

}
