<?php
/**
 *
 * @class 		GJ_Application
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Application{
    static $cache = array();

    public $post;

    public function __construct($post)
    {
        $this->post = $post;
    }

    /**
     * @param string|object $post
     * @param bool $force
     * @return GJ_Application|null
     */
    static function get_application($post = null, $force = false){
        $post_id = 0;
        if($post === null){
            $post = get_post();
        }
        if(is_numeric($post)){
            $post = get_post($post);
            if($post && !is_wp_error($post)){
                $post_id = $post->ID;
            }
        }
        elseif(is_object($post))
        {
            $post_id = $post->ID;
        }

        if($post_id){

            if($force){
                clean_post_cache( $post_id );
                $post = get_post($post_id);
            }

            if($force || !isset(self::$cache[$post_id])){
                self::$cache[$post_id] = new GJ_Application($post);
            }

            return self::$cache[$post_id];
        }

        return null;
    }
    
    public function get_id(){
        return $this->post->ID;
    }

    public function get_status(){
        return $this->post->post_status;
    }

    public function get_title($original = false){
        if($original){
            return $this->post->post_title;
        }

        return get_the_title($this->post->ID);
    }

    public function get_full_name(){
        return $this->get_title();
    }

    public function get_email(){
        return get_post_meta($this->get_id(), 'email', true);
    }

    public function get_candidate(){ 
        $resume = get_post_meta($this->get_id(), 'resume', true);
        if($resume){
            return GJ_Candidate::get_candidate($resume);
        }

        return null;
    }

    public function get_cv(){
        $cv = get_post_meta($this->get_id(), 'cv', true);
        if ( ! $path = get_attached_file( $cv ) ) {
            return null;
        }

        return wp_parse_args( array(
            'ID'    => $cv,
            'name'  => basename( $path ),
            'path'  => $path,
            'url'   => wp_get_attachment_url( $cv ),
            'title' => get_the_title( $cv ),
        ), wp_get_attachment_metadata( $cv ) );
    }

    public function get_cv_url(){
        $cv = get_post_meta($this->get_id(), 'cv', true);
        if ( $cv ) {
            return wp_get_attachment_url( $cv );
        }

        return null;
    }

    public function get_cv_path(){
        $cv = get_post_meta($this->get_id(), 'cv', true);
        if ( $cv ) {
            return get_attached_file( $cv );
        }

        return null;
    }

    public function get_created($format = ''){
        if(!$format){
            $format = get_option('date_format');
        }
        if($this->post->post_date){
            return date_i18n($format, strtotime($this->post->post_date));
        }

        return '';
    }

    public function get_message($filter = true){
        $content = $this->post->post_content;

        if($filter){
            $content = strip_shortcodes($content);
            $content = apply_filters('the_content', $content);
        }

        return $content;
    }
    public function get_private_note(){
        return get_post_meta($this->get_id(), GJ_PREFIX.'private_note', true);
    }
    public function get_source(){
        $source = get_post_meta($this->get_id(), GJ_PREFIX.'source', true);
        if(!$source){
            $source = 'form';
        }

        return $source;
    }

    public function get_author_id(){
        return $this->post->post_author;
    }

    public function get_author(){
        return GJ_User::get_user($this->get_author_id());
    }

    public function view_permalink(){
        $url = gj_dashboard_endpoint_url("application");

        $permalink = get_option( 'permalink_structure' );
        if(substr($permalink, -12) === '/%postname%/'){
            $url = $url."/".$this->get_id();
        }else{
            $url = add_query_arg(array('postID' => $this->get_id()), $url);
        }

        return $url;
    }

    public function get_job_id(){
        return get_post_meta($this->get_id(), GJ_PREFIX.'job_id', true);
    }

    public function get_job(){
        return GJ_Job::get_job($this->get_job_id());
    }

    public function is_job_author(){
        $job = $this->get_job();
        if($job && $job->get_author_id() != get_current_user_id()){
            return false;
        }

        return true;
    }

    public function is_author(){
        if($this->get_author_id() != get_current_user_id()){
            return false;
        }

        return true;
    }

    public function can_view(){
        $job = $this->get_job();
        if(current_user_can('administrator') || $job && $job->get_author_id() == get_current_user_id()){
            return true;
        }

        return false;
    }


    public function note($private_note){
        update_post_meta($this->get_id(), GJ_PREFIX.'private_note', $private_note);
    }

    public function change_status($status){

        if($status == 'pending' || $status == 'publish' || $status == 'gj-rejected'){
            wp_update_post(array(
                'ID' => $this->get_id(),
                'post_status' => $status
            ));
        }
    }

    function get_field_value($field_name){
        $value = get_post_meta($this->get_id(), GJ_PREFIX.$field_name, true);
        return apply_filters('gj_application_field_value', $value, $this);
    }

    static function get_status_array(){
        return array(
            'publish' => esc_html__('Approved', 'gj'),
            'pending' => esc_html__('Pending', 'gj'),
            'gj-rejected' => esc_html__('Rejected', 'gj'),
        );
    }

    static function get_status_title($status){
        $status_arr = self::get_status_array();
        if(isset($status_arr[$status])){
            return $status_arr[$status];
        }

        return '';
    }

    static function get_emails(){
        $application_emails = array();
        $application_emails['interview'] = array(
            'id' => 'interview',
            'title' => esc_html__('Interview Letter', 'gj'),
            'subject' => gj_option('email_application_interview_subject'),
            'content' => gj_option('email_application_interview_content'),
        );
        $application_emails['accept'] = array(
            'id' => 'accept',
            'title' => esc_html__('Accept Letter', 'gj'),
            'subject' => gj_option('email_application_accept_subject'),
            'content' => gj_option('email_application_accept_content'),
        );
        $application_emails['reject'] = array(
            'id' => 'reject',
            'title' => esc_html__('Reject Letter', 'gj'),
            'subject' => gj_option('email_application_reject_subject'),
            'content' => gj_option('email_application_reject_content'),
        );

        return apply_filters('gj_application_emails', $application_emails);
    }

}