<?php
/**
 *
 * @class 		GJ_Candidate
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Candidate extends GJ_Post{

    /**
     * @param string|object $post
     * @param bool $force
     * @return GJ_Candidate|null
     */
    static function get_candidate($post = null, $force = false){
        return parent::get_post($post, $force);
    }

    public function get_edit_url(){
        $url = gj_dashboard_endpoint_url("edit-candidate");

        $permalink = get_option( 'permalink_structure' );
        if(substr($permalink, -12) === '/%postname%/'){
            $url = $url."/".$this->get_id();
        }else{
            $url = add_query_arg(array('postID' => $this->get_id()), $url);
        }

        return $url;
    }

    function get_headline(){
        return get_post_meta($this->get_id(), 'headline', true);
    }

    function hour_rate(){
        return get_post_meta($this->get_id(), 'hour_rate', true);
    }

    function get_birthday(){
        return get_post_meta($this->get_id(), 'birthday', true);
    }

    function get_gender(){
	    return get_post_meta( $this->get_id(), 'gender', true );
    }

    function can_update(){
        if(get_current_user_id() == $this->get_author_id()){
            return true;
        }

        return false;
    }

    function get_cv(){
        $cv = get_post_meta($this->get_id(), 'cv', true);
        if ( ! $path = get_attached_file( $cv ) ) {
            return false;
        }

        return wp_parse_args( array(
            'ID'    => $cv,
            'name'  => get_the_title( $cv ),
            'path'  => $path,
            'url'   => wp_get_attachment_url( $cv ),
            'title' => get_the_title( $cv ),
        ), wp_get_attachment_metadata( $cv ) );
    }

    function get_cv_url(){
        $cv = get_post_meta($this->get_id(), 'cv', true);
        $url = "";
        if($cv){
            $url = wp_get_attachment_url( $cv );
        }

        return apply_filters('gj_cv_url', $url);
    }

    function get_cover_letter(){
        return get_post_meta($this->get_id(), 'cover_letter', true);
    }

    public function change_status($status, $send_email = true){

        do_action('gj_before_change_candidate_status', $status, $send_email, $this);

        global $wpdb;

        if ($status != 'draft' && $status != 'pending' && !$this->post->post_name) {
            $post_name = sanitize_title($this->post->post_title);
            $post_name = wp_unique_post_slug($post_name, $this->get_id(), $status, 'gj_candidate', 0);

            $sql = "UPDATE {$wpdb->posts} SET post_status = %s, post_name = %s WHERE ID = %d";
            $wpdb->query($wpdb->prepare($sql, $status, $post_name, $this->get_id()));
        } else {
            $sql = "UPDATE {$wpdb->posts} SET post_status = %s WHERE ID = %d";
            $wpdb->query($wpdb->prepare($sql, $status, $this->get_id()));
        }

        $old_status = $this->get_status();
        if($old_status == 'publish' || $status == 'publish'){
            delete_transient( 'gj_count_candidates' );
        }

        clean_post_cache( $this->get_id() );

        //send email
        if($send_email){
            if($status == 'publish'){
                GJ_Email::send_email('approved_resume', $this);
            }elseif($status == 'pending'){
                GJ_Email::send_email('review_resume', $this);

            }elseif($status == 'gj-rejected'){
                GJ_Email::send_email('rejected_resume', $this);
            }
        }

        do_action('gj_change_candidate_status', $status, $send_email, $this);
    }

    function get_admin_url() {

        $action = '&action=edit';

        $post_type_object = get_post_type_object( $this->post->post_type );

        if ( $post_type_object->_edit_link ) {
            $link = admin_url( sprintf( $post_type_object->_edit_link . $action, $this->get_id() ) );
        } else {
            $link = '';
        }

        return $link;
    }

    public function can_edit() {
        if (current_user_can('edit_candidate', $this->get_id())) {
            return true;
        }

        return false;
    }

    public function can_publish() {
        if (current_user_can('edit_candidate', $this->get_id())) {
            if ($this->has_status(array('draft'))) {
                return true;
            }
        }

        return false;
    }

    public function edit_link() {
        $url = gj_dashboard_endpoint_url("resume", $this->get_id());

        return $url;
    }

    static function get_status_array($draft = true) {
        $status = array(
            'publish' => esc_html__('Publish', 'gj'),
            'pending' => esc_html__('Pending', 'gj'),
            'gj-rejected' => esc_html__('Rejected', 'gj'),
        );

        if ($draft) {
            $status['draft'] = esc_html__('Draft', 'gj');
        }

        return $status;
    }

    static function get_status_title($status){
        $status_arr = self::get_status_array();
        if(isset($status_arr[$status])){
            return $status_arr[$status];
        }

        return '';
    }

    static function remove_reference($candidate_id){
        if($candidate_id && get_post_type($candidate_id) == 'gj_candidate'){

            $fields = gj_fields($candidate_id);
            if($fields){
                foreach ($fields as $field){
                    $field->deletePost();
                }
            }

            if(get_post_status() == 'publish'){
                delete_transient( 'gj_count_candidates');
            }
            global $wpdb;
            $wpdb->delete( $wpdb->prefix.'gj_save_resums', array( 'post_id' => $candidate_id,), array( '%d' ) );

            return true;
        }

        return false;
    }
}