<?php
/**
 * @class 		GJ_Controller
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Controller {

    static function init() {
        add_action('wp', array(__CLASS__, 'form_action'), 20);
        add_action('wp', array(__CLASS__, 'dashboard_permission'), 20);
        add_action('wp_loaded', array(__CLASS__, 'cancel_order'), 20);
        add_action('wp_loaded', array(__CLASS__, 'social_login'), 20);
        add_action('wp_loaded', array(__CLASS__, 'social_apply'), 20);
        add_action('wp_loaded', array(__CLASS__, 'received_payment'), 20);

        add_action('wp_loaded', array(__CLASS__, 'verify_account'), 20);
        add_action('wp_loaded', array(__CLASS__, 'send_mail_queue'), 99);
        add_action('wp_footer', array(__CLASS__, 'confirm_job_alert'));
        add_action('wp_footer', array(__CLASS__, 'unsubscribe_job_alert'));
        add_action('wp_footer', array(__CLASS__, 'show_apply_form'));
    }

    static function dashboard_permission() {
        global $post, $wp_query; 
        if ($post && $post->ID == gj_get_page_id('dashboard')) { 

            $endpoint = gj_current_dashboard_endpoint();
            $dashboard = gj_get_page_permalink('dashboard');

            $continue = apply_filters('gj_top_dashboard_permission', null, $endpoint);
            if($continue === false){
                return false;
            }

            if (!is_user_logged_in()) {
                $url = gj_get_page_permalink('login');
                $redirect = $_SERVER['REQUEST_URI'];
                if ($redirect) {
                    $url = add_query_arg('redirect_to', urlencode($redirect), $url);
                }
                wp_redirect($url);
                exit;
            } elseif (gj_option('verify_account')) {
                $user = GJ_User::get_user();
                if (!$user->is_verified()) {
                    $url = gj_get_page_permalink('verify');
                    wp_redirect($url);
                    exit;
                }
            }

            $continue = apply_filters('gj_before_dashboard_permission', null, $endpoint);
            if($continue === false){
                return false;
            }

            switch ($endpoint) {
                case 'jobs':
                case 'packages':
                case 'new-package':
                case 'save-resumes':
                case 'view-resumes':
                    if (!current_user_can('create_jobs')) {
                        wp_redirect($dashboard);
                        exit;
                    }
                    break;
                case 'job':
                    $postID = isset($wp_query->query_vars['postID']) ? $wp_query->query_vars['postID'] : '';
                    if ($postID) {
                        $job = GJ_Job::get_job($postID);
                        if (!$job || !$job->can_edit()) {
                            wp_redirect($dashboard);
                            exit;
                        }
                    } else {
                        if (!current_user_can('create_jobs')) {
                            wp_redirect($dashboard);
                            exit;
                        }
                    }
                    break;
                case 'company':
                    $postID = isset($wp_query->query_vars['postID']) ? $wp_query->query_vars['postID'] : '';
                    if ($postID) {
                        $employer = GJ_Employer::get_employer($postID);
                        if (!$employer || !$employer->can_edit()) {
                            wp_redirect($dashboard);
                            exit;
                        }
                    } else {
                        if (!current_user_can('create_employers')) {
                            wp_redirect($dashboard);
                            exit;
                        }
                    }
                    break;
                case 'resume':
                    $postID = isset($wp_query->query_vars['postID']) ? $wp_query->query_vars['postID'] : '';
                    if ($postID) {
                        $candidate = GJ_Candidate::get_candidate($postID);
                        if (!$candidate || !$candidate->can_edit()) {
                            wp_redirect($dashboard);
                            exit;
                        }
                    } else {
                        if (!current_user_can('create_candidates')) {
                            wp_redirect($dashboard);
                            exit;
                        }
                    }
                    break;
                case 'orders':
                    if (!gj_display_order_on_dashboard()) {
                        wp_redirect($dashboard);
                        exit;
                    }
                    break;
                case 'order':
                    global $wp_query;
                    $order_id = isset($wp_query->query_vars['postID']) ? $wp_query->query_vars['postID'] : 0;
                    $order = GJ_Order::get_order($order_id);
                    if (!$order || !$order->can_view()) {
                        wp_redirect($dashboard);
                        exit;
                    }
                    break;
                case 'follows':
                case 'save-jobs':
                    if (!current_user_can('apply_job')) {
                        wp_redirect($dashboard);
                        exit;
                    }
                    break;
                case 'application':
					$postID = isset($wp_query->query_vars['postID']) ? $wp_query->query_vars['postID'] : '';
                    $application = GJ_Application::get_application($postID);
                    if (!$application || !$application->can_view()) {
                        wp_redirect($dashboard);
                        exit;
                    }
                    break;
                default :
                    do_action('gj_dashboard_permission', $endpoint);
                    break;
            }
        }
    }

    static function cancel_order() {
        if (isset($_GET['gj_cancel_order']) && $_GET['gj_cancel_order'] == 'true' && $_GET['order_id'] && $_GET['key']) {
            $order_id = (int) $_GET['order_id'];
            $key = sanitize_text_field($_GET['key']);
            $order = GJ_Order::get_order($order_id);
            if ($order && $order->get_author_id() == get_current_user_id() && $order->get_key() == $key) {
                $order->cancelled_order();
            }

            $redirect = isset($_GET['redirect']) ? esc_url_raw($_GET['redirect']) : '';
            if ($redirect) {
                wp_safe_redirect($redirect);
                exit;
            }
        }
    }

    static function social_login() {
        if (isset($_GET['gj_social_login']) && $_GET['gj_social_login']) {
            $social = GJ()->social_logins()->get_social(sanitize_text_field($_GET['gj_social_login']));
            if ($social) {
                $social->oauth();
            }
        }
    }

    static function social_apply() {
        if (isset($_GET['gj_social_apply']) && $_GET['gj_social_apply']) {
            $apply = GJ()->applies()->get_apply(sanitize_text_field($_GET['gj_social_apply']));
            if ($apply) {
                $apply->oauth();
            }
        }
    }

    static function verify_account() {
        if (isset($_GET['verify_account']) && $_GET['verify_account']) {
            $user_id = intval($_GET['verify_account']);
            $verify_code = sanitize_text_field($_GET['verify_code']);
            if ($user_id && $verify_code) {
                $_verify_code = get_user_meta($user_id, GJ_PREFIX . 'verify_code', true);
                if ($verify_code === $_verify_code) {
                    delete_user_meta($user_id, GJ_PREFIX . 'verify_code');
                    if (!is_user_logged_in()) {
                        wp_clear_auth_cookie();
                        wp_set_current_user($user_id);
                        wp_set_auth_cookie($user_id);
                    }

                    $redirect = apply_filters('gj_verify_account_redirect', gj_get_page_permalink('verify'));

                    wp_redirect($redirect);
                    exit;
                }
            }
        }
    }

    static function received_payment() {
        if (isset($_GET['gj_payment']) && $_GET['gj_payment']) {
            $payment = GJ()->payment_gateways()->get_payment_gateway(sanitize_text_field($_GET['gj_payment']));
            if ($payment) {
                $payment->payment_recieved();
            }
        }
    }

    static function send_mail_queue() {
        GJ_Email_Queue::send_emails();
    }

    static function confirm_job_alert() {
        if (isset($_GET['confirm_job_alert']) && $_GET['confirm_job_alert']) {
            $alert_id = intval($_GET['alert-id']);
            $code = sanitize_text_field($_GET['code']);
            $alert = GJ_Alert::get_alert($alert_id);
            if ($alert && !$alert->get_status() && $alert->check_confirm_link($code) === true) {
                $alert->change_status(1);
                gj_get_template_part('job-alert-popup/confirmed');
                ?>
                <script type="text/javascript">
                    jQuery(window).on('load', function () {
                        jQuery('#gj-job-alert-confirmed-popup').modal('show');
                    });
                </script>
                <?php
            }
        }
    }

    static function unsubscribe_job_alert() {
        if (isset($_GET['unsubscribe_job_alert']) && $_GET['unsubscribe_job_alert']) {
            $alert_id = intval($_GET['alert-id']);
            $code = sanitize_text_field($_GET['code']);
            $alert = GJ_Alert::get_alert($alert_id);
            if ($alert && $alert->check_unsubscribe_link($code) === true) {
                GJ_Alert::delete($alert_id);
                gj_get_template_part('job-alert-popup/unsubscribed');
                ?>
                <script type="text/javascript">
                    jQuery(window).on('load', function () {
                        jQuery('#gj-job-alert-unsubscribed-popup').modal('show');
                    });
                </script>
                <?php
            }
        }
    }

    static function form_action() {
        if (isset($_POST) && $_POST) {
            if (isset($_POST['gj-action']) && wp_verify_nonce(sanitize_text_field($_POST['gj-action']), 'gj-checkout')) {
                $cart = new GJ_Cart();
                if (!$cart->is_empty()) {

                    $order_id = GJ_Order::create_new($cart);
                    $order = GJ_Order::get_order($order_id);

                    if ($order->get_total_price() <= 0) {
                        $order->completed_order('', false, false);
                        update_post_meta($order->get_id(), GJ_PREFIX . 'payment_method_title', 'Auto');
                        $url = gj_dashboard_endpoint_url('thank-you-for-ordering');
                        $url = add_query_arg(array(
                                'order-id' => $order_id,
                                'key' => $order->get_key(),
                        ), $url);

                        wp_redirect($url);
                        exit;
                    } else {
                        $payment_method = sanitize_textarea_field($_POST['payment_method']);
                        $payment_gateway = GJ()->payment_gateways()->get_payment_gateway($payment_method);
                        if ($payment_gateway) {
                            update_post_meta($order_id, GJ_PREFIX . 'payment_method', $payment_method);
                            update_post_meta($order_id, GJ_PREFIX . 'payment_method_title', $payment_gateway->get_title());
                            $payment_gateway->process_payment($order_id);
                        } else {
                            wp_redirect(gj_dashboard_endpoint_url('checkout'));
                            exit;
                        }
                        exit;
                    }
                }
            }
        }
    }

    static function save_settings() {
        check_ajax_referer('gj-security');
        $model = gj_clean2($_POST['model']);
        foreach ($model as $key => $value) {
            if(is_string($value)){
                $model[$key] = stripslashes($value);
            }
        }
        update_option('gj_settings',  $model);

        GJ_Post_Types::register_post_types();

        // Flush rules after install
        flush_rewrite_rules();
    }

    static function reset_settings() {
        check_ajax_referer('gj-security');
        GJ_Install::create_options(true);
    }

    static function logged_in_fallback($data) {
        if (isset($_POST['fallback_action']) && sanitize_text_field($_POST['fallback_action']) == 'show_apply_form') {
            $_SESSION['show_apply_form'] = true;
        }

        return $data;
    }

    static function show_apply_form() {
        if (isset($_SESSION['show_apply_form']) && (boolean)$_SESSION['show_apply_form']) {
            $user = GJ_User::get_user();
            $post = get_post();
            if ($post && $post->post_type == 'gj_job' && $user->is_candidate()) {
                ?>
                <script type="text/javascript">
                    jQuery(window).on('load', function () {
                        jQuery('#gj-modal-apply-<?php echo intval($post->ID); ?>').modal('show');
                    });
                </script>
                <?php
            }
            unset($_SESSION['show_apply_form']);
        }
    }

    /**
     * Add order note via ajax.
     */
    public static function add_order_note() {
        check_ajax_referer('gj-security');

        if (!current_user_can('manage_options')) {
            wp_die(- 1);
        }

        $post_id = absint($_POST['post_id']);
        $note = wp_kses_post(trim(stripslashes($_POST['note'])));

        if ($post_id > 0) {
            $order = GJ_Order::get_order($post_id);
            $comment_id = $order->add_order_note($note, 0, true);

            echo '<li rel="' . esc_attr($comment_id) . '" class="gj-note ';
            echo '"><div class="gj-note-content">';
            echo wpautop(wptexturize($note));
            echo '</div><p class="meta"><a href="#" class="gj-delete-note">' . esc_html__('Delete note', 'gj') . '</a></p>';
            echo '</li>';
        }
        wp_die();
    }

    public static function delete_order_note() {
        check_ajax_referer('gj-security');

        if (!current_user_can('manage_options')) {
            wp_die(- 1);
        }

        $note_id = intval($_POST['note_id']);

        if ($note_id > 0) {
            wp_delete_comment($note_id);
        }
        wp_die();
    }

    static function jobs_expired() {
        global $wpdb;
        $sql = "SELECT p.ID FROM {$wpdb->posts} AS p  
        JOIN {$wpdb->postmeta} AS pm ON pm.post_id = p.ID 
        JOIN {$wpdb->postmeta} AS pm1 ON pm1.post_id = p.ID 
        WHERE p.post_type='gj_job' AND p.post_status='publish' AND pm.meta_key = %s AND pm1.meta_key = %s AND pm.meta_value != '1' AND pm1.meta_value != '' AND CAST(pm1.meta_value AS UNSIGNED) <= %d LIMIT 0,100";
        $jobs = $wpdb->get_results($wpdb->prepare($sql, GJ_PREFIX . 'never_expiry', GJ_PREFIX . 'expiry', current_time('timestamp')));
        if ($jobs) {
            foreach ($jobs AS $job) {
                $job = GJ_Job::get_job($job->ID);
                if($job){
                    $job->change_status('gj-expired');
                }
            }
        }
    }

    static function jobs_export() {
        check_ajax_referer('gj-security');
        $job_types = sanitize_text_field($_POST['job_type']);
        if (!$job_types) {
            exit;
        }
        $job_type = explode(',', $job_types);

        $upload = wp_upload_dir();
        $targetDir = $upload['basedir'];
        $targetUrl = $upload['baseurl'];
        $targetDir = $targetDir . '/jobs_import_export/exports';
        $targetUrl = $targetUrl . '/jobs_import_export/exports';
        if (!is_dir($targetDir)) {
            wp_mkdir_p($targetDir);
        }

        if (count($job_type) >= 1) {
            $files = array();

            foreach ($job_type as $type_job) {
                $args = array(
                    'posts_per_page' => - 1,
                    'orderby' => 'date',
                    'order' => 'DESC',
                    'post_type' => $type_job
                );
                switch ($type_job) {
                    case 'gj_job':
                        $filename = 'jobs-' . time() . '.csv';
                        $taxs = gj_get_job_taxonomies();

                        $args['post_status'] = array(
                            'publish',
                            'pending',
                            'draft',
                            'gj-rejected',
                        );
                        break;
                    case 'gj_candidate':
                    case 'gj_employer':
                        if($type_job == 'gj_candidate'){
                            $filename = 'candidates-' . time() . '.csv';
                            $taxs = gj_get_candidate_taxonomies();
                        }else{
                            $filename = 'employers-' . time() . '.csv';
                            $taxs = gj_get_employer_taxonomies();
                        }
                        $args['post_status'] = array(
                            'publish',
                            'pending',
                            'gj-incomplete'
                        );
                        break;
                }

                $getposts = get_posts($args);

                if (!count($getposts)) {
                    continue;
                }

                $header = array();
                $items = array();

                $ignored_fields = array('filter', 'pinged', 'to_ping', 'ping_status', '_edit_last', '_edit_lock');
                $meta_keys = array();

                foreach ($getposts as $pkey => $post) : setup_postdata($post);
                    $post_id = $post->ID;

                    $item = array();
                    foreach ($post as $key=>$value){
                        if($pkey == 0){
                            if(!in_array($key, $ignored_fields)){
                                $header[] = $key;
                            }
                        }

                        if(!in_array($key, $ignored_fields)){
                            $item[] = $value;
                        }
                    }

                    if($taxs){
                        $post->taxs = array();
                        foreach ($taxs as $tax){
                            if($pkey == 0){
                                if(!in_array($tax, $ignored_fields)){
                                    $header[] = $tax;
                                }
                            }

                            if(!in_array($tax, $ignored_fields)){
                                $tax_objects = wp_get_post_terms($post_id, $tax);
                                if($tax_objects){
                                    if($tax == 'gj_state'){
                                        $tax_names = array();
                                        foreach ($tax_objects as $tax_object){
                                            $tax_names[] = get_term_meta($tax_object->term_id, 'country', true)."/".$tax_object->name;
                                        }
                                    }else{
                                        $tax_names = wp_list_pluck($tax_objects, 'name');
                                    }
                                    $item[] = implode("|", $tax_names);
                                }else{
                                    $item[] = '';
                                }
                            }
                        }
                    }

                    $metadatas = get_post_meta( $post_id);
                    if($pkey == 0){
                        foreach ($metadatas as $mkey => $mvalue) {
                            if (!in_array($mkey, $ignored_fields)) {
                                $header[] = $mkey;
                                $meta_keys[] = $mkey;
                            }
                        }
                    }

                    foreach ($meta_keys as $mkey){
                        if(isset($metadatas[$mkey])){
                            switch ($mkey){
                                case 'gallery' :
                                case 'portfolio' :
                                        if($metadatas[$mkey] && $metadatas[$mkey][0]){
                                            $gallery = maybe_unserialize($metadatas[$mkey][0]);
                                            $gallery_arr = array();
                                            foreach ($gallery as $image_id){
                                                $gallery_arr[] = wp_get_attachment_url($image_id);
                                            }

                                            $item[] = implode("|", $gallery_arr);
                                        }else{
                                            $item[] = "";
                                        }
                                    break;
                                case 'cv' :
                                case '_thumbnail_id' :
                                        if($metadatas[$mkey]){
                                            $item[] = wp_get_attachment_url($metadatas[$mkey][0]);
                                        }else{
                                            $item[] = "";
                                        }
                                    break;
                                default :
                                    $mvalue = $metadatas[$mkey];
                                    if(is_array($mvalue)){
                                        $mvalue = array_filter($mvalue);
                                        if($mvalue){
                                            $item[] = implode("|", $mvalue);
                                        }else{
                                            $item[] = "";
                                        }
                                    }else{
                                        $item[] = $mvalue;
                                    }
                            }

                        }else{
                            $item[] = "";
                        }
                    }

                    $items[] = $item;
                endforeach;

                $dir_export = $targetDir . DIRECTORY_SEPARATOR . $filename;
                $files[] = $dir_export;
                $fh = @fopen($dir_export, 'w');
                fputcsv($fh, $header, ',', chr(0));
                foreach ($items as $item) {
                    fputcsv($fh, $item);
                }
                fclose($fh);
            }
            $zip_name = 'jobs-' . time();
            $bundle_dir = $targetDir . DIRECTORY_SEPARATOR . $zip_name;
            @mkdir($bundle_dir);
            $bundle_zip = $targetDir . DIRECTORY_SEPARATOR . $zip_name . '.zip';
            $bundle_zip_url = $targetUrl . '/' . $zip_name . '.zip';

            foreach ($files as $file) {
                @copy($file, $bundle_dir . DIRECTORY_SEPARATOR . basename($file));
                unlink($file);
            }

            gj_zip_dir($bundle_dir, $bundle_zip);

            array_map('unlink', glob("$bundle_dir/*.*"));
            rmdir($bundle_dir);
            echo json_encode(array(
                'success' => true,
                'message' => esc_html__('Export successfully.', 'gj'),
                'path_down' => $bundle_zip_url,
            ));
        }

        exit;
    }

    static function upload_csv_actions() {
        include_once 'job-imports-upload-handler.php';
        die;
    }

    static function set_post_types() {
        require_once GJ_PLUGIN_DIR . '/includes/libs/parsecsv/vendor/autoload.php';

        $eventKey = isset($_POST['filekey']) ? sanitize_key($_POST['filekey']) : '';
        $file = GJ_IMPORT_DIR . '/' . $eventKey . '/' . $eventKey;
        $csv = new ParseCsv\Csv($file);
        $Headers = $csv->titles;
        $type = 'gj_job';
        if (in_array('gj_candidate', $Headers)) {
            $type = 'gj_candidate';
        } elseif (in_array('gj_employer', $Headers)) {
            $type = 'gj_employer';
        }

        echo json_encode(array(
            'success' => true,
            'type' => $type
        ));
        die();
    }

    static function parse_data_to_import() {

        require_once GJ_PLUGIN_DIR . '/includes/libs/parsecsv/vendor/autoload.php';

        $startLimit = intval($_POST['postData']['startLimit']);
        $importedSuccess = intval($_POST['postData']['importedSuccess']);
        $limit = intval($_POST['postData']['Limit']);

        $importType = sanitize_text_field($_POST['postData']['import_type']);
        $import_mode = sanitize_text_field($_POST['postData']['import_mode']);
        $eventKey = sanitize_text_field($_POST['postData']['event_key']);

        $get_screen_info = GJ_Admin_Jobs_Tools::getPostValues(sanitize_key($eventKey));
        $fields_mapping = $get_screen_info[$eventKey]['fields_mapping'];

        $eventDir = GJ_IMPORT_DIR . '/' . $eventKey;
        $eventFile = $eventDir . '/' . $eventKey;

        $csv = new ParseCsv\Csv();
        $csv->offset = $startLimit;
        $csv->limit = $limit;
        $csv->parse($eventFile);

        $data = $csv->data;
        foreach ($data as $row){
            if(!$row['post_title'] && !$row['post_content']){
                continue;
            }
            $post_data = array();
            $post_extra_data = array();
            $terms_data = array();
            foreach ($fields_mapping['core'] as $field=>$mapfield){
                $post_data[$field] = isset($row[$mapfield]) ? $row[$mapfield] : '';
            }

            foreach ($fields_mapping['term'] as $field=>$mapfield){
                $terms_data[$field] = isset($row[$mapfield]) ? $row[$mapfield] : '';
            }

            foreach ($fields_mapping['extra'] as $field=>$mapfield){
                $post_extra_data[$field] = isset($row[$mapfield]) ? $row[$mapfield] : '';
            }

            $post = null;
            $insert = $update = false;
            if($post_data['ID']){
                $post = get_post($post_data['ID']);
                if(!$post || is_wp_error($post)){
                    $insert = true;
                }else{
                    if($import_mode != 'update_existing_items'){
                        continue;
                    }else{
                        $update = true;
                    }
                }
            }else{
                $insert = true;
            }


            $post_data['post_type'] = $importType;

            $author_obj = get_user_by('id', $post_data['post_author']);
            if(!$author_obj || is_wp_error($author_obj)){
                $post_data['post_author'] = get_current_user_id();
            }

            if($insert){
                unset($post_data['ID']);
                $post_data['ID'] = wp_insert_post($post_data);
                $postID = $post_data['ID'];
                if (!array_key_exists('_gj_featured', $post_extra_data)) {
                    update_post_meta($post_data['ID'], '_gj_featured', '');
                }

                if($importType == 'gj_job'){
                    if (!array_key_exists('_gj_expiry', $post_extra_data)) {
                        update_post_meta($post_data['ID'], '_gj_expiry', '');
                    }
                    if (!array_key_exists('_gj_expiry_date', $post_extra_data)) {
                        update_post_meta($post_data['ID'], '_gj_expiry_date', '');
                    }

                    if (!array_key_exists('salary_from', $post_extra_data)) {
                        update_post_meta($post_data['ID'], 'salary_from', '');
                    }
                    if (!array_key_exists('salary_to', $post_extra_data)) {
                        update_post_meta($post_data['ID'], 'salary_to', '');
                    }
                }
            }else if($update){
                $postID = wp_update_post($post_data);
            }

            if($postID){
                $importedSuccess++;
            } else{
                continue;
            }

            switch ($importType){
                case 'gj_employer':
                    $taxs = gj_get_employer_taxonomies();
                    break;
                case 'gj_candidate':
                    $taxs = gj_get_candidate_taxonomies();
                    break;
                default:
                    $taxs = gj_get_job_taxonomies();
                    break;
            }

            foreach ($taxs as $tax){
                if($tax == 'gj_city'){
                    continue;
                }

                if(isset($terms_data[$tax])){
                    $terms = explode('|', $terms_data[$tax]);
                    $term_ids = array();
                    foreach ($terms as $term){
                        if($term !== ""){
                            if(is_int($term)){
                                $term_ids[] = $term;
                            }else{
                                if($tax == 'gj_state'){
                                    $termArr = explode('/',$term);
                                    if(!$termArr || count($termArr) < 2){
                                        continue;
                                    }

                                    $country = $termArr[0];
                                    $term = $termArr[1];
                                }

                                $ide_term = get_term_by('name', $term, $tax);
                                if (!$ide_term) {
                                    $new_term = wp_insert_term($term, $tax);
                                    $ide_term_id = $new_term['term_id'];
                                    if($tax == 'gj_state'){
                                        update_term_meta($ide_term_id, 'country', $country);
                                    }
                                } else {
                                    $ide_term_id = $ide_term->term_id;
                                }

                                $term_ids[] = $ide_term_id;
                            }
                        }
                    }

                    wp_set_post_terms($post_data['ID'], $term_ids, $tax);

                    if($tax == 'gj_state' && $term_ids && $terms_data['gj_city']){
                        $tax = 'gj_city';
                        $state_id = $term_ids[0];
                        $terms = explode('|', $terms_data[$tax]);
                        $term_ids = array();
                        foreach ($terms as $term){
                            if($term !== ""){
                                if(is_int($term)){
                                    $term_ids[] = $term;
                                }else{
                                    $ide_term = get_term_by('name', $term, $tax);
                                    if (!$ide_term) {
                                        $new_term = wp_insert_term($term, $tax);
                                        $ide_term_id = $new_term['term_id'];
                                        update_term_meta($ide_term_id, 'state', $state_id);
                                    } else {
                                        $ide_term_id = $ide_term->term_id;
                                    }
                                    $term_ids[] = $ide_term_id;
                                }
                            }
                        }

                        wp_set_post_terms($post_data['ID'], $term_ids, $tax);
                    }
                }
            }


            if($post_data['ID']){
                foreach ($post_extra_data as $key_extra => $extra_field){
                    if($key_extra == '_gj_employer' && $extra_field){
                        $employer_post = get_post($extra_field);
                        if($employer_post && !is_wp_error($employer_post) && $employer_post->post_type == 'gj_employer'){
                            update_post_meta($post_data['ID'], '_gj_employer', $extra_field);
                        }
                    }

                    if ($key_extra == 'gallery' || $key_extra == 'portfolio') {
                        $galleries_url = explode('|', $extra_field);
                        $galleries_url = array_filter($galleries_url);
                        $gallery_ids = array();
                        if ($galleries_url) {
                            foreach ($galleries_url as $gallery_url) {
                                if (is_numeric($galleries_url)) {
                                    $gallery_ids[] = $gallery_url;
                                } else {
                                    $attachment_id = gj_get_image_id_by_url($gallery_url);
                                    if ($attachment_id) {
                                        $gallery_ids[] = $attachment_id;
                                    } else {
                                        $file_name = basename($gallery_url);
                                        $tmp = download_url($gallery_url);
                                        $file_array = array(
                                            'name' => $file_name,
                                            'tmp_name' => $tmp
                                        );

                                        // Check for download errors
                                        if (is_wp_error($tmp)) {
                                            @unlink($file_array['tmp_name']);
                                            continue;
                                        }

                                        $media_id = media_handle_sideload($file_array, $post_data['ID']);
                                        // Check for handle sideload errors.
                                        if (is_wp_error($media_id)) {
                                            @unlink($file_array['tmp_name']);
                                            continue;
                                        }

                                        $gallery_ids[] = $media_id;
                                    }
                                }
                            }
                        }

                        if($gallery_ids){
                            update_post_meta($post_data['ID'], $key_extra, $gallery_ids);
                        }

                        continue;
                    }

                    if (($key_extra == '_thumbnail_id' || $key_extra == 'cv') && $extra_field) {
                        if (is_numeric($extra_field)) {
                            update_post_meta($post_data['ID'], $key_extra, $extra_field);
                        } else {
                            $attachment_id = gj_get_image_id_by_url($extra_field);
                            if ($attachment_id) {
                                update_post_meta($post_data['ID'], $key_extra, $attachment_id);
                            } else {
                                $file_name = basename($extra_field);
                                $tmp = download_url($extra_field);

                                $file_array = array(
                                    'name' => $file_name,
                                    'tmp_name' => $tmp
                                );

                                // Check for download errors
                                if (is_wp_error($tmp)) {
                                    @unlink($file_array['tmp_name']);
                                    continue;
                                }
                                $media_id = media_handle_sideload($file_array, $post_data['ID']);

                                // Check for handle sideload errors.
                                if (is_wp_error($media_id)) {
                                    @unlink($file_array['tmp_name']);
                                    continue;
                                }

                                update_post_meta($post_data['ID'], $key_extra, $media_id);
                            }
                        }

                        continue;
                    }

                    if(is_serialized($extra_field)){
                        update_post_meta($post_data['ID'], $key_extra, @unserialize($extra_field));
                    }else{
                        $extra_field_arr = explode("|", $extra_field);
                        if(count($extra_field_arr) > 1){
                            update_post_meta($post_data['ID'], $key_extra, $extra_field_arr);
                        }else{
                            update_post_meta($post_data['ID'], $key_extra, $extra_field);
                        }
                    }
                }
            }
        }

        echo json_encode(array(
                'importedSuccess' => $importedSuccess
        ));

        die;
    }

    static function create_default_products(){
        $setting_pages = array(
            'login' => array('title' => esc_html__('Login', 'gj'), 'content' => '[gj_login]'),
            'register' => array('title' => esc_html__('Register', 'gj'), 'content' => '[gj_register]'),
            'verify' => array('title' => esc_html__('Verify Account', 'gj'), 'content' => '[gj_verify_account]'),
            'lostpass' => array('title' => esc_html__('Lost Password', 'gj'), 'content' => '[gj_lostpassword]'),
            'dashboard' => array('title' => esc_html__('Dashboard', 'gj'), 'content' => ''),
            'jobs' => array('title' => esc_html__('Jobs', 'gj'), 'content' => ''),
            'candidates' => array('title' => esc_html__('Candidates', 'gj'), 'content' => ''),
            'employers' => array('title' => esc_html__('Employers', 'gj'), 'content' => '')
        );

        $settings = gj_option();    
        $has_update = false;
        foreach ($setting_pages as $page_key=>$page){
            if(!gj_get_page_id($page_key)){
                $page_id = wp_insert_post(array(
                    'post_title' => $page['title'],
                    'post_type' => 'page',
                    'post_status' => 'publish',
                    'post_content' => $page['content'],
                ));

                if($page_id && !is_wp_error($page_id)){
                    $settings[$page_key.'_page_id'] = array('ID'=> $page_id, 'title'=> $page['title']);
                    $has_update = true;
                }
            }
        }

        if($has_update){
            update_option('gj_settings',  $settings);
        }

        echo json_encode(array('success' => true, 'message' => esc_html__('Success', 'gj')));
        exit;
    }

    static function reorder_all_fields(){
        global $wpdb;
        $post_types = gj_field_manager_post_types();
        foreach ($post_types as $post_type => $post_type_options){
            if($post_type_options['grouped']){
                $sql = "SELECT ID FROM {$wpdb->posts} as p join {$wpdb->postmeta} as pm ON pm.post_id = p.ID WHERE p.post_type = %s AND p.post_status= 'publish' AND pm.meta_key = %s AND pm.meta_value = %s ORDER BY p.menu_order ASC";
                $sql = $wpdb->prepare($sql, 'gj_field_groups', 'post_type', $post_type);
                $groups = $wpdb->get_results($sql);
                $gorder = 1;
                if($groups){
                    foreach ($groups as $group){
                        $sql = "UPDATE {$wpdb->posts} SET menu_order = %d WHERE ID = %d";
                        $wpdb->query($wpdb->prepare($sql, $gorder, $group->ID));

                        $sql = "SELECT ID FROM {$wpdb->posts} WHERE post_type = %s AND post_status= 'publish' AND post_parent = %d ORDER BY menu_order ASC";
                        $sql = $wpdb->prepare($sql, 'gj_fields', $group->ID);
                        $fields = $wpdb->get_results($sql);
                        if($fields){
                            $forder = 1;
                            foreach ($fields as $field){
                                $sql = "UPDATE {$wpdb->posts} SET menu_order = %d WHERE ID = %d";
                                $wpdb->query($wpdb->prepare($sql, $forder, $field->ID));
                                $forder++;
                            }
                        }
                        $gorder++;
                    }
                }
            }else{
                $sql = "SELECT ID FROM {$wpdb->posts} as p join {$wpdb->postmeta} as pm ON pm.post_id = p.ID WHERE p.post_type = %s AND p.post_status= 'publish' AND pm.meta_key = %s AND pm.meta_value = %s ORDER BY p.menu_order ASC";
                $sql = $wpdb->prepare($sql, 'gj_fields', 'post_type', $post_type);
                $fields = $wpdb->get_results($sql);
                if($fields){
                    $forder = 1;
                    foreach ($fields as $field){
                        $sql = "UPDATE {$wpdb->posts} SET menu_order = %d WHERE ID = %d";
                        $wpdb->query($wpdb->prepare($sql, $forder, $field->ID));
                        $forder++;
                    }
                }
            }
        }

        echo json_encode(array('success' => true, 'message' => esc_html__('Success', 'gj')));

        exit;
    }
}   

GJ_Controller::init();
