<?php
/**
 * @class 		GJ_Email
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

if (!defined('ABSPATH'))
    exit;

class GJ_Email {

    public static function get_blogname() {
        return wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
    }

    static public function send_email($type, $args) {

        $emails = self::get_emails($type, $args);
        if ($emails) {
            $email_queue_types = (array) apply_filters('gj_email_queue_types', array('new_job'));
            $mailqueue = in_array($type, $email_queue_types);
            foreach ($emails as $email) {
                if ($email['content'] && $email['recipients'] && $email['subject']) {
                    //add mail queue
                    $from_name = gj_option('email_from_name', self::get_blogname());
                    $from_address = gj_option('email_from_address', get_option('admin_email', ''));

                    do_action('gj_before_send_email', $email, $mailqueue, $type, $args);
                    if ($mailqueue) {
                        GJ_Email_Queue::add($from_name, $from_address, $email['recipients'], $email['subject'], nl2br($email['content']));
                    } else {
                        //send directly
                        $email_type = 'text/html';

                        $headers = array();
                        $headers[] = 'Content-Type: '.$email_type.'; charset=UTF-8';

                        $headers[] = 'From: ' . $from_name . ' <' . $from_address . '>';
                        if (isset($email['reply_name']) && isset($email['reply_to'])) {
                            $headers[] = 'Reply-To: ' . $email['reply_name'] . ' <' . $email['reply_to'] . '>';
                        } elseif (isset($email['reply_to'])) {
                            $headers[] = 'Reply-To: <' . $email['reply_to'] . '>';
                        }

                        $content = apply_filters('the_content', $email['content']);
                        $attachments = isset($email['attachments']) ? $email['attachments'] : array();
                        wp_mail($email['recipients'], $email['subject'], $content, $headers, $attachments);
                    }
                    do_action('gj_after_send_email', $email, $mailqueue, $type, $args);
                }
            }

            if($mailqueue){
                GJ_Email_Queue::send_emails();
            }
        }
    }

    static public function get_emails($type, $args) {
        $emails = array();
        if ($type) {
            $function = 'get_email_' . $type;
            if (method_exists('GJ_Email', $function)) {
                $emails = self::$function($args);
            } else {
                $emails = (array) apply_filters('gj_get_emails_' . $type, $emails, $args);
            }
        }

        $emails = apply_filters('gj_get_emails', $emails, $type, $args);

        return $emails;
    }

    static public function get_email_resetpass($args) {

        $type = 'resetpass';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_User $user*/
            $user = $args;
            $recipient = $user->get_email();
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'user' => $user,
                'user_login' => $user->get_login(),
                'resetpass_url' => $user->get_resetpass_url(),
                'email_type'=>'reset-password'
            );
            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_register($args) {
        $type = 'register';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            $user = GJ_User::get_user($args['user_id']);
            $password = isset($args['password']) ? $args['password'] : '';
            $auto_generate_password = isset($args['auto_generate_password']) ? $args['auto_generate_password'] : false;

            $recipient = $user->get_email();
            $subject = gj_option('email_' . $type . '_subject');

            $verify_account = gj_option('verify_account') ? true : false;
            if ($verify_account) {
                $verify_account = $user->is_verified() ? false : true;
            }
            $args = array(
                'user' => $user,
                'user_id' => $args['user_id'],
                'auto_generate_password' => $auto_generate_password,
                'user_password' => $password,
                'user_login' => $user->get_login(),
                'dashboard_url' => gj_get_page_permalink('dashboard'),
                'verify_account' => $verify_account,
                'activation_url' => $verify_account ? $user->get_activation_url(false) : '',
                'email_type'=>'new-register'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_admin_register($args) {
        $type = 'admin_register';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            $user = GJ_User::get_user($args['user_id'], true);
            $recipient = gj_option('admin_email_receiver', get_option('admin_email', ''));
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'user' => $user,
                'user_id' => $args['user_id'],
                'user_login' => $user->get_login(),
                'display_name' => $user->get_display_name(),
                'email' => $user->get_email(),
                'role' => in_array('gj_employer', (array) $user->user->roles) ? _x('Employer', 'Role for email', 'gj') : (in_array('gj_candidate', (array) $user->user->roles) ? _x('Candidate', 'Role for email', 'gj') : implode(', ', $user->user->roles)),
                'edit_url' => admin_url('user-edit.php?user_id=' . $args['user_id']),
                'email_type'=>'admin/new-register'
            );
            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_review_company($args) {
        $type = 'review_company';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Employer $employer*/
            $employer = $args;
            $recipient = gj_option('admin_email_receiver', get_option('admin_email', ''));
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'employer' => $employer,
                'author_name' => $employer->get_author()->get_display_name(),
                'email_type'=>'admin/review-company'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_approved_company($args) {
        $type = 'approved_company';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Employer $employer*/
            $employer = $args;
            $author = $employer->get_author();
            $recipient = $employer->get_email();
            if(!$recipient){
                $recipient = $author->get_email();
            }
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'employer' => $employer,
                'author' => $employer->get_author(),
                'author_name' => $employer->get_title(),
                'email_type'=>'approved-company'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_rejected_company($args) {
        $type = 'rejected_company';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Employer $employer*/
            $employer = $args;

            $author = $employer->get_author();
            $recipient = $employer->get_email();
            if(!$recipient){
                $recipient = $author->get_email();
            }
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'employer' => $employer,
                'author_name' => $employer->get_title(),
                'email_type'=>'rejected-company'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_review_resume($args) {
        $type = 'review_resume';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Candidate $candidate*/
            $candidate = $args;
            $recipient = gj_option('admin_email_receiver', get_option('admin_email', ''));
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'candidate' => $candidate,
                'author_name' => $candidate->get_author()->get_display_name(),
                'email_type'=>'admin/review-company'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_approved_resume($args) {
        $type = 'approved_resume';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Candidate $candidate*/
            $candidate = $args;
            $author = $candidate->get_author();
            $recipient = $candidate->get_email();
            if(!$recipient){
                $recipient = $author->get_email();
            }
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'candidate' => $candidate,
                'author' => $candidate->get_author(),
                'author_name' => $candidate->get_title(),
                'email_type'=>'approved-resume'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_rejected_resume($args) {
        $type = 'rejected_resume';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Candidate $candidate*/
            $candidate = $args;

            $author = $candidate->get_author();
            $recipient = $candidate->get_email();
            if(!$recipient){
                $recipient = $author->get_email();
            }
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'candidate' => $candidate,
                'author_name' => $candidate->get_title(),
                'email_type'=>'rejected-resume'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_review_job($args) {
        $type = 'review_job';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Job $job*/
            $job = $args;
            $recipient = gj_option('admin_email_receiver', get_option('admin_email', ''));
            $subject = gj_option('email_' . $type . '_subject');
            $author = $job->get_author();
            $args = array(
                'job' => $job,
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'admin/review-job'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
                'args' => $args,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_new_job($args) {
        $type = 'new_job';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Job $job*/
            $job = $args;
            if($job){
                $author = $job->get_author();
                $employer = $job->get_employer();
                $emails = array();
                if ($employer && $follower_ids = $author->get_follower_ids()) {
                    $subject = gj_option('email_' . $type . '_subject');
                    $subject = str_replace(array('#employer_name#'), array($employer->get_title()), $subject);
                    foreach ($follower_ids as $follower_id) {
                        if ($follower = GJ_User::get_user($follower_id)) {
                            $recipient = $follower->get_email();
                            $args = array(
                                'job' => $job,
                                'follower' => $follower,
                                'follower_name' => $follower->get_display_name(),
                                'employer_name' => $employer->get_title(),
                                'email_type'=>'new-job'
                            );

                            $email = array(
                                'subject' => $subject,
                                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                                'recipients' => $recipient,
                            );

                            $emails[] = $email;
                        }
                    }
                }
                return $emails;
            }
        }

        return array();
    }

    static public function get_email_approved_job($args) {
        $type = 'approved_job';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Job $job*/
            $job = $args;
            $author = $job->get_author();
            $recipient = $author->get_email();
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'job' => $job,
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'approved-job'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_rejected_job($args) {
        $type = 'rejected_job';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Job $job*/
            $job = $args;

            $author = $job->get_author();
            $recipient = $author->get_email();
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'job' => $job,
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'rejected-job'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
                'args' => $args,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_expired_job($args) {
        $type = 'expired_job';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Job $job*/
            $job = $args;
            if ($job) {
                $author = $job->get_author();
                $recipient = $author->get_email();
                $subject = gj_option('email_' . $type . '_subject');

                $expiry_date = date_i18n(get_option('date_format'), $job->get_expiry());
                $args = array(
                    'job' => $job,
                    'user' => $author,
                    'user_name' => $author->get_display_name(),
                    'job_title' => $job->get_title(),
                    'expiry_date' => $expiry_date,
                    'email_type'=>'job-expired'
                );

                $email = array(
                    'subject' => $subject,
                    'content' => gj_get_template_part('emails/email_template', $args, true, false),
                    'recipients' => $recipient,
                );

                return array($email);
            }
        }

        return array();
    }

    static public function get_email_new_order($args) {
        $type = 'new_order';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Order $order*/
            $order = $args;
            $author = $order->get_author();
            $recipient = $author->get_email();
            $heading = gj_option('email_' . $type . '_heading');
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'order' => $order,
                'order_number' => $order->get_id(),
                'order_date' => $order->get_created(get_option('date_format')),
                'order_status' => $order->get_status(),
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'new-order'
            );

            $email = array(
                'subject' => $subject,
                'heading' => $heading,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_new_order_admin($args) {
        $type = 'new_order_admin';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Order $order*/
            $order = $args;
            $author = $order->get_author();
            $recipient = gj_option('admin_email_receiver', get_option('admin_email', ''));
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'order' => $order,
                'order_number' => $order->get_id(),
                'order_date' => $order->get_created(get_option('date_format')),
                'order_status' => $order->get_status(),
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'admin/new-order'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_hold_order($args) {
        $type = 'hold_order';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Order $order*/
            $order = $args;
            $author = $order->get_author();
            $recipient = $author->get_email();
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'order' => $order,
                'order_number' => $order->get_id(),
                'order_date' => $order->get_created(get_option('date_format')),
                'order_status' => $order->get_status(),
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'hold-order'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_completed_order($args) {
        $type = 'completed_order';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Order $order*/
            $order = $args;
            $author = $order->get_author();
            $recipient = $author->get_email();
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'order' => $order,
                'order_number' => $order->get_id(),
                'order_date' => $order->get_created(get_option('date_format')),
                'order_status' => $order->get_status(),
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'completed-order'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }
	
	static public function get_email_cancelled_order($args) {
        $type = 'cancelled_order';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Order $order*/
            $order = $args;
            $author = $order->get_author();
            $recipient = $author->get_email();
            $subject = gj_option('email_' . $type . '_subject');

            $args = array(
                'order' => $order,
                'order_number' => $order->get_id(),
                'order_date' => $order->get_created(get_option('date_format')),
                'order_status' => $order->get_status(),
                'author' => $author,
                'author_name' => $author->get_display_name(),
                'email_type'=>'cancelled-order'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_new_application($args) {
        $type = 'new_application';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Application $application*/
            $application = $args;
            $job = $application->get_job();
            $job_author = $job->get_author();
            $user_name = $application->get_full_name();
            $user_email = $application->get_email();
            $cv_path = $application->get_cv_path();
            $recipient = $user_email;
            $subject = gj_option('email_' . $type . '_subject');
            $subject = str_replace(array('#job_title#'), array($job->get_title()), $subject);

            $args = array(
                'job' => $job,
                'employer' => $job_author,
                'employer_name' => $job_author->get_display_name(),
                'employer_email' => $job_author->get_email(),
                'candidate_name' => $user_name,
                'candidate_email' => $user_email,
                'application' => $application,
                'email_type'=>'new-application'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
                'attachments' => array($cv_path)
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_new_application_employer($args) {
        $type = 'new_application_employer';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            /** @var GJ_Application $application*/
            $application = $args;
            $job = $application->get_job();
            $job_author = $job->get_author();
            $user_name = $application->get_full_name();
            $user_email = $application->get_email();
            $cv_path = $application->get_cv_path();

            $recipient = $job->get_email_for_apply();
            $subject = gj_option('email_' . $type . '_subject');
            $subject = str_replace(array('#job_title#'), array($job->get_title()), $subject);

            $args = array(
                'job' => $job,
                'job_title' => $job->get_title(),
                'employer' => $job_author,
                'employer_name' => $job_author->get_display_name(),
                'employer_email' => $job_author->get_email(),
                'candidate_name' => $user_name,
                'candidate_email' => $user_email,
                'application' => $application,
                'email_type'=>'new-application-employer'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
                'attachments' => array($cv_path)
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_application($args) {

        $type = 'application';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            $application_id = $args['application_id'];
            $application = GJ_Application::get_application($application_id);
            $job = $application->get_job();
            $job_author = $job->get_author();

            $author_name = $job_author->get_display_name();
            $author_email = $job_author->get_email();
            $candidate_name = $application->get_full_name();
            $candidate_email = $application->get_email();

            $subject = str_replace(array('#employer_name#', '#employer_email#', '#candidate_name#', '#candidate_email#'), array($author_name, $author_email, $candidate_name, $candidate_email), $args['subject']);
            $content = str_replace(array('#employer_name#', '#employer_email#', '#candidate_name#', '#candidate_email#'), array($author_name, $author_email, $candidate_name, $candidate_email), $args['content']);

            $recipient = $application->get_email();
            $reply_to = $job_author->get_email();
            $reply_name = $job_author->get_display_name();

            $args = array(
                'application' => $application,
                'job' => $job,
                'employer' => $job_author,
                'employer_name' => $author_name,
                'employer_email' => $author_email,
                'candidate' => $application->get_author(),
                'candidate_name' => $candidate_name,
                'candidate_email' => $candidate_email,
                'subject' => $subject,
                'content' => $content,
                'email_type'=>'application-contact'
            );

            $email = array(
                'subject' => $subject,
                'content' => gj_get_template_part('emails/email_template', $args, true, false),
                'recipients' => $recipient,
                'reply_to' => $reply_to,
                'reply_name' => $reply_name,
            );

            return array($email);
        }

        return array();
    }

    static public function get_email_contact($args) {
        $type = 'contact';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            $item_id = $args['item_id'];
            $from_name = $args['name'];
            $from_email = $args['email'];
            $mesage = $args['message'];
            $post = get_post($item_id);
            if ($post) {
                $itemObj = null;
                if(get_post_type($item_id) === 'gj_job'){
                    $itemObj = GJ_Job::get_job($item_id);
                    $employer = $itemObj->get_employer();
                    if($employer){
                        $to_name = $employer->get_title();
                        $to_email = $employer->get_email();
                    }else{
                        $author = $itemObj->get_author();
                        $to_email = $author->get_email();
                        $to_name = $author->get_display_name();
                    }
                }elseif(get_post_type($item_id) === 'gj_candidate' ){
                    $itemObj = GJ_Candidate::get_candidate($item_id);
                    $to_email = $itemObj->get_email();
                    $to_name = $itemObj->get_title();
                }elseif(get_post_type($item_id) === 'gj_employer' ){
                    $itemObj = GJ_Employer::get_employer($item_id);
                    $to_email = $itemObj->get_email();
                    $to_name = $itemObj->get_title();
                }
                
                $current_user_id = get_current_user_id();
                if ($current_user_id >0) {
                    $user = GJ_User::get_user($current_user_id);
                }

                $subject = gj_option('email_' . $type . '_subject');
                $subject = str_replace(array('#from_email#'), array($from_email), $subject);
                $recipient = $itemObj->get_email();

                if ($current_user_id != 0) {
                    $reply_to = $user->get_email();
                    $reply_name = $user->get_display_name();

                    $args = array(
                        'user' => $user,
                        'item_id' => $item_id,
                        'item_name' => $itemObj->get_title(),
                        'from_name' => $from_name,
                        'from_email' => $from_email,
                        'to_name' => $to_name,
                        'to_email' => $to_email,
                        'message' => $mesage,
                        'email_type'=>'contact'
                    );
                    $email = array(
                        'subject' => $subject,
                        'content' => gj_get_template_part('emails/email_template', $args, true, false),
                        'recipients' => $recipient,
                        'reply_to' => $reply_to,
                        'reply_name' => $reply_name,
                    );
                } else {
                    $args = array(
                        'item_id' => $item_id,
                        'item_name' => $itemObj->get_title(),
                        'from_name' => $from_name,
                        'from_email' => $from_email,
                        'to_name' => $to_name,
                        'to_email' => $to_name,
                        'message' => $mesage,
                        'email_type'=>'contact'
                    );
                    $email = array(
                        'subject' => $subject,
                        'content' => gj_get_template_part('emails/email_template', $args, true, false),
                        'recipients' => $recipient,
                        'reply_to' => $from_email,
                        'reply_name' => $from_name,
                    );
                }
                return array($email);
            }
        }

        return array();
    }

    static public function get_email_verify_account($args) {
        $type = 'verify_account';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            $user = $args['user'];
            if ($user) {
                $subject = gj_option('email_' . $type . '_subject');
                $recipient = $user->get_email();

                $args = array(
                    'user' => $user,
                    'activation_url' => $user->get_activation_url(),
                    'display_name' => $user->get_display_name(),
                    'email_type'=>'verify-account'
                );

                $email = array(
                    'subject' => $subject,
                    'content' => gj_get_template_part('emails/email_template', $args, true, false),
                    'recipients' => $recipient,
                );

                return array($email);
            }
        }

        return array();
    }

    static public function get_email_delete_account($args) {
        $type = 'delete_account';
        $enable_email = gj_option('email_' . $type . '_enable');
        if ($enable_email) {
            $user = $args['user'];
            if ($user) {

                $subject = gj_option('email_' . $type . '_subject');
                $content = gj_option('email_' . $type . '_content');
                $recipient = $user->get_email();

                $args = array(
                    'display_name' => $user->get_display_name(),
                    'email' => $user->get_email(),
                );

                $email = array(
                    'subject' => $subject,
                    'content' => $content,
                    'recipients' => $recipient,
                    'args' => $args,
                );

                return array($email);
            }
        }

        return array();
    }
}
