<?php
/**
 * @class 		GJ_Employer
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Employer extends GJ_Post {

    /**
     * @param string|object $post
     * @param bool $force
     * @return GJ_Employer|null
     */
    static function get_employer($post = null, $force = false) {
        return parent::get_post($post, $force);
    }

    function get_headline() {
        return get_post_meta($this->get_id(), 'headline', true);
    }

    function get_size() {
        $size = wp_get_post_terms($this->get_id(), 'gj_size');
        if ($size) {
            $size = $size[0];
            return $size->name;
        }

        return '';
    }

    function founded_date() {
        return get_post_meta($this->get_id(), 'foundeddate', true);
    }

    function get_jobs($status = 'any', $fields = ''){

        $author_id = $this->get_author_id();
        if($author_id == 1){
            $args = array(
                'post_type' => 'gj_job',
                'post_status' => $status,
                'meta_query' => array(
                    array(
                        'key' => GJ_PREFIX.'employer',
                        'value' => $this->get_id(),
                        'compare' => '='
                    )
                ),
                'fields' => $fields
            );
        }else{
            $args = array(
                'post_type' => 'gj_job',
                'post_status' => $status,
                'author' => $author_id,
                'fields' => $fields
            );
        }

         // perform the query
         $nedl_query = new WP_Query( $args );

         return $nedl_query->posts;
    }

    function count_jobs($status = 'any'){
        return count($this->get_jobs($status, 'ids'));
    }

    function get_opening_jobs(){
        return $this->get_jobs('publish');
    }

    function count_opening_jobs(){
        return count($this->get_jobs('publish', 'ids'));
    }

    function count_followers() {
        global $wpdb;
        $sql = "SELECT COUNT(DISTINCT ID) FROM {$wpdb->prefix}gj_follows WHERE post_id = %d";
        $total = $wpdb->get_var($wpdb->prepare($sql, $this->get_id()));

        return $total;
    }

    public function change_status($status, $send_email = true) {

        do_action('gj_before_change_employer_status', $status, $send_email, $this);

        global $wpdb;
        if ($status != 'draft' && $status != 'pending' && !$this->post->post_name) {
            $post_name = sanitize_title($this->post->post_title);
            $post_name = wp_unique_post_slug($post_name, $this->get_id(), $status, 'gj_employer', 0);

            $sql = "UPDATE {$wpdb->posts} SET post_status = %s, post_name = %s WHERE ID = %d";
            $wpdb->query($wpdb->prepare($sql, $status, $post_name, $this->get_id()));
        } else {
            $sql = "UPDATE {$wpdb->posts} SET post_status = %s WHERE ID = %d";
            $wpdb->query($wpdb->prepare($sql, $status, $this->get_id()));
        }

        $old_status = $this->get_status();
        if ($old_status == 'publish' || $status == 'publish') {
            delete_transient('gj_count_employers');
        }

        clean_post_cache($this->get_id());

        //send email
        if ($send_email) {
            if ($status == 'publish') {
                GJ_Email::send_email('approved_company', $this);
            } elseif ($status == 'pending') {
                GJ_Email::send_email('review_company', $this);
            } elseif ($status == 'gj-rejected') {
                GJ_Email::send_email('rejected_company', $this);
            }
        }

        do_action('gj_change_employer_status', $status, $send_email, $this);
    }

    public function can_edit() {
        if (current_user_can('edit_employer', $this->get_id())) {
            return true;
        }

        return false;
    }

    public function can_publish() {
        if (current_user_can('edit_employer', $this->get_id())) {
            if ($this->has_status(array('draft'))) {
                return true;
            }
        }

        return false;
    }

    public function edit_link() {
        $url = gj_dashboard_endpoint_url("company", $this->get_id());

        return $url;
    }


    static function get_status_array($draft = true) {
        $status = array(
            'publish' => esc_html__('Publish', 'gj'),
            'pending' => esc_html__('Pending', 'gj'),
            'gj-rejected' => esc_html__('Rejected', 'gj'),
        );

        if ($draft) {
            $status['draft'] = esc_html__('Draft', 'gj');
        }

        return $status;
    }

    static function get_status_title($status) {
        $status_arr = self::get_status_array();
        if (isset($status_arr[$status])) {
            return $status_arr[$status];
        }

        return '';
    }

    static function remove_reference($id) {
        if ($id && get_post_type($id) == 'gj_employer') {
            $fields = gj_fields($id);
            if($fields){
                foreach ($fields as $field){
                    $field->deletePost();
                }
            }

            $post = get_post($id);
            if ($post->post_status == 'publish') {
                delete_transient('gj_count_employers');
            }

            global $wpdb;

            $wpdb->delete($wpdb->prefix . 'gj_follows', array('post_id' => $id,), array('%d'));

            $employer = GJ_Employer::get_employer($post);
            $jobs = $employer->get_jobs('any', 'ids');
            if(count($jobs)){
                foreach ($jobs as $job) {
                    update_post_meta($job->ID, GJ_PREFIX.'employer', '');
                }
            }
        }
    }
}
