<?php
/**
 * @class 		GJ_Job
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Job extends GJ_Post {

    /**
     * @param null $post
     * @param bool $force
     * @return GJ_Job|null
     */
    static function get_job($post = null, $force = false) {
        return parent::get_post($post, $force);
    }

    function get_thumbnail($size = 'full') {
        $employer = $this->get_employer();
        if($employer){
            return $employer->get_thumbnail($size);
        }
        
        return get_avatar($this->get_author_id(), $size);
    }

    function get_currency() {
        return gj_option('job_currency' , 'USD');
    }

    function get_deadline() {
        $deadline = get_post_meta($this->get_id(), 'deadline', true);

        return $deadline;
    }

    function get_email_for_apply() {
        $employer = $this->get_author();
        $email_employer = $employer->get_email();
        $emails = get_post_meta($this->get_id(), 'email_application', true);
        if ($emails) {
            $emails_array = array_map('trim', explode(',', $emails));
            return $emails_array;
        } else {
            return $email_employer;
        }
    }

    function get_custom_apply_url() {
        return get_post_meta($this->get_id(), 'apply_url', true);
    }

    function get_related($args = array()) {

        $id = $this->get_id();
        $categories = $this->get_categories();

        $default_args = array(
            'post_type' => 'gj_job',
            'post_status' => gj_option('show_expired_job') ? array('publish', 'gj-expired') : 'publish',
            'post__not_in' => array($id),
            'post_author' => $this->get_author_id(),
            'posts_per_page' => gj_option('limit_item_related'),
        );

        if ($categories) {
            $default_args['tax_query'] = array('relation' => 'OR');
            foreach ($categories as $category) {
                $default_args['tax_query'][] = array(
                    'taxonomy' => 'gj_cat',
                    'field' => 'term_id',
                    'terms' => $category->term_id
                );
            }
        }

        $args = wp_parse_args($args, $default_args);
        $jobs = get_posts($args);
        if ($jobs) {
            foreach ($jobs as $key => $job) {
                $jobs[$key] = GJ_Job::get_job($job);
            }
        }

        return $jobs;
    }

    function get_jobs_by_author($args = array()) {
        $id = $this->get_id();

        $default_args = array(
            'posts_per_page' => -1,
            'post_type' => 'gj_job',
            'post_status' => gj_option('show_expired_job') ? array('publish', 'gj-expired') : 'publish',
            'post__not_in' => array($id),
            'post_author' => $this->get_author_id(),
        );

        $args = wp_parse_args($args, $default_args);
        $jobs = get_posts($args);
        if ($jobs) {
            foreach ($jobs as $key => $job) {
                $jobs[$key] = GJ_Job::get_job($job);
            }
        }

        return $jobs;
    }

    public function get_employer($status = '') {
        $employer_id = get_post_meta($this->get_id(), GJ_PREFIX . 'employer', true);
        if($employer_id){
            $employer = GJ_Employer::get_employer($employer_id);
        }else{
            $author = $this->get_author();
            $employer = $author->get_first_employer();
        }

        return $employer;
    }

    public function get_email(){
        $employer = $this->get_employer();
        if($employer){
            return $employer->get_email();
        }else{
            $author = $this->get_author();
            return $author->get_email();
        }
    }

    public function get_expiry() {
        return get_post_meta($this->get_id(), GJ_PREFIX . 'expiry', true);
    }

    public function is_never_expiry() {
        return get_post_meta($this->get_id(), GJ_PREFIX . 'never_expiry', true) ? true : false;
    }

    public function is_free(){
        return get_post_meta($this->get_id(), GJ_PREFIX . 'free_job', '1');
    }

    public function applications_permalink() {

        $url = gj_dashboard_endpoint_url("applications", $this->get_id());

        return $url;
    }

    public function count_applications() {
        global $wpdb;
        $sql = "SELECT COUNT(1) FROM {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON p.ID = pm.post_id
                  WHERE p.post_type = %s AND pm.meta_key = %s AND pm.meta_value = %s";
        $sql = $wpdb->prepare($sql, 'gj_application', GJ_PREFIX . 'job_id', $this->get_id());

        return $wpdb->get_var($sql);
    }

    public function get_application_ids($limit = 0) {
        global $wpdb;
        $sql = "SELECT ID FROM {$wpdb->posts} AS p JOIN {$wpdb->postmeta} AS pm ON p.ID = pm.post_id
                  WHERE p.post_type = %s AND pm.meta_key = %s AND pm.meta_value = %s";
        if ($limit) {
            $sql .= ' LIMIT 0,%d';
            $sql = $wpdb->prepare($sql, 'gj_application', GJ_PREFIX . 'job_id', $this->get_id(), $limit);
        } else {
            $sql = $wpdb->prepare($sql, 'gj_application', GJ_PREFIX . 'job_id', $this->get_id());
        }

        $applications = $wpdb->get_results($sql);
        $ids = array();
        if ($applications) {
            foreach ($applications as $application) {
                $ids[] = $application->ID;
            }
        }

        return $ids;
    }

    public function edit_link() {
        $url = gj_dashboard_endpoint_url("job", $this->get_id());
        return $url;
    }

    public function change_status($status, $send_email = true) {

        do_action('gj_before_change_job_status', $status, $send_email, $this);

        global $wpdb;
        $old_status = $this->get_status();

        if ($status != 'draft' && $status != 'pending' && !$this->post->post_name) {
            $post_name = sanitize_title($this->post->post_title);
            $post_name = wp_unique_post_slug($post_name, $this->get_id(), $status, 'gj_job', 0);

            $sql = "UPDATE {$wpdb->posts} SET post_status = %s, post_name = %s WHERE ID = %d";
            $wpdb->query($wpdb->prepare($sql, $status, $post_name, $this->get_id()));
        } else {
            $sql = "UPDATE {$wpdb->posts} SET post_status = %s WHERE ID = %d";
            $wpdb->query($wpdb->prepare($sql, $status, $this->get_id()));
        }

        if ($status == 'publish') {
            $this->set_publish();
        }elseif($status == 'gj-expired'){
            update_post_meta($this->get_id(), GJ_PREFIX.'featured', '');
        }

        if (($old_status != 'publish' && $status == 'publish' ) || ($old_status == 'publish' && $status != 'publish' )) {
            delete_transient('gj_count_jobs');
        }

        //clean cache
        $job = GJ_Job::get_job($this->get_id(), true);

        //send email
        if ($send_email) {
            if ($status == 'publish') {
                GJ_Email::send_email('approved_job', $job);
            } elseif ($status == 'pending') {
                GJ_Email::send_email('review_job', $job);
            } elseif ($status == 'gj-rejected') {
                GJ_Email::send_email('rejected_job', $job);
            }
            elseif ($status == 'gj-expired') {
                GJ_Email::send_email('expired_job', $job);
            }
        }

        //send to followers
        if ($status == 'publish') {
            GJ_Email::send_email('new_job', $job);
        }

        do_action('gj_change_job_status', $status, $send_email, $job);
    }

    public function set_publish() {
        $process = apply_filters('gj_publish_job', null, $this);
        if($process === false){
            return false;
        }

        $expiry = gj_get_job_expiry();
        update_post_meta($this->get_id(), GJ_PREFIX . 'never_expiry', '');
        update_post_meta($this->get_id(), GJ_PREFIX . 'expiry', $expiry);
    }

    public function renew() {
        $process = apply_filters('gj_renew_job', null, $this);
        if($process === false){
            return false;
        }

        global $wpdb;
        $wpdb->update($wpdb->posts, array('post_date' => current_time('mysql'), 'post_date_gmt' => current_time('mysql', true), 'post_modified' => current_time('mysql'), 'post_modified_gmt' => current_time('mysql', true)), array('ID' => $this->get_id()));
    }

    public function can_edit() {
        if (current_user_can('edit_job', $this->get_id())) {
            if (!$this->has_status(array('pending'))) {
                return true;
            } 
        }

        return false;
    }

    public function can_publish() {
        if (current_user_can('edit_job', $this->get_id())) {
            if ($this->has_status(array('draft', 'expired'))) {
                return true;
            }
        }

        return false;
    }

    public function can_unpublish() {
        if (current_user_can('edit_job', $this->get_id())) {
            if ($this->has_status(array('publish'))) {
                return true;
            }
        }

        return false;
    }

    public function can_apply() {
        if ($this->has_status('publish')) {

            $deadline = $this->get_deadline();

            if (!$deadline || ($deadline && (strtotime($deadline) + 86400) > current_time('timestamp'))) {
                return true;
            }
        }

        if ($this->has_status('expired')) {
            return 0;
        }

        return false;
    }

    public function can_delete() {
        if (
                current_user_can('delete_job', $this->get_id()) && $this->has_status(array('publish', 'pending', 'expired', 'reject', 'draft'))
        ) {
            return true;
        }

        return false;
    }

    public function can_renew() {
        if (
                current_user_can('edit_job', $this->get_id()) && $this->has_status(array('publish'))
        ) {
            return true;
        }

        return false;
    }

    public function can_make_featured() {
        if (
                current_user_can('edit_job', $this->get_id())
        ) {
            if ($this->has_status(array('publish', 'pending')) && !$this->is_featured() ) {
                return true;
            }
        }

        return false;
    }

    static function get_status_array($draft = true, $expired = false) {
        $status = array(
            'publish' => esc_html__('Publish', 'gj'),
            'pending' => esc_html__('Pending', 'gj'),
            'gj-rejected' => esc_html__('Rejected', 'gj'),
            'gj-expired' => esc_html__('Expired', 'gj'),
        );

        if ($expired) {
            $status['gj-expired'] = esc_html__('Expired', 'gj');
        }

        if ($draft) {
            $status['draft'] = esc_html__('Draft', 'gj');
        }

        return $status;
    }

    static function get_status_title($status) {
        $status_arr = self::get_status_array(true);
        if (isset($status_arr[$status])) {
            return $status_arr[$status];
        }

        return '';
    }

    static function remove_reference($job_id) {
        if ($job_id && get_post_type($job_id) == 'gj_job') {
            $fields = gj_fields($job_id);
            if($fields){
                foreach ($fields as $field){
                    $field->deletePost();
                }
            }

            if (get_post_status($job_id) == 'publish') {
                delete_transient('gj_count_jobs');
            }

            global $wpdb;
            $wpdb->delete($wpdb->prefix . 'gj_save_jobs', array('post_id' => $job_id,), array('%d'));
        }
    }

    function get_source_import() {
        $import_source = get_post_meta($this->get_id(), GJ_PREFIX . 'import_source', true);
        if ($import_source) {
            return $import_source;
        }

        return null;
    }

    /*function get_locations() {
        $args = array('orderby' => 'ID', 'order'=>'DESC');
        $locations = wp_get_post_terms($this->get_id(), 'gj_location', $args);

        return $locations;
    }

    function get_locations_links() {
        $location_links = array();
        $locations = $this->get_locations();
        if ($locations) {
            foreach ($locations as $location) {
                $location_links[] = '<a href="'.esc_url(get_term_link($location,'gj_location')).'"><span>' . $location->name . '</span></a>';
            }
        }

        if ($location_links) {
            return implode(', ', $location_links);
        } else {
            return '';
        }
    }*/

}
