<?php
/**
 * @class 		GJ_Candidate_Listing
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class GJ_Candidate_Listing extends GJ_Listing{

    public $post_type = 'gj_candidate';

    /**
     *
     * @return GJ_Candidate_Listing
     */
    static function instance(){
        return new GJ_Candidate_Listing();
    }

    /**
     *
     * @return Array
     */
    public function get_data_filters($source = null){
        static $data_filters = null;
        if(is_null($data_filters)) {
            if($source === null){
                $source = gj_clean($_REQUEST);
            }

            $data_filters = parent::get_data_filters($source);

            if (isset($source['min_rate']) && $source['min_rate'] !== '') {
                $data_filters['min_rate'] = intval($source['min_rate']);
            }

            if (isset($source['max_rate']) && $source['max_rate'] !== '') {
                $data_filters['max_rate'] = intval($source['max_rate']);
            }

            $data_filters = apply_filters('gj_filters_data', $data_filters);
        }

        return $data_filters;
    }

    /**
     *
     * @return Array
     */
    public function get_query_args($data_filters) {

        $args = parent::get_query_args($data_filters);

        $order_by = isset($data_filters['order']) && $data_filters['order'] ? $data_filters['order'] : null;
        if(!$order_by){
            $order_by = gj_option('sorting_candidates_default');
        }
        
        if($order_by == 'name'){
            $args['orderby'] = array(
                '_gj_featured_clause' => 'DESC',
                'title' => 'ASC',
            );
        }elseif($order_by == 'date'){
            $args['orderby'] = array(
                '_gj_featured_clause' => 'DESC',
                'date' => 'DESC',
            );
        }

        if(isset($data_filters['min_rate']) && $data_filters['min_rate'] !== '' && isset($data_filters['max_rate']) && $data_filters['max_rate'] !== ''){
            $args['meta_query'][] = array(
                'key' => 'hour_rate',
                'value' => [$data_filters['min_rate'], $data_filters['max_rate']],
                'type' => 'NUMERIC',
                'compare' => 'BETWEEN',
            );
        }

        if(isset($data_filters['recommend']) && $data_filters['recommend']){
            if (is_user_logged_in() && class_exists('GJ_User')) {
                $user = GJ_User::get_user();
                if ($user->is_employer()) {
                    $employer = $user->get_first_employer();
                    if ($employer) {
                        $categories = $employer->get_categories();
                        if ($categories) {
                            $args['gj_cat'] = wp_list_pluck($categories, 'term_id');
                        }
                        $skills = $employer->get_skills();
                        if ($skills) {
                            $args['gj_skill'] = wp_list_pluck($skills, 'term_id');
                        }
                        $levels = $employer->get_levels();
                        if ($levels) {
                            $args['gj_level'] = wp_list_pluck($levels, 'term_id');
                        }
                    }
                }
            }

            $args['meta_query']['relation'] = 'OR';
        }

        if(isset($data_filters['posts_per_page']) && $data_filters['posts_per_page']){
            $args['posts_per_page'] = $data_filters['posts_per_page'];
        }else{
            $args['posts_per_page'] = gj_option('candidates_per_page', get_option('posts_per_page', 20));
        }

        return $args;
    }

    /**
     *
     * @return Array
     */
    public function _get_request_args( $data_filters, $restrict = false ) {
        $args = parent::_get_request_args($data_filters, $restrict);

        if (isset($data_filters['min_rate']) && $data_filters['min_rate'] !== '' && isset($data_filters['max_rate']) && $data_filters['max_rate'] !== '') {
            $args['min_rate'] = $data_filters['min_rate'];
            $args['max_rate'] = $data_filters['max_rate'];
        }
        
        if(isset($args['order']) &&  $args['order'] == gj_option('sorting_employers_default')){
            unset($args['order']);
        }

        return $args;
    }
}