<?php
/**
 * Contains the query functions for inTravel which alter the front-end post queries and loops
 *
 * @class 		GJ_Job_Listing
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class GJ_Job_Listing extends GJ_Listing{

    /**
     *
     * @return GJ_Job_Listing
     */
    static function instance(){
        return new GJ_Job_Listing();
    }

    /**
     *
     * @return Array
     */

    public function get_data_filters($source = null){

        static $data_filters = null;

        if(is_null($data_filters)) {
            if($source === null){
                $source = gj_clean($_REQUEST);
            }

            $data_filters = parent::get_data_filters($source);

            if (isset($source['min_salary']) && $source['min_salary'] !== '') {
                $data_filters['min_salary'] = intval($source['min_salary']);
            }

            if (isset($source['max_salary']) && $source['max_salary'] !== '') {
                $data_filters['max_salary'] = intval($source['max_salary']);
            }

            $data_filters = apply_filters('gj_filters_data', $data_filters);
        }

        return $data_filters;
    }

    /**
     *
     * @param $query
     */
    public function add_query_url_params($query){

        $paged = get_query_var('page');

        $query->set('paged', $paged);

        $tax_query = array('relation' => 'AND');
        $filter_taxonomy = false;
        $job_taxs = $this->get_taxonomies();
        if($job_taxs){
            foreach ($job_taxs as $job_tax_key) {
                if ( isset($_GET[$job_tax_key]) && $_GET[$job_tax_key] ) {
                    $job_tax_values = gj_clean($_GET[$job_tax_key]);
                    $filter_taxs = array(
                        'taxonomy' => $job_tax_key,
                        'field'    => 'slug',
                        'terms'    => $job_tax_values,
                    );

                    if ( $filter_taxs ) {
                        array_push($tax_query, $filter_taxs);
                    }
                }
            }
        }

        if ($filter_taxonomy) {
            $query->set( 'tax_query', $tax_query );
        }

        if (isset($_GET['keyword']) && $_GET['keyword']) {
            $s = sanitize_text_field( $_GET['keyword'] );
            $query->set( 'search_prod_title', $s );
        }
    }

    /**
     *
     * @return Array
     */
    public function get_query_args($data_filters) {

        $args = parent::get_query_args($data_filters);
        $args['post_status'] = gj_option('show_expired_job') ? array('publish', 'gj-expired') : array('publish');

        $order_by = isset($data_filters['order']) && $data_filters['order'] ? $data_filters['order'] : null;
        if(!$order_by){
            $order_by = gj_option('sorting_jobs_default');
        }

        if($order_by == 'name'){
            $args['orderby'] = array(
                '_gj_featured_clause' => 'DESC',
                'title' => 'ASC',
            );
        }elseif($order_by == 'date'){
            $args['orderby'] = array(
                '_gj_featured_clause' => 'DESC',
                'date' => 'DESC',
            );
        }elseif ($order_by == 'salary') {
            $args['meta_query']['salary_to_clause'] = array(
                'key' => 'salary_to',
                'compare' => 'EXISTS',
                'type' => 'NUMERIC',
            );
            $args['meta_query']['salary_from_clause'] = array(
                'key' => 'salary_from',
                'compare' => 'EXISTS',
                'type' => 'NUMERIC',
            );
            $args['orderby'] = array(
                '_gj_featured_clause' => 'DESC',
                'salary_to_clause' => 'DESC',
                'salary_from_clause' => 'DESC',
            );
        }

        if(isset($data_filters['min_salary']) && $data_filters['min_salary'] !== '' && isset($data_filters['max_salary']) && $data_filters['max_salary'] !== ''){
            $args['meta_query'][] = array(
                'key' => 'salary_from',
                'value' => [$data_filters['min_salary'], $data_filters['max_salary']],
                'type' => 'NUMERIC',
                'compare' => 'BETWEEN',
            );

            $args['meta_query'][] = array(
                'key' => 'salary_to',
                'value' => [$data_filters['min_salary'], $data_filters['max_salary']],
                'type' => 'NUMERIC',
                'compare' => 'BETWEEN',
            );
        }

        if(isset($data_filters['recommend']) && $data_filters['recommend']){
            if (is_user_logged_in() && class_exists('GJ_User')) {
                $user = GJ_User::get_user();
                if ($user->is_candidate()) {
                    $candidate = $user->get_first_candidate();
                    if ($candidate) {
                        $categories = $candidate->get_categories();
                        if ($categories) {
                            $args['gj_cat'] = wp_list_pluck($categories, 'term_id');
                        }
                        $skills = $candidate->get_skills();
                        if ($skills) {
                            $args['gj_skill'] = wp_list_pluck($skills, 'term_id');
                        }
                        $levels = $candidate->get_levels();
                        if ($levels) {
                            $args['gj_level'] = wp_list_pluck($levels, 'term_id');
                        }
                    }
                }
            }

            $args['meta_query']['relation'] = 'OR';
        }

        if(isset($data_filters['posts_per_page']) && $data_filters['posts_per_page']){
            $args['posts_per_page'] = $data_filters['posts_per_page'];
        }else{
            $args['posts_per_page'] = gj_option('jobs_per_page', get_option('posts_per_page', 20));
        }

        return $args;
    }

    /**
     *
     * @return Array
     */
    public static function get_request_taxonomies($tax){
        $current_term = get_queried_object();
        static $taxonomies = array();
        if(!isset($taxonomies[$tax])){

            $taxonomies[$tax] = array();

            if ( isset($_REQUEST[$tax]) && $_REQUEST[$tax] ) {
                $taxonomies[$tax] = (array)gj_convert_tax_slug_to_id($tax, gj_clean($_REQUEST[$tax]));
            }

            if($current_term && isset($current_term->taxonomy) && $current_term->taxonomy == $tax){
                $taxonomies[$tax][] = $current_term->term_id;
            }

            if ($taxonomies[$tax]) {
                $taxonomies[$tax] = array_unique($taxonomies[$tax]);
            }
        }

        return $taxonomies[$tax];
    }

    /**
     *
     * @return Array
     */
    public function _get_request_args( $data_filters, $restrict = false ) {
        $args = parent::_get_request_args($data_filters, $restrict);


        if (isset($data_filters['min_salary']) && $data_filters['min_salary'] !== '' && isset($data_filters['max_salary']) && $data_filters['max_salary'] !== '') {
            $args['min_salary'] = $data_filters['min_salary'];
            $args['max_salary'] = $data_filters['max_salary'];
        }

        if(isset($data_filters['order']) &&  $data_filters['order'] == gj_option('sorting_jobs_default')){
            unset($data_filters['order']);
        }

        return $args;
    }
}

