<?php
/**
 * Contains the query functions for inTravel which alter the front-end post queries and loops
 *
 * @class 		GJ_Listing
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class GJ_Listing {

    public $post_type = 'gj_job';

    public function get_data_filtered($filters = null){
        if(is_null($filters)){
            $filters = $this->get_data_filters();
        }

        $unuses = array('paged', 'url', 'order', 'post_type', 'min_salary', 'max_salary');
        foreach ($unuses as $key) {
            if(isset($filters[$key])){
                unset($filters[$key]);
            }
        }

        $has_lat_lng = isset($filters['lng']) && $filters['lng'] && isset($filters['lat']) && $filters['lat'];
        if(isset($filters['location']) && (!$has_lat_lng || !$filters['location'])){
            unset($filters['location']);
        }
        if(isset($filters['radius']) && (!$has_lat_lng || !$filters['radius'])){
            unset($filters['radius']);
        }

        if(isset($filters['lng'])){
            unset($filters['lng']);
        }
        if(isset($filters['lat'])){
            unset($filters['lat']);
        }

        return $filters;
    }

    public function get_data_filters($source = null){
        if($source === null){
            $source = gj_clean($_REQUEST);
        }

        $data_filters = array();

        $data_filters['post_type'] = $this->post_type;

        if ( isset( $source['url']) ) {
            $data_filters['url'] = $source['url'];
        }

        if (isset($source['keyword']) && $source['keyword']) {
            $data_filters['keyword'] = sanitize_text_field($source['keyword']);
        }

        if (isset($source['order']) && $source['order']) {
            $data_filters['order'] = $source['order'];
        }

        if (isset($source['lat']) && $source['lat']) {
            $data_filters['lat'] = $source['lat'];
        }
        if (isset($source['lng']) && $source['lng']) {
            $data_filters['lng'] = $source['lng'];
        }
        if (isset($source['radius']) && $source['radius']) {
            $data_filters['radius'] = $source['radius'];
        }
        if (isset($source['location']) && $source['location']) {
            $data_filters['location'] = filter_var($source['location'], FILTER_SANITIZE_STRING);
        }
        if (isset($source['unit']) && $source['unit']) {
            $data_filters['unit'] = $source['unit'];
        }

        $data_filters['paged'] = isset($source['paged']) ? ($source['paged'])  : 1;

        if(get_query_var('page') > 1){
            $data_filters['paged'] = get_query_var('page');
        }

        $job_taxs = $this->get_taxonomies();
        $current_term = get_queried_object();

        foreach ($job_taxs as $tax_key) {
            $tax_slug = gj_get_taxonomy_slug($tax_key);
            if ( isset($source[$tax_slug]) && $source[$tax_slug] ) {
                $term_ids_f = (array)$source[$tax_slug];
                 $term_ids = array_map('sanitize_text_field', $term_ids_f);   
                if (isset($data_filters[$tax_key])) {
                    $data_filters[$tax_key] = array_merge($data_filters[$tax_key], $term_ids);
                } else {
                    $data_filters[$tax_key] = $term_ids;
                }
            }

            if($current_term && isset($current_term->taxonomy) && $current_term->taxonomy== $tax_key){
                if (isset($data_filters[$tax_key])) {
                    $data_filters[$tax_key][] = $current_term->slug;
                } else {
                    $data_filters[$tax_key] = (array)$current_term->slug;
                }
            }

            if (isset($data_filters[$tax_key])) {
                $data_filters[$tax_key] = array_unique($data_filters[$tax_key]);
            }
        }
        //var_dump($data_filters);die;

        return $data_filters;
    }

    public function get_taxonomies(){
        switch ($this->post_type){
            case 'gj_candidate' :
                return gj_get_candidate_taxonomies();
            case 'gj_employer' :
                return gj_get_employer_taxonomies();
            default:
                return gj_get_job_taxonomies();
        }
    }

    /**
     * Apply archive page / taxonomy page
     *
     * @param $query
     */
    public function add_query_url_params($query){

        $paged = get_query_var('page');

        $query->set('paged', $paged);

        $tax_query = array('relation' => 'AND');
        $filter_taxonomy = false;
        $job_taxs = $this->get_taxonomies();
        if($job_taxs){
            foreach ($job_taxs as $job_tax_key) {
                if ( isset($_GET[$job_tax_key]) && $_GET[$job_tax_key] ) {
                    $job_tax_values = gj_clean($_GET[$job_tax_key]);
                    $filter_taxs = array(
                        'taxonomy' => $job_tax_key,
                        'field'    => 'slug',
                        'terms'    => $job_tax_values,
                    );

                    if ( $filter_taxs ) {
                        array_push($tax_query, $filter_taxs);
                    }
                }
            }
        }

        if ($filter_taxonomy) {
            $query->set( 'tax_query', $tax_query );
        }

        if (isset($_GET['keyword']) && $_GET['keyword']) {
            $s = sanitize_text_field( $_GET['keyword'] );
            $query->set( 's', $s );
        }
    }

    /**
     * Apply ajax
     *
     * @return WP_Query
     */
    public function get_query_args($data_filters) {
        $args = array(
            'post_status' => array('publish'),
        );

        if (isset($data_filters['keyword']) && $data_filters['keyword']) {
            $args['search_prod_title'] = sanitize_text_field( $data_filters['keyword'] );
        }

        $filter_taxonomy = false;

        $args['tax_query'] = array(
            'relation' => 'AND'
        );

        if(isset($data_filters['featured']) && ($data_filters['featured']) !== ''){
            if($data_filters['featured']){
                $args['meta_query'][] = array(
                    'key' => '_gj_featured',
                    'compare' => '=',
                    'value' => '1',
                );
            }else{
                $args['meta_query'][] = array(
                    'key' => '_gj_featured',
                    'compare' => '=',
                    'value' => '',
                );
            }
        }

        $job_taxs = self::get_taxonomies();
        foreach ($job_taxs as $tax) {
            if ( isset($data_filters[$tax]) && is_array($data_filters[$tax]) && $data_filters[$tax] ) {
                $is_numb = is_int($data_filters[$tax][0]) ? true : false;
                $filter_taxonomy = true;
                $args['tax_query'][] = array(
                    'taxonomy' => $tax,
                    'field'    => $is_numb ? 'term_id' : 'slug',
                    'terms'    => $data_filters[$tax]
                );
            }
        }

        $order_by = isset($data_filters['order']) && $data_filters['order'] ? $data_filters['order'] : null;
       
        if(!isset($args['meta_query'])){
            $args['meta_query'] = array();
        }
        $args['meta_query']['_gj_featured_clause'] = array(
            'key' => '_gj_featured',
            'compare' => 'EXISTS',
        );
        if($order_by == 'name'){
            $args['orderby'] = array(
                '_gj_featured_clause' => 'DESC',
                'title' => 'ASC',
            );
        }else{
            $args['orderby'] = array(
                '_gj_featured_clause' => 'DESC',
                'date' => 'DESC',
            );
        }

        if (isset($data_filters['paged'])) {
            $args['paged'] = (int) $data_filters['paged'];
        } else {
            $args['paged'] = 1;
        }

        if ( !$filter_taxonomy ) {
            unset($args['tax_query']);
        }

        if(isset($data_filters['posts_per_page']) && $data_filters['posts_per_page']){
            $args['posts_per_page'] = $data_filters['posts_per_page'];
        }else{
            $args['posts_per_page'] = get_option('posts_per_page', 20);
        }

        $includes_args = array('post_type', 'date_query', 'fields', 'date', 'include', 'exclude', 'suppress_filters');
        foreach ($includes_args as $key) {
            if(isset($data_filters[$key])){
                $args[$key] = $data_filters[$key];
            }
        }

        $args = apply_filters('gj_filter_args', $args);

        return $args;
    }

    public function get_query($data_filters = null){
        if($data_filters == null){
            $data_filters = $this->get_data_filters();
        }

        $args = $this->get_query_args( $data_filters );

        do_action('gj_before_list_query', $args, $data_filters);
        add_filter( 'posts_where', 'gj_query_title_filter', 10, 2 );
        $query = new \WP_Query( $args );
        remove_filter( 'posts_where', 'gj_query_title_filter', 500 );
        do_action('gj_after_listing_query', $query, $args, $data_filters);
        $query = apply_filters('gj_listing_query', $query, $data_filters);
        return $query;
    }

    public function get_request_args($data_filters, $restrict = false){
        $args = $this->_get_request_args($data_filters, $restrict);

        return apply_filters('gj_listing_request_args', $args, $data_filters, $restrict);
    }

    public function _get_request_args( $data_filters, $restrict = false) {
        $args = array();

        $includes_args = array( 'feed', 'keyword', 'location', 'lat', 'lng', 'radius', 'unit');
        foreach ($includes_args as $key) {
            if(isset($data_filters[$key]) && $data_filters[$key]){
                $args[$key] = sanitize_text_field($data_filters[$key]);
            }
        }

        $taxonomy_names = self::get_taxonomies();
        foreach($taxonomy_names as $tax_key){
            if (isset($data_filters[$tax_key]) && is_array($data_filters[$tax_key]) && count($data_filters[$tax_key]) >0) {
                $tax_slug = gj_get_taxonomy_slug($tax_key);
                if(count($data_filters[$tax_key]) > 1){
                    foreach($data_filters[$tax_key] as $slug){
                        $args[$tax_slug.'%5B%5D='.$slug] = '';
                    }
                }else{
                    $args[$tax_slug.'='.$data_filters[$tax_key][0]] = '';
                }
            }
        }

        if(!$restrict){
            $includes_args = array( 'paged', 'order');
            foreach ($includes_args as $key) {
                if(isset($data_filters[$key]) && $data_filters[$key]){
                    if($key == 'paged'){
                        if($data_filters[$key] > 1){
                            $args['page'] = $data_filters[$key];
                        }
                    }else{
                        $args[$key] = $data_filters[$key];
                    }
                }
            }
        }

        return $args;
    }

    public function get_request_url( $filters = null, $restrict = false ) {
        if(is_null($filters)){
            $filters = $this->get_data_filters();
        }

        $args = $this->get_request_args($filters);

        if(isset($args['paged']) && $args['paged'] <=1){
            unset($args['paged']);
        }

        $url = '';
        if(!$restrict){
            if ( isset($filters['url']) ) {
                $url = $filters['url'];
            }else{
                $url = gj_get_page_permalink('jobs');
            }
        }
        $url = add_query_arg( $args, $url );

        $url = apply_filters('gj_listing_request_url', $url, $args, $filters, $restrict);

        return $url;
    }

    public function get_feed_url($filters = null){
        if(is_null($filters)){
            $filters = $this->get_data_filters();
        }

        $endpoint = str_replace('gj_', '', $this->post_type).'_feed';

        $filters['url'] = home_url('/');
        $filters = array('feed'=>$endpoint) + $filters;

        return $this->get_request_url($filters);
    }
}