<?php
/**
 * @class 		GJ_Log
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Order{
    static $cache = array();

    public $post;

    public function __construct($post)
    {
        $this->post = $post;
    }

    /**
     * @param null $post
     * @param bool $force
     * @return GJ_Order|null
     */
    static function get_order($post = null, $force = false){
        $post_id = 0;
        if($post === null){
            $post = get_post();
        }
        if(is_numeric($post)){
            $post = get_post($post);
            if($post && !is_wp_error($post)){
                $post_id = $post->ID;
            }
        }
        elseif(is_object($post))
        {
            $post_id = $post->ID;
        }

        if(isset($post->post_type) && $post->post_type != 'gj_order'){
            return null;
        }

        if($post_id){

            if($force){
                clean_post_cache( $post_id );
                $post = get_post($post_id);
            }

            if($force || !isset(self::$cache[$post_id])){
                self::$cache[$post_id] = new GJ_Order($post);
            }

            return self::$cache[$post_id];
        }

        return null;
    }

    public function get_id(){

        return $this->post->ID;
    }

    public function get_title(){

        return get_the_title($this->post->ID);
    }

    public function get_price(){

        return get_post_meta($this->post->ID, GJ_PREFIX.'price', true);
    }

    public function get_total_price(){

        return get_post_meta($this->post->ID, GJ_PREFIX.'total_price', true);
    }

    public function get_tax_price(){
        return get_post_meta($this->post->ID, GJ_PREFIX.'tax_price', true);
    }

    public function get_tax_value(){
        return get_post_meta($this->post->ID, GJ_PREFIX.'tax_value', true);
    }

    public function has_tax(){
        return get_post_meta($this->post->ID, GJ_PREFIX.'use_tax', true);
    }

    public function get_currency(){

        return get_post_meta($this->post->ID, GJ_PREFIX.'currency', true);
    }

    public function get_author_id(){
        return $this->post->post_author;
    }

    public function get_author(){
        return GJ_User::get_user($this->get_author_id());
    }

    public function get_created( $format = '' ){
        $created = $this->post->post_date;
        if($created && $format){
            return date_i18n($format, strtotime($created));
        }

        return $created;
    }

    public function get_purchased_date(){
        return get_post_meta($this->post->ID, GJ_PREFIX.'purchased_date', true);
    }

    public function get_key(){
        return get_post_meta($this->post->ID, GJ_PREFIX.'key', true);
    }

    function count_products(){
        $products = $this->get_products();
        return count($products);
    }

    /**
     * @return GJ_Product[]
     */
    public function get_products(){
        $_products = get_post_meta($this->post->ID, GJ_PREFIX.'products', true);
        $products = array();
        if($_products && is_array($_products)){
            foreach ($_products as $_product){
                $products[] = new GJ_Product($_product['type'], $_product['meta']);
            }
        }

        return $products;
    }

    /**
     * @return GJ_Product|null
     */
    function get_last_product(){
        $products = $this->get_products();
        if($products){
            return $products[count($products) -1];
        }

        return null;
    }

    public function completed_order($note = '', $send_email = true, $send_admin_email = true){
        $process = apply_filters('gj_before_completed_order', null, $this);

        if($process === false){
            return false;
        }

        $this->change_status('gj-completed', $note, $send_email, $send_admin_email);

        update_post_meta($this->get_id(), GJ_PREFIX.'purchased_date', current_time('timestamp'));

        $products = $this->get_products();
        foreach ($products as $product){
            $product->completed_order($this->get_author_id(), $this);
        }

        do_action('gj_after_completed_order', $this->get_id());
    }

    public function cancelled_order($note = '', $send_email = true){
        $process = apply_filters('gj_before_cancel_order', null, $this);

        if($process === false){
            return false;
        }

        $this->change_status('gj-cancelled', $note, $send_email);
        $products = $this->get_products();
        foreach ($products as $product){
            $product->cancelled_order($this->get_author_id(), $this);
        }

        do_action('gj_ater_cancelled_order', $this->get_id());
    }

    public function get_status(){
        return $this->post->post_status;
    }

    public function has_status($check_status){
        $check_status = !is_array($check_status) ? (array)$check_status : $check_status;
        $status = $this->get_status();
        $status = str_replace('gj-', '', $status);
        if(in_array($status, $check_status)){
            return true;
        }

        return false;
    }

    public function change_status($status, $note = '' , $send_email = true, $send_email_admin = true){
        $old_status = $this->get_status();

        global $wpdb;
        $sql = "UPDATE {$wpdb->posts} SET post_status = %s WHERE ID = %d";
        $wpdb->query($wpdb->prepare($sql, $status, $this->get_id()));
		
        if($old_status != $status){
            $transition_note = sprintf( esc_html__( 'Order status changed from %1$s to %2$s.', 'gj' ), $this->get_status_title($old_status), $this->get_status_title($status) );
        }else{
            $transition_note = sprintf( esc_html__( 'Order status set to %s.', 'gj' ), $this->get_status_title($status));
        }

        $note = $note ? $note . ' '.$transition_note : $transition_note;
        $this->add_order_note($note);
		$this->post->post_status = $status;

        //send email
        if($send_email){
            if($status == 'gj-completed'){
                GJ_Email::send_email('completed_order', $this);
            }elseif($status == 'gj-hold'){
                GJ_Email::send_email('hold_order', $this);
            }elseif($status == 'gj-cancelled'){
				GJ_Email::send_email('cancelled_order', $this);
			}
        }

        if($send_email_admin){
            if($status == 'gj-completed' || $status == 'gj-hold'){
                GJ_Email::send_email('new_order_admin', $this);
            }
        }
    }

    public function can_pay($key){
        if($this->get_author_id() != get_current_user_id()){
            return new WP_Error(1, esc_html__('You do not have permission to pay this order.', 'gj'));
        }

        if($key != $this->get_key()){
            return new WP_Error(2, esc_html__('Invalid key.', 'gj'));
        }

        return true;
    }

    public function can_view(){
        if($this->get_author_id() == get_current_user_id()){
            return true;
        }

        return false;
    }
    
    public function get_received_url() {
        $args = array(
            'order_id'=> $this->get_id(),
            'key'=> $this->get_key(),
        );

        $order_received_url = add_query_arg( $args, gj_dashboard_endpoint_url( 'thank-you-for-ordering' ) );

        return $order_received_url;
    }

    public function get_pay_url(){
        $pay_url = add_query_arg( array(
            'order_id'=> $this->get_id(),
            'key'=> $this->get_key(),
        ), gj_dashboard_endpoint_url('pay-order'));

        return $pay_url;
    }

    public function get_cancel_url($redirect = '') {
        $cancel_url = add_query_arg( array(
            'gj_cancel_order'=> 'true',
            'order_id'=> $this->get_id(),
            'key'=> $this->get_key(),
            'redirect'=> $redirect ? $redirect : gj_get_page_permalink( 'dashboard' ),
        ), gj_get_page_permalink( 'dashboard' ) );

        return $cancel_url;
    }

    public function add_order_note( $note, $is_customer_note = 0, $added_by_user = false ) {
        if ( ! $this->get_id() ) {
            return 0;
        }

        if ( is_user_logged_in() && current_user_can('manage_options') && $added_by_user ) {
            $user                 = get_user_by( 'id', get_current_user_id() );
            $comment_author       = $user->display_name;
            $comment_author_email = $user->user_email;
        } else {
            $comment_author       = 'gj';
            $comment_author_email = strtolower( 'gj' ) . '@';
            $comment_author_email .= isset( $_SERVER['HTTP_HOST'] ) ? str_replace( 'www.', '', $_SERVER['HTTP_HOST'] ) : 'noreply.com';
            $comment_author_email = sanitize_email( $comment_author_email );
        }
        $commentdata = apply_filters( 'gj_new_order_note_data', array(
            'comment_post_ID'      => $this->get_id(),
            'comment_author'       => $comment_author,
            'comment_author_email' => $comment_author_email,
            'comment_author_url'   => '',
            'comment_content'      => $note,
            'comment_agent'        => 'gj',
            'comment_type'         => 'order_note',
            'comment_parent'       => 0,
            'comment_approved'     => 1,
        ), array( 'order_id' => $this->get_id(), 'is_customer_note' => $is_customer_note ) );

        $comment_id = wp_insert_comment( $commentdata );

        return $comment_id;
    }

    static function get_status_array($cancel = true, $pendingPayment = false){
        $status = array(
            'gj-completed' => esc_html__('Compeleted', 'gj'),
            'gj-hold' => esc_html__('Hold', 'gj'),
        );

        if($cancel){
            $status['gj-cancelled'] = esc_html__('Canceled', 'gj');
        }

        if($pendingPayment){
            $status['gj-pending-payment'] = esc_html__('Pending payment', 'gj');
        }

        return $status;
    }

    static public function get_status_title($status){
        $status_array = self::get_status_array(true, true);
        return isset($status_array[$status]) ? $status_array[$status] : '';
    }

    public function get_payment_method_id(){
        return get_post_meta($this->post->ID, GJ_PREFIX.'payment_method', true);
    }

    public function get_payment_method(){
        return GJ()->payment_gateways->get_payment_gateway($this->get_payment_method_id());
    }

    public function get_payment_method_title(){
        return get_post_meta($this->post->ID, GJ_PREFIX.'payment_method_title', true);
    }

    public function get_view_link(){
        $url = gj_dashboard_endpoint_url("order");

        $permalink = get_option( 'permalink_structure' );
        if(substr($permalink, -12) === '/%postname%/'){
            $url = $url."/".$this->get_id();
        }else{
            $url = add_query_arg(array('postID' => $this->get_id()), $url);
        }

        return $url;
    }

    public function get_admin_url(){
        return get_admin_url().'post.php?post='.$this->get_id().'&action=edit';
    }

    /**
     * @param GJ_Cart $cart
     * @return int|WP_Error
     */
    static function create_new($cart, $args = array()){
        $post_args = array(
            'post_title' => '',
            'post_type' => 'gj_order',
            'post_status' =>  isset($args['post_status']) ? $args['post_status'] : 'gj-pending-payment',
            'post_author' => isset($args['post_author']) ? $args['post_author'] : get_current_user_id()
        );

        $post_id = wp_insert_post($post_args);
        if($post_id) {
            wp_update_post(array(
                'ID' => $post_id,
                'post_title' => sprintf(esc_html__('Order #%d', 'gj'), $post_id)
            ));


            $order = self::get_order($post_id);

            $order->update_cart_info($cart);

            do_action('gj_create_new_order', $post_id, $cart);

            $cart->empty_cart();
        }

        return $post_id;
    }

    /**
     * @param GJ_Cart $cart
     */
    function update_cart_info($cart){
        $post_id = $this->get_id();
        update_post_meta($post_id, GJ_PREFIX . 'key', wp_generate_password(12, false));
        update_post_meta($post_id, GJ_PREFIX . 'currency', $cart->get_currency());
        update_post_meta($post_id, GJ_PREFIX . 'price', $cart->get_sub_total_price());
        update_post_meta($post_id, GJ_PREFIX . 'total_price', $cart->get_total_price());
        $use_tax = gj_option('tax_used');
        if($use_tax){
            update_post_meta($post_id, GJ_PREFIX . 'use_tax', 1);
            update_post_meta($post_id, GJ_PREFIX . 'tax_price', $cart->get_tax_price());
        }

        $products = $cart->get_products();
        $meta_products = array();

        foreach ($products as $product){
            $meta_products[] = array(
                'type' => $product->type,
                'meta' => $product->get_meta()
            );
        }

        update_post_meta($post_id, GJ_PREFIX . 'products', $meta_products);

        do_action('gj_update_cart_info', $cart, $this);
    }
}