<?php
/**
 * @class 		GJ_Post_Types
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Post_Types
{
    static function init(){
        add_action( 'init', array( __CLASS__, 'register_post_types' ), 5 );
        add_action( 'init', array( __CLASS__, 'register_post_status' ), 9 );
    }

    static function get_job_capabilities(){
        $caps = array(
            // meta caps (don't assign these to roles)
            'edit_post'              => 'edit_job',
            'read_post'              => 'read_job',
            'delete_post'            => 'delete_job',

            // primitive/meta caps
            'create_posts'           => 'create_jobs',

            // primitive caps used outside of map_meta_cap()
            'edit_posts'             => 'edit_jobs',
            'edit_others_posts'      => 'edit_others_jobs',
            'publish_posts'          => 'publish_jobs',
            'read_private_posts'     => 'read_private_jobs',

            // primitive caps used inside of map_meta_cap()
            'read'                   => 'read',
            'delete_posts'           => 'delete_jobs',
            'delete_private_posts'   => 'delete_private_jobs',
            'delete_published_posts' => 'delete_published_jobs',
            'delete_others_posts'    => 'delete_others_jobs',
            'edit_published_posts'   => 'edit_published_jobs',
            'edit_private_posts'     => 'edit_private_jobs',
        );

        return $caps;
    }

    static function get_employer_capabilities(){
        $caps = array(
            // meta caps (don't assign these to roles)
            'edit_post'              => 'edit_employer',
            'read_post'              => 'read_employer',
            'delete_post'            => 'delete_employer',

            // primitive/meta caps
            'create_posts'           => 'create_employers',

            // primitive caps used outside of map_meta_cap()
            'edit_posts'             => 'edit_employers',
            'edit_others_posts'      => 'edit_others_employers',
            'publish_posts'          => 'publish_employers',
            'read_private_posts'     => 'read_private_employers',

            // primitive caps used inside of map_meta_cap()
            'read'                   => 'read',
            'delete_posts'           => 'delete_employers',
            'delete_private_posts'   => 'delete_private_employers',
            'delete_published_posts' => 'delete_published_employers',
            'delete_others_posts'    => 'delete_others_employers',
            'edit_published_posts'   => 'edit_published_employers',
            'edit_private_posts'     => 'edit_private_employers',
        );

        return $caps;
    }


    static function get_candidate_capabilities(){
        $caps = array(
            // meta caps (don't assign these to roles)
            'edit_post'              => 'edit_candidate',
            'read_post'              => 'read_candidate',
            'delete_post'            => 'delete_candidate',

            // primitive/meta caps
            'create_posts'           => 'create_candidates',

            // primitive caps used outside of map_meta_cap()
            'edit_posts'             => 'edit_candidates',
            'edit_others_posts'      => 'edit_others_candidates',
            'publish_posts'          => 'publish_candidates',
            'read_private_posts'     => 'read_private_candidates',

            // primitive caps used inside of map_meta_cap()
            'read'                   => 'read',
            'delete_posts'           => 'delete_candidates',
            'delete_private_posts'   => 'delete_private_candidates',
            'delete_published_posts' => 'delete_published_candidates',
            'delete_others_posts'    => 'delete_others_candidates',
            'edit_published_posts'   => 'edit_published_candidates',
            'edit_private_posts'     => 'edit_private_candidates',
        );

        return $caps;
    }

    static function register_post_types(){

        //Resigter Job Listing
        $labels = array(
            'name' 					=> esc_html__('Jobs', 'gj'),
            'singular_name' 		=> esc_html__('Job', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Jobs', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Job', 'gj'),
            'edit_item' 			=> esc_html__('Edit Job', 'gj'),
            'new_item' 				=> esc_html__('New Job', 'gj'),
            'view_item' 			=> esc_html__('View Job', 'gj'),
            'search_items' 			=> esc_html__('Search Job', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'not_found_in_trash' 	=> esc_html__('Not found in trash', 'gj'),
            'parent_item_colon' 	=> '',
        );

        $args = array(
            'labels' 			=> $labels,
            'public' 			=> true,
            'show_ui' 			=> true,
            'capability_type' 	=> 'page',
            'map_meta_cap'    => true,
            'capabilities'    => self::get_job_capabilities(),
            'taxonomies'        => array( 'gj_type', ),
            'hierarchical' 		=> true,
            'rewrite' 			=> array('slug' => gj_option('job_slug', 'job'), 'with_front' => true),
            //'query_var' 		=> true,
            'exclude_from_search' => true,
            'show_in_nav_menus' => true,
            'show_in_rest' => true,
            'has_archive'       => false,
            'supports' 			=> array('title', 'editor', 'author'),
        );

        register_post_type( 'gj_job' , $args );

        //Resigter Employer
        $labels = array(
            'name' 					=> esc_html__('Employers', 'gj'),
            'singular_name' 		=> esc_html__('Employer', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Employers', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Employer', 'gj'),
            'edit_item' 			=> esc_html__('Edit Employer', 'gj'),
            'new_item' 				=> esc_html__('New Employer', 'gj'),
            'view_item' 			=> esc_html__('View Employer', 'gj'),
            'search_items' 			=> esc_html__('Search Employer', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'not_found_in_trash' 	=> esc_html__('Not found in trash', 'gj'),
            'parent_item_colon' 	=> '',
        );

        $args = array(
            'labels' 			=> $labels,
            'public' 			=> true,
            'show_ui' 			=> true,
            'hierarchical' 		=> false,
            'rewrite' 			=> array('slug' => gj_option('employer_slug', 'employer'), 'with_front' => true),
            //'query_var' 		=> true,
            'exclude_from_search' => true,
            'show_in_nav_menus' => true,
            'show_in_rest' => true,
            'has_archive'       => false,
            'supports' 			=> array('title', 'editor', 'author'),
            'map_meta_cap'    => true,
            'capabilities'    => self::get_employer_capabilities(),
        );

        register_post_type( 'gj_employer' , $args );

        //Resigter Candidate
        $labels = array(
            'name' 					=> esc_html__('Candidates', 'gj'),
            'singular_name' 		=> esc_html__('Candidate', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Candidates', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Candidate', 'gj'),
            'edit_item' 			=> esc_html__('Edit Candidate', 'gj'),
            'new_item' 				=> esc_html__('New Candidate', 'gj'),
            'view_item' 			=> esc_html__('View Candidate', 'gj'),
            'search_items' 			=> esc_html__('Search Candidate', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'not_found_in_trash' 	=> esc_html__('Not found in trash', 'gj'),
            'parent_item_colon' 	=> '',
        );

        $args = array(
            'labels' 			=> $labels,
            'public' 			=> true,
            'show_ui' 			=> true,
            'hierarchical' 		=> false,
            'rewrite' 			=> array('slug' => gj_option('candidate_slug', 'candidate'), 'with_front' => true),
            //'query_var' 		=> true,
            'exclude_from_search' => true,
            'show_in_nav_menus' => true,
            'show_in_rest' => true,
            'has_archive'       => false,
            'supports' 			=> array('title', 'editor', 'author'),
            'map_meta_cap'    => true,
            'capabilities'    => self::get_candidate_capabilities(),
        );

        register_post_type( 'gj_candidate' , $args );

        //Applications
        $labels = array(
            'name' 					=> esc_html__('Applications', 'gj'),
            'singular_name' 		=> esc_html__('Application', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Applications', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Application', 'gj'),
            'edit_item' 			=> esc_html__('Edit Applications', 'gj'),
            'new_item' 				=> esc_html__('New Applications', 'gj'),
            'view_item' 			=> esc_html__('View Applications', 'gj'),
            'search_items' 			=> esc_html__('Search Applications', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'not_found_in_trash' 	=> esc_html__('Not found in trash', 'gj'),
            'parent_item_colon' 	=> '',
        );

        $args = array(
            'labels' 			=> $labels,
            'public' 			=> false,
            'show_ui' 			=> true,
            'capability_type' 	=> 'page',
            'hierarchical' 		=> false,
            'rewrite' 			=> false,
            //'query_var' 		=> true,
            'exclude_from_search' => true,
            'show_in_nav_menus' => true,
            //'show_in_menu' => 'edit.php?post_type=gj_job',
            'has_archive'       => true,
            'supports' 			=> array('title', 'editor'),
            'map_meta_cap'        => true,
            'capabilities' => array(
                'create_posts' => false
            )
        );

        register_post_type( 'gj_application' , $args );

        //Order
        $labels = array(
            'name' 					=> esc_html__('Orders', 'gj'),
            'singular_name' 		=> esc_html__('Order', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Orders', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Order', 'gj'),
            'edit_item' 			=> esc_html__('Edit Order', 'gj'),
            'new_item' 				=> esc_html__('New Order', 'gj'),
            'view_item' 			=> esc_html__('View Order', 'gj'),
            'search_items' 			=> esc_html__('Search Order', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'not_found_in_trash' 	=> esc_html__('Not found in trash', 'gj'),
            'parent_item_colon' 	=> '',
        );

        $args = array(
            'labels' 			=> $labels,
            'public' 			=> false,
            'show_ui' 			=> true,
            'capability_type' 	=> 'page',
            'hierarchical' 		=> false,
            'rewrite' 			=> false,
            //'query_var' 		=> true,
            'show_in_nav_menus' => true,
            'show_in_menu' => 'edit.php?post_type=gj_job',
            'has_archive'       => true,
            'supports' 			=> array('title'),
            'map_meta_cap'        => true,
            'capabilities' => array(
                'create_posts' => false
            )
        );

        register_post_type( 'gj_order' , $args );

        //Register Cat
        $labels = array(
            'name' 					=> esc_html__('Categories', 'gj'),
            'popular_items' 		=> esc_html__('Popular Categories', 'gj'),
            'singular_name' 		=> esc_html__('Category', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Categories', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Category', 'gj'),
            'edit_item' 			=> esc_html__('Edit Category', 'gj'),
            'new_item' 				=> esc_html__('New Category', 'gj'),
            'view_item' 			=> esc_html__('View Category', 'gj'),
            'search_items' 			=> esc_html__('Search Category', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
        );

        register_taxonomy('gj_cat',
            array('gj_job', 'gj_candidate', 'gj_employer'),
            array(
                'hierarchical' 		=> true,
                'public'            => true,
                'labels' 			=> $labels,
                'show_admin_column'	=> false,
                'show_in_rest'	=> true,
                //'query_var' 		=> true,
                'rewrite'           => array(
                    'slug'                       => gj_option('category_slug', 'category'),
                    'with_front'                 => true,
                    'hierarchical'               => false,
                ),
            )
        );

        if(!gj_option('disable_type')){
            //Register Type
            $labels = array(
                'name' 					=> esc_html__('Types', 'gj'),
                'popular_items' 		=> esc_html__('Popular Types', 'gj'),
                'singular_name' 		=> esc_html__('Type', 'gj'),
                'add_new' 				=> esc_html__('Add New', 'gj'),
                'all_items' 			=> esc_html__('Types', 'gj'),
                'add_new_item' 			=> esc_html__('Add New Type', 'gj'),
                'edit_item' 			=> esc_html__('Edit Type', 'gj'),
                'new_item' 				=> esc_html__('New Type', 'gj'),
                'view_item' 			=> esc_html__('View Type', 'gj'),
                'search_items' 			=> esc_html__('Search Type', 'gj'),
                'not_found' 			=> esc_html__('Not found', 'gj'),
                'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
            );

            register_taxonomy('gj_type',
                array('gj_job', 'gj_candidate'),
                array(
                    'hierarchical' 		=> true,
                    'public'            => true,
                    'labels' 			=> $labels,
                    'show_admin_column'	=> false,
                    'show_in_rest'	=> true,
                    //'query_var' 		=> true,
                    'rewrite'           => array(
                        'slug'                       => gj_option('type_slug', 'type'),
                        'with_front'                 => true,
                        'hierarchical'               => false,
                    ),
                )
            );
        }

        //Register Price
        $labels = array(
            'name' 					=> esc_html__('Salaries', 'gj'),
            'popular_items' 		=> esc_html__('Popular Salaries', 'gj'),
            'singular_name' 		=> esc_html__('Salary', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Salary', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Salary', 'gj'),
            'edit_item' 			=> esc_html__('Edit Salary', 'gj'),
            'new_item' 				=> esc_html__('New Salary', 'gj'),
            'view_item' 			=> esc_html__('View Salary', 'gj'),
            'search_items' 			=> esc_html__('Search Salary', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
        );

        register_taxonomy('gj_salary',
            array('gj_job'),
            array(
                'hierarchical' 		=> true,
                'public'            => true,
                'labels' 			=> $labels,
                'show_admin_column'	=> false,
                'show_in_rest'	=> true,
                //'query_var' 		=> true,
                'rewrite'           => array(
                    'slug'                       => gj_option('salary_slug', 'salary'),
                    'with_front'                 => true,
                    'hierarchical'               => false,
                ),
            )
        );

        if(!gj_option('disable_skill')) {
            //Register skill
            $labels = array(
                'name' => esc_html__('Skills', 'gj'),
                'popular_items' => esc_html__('Popular Skills', 'gj'),
                'singular_name' => esc_html__('Skill', 'gj'),
                'add_new' => esc_html__('Add New', 'gj'),
                'all_items' => esc_html__('Skills', 'gj'),
                'add_new_item' => esc_html__('Add New Skill', 'gj'),
                'edit_item' => esc_html__('Edit Skill', 'gj'),
                'new_item' => esc_html__('New Skill', 'gj'),
                'view_item' => esc_html__('View Skill', 'gj'),
                'search_items' => esc_html__('Search Skill', 'gj'),
                'not_found' => esc_html__('Not found', 'gj'),
                'no_terms' => esc_html__('Not found in trash', 'gj'),
            );

            register_taxonomy('gj_skill',
                array('gj_job', 'gj_candidate', 'gj_employer'),
                array(
                    'hierarchical' => true,
                    'public' => true,
                    'labels' => $labels,
                    'show_admin_column' => false,
                    'show_in_rest'	=> true,
                    //'query_var' 		=> true,
                    'rewrite' => array(
                        'slug' => gj_option('skill_slug', 'salary'),
                        'with_front' => true,
                        'hierarchical' => false,
                    ),
                )
            );
        }

        if(!gj_option('disable_level')) {

            //Register level
            $labels = array(
                'name' => esc_html__('Levels', 'gj'),
                'popular_items' => esc_html__('Popular Levels', 'gj'),
                'singular_name' => esc_html__('Level', 'gj'),
                'add_new' => esc_html__('Add New', 'gj'),
                'all_items' => esc_html__('Levels', 'gj'),
                'add_new_item' => esc_html__('Add New Level', 'gj'),
                'edit_item' => esc_html__('Edit Level', 'gj'),
                'new_item' => esc_html__('New Level', 'gj'),
                'view_item' => esc_html__('View Level', 'gj'),
                'search_items' => esc_html__('Search Level', 'gj'),
                'not_found' => esc_html__('Not found', 'gj'),
                'no_terms' => esc_html__('Not found in trash', 'gj'),
            );

            register_taxonomy('gj_level',
                array('gj_job', 'gj_candidate'),
                array(
                    'hierarchical' => true,
                    'public' => true,
                    'labels' => $labels,
                    'show_admin_column' => false,
                    'show_in_rest'	=> true,
                    //'query_var' 		=> true,
                    'rewrite' => array(
                        'slug' => gj_option('level_slug', 'level'),
                        'with_front' => true,
                        'hierarchical' => false,
                    ),
                )
            );
        }

        //Register Expericence
        $labels = array(
            'name' 					=> esc_html__('Experiences', 'gj'),
            'popular_items' 		=> esc_html__('Experiences', 'gj'),
            'singular_name' 		=> esc_html__('Experience', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Experience', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Experience', 'gj'),
            'edit_item' 			=> esc_html__('Edit Experience', 'gj'),
            'new_item' 				=> esc_html__('New Experience', 'gj'),
            'view_item' 			=> esc_html__('View Experience', 'gj'),
            'search_items' 			=> esc_html__('Search Experience', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
        );

        register_taxonomy('gj_expericence',
            array('gj_job', 'gj_candidate'),
            array(
                'hierarchical' 		=> true,
                'public'            => true,
                'labels' 			=> $labels,
                'show_admin_column'	=> false,
                'show_in_rest'	=> true,
                //'query_var' 		=> true,
                'rewrite'           =>  array(
                    'slug'                       => gj_option('expericence_slug', 'expericence'),
                    'with_front'                 => true,
                    'hierarchical'               => false,
                ),
            )
        );

        //Register Gender
        $labels = array(
            'name' 					=> esc_html__('Gender', 'gj'),
            'popular_items' 		=> esc_html__('Gender', 'gj'),
            'singular_name' 		=> esc_html__('Gender', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Gender', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Gender', 'gj'),
            'edit_item' 			=> esc_html__('Edit Gender', 'gj'),
            'new_item' 				=> esc_html__('New Gender', 'gj'),
            'view_item' 			=> esc_html__('View Gender', 'gj'),
            'search_items' 			=> esc_html__('Search Gender', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
        );

        register_taxonomy('gj_gender',
            array('gj_job', 'gj_candidate'),
            array(
                'hierarchical' 		=> true,
                'public'            => true,
                'labels' 			=> $labels,
                'show_admin_column'	=> false,
                'show_in_rest'	=> true,
                //'query_var' 		=> true,
                'rewrite'           =>  array(
                    'slug'                       => gj_option('gender_slug', 'gender'),
                    'with_front'                 => true,
                    'hierarchical'               => false,
                ),
            )
        );

        //Register State
        $labels = array(
            'name' 					=> esc_html__('States', 'gj'),
            'popular_items' 		=> esc_html__('Popular States', 'gj'),
            'singular_name' 		=> esc_html__('State', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('States', 'gj'),
            'add_new_item' 			=> esc_html__('Add New', 'gj'),
            'edit_item' 			=> esc_html__('Edit State', 'gj'),
            'new_item' 				=> esc_html__('New State', 'gj'),
            'view_item' 			=> esc_html__('View State', 'gj'),
            'search_items' 			=> esc_html__('Search State', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
        );

        register_taxonomy('gj_state',
            array('gj_job', 'gj_candidate', 'gj_employer'),
            array(
                'hierarchical' 		=> false,
                'public'            => true,
                'labels' 			=> $labels,
                'show_admin_column'	=> false,
                'show_in_rest'	=> true,
                //'query_var' 		=> true,
                'rewrite'           => array(
                    'slug'                       => gj_option('state_slug', 'state'),
                    'with_front'                 => true,
                    'hierarchical'               => false,
                ),
            )
        );

        //Register City
        $labels = array(
            'name' 					=> esc_html__('Cities', 'gj'),
            'popular_items' 		=> esc_html__('Popular Cities', 'gj'),
            'singular_name' 		=> esc_html__('City', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Cities', 'gj'),
            'add_new_item' 			=> esc_html__('Add New', 'gj'),
            'edit_item' 			=> esc_html__('Edit City', 'gj'),
            'new_item' 				=> esc_html__('New City', 'gj'),
            'view_item' 			=> esc_html__('View City', 'gj'),
            'search_items' 			=> esc_html__('Search City', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
        );

        register_taxonomy('gj_city',
            array('gj_job', 'gj_candidate', 'gj_employer'),
            array(
                'hierarchical' 		=> false,
                'public'            => true,
                'labels' 			=> $labels,
                'show_admin_column'	=> false,
                'show_in_rest'	=> true,
                //'query_var' 		=> true,
                'rewrite'           => array(
                    'slug'                       => gj_option('city_slug', 'city'),
                    'with_front'                 => true,
                    'hierarchical'               => false,
                ),
            )
        );

        //Register Sizes
        $labels = array(
            'name' 					=> esc_html__('Sizes', 'gj'),
            'popular_items' 		=> esc_html__('Sizes', 'gj'),
            'singular_name' 		=> esc_html__('Size', 'gj'),
            'add_new' 				=> esc_html__('Add New', 'gj'),
            'all_items' 			=> esc_html__('Size', 'gj'),
            'add_new_item' 			=> esc_html__('Add New Size', 'gj'),
            'edit_item' 			=> esc_html__('Edit Size', 'gj'),
            'new_item' 				=> esc_html__('New Size', 'gj'),
            'view_item' 			=> esc_html__('View Size', 'gj'),
            'search_items' 			=> esc_html__('Search Size', 'gj'),
            'not_found' 			=> esc_html__('Not found', 'gj'),
            'no_terms' 	            => esc_html__('Not found in trash', 'gj'),
        );

        register_taxonomy('gj_size',
            array('gj_job', 'gj_employer'),
            array(
                'hierarchical' 		=> true,
                'public'            => true,
                'labels' 			=> $labels,
                'show_admin_column'	=> false,
                'show_in_rest'	=> true,
                //'query_var' 		=> true,
                'rewrite'           => false,
            )
        );

        $labels = array(
            'name'                  => esc_html__('Gj Field Groups', 'gj'),
        );
        $args = array(
            'labels'             => $labels,
            'public' 			=> false,
            'show_ui' 			=> false,
            'capability_type' 	=> 'page',
            'hierarchical' 		=> false,
            'rewrite' 			=> false,
            //'query_var' 		=> true,
            'exclude_from_search' => true,
            'show_in_nav_menus' => false,
            'show_in_menu' => false,
            'has_archive'       => false,
            'supports' 			=> array('title'),
            'map_meta_cap'        => true,
            'capabilities' => array(
                'create_posts' => false
            )
        );

        register_post_type( 'gj_field_groups' , $args );

        $labels = array(
            'name'                  => esc_html__('Gj Fields', 'gj'),
        );
        $args = array(
            'labels'             => $labels,
            'public' 			=> false,
            'show_ui' 			=> true,
            'capability_type' 	=> 'page',
            'hierarchical' 		=> false,
            'rewrite' 			=> false,
            //'query_var' 		=> true,
            'exclude_from_search' => true,
            'show_in_nav_menus' => false,
            'show_in_menu' => false,
            'has_archive'       => false,
            'supports' 			=> array('title'),
            'map_meta_cap'        => true,
            'capabilities' => array(
                'create_posts' => false
            )
        );

        register_post_type( 'gj_fields' , $args );

    }

    static function register_post_status(){
        $order_statuses = apply_filters( 'gj_register_order_post_statuses',
            array(
                'gj-pending-payment'    => array(
                    'label'                     => _x( 'Pending Payment', 'Order status', 'gj' ),
                    'public'                    => false,
                    'private'                   => 'protected',
                    'exclude_from_search'       => true,
                    'show_in_admin_all_list'    => false,
                    'show_in_admin_status_list' => false,
                    'label_count'               => _n_noop( 'Pending Payment <span class="count">(%s)</span>', 'Pending Payment <span class="count">(%s)</span>', 'gj' )
                ),
                'gj-expired'    => array(
                    'label'                     => _x( 'Expired', 'Order status', 'gj' ),
                    'public'                    => gj_option('show_expired_job') ? true : false,
                    'private'                    => true,
                    'exclude_from_search'       => true,
                    'show_in_admin_all_list'    => true,
                    'show_in_admin_status_list' => true,
                    'label_count'               => _n_noop( 'Expired <span class="count">(%s)</span>', 'Expired <span class="count">(%s)</span>', 'gj' )
                ),
                'gj-rejected'    => array(
                    'label'                     => _x( 'Reject', 'Order status', 'gj' ),
                    'public'                    => false,
                    'private'                    => true,
                    'exclude_from_search'       => true,
                    'show_in_admin_all_list'    => true,
                    'show_in_admin_status_list' => true,
                    'label_count'               => _n_noop( 'Reject <span class="count">(%s)</span>', 'Reject <span class="count">(%s)</span>', 'gj' )
                ),
                'gj-completed'    => array(
                    'label'                     => _x( 'Completed', 'Order status', 'gj' ),
                    'public'                    => false,
                    'exclude_from_search'       => true,
                    'show_in_admin_all_list'    => true,
                    'show_in_admin_status_list' => true,
                    'label_count'               => _n_noop( 'Completed <span class="count">(%s)</span>', 'Completed <span class="count">(%s)</span>', 'gj' )
                ),
                'gj-hold'    => array(
                    'label'                     => _x( 'Hold', 'Order status', 'gj' ),
                    'public'                    => false,
                    'exclude_from_search'       => true,
                    'show_in_admin_all_list'    => true,
                    'show_in_admin_status_list' => true,
                    'label_count'               => _n_noop( 'Hold <span class="count">(%s)</span>', 'Hold <span class="count">(%s)</span>', 'gj' )
                ),
                'gj-cancelled'    => array(
                    'label'                     => _x( 'Canceled', 'Order status', 'gj' ),
                    'public'                    => false,
                    'exclude_from_search'       => true,
                    'show_in_admin_all_list'    => true,
                    'show_in_admin_status_list' => true,
                    'label_count'               => _n_noop( 'Canceled <span class="count">(%s)</span>', 'Canceled <span class="count">(%s)</span>', 'gj' )
                ),
            )
        );

        foreach ( $order_statuses as $order_status => $values ) {
            register_post_status( $order_status, $values );
        }
    }
}

GJ_Post_Types::init();
?>