<?php
/**
 * @class 		GJ_Post
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_Post{
    static $cache;
    public $post;

    public function __construct($post)
    {
        $this->post = $post;
    }

    /**
     * @param string|object $post
     * @param bool $force
     * @return GJ_Post|null
     */
    static function get_post($post = null, $force = false){
        $post_id = 0;
        if($post === null){
            $post = get_post();
        }
        if(is_numeric($post)){
            $post = get_post($post);
            if($post && !is_wp_error($post)){
                $post_id = $post->ID;
            }
        }
        elseif(is_object($post))
        {
            $post_id = $post->ID;
        }

        if($post_id){
            if($force){
                clean_post_cache( $post_id );
                $post = get_post($post_id);
            }

            if($force || !isset(self::$cache[$post_id])){
                switch($post->post_type){
                    case 'gj_candidate' : 
                        self::$cache[$post_id] = new GJ_Candidate($post);
                        break;
                    case 'gj_employer' : 
                        self::$cache[$post_id] = new GJ_Employer($post);
                        break;
                    case 'gj_job' :
                        self::$cache[$post_id] = new GJ_Job($post);
                        break;
                    default :
                        $post_type = $post->post_type;
                        $post_type_arr = explode('_', $post_type);
                        $post_type_arr = array_map('ucfirst', $post_type_arr);
                        $class = implode("_", $post_type_arr);
                        if(class_exists($class)){
                            self::$cache[$post_id] = new $class($post);
                        }else{
                            self::$cache[$post_id] = new GJ_Post($post);
                        }
                }
            }

            return self::$cache[$post_id];
        }

        return null;
    }

    function get_id(){

        return $this->post->ID;
    }

    function get_title($orgiginal = false){
        if($orgiginal){
            return $this->post->post_title;
        }

        return get_the_title($this->get_id());
    }

    public function get_created() {
        $date = $this->post->post_date;
        return $date;
    }

    function get_display_name(){

        return $this->get_title();
    }

    function get_description($filter = false){

        $content = $this->post->post_content;

        if($filter){
            $content = strip_shortcodes($content);
            $content = apply_filters('the_content', $content);
        }

        return $content;
    }

    function get_short_description() {

        return stripslashes($this->post->post_excerpt);
    }

    function get_thumbnail($size = 'full'){
        $image = get_the_post_thumbnail($this->get_id(), $size, array('alt' => get_the_title($this->get_id())));
        return $image;
    }

    function permalink(){
        $link = get_the_permalink($this->get_id());
        if(in_array($this->get_status(), array('publish', 'gj-expired'))){
            return $link;
        }
        else{
            return add_query_arg('preview', 'true', $link);
        }
    }

    public function admin_link(){
        return get_admin_url().'post.php?post='.$this->get_id().'&action=edit';
    }

    function get_views(){
        return get_post_meta($this->get_id(), GJ_PREFIX.'views', true);
    }

    function get_address(){
        return get_post_meta($this->get_id(), 'address', true);
    }

    function get_map() {
        $map = array();
        $map[0] = get_post_meta($this->get_id(), 'lat', true);
        $map[1] = get_post_meta($this->get_id(), 'lng', true);
        $map[2] = 10;
        
        return $map;
    }

    public function get_location($link = false){
        $locations = array();
        $city = $this->get_city($link);
        $state = $this->get_state($link);
        if($link){
            $locations[] = $city;
            $locations[] = $state;
        }else{
            if($city){
                $locations[] = $city->name;
            }
            if($state){
                $locations[] = $state->name;
            }
        }

        $locations = array_filter($locations);

        return implode(', ', $locations);
    }

    function get_full_address($link = false) {
        $address = array();
        if ($this->get_address()) {
            $address[] = $this->get_address();
        }

        $city = $this->get_city($link);
        $state = $this->get_state($link);

        if($link){
            $address[] = $city;
            $address[] = $state;
        }else{
            if($city){
                $address[] = $city->name;
            }
            if($state){
                $address[] = $state->name;
            }
        }

        if ($address) {
            return implode(', ', $address);
        } else {
            return '';
        }
    }

    public function set_featured() {
        $process = apply_filters('gj_featured_post', null, $this);
        if($process === false){
            return false;
        }

        update_post_meta($this->get_id(), GJ_PREFIX . 'featured', '1');
    }

    public function unfeatured() {
        $process = apply_filters('gj_unfeatured_post', null, $this);
        if($process === false){
            return false;
        }

        update_post_meta($this->get_id(), GJ_PREFIX . 'featured', '');
    }
    
    public function get_featured() {
        return get_post_meta($this->get_id(), GJ_PREFIX . 'featured', true) ? true : false;
    }

    public function is_featured() {
        $featured = $this->get_featured();
        return $featured;
    }

    function get_reason(){
        return get_post_meta($this->get_id(), GJ_PREFIX.'reason', true);
    }

    function get_type(){
        if(gj_option('disable_type')){
            return null;
        }

        $types = wp_get_post_terms( $this->get_id(), 'gj_type');
        if($types && !is_wp_error($types)){
            return $types[0];
        }

        return null;
    }

    public function get_state($link = false){
        $state = wp_get_post_terms($this->get_id(), 'gj_state');
        if($state){
            $state = $state[0];
            if($link){
                return "<a href='".esc_url(get_term_link($state->term_id, "gj_state" ))."' title='".esc_attr($state->name)."'>".$state->name.'</a>';
            }

            return $state;
        }

        return null;
    }

    public function get_city($link = false){
        $state = wp_get_post_terms($this->get_id(), 'gj_city');
        if($state){
            $state = $state[0];
            if($link){
                return "<a href='".esc_url(get_term_link($state->term_id, "gj_city" ))."' title='".esc_attr($state->name)."'>".$state->name.'</a>';
            }

            return $state;
        }

        return null;
    }

    function get_category(){
        $cats = $this->get_categories();
        if($cats){
            return $cats[0];
        }

        return null;
    }

    function get_categories(){
        $cats = wp_get_post_terms( $this->get_id(), 'gj_cat');
        return $cats;
    }

    function get_categories_links(){
        $category_links = array();
        $categories = $this->get_categories();
        if($categories){
            foreach ($categories as $category){
                $category_links[] = '<a href="'.esc_url(get_term_link($category->term_id, 'gj_cat')).'">'.$category->name.'</a>';
            }
        }

        if($category_links){
            return implode(', ', $category_links);
        }
        else{
            return '';
        }
    }

    function get_category_titles(){
        $category_titles = array();
        $cats = $this->get_categories();
        if($cats){
            foreach ($cats as $cat){
                $category_titles[] = $cat->name;
            }
        }

        return $category_titles;
    }

    function get_skill() {
        if (gj_option('disable_skill')) {
            return null;
        }

        $skills = wp_get_post_terms($this->get_id(), 'gj_skill');
        if ($skills && !is_wp_error($skills)) {
            return $skills[0];
        }

        return null;
    }

    function get_skills(){
        if(gj_option('disable_skill')){
            return null;
        }

        $skills = wp_get_post_terms( $this->get_id(), 'gj_skill');
        if($skills && !is_wp_error($skills)){
            return $skills;
        }

        return null;
    }

    function get_skills_links(){
        $skill_links = array();
        $skills = $this->get_skills();
        if($skills){
            foreach ($skills as $skill){
                $skill_links[] = '<a href="'.esc_url(get_term_link($skill->term_id, 'gj_skill')).'">'.$skill->name.'</a>';
            }
        }

        if($skill_links){
            return implode(', ', $skill_links);
        }
        else{
            return '';
        }
    }

    function get_level(){
        if(gj_option('disable_level')){
            return null;
        }

        $levels = wp_get_post_terms( $this->get_id(), 'gj_level');
        if($levels && !is_wp_error($levels)){
            return $levels[0];
        }
        return null;
    }

    function get_level_link(){
        $level = $this->get_level();
        if($level){
            return '<a href="'.esc_url(get_term_link($level->term_id, 'gj_level')).'">'.$level->name.'</a>';
        }
        return null;
    }

    function get_levels(){
        if(gj_option('disable_level')){
            return null;
        }

        $levels = wp_get_post_terms($this->get_id(), 'gj_level');

        return $levels;
    }

    function get_levels_links(){
        $level_links = array();
        $levels = $this->get_levels();
        if($levels){
            foreach ($levels as $level){
                $level_links[] = '<a href="'.esc_url(get_term_link($level->term_id, 'gj_level')).'">'.$level->name.'</a>';
            }
        }

        if($level_links){
            return implode(', ', $level_links);
        }
        else{
            return '';
        }
    }

    function get_types(){
        if(gj_option('disable_type')){
            return null;
        }

        $types = wp_get_post_terms($this->get_id(), 'gj_type');

        return $types;
    }

    function get_types_links(){
        $type_links = array();
        $types = $this->get_types();
        if($types){
            foreach ($types as $type){
                $type_links[] = '<a href="'.esc_url(get_term_link($type->term_id, 'gj_type')).'">'.$type->name.'</a>';
            }
        }

        if($type_links){
            return implode(', ', $type_links);
        }
        else{
            return '';
        }
    }

    function has_salary(){
        return $this->get_salary_from() !== '' && $this->get_salary_to() !== '';
    }

    function get_salary_from(){
        return get_post_meta($this->get_id(), 'salary_from', true);
    }

    function get_salary_to(){
        return get_post_meta($this->get_id(), 'salary_to', true);
    }

    function get_salary() {
        $salary_from = $this->get_salary_from();
        $salary_to = $this->get_salary_to();
        return gj_salary($salary_from, $salary_to);
    }

    function get_salary_postfix() {
        return get_post_meta($this->get_id(), 'salary_postfix', true);
    }

    function get_email() {
        $email = get_post_meta($this->get_id(), 'email', true);
        if(!$email){
            $user = GJ_User::get_user($this->get_author_id());
            $email = $user->get_email();
        }
        
        return $email;
    }

    function get_phone() {
        return get_post_meta($this->get_id(), 'phone', true);
    }

    function get_website() {
        return get_post_meta($this->get_id(), 'website', true);
    }

    function get_social_media() {
        return get_post_meta($this->get_id(), 'social', true);
    }

    function get_gallery() {
        return get_post_meta($this->get_id(), 'gallery');
    }


    function get_status(){
        return $this->post->post_status;
    }

    public function has_status($check_status) {
        $check_status = !is_array($check_status) ? (array) $check_status : $check_status;
        $status = $this->get_status();
        $status = str_replace('gj-', '', $status);
        if (in_array($status, $check_status)) {
            return true;
        }

        return false;
    }

    function get_author_id(){
        return $this->post->post_author;
    }

    function get_author(){
        return GJ_User::get_user($this->get_author_id());
    }

    public function change_status($status, $send_email = true){
        return false;
    }

    public function is_active(){
        if($this->get_status() == 'publish'){
            return true;
        }

        return false;
    }

    public function is_pending(){
        if($this->get_status() == 'pending'){
            return true;
        }

        return false;
    }

    function get_admin_url() {

        $action = '&action=edit';

        $post_type_object = get_post_type_object( $this->post->post_type );

        if ( $post_type_object->_edit_link ) {
            $link = admin_url( sprintf( $post_type_object->_edit_link . $action, $this->get_id() ) );
        } else {
            $link = '';
        }

        return $link;
    }
}
