<?php
class GJ_Product{
    public $type;
    public $meta = array();
    static function get_types(){
        $products = array(
            'newjob' => array(
                'title' => esc_html__('New Job', 'gj'),
                'subType' => false,
                'together' => true,
            ),
            'featuredjob' => array(
                'title' => esc_html__('Featured Job', 'gj'),
                'subType' => false,
                'together' => true
            ),
            'renewjob' => array(
                'title' => esc_html__('Renew Job', 'gj'),
                'subType' => false,
                'together' => true
            ),
        );

        return apply_filters('gj_product_types', $products);
    }

    function __construct($type, $meta = array())
    {
        $this->type = $type;
        $this->meta = $meta;

    }

    function is_together(){
        $all_types = self::get_types();
        $type = isset($all_types[$this->type]) ? $all_types[$this->type] : null;
        $together = isset($type['together']) ? $type['together'] : false;
        return $together;
    }

    function allow_recurring(){
        $all_types = self::get_types();
        $type = isset($all_types[$this->type]) ? $all_types[$this->type] : null;
        $recurring = isset($type['allowRecurring']) ? $type['allowRecurring'] : false;
        return $recurring;
    }

    function has_sub_type(){
        $all_types = self::get_types();
        $type = isset($all_types[$this->type]) ? $all_types[$this->type] : null;
        $subType = isset($type['subType']) ? $type['subType'] : false;
        return $subType;
    }

    function get_title(){
        $all_types = self::get_types();
        $type = isset($all_types[$this->type]) ? $all_types[$this->type] : null;
        return $type ? $type['title'] : null;
    }

    function get_title_for_order(){
        $title = null;
        switch ($this->type){
            case 'featuredjob' :
                $title = sprintf(esc_html__('Feature %s', 'gj'), get_the_title($this->get_meta('item_id')));
                break;
            case 'renewjob' :
                $title = sprintf(esc_html__('Renew %s', 'gj'), get_the_title($this->get_meta('item_id')));
                break;
            case 'newjob' :
                $title = sprintf(esc_html__('Submit %s', 'gj'), get_the_title($this->get_meta('item_id')));
                break;
            default :
                $title = $this->get_title();
        }

        return apply_filters('gj_product_title_for_order', $title, $this);
    }

    function _get_price(){
        $all_types = self::get_types();
        $type = isset($all_types[$this->type]) ? $all_types[$this->type] : null;
        return $type && isset($type['price']) ? $type['price'] : null;
    }

    function get_price(){
        if($this->_get_price()){
            return $this->_get_price();
        }else{
            return isset($this->meta['price']) ? $this->get_meta('price') : $this->init_price();
        }
    }

    function init_price(){
        $price = 0;
        switch ($this->type){
            case 'newjob' :
                $price = gj_option('job_price');
                break;
            case 'featuredjob' :
                $price = gj_option('featured_job_price');
                break;
            case 'renewjob' :
                $price = gj_option('renew_job_price');
                break;
        }

        return apply_filters('gj_product_price', $price, $this);
    }

    function get_expiry(){

        return get_post_meta($this->get_meta('item_id'), GJ_PREFIX.'expiry', true);
    }

    function get_expiry_unit(){

        return get_post_meta($this->get_meta('item_id'), GJ_PREFIX.'expiry_unit', true);
    }

    function get_expiry_title(){
        $unit = $this->get_expiry_unit();
        $expiry = $this->get_expiry();
        switch ($unit){
            case 'day':
                return sprintf(_n('%d day', '%d days', $expiry, 'gj'), $expiry);
            case 'month':
                return sprintf(_n('%d month', '%d months', $expiry, 'gj'), $expiry);
            case 'year':
                return sprintf(_n('%d year', '%d years', $expiry, 'gj'), $expiry);
        }

        return '';
    }

    function add_meta($meta = array(), $map_price = true){
        if($map_price){
            $meta['price'] = $this->init_price();
        }

        $this->meta = array_merge($this->meta, $meta);
    }

    function get_meta($meta_key = null){
        if($meta_key === null){
            return $this->meta;
        }elseif($meta_key && isset($this->meta[$meta_key])){
            return $this->meta[$meta_key];
        }

        return null;
    }

    function completed_order($user_id = null, $order = null){

        $continue = apply_filters('gj_before_product_order_completed', null, $user_id, $order, $this);

        if($continue === false){
            return false;
        }

        switch ($this->type){
            case 'featuredjob':
                $job = GJ_Job::get_job($this->get_meta('item_id'));
                if($job){
                    update_post_meta($job->get_id(), GJ_PREFIX.'is_new_featured', '1');
                    if($job->has_status('publish')){
                        //set featured
                        $job->set_featured();
                    }
                }
                break;
            case 'renewjob':
                $job = GJ_Job::get_job($this->get_meta('item_id'));
                if($job){
                    $job->renew();
                }
                break;
            case 'newjob':
                $job = GJ_Job::get_job($this->get_meta('item_id'));
                if($job){
                    if(gj_option('new_job_auto_approved')){
                        $job->change_status('publish');
                    }else{
                        $job->change_status('pending');
                    }
                }
                break;
        }

        do_action('gj_product_order_completed', $user_id, $order, $this);
    }

    function cancelled_order($user_id, $order){

    }
}