<?php
/**
 * Contains the query functions for inTravel which alter the front-end post queries and loops
 *
 * @class 		GJ_Query
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class GJ_Query {

    public $query_vars = array();

    static function init(){
        if (!is_blog_admin()) {
            add_filter('posts_join', array( __CLASS__, 'posts_join' ), 10, 2);
            add_filter('posts_where', array( __CLASS__, 'posts_where' ), 10, 2);
        }
    }

    public static function set_post_to_publish( $posts ) {
        // Remove the filter again, otherwise it will be applied to other queries too.
        remove_filter( 'posts_results', array( __CLASS__, 'set_post_to_publish' ), 10 );

        if ( empty( $posts ) ) {
            return;
        }

        $post_id = $posts[0]->ID;

        // If the post has gone live, redirect to it's proper permalink.
        self::maybe_redirect_to_published_post( $post_id );

        if ( self::is_public_preview_available( $post_id ) ) {
            // Disable comments and pings for this post.
            add_filter('comments_open', '__return_false');
            add_filter('pings_open', '__return_false');
        }

        return $posts;
    }

    private static function maybe_redirect_to_published_post( $post_id ) {
        if ( ! in_array( get_post_status( $post_id ), self::get_published_statuses() ) ) {
            return false;
        }

        wp_redirect( get_permalink( $post_id ), 301 );
        exit;
    }

    private static function get_published_statuses() {
        $published_statuses = array( 'publish', 'private');

        return apply_filters( 'gj_published_statuses', $published_statuses );
    }

    private static function is_public_preview_available( $post_id ) {
        if ( empty( $post_id ) ) {
            return false;
        }

        $post = get_post($post_id);
        if(!is_super_admin() && $post->post_author != get_current_user_id()){
            return false;
        }

        return true;
    }

    static function posts_join($join, $query){
        if($query->get('post_type') == 'gj_job' || $query->get('post_type') == 'gj_candidate' || $query->get('post_type') == 'gj_employer'){
            if(isset($_REQUEST['lat'])
                && isset($_REQUEST['lng'])
                && !empty($_REQUEST['lat'])
                && !empty($_REQUEST['lng'])
            ){
                global $wpdb;
                $join .= " LEFT JOIN $wpdb->postmeta as lat_meta ON $wpdb->posts.ID = lat_meta.post_id ";
                $join .= " LEFT JOIN $wpdb->postmeta as lng_meta ON $wpdb->posts.ID = lng_meta.post_id ";
            }

        }

        return $join;
    }

    static function posts_where($where, $query){
        if($query->get('post_type') == 'gj_job' || $query->get('post_type') == 'gj_employer' || $query->get('post_type') == 'gj_candidate'){
            if(isset($_REQUEST['lat'])
                && isset($_REQUEST['lng'])
                && !empty($_REQUEST['lat'])
                && !empty($_REQUEST['lng'])
            ){
                $lat = (float)$_REQUEST['lat'];
                $lng = (float)$_REQUEST['lng'];
                $unit = gj_option('search_unit');
                if(isset($_REQUEST['radius'])){
                    $radius = intval($_REQUEST['radius']);
                }else{
                    $radius = gj_option('default_search_radius');
                }

                if( $unit == 'Km' ){
                   $radius = (float)$radius/1.609344;
                }

                $where .= " AND lat_meta.meta_key = 'lat' AND lng_meta.meta_key = 'lng' AND ( ( acos( sin( lat_meta.meta_value * 0.0175) * sin( $lat * 0.0175) + cos( lat_meta.meta_value * 0.0175) * cos( $lat * 0.0175 ) * cos( ( $lng  * 0.0175 ) - (lng_meta.meta_value * 0.0175 ) ) ) * 3959 ) < $radius ) ";
            }

        }

        return $where;
    }
}

GJ_Query::init();
