<?php
/**
 * @class 		GJ_User
 * @package		GJ/Classes
 * @author 		InwaveThemes
 */

class GJ_User {

    static $cache;
    public $user;

    static function init() {
        add_action('delete_user', array(__CLASS__, 'delete_user'), 10, 2);
        add_filter('pre_get_avatar', array(__CLASS__, 'pre_get_avatar'), 99, 5);
        add_filter('get_avatar_url', array(__CLASS__, 'get_avatar_url'), 99, 3);

        add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue_scripts' ) );
        add_action('wp_print_footer_scripts', array(__CLASS__, 'print_footer_scripts'), 99);
    }

    static function enqueue_scripts(){
        if(gj_current_dashboard_endpoint() === 'profile') {
            $fields = GJ_Fields::instance();
            $types = array("datetime");
            foreach ($types as $type){
                $type = $fields->type($type);
                if($type){
                    $type->enqueue();
                }
            }
            $fields->registerScripts();
            $fields->enqueueScripts(true);
        }
    }

    static function print_footer_scripts(){
        if(gj_current_dashboard_endpoint() === 'profile') {
            $fields = array(
                "fields" => array(
                    array(
                        "type" => "image",
                        "label" => esc_html__("Avatar", 'gj'),
                        "model" => "avatar",
                    ),
                    array(
                        "type" => "input",
                        "inputType" => "text",
                        "label" => esc_html__("First Name", 'gj'),
                        "model" => "firstName",
                        "required" => true,
                        "default" => "",
                    ),
                    array(
                        "type" => "input",
                        "inputType" => "text",
                        "label" => esc_html__("Last Name", 'gj'),
                        "model" => "lastName",
                        "required" => true,
                        "default" => "",
                    ),
                    array(
                        "type" => "input",
                        "inputType" => "email",
                        "label" => esc_html__("Email", 'gj'),
                        "model" => "email",
                        "required" => true,
                        "default" => "",
                    ),
                    array(
                        "type" => "input",
                        "inputType" => "url",
                        "label" => esc_html__("Url", 'gj'),
                        "model" => "url",
                        "required" => true,
                        "default" => "",
                    ),
                    array(
                        "type" => "input",
                        "inputType" => "password",
                        "label" => esc_html__("New Password", 'gj'),
                        "model" => "new_password",
                        "required" => false,
                        "default" => "",
                    ),
                    array(
                        "type" => "input",
                        "inputType" => "password",
                        "label" => esc_html__("Confirm Password", 'gj'),
                        "model" => "password_confirm",
                        "required" => false,
                        "default" => "",
                    ),
                )
            );

            $fields = apply_filters('gj_user_profile_fields', $fields);

            $user_data = get_userdata(get_current_user_id());
            $avatar = get_user_meta(get_current_user_id(), GJ_PREFIX.'avatar', true);
            if($avatar){
                $imageData['id'] = $avatar;
                $imageData['url'] = wp_get_attachment_image_src( $avatar )[0];
            }else{
                $imageData = new stdClass();
            }

            $model = array();
            $model["avatar"] = $imageData;
            $model["firstName"] = $user_data->first_name;
            $model["lastName"] = $user_data->last_name;
            $model["email"] = $user_data->user_email;
            $model["url"] = $user_data->user_url;

            $model = apply_filters('gj_user_profile_model', $model);
            ?>

            <script type="text/javascript">
                var vmPostApp;
                jQuery(document).ready(function () {
                    vmPostApp = new Vue({
                        el: "#profile-form",
                        components: {
                            "vue-form-generator": VueFormGenerator.component,
                        },
                        data: {
                            model: <?php echo json_encode($model); ?>,
                            schema:  <?php echo json_encode($fields); ?>,
                            formOptions: {
                                validateAfterLoad: false,
                                validateAfterChanged: true
                            }
                        }
                    });
                });
            </script>
            <?php
        }
    }


    static function delete_user($user_id, $reassign) {
        global $wpdb;
        $post_types_to_delete['job'] = 'gj_job';
        $post_types_to_delete['application'] = 'gj_application';
        $post_types_to_delete[] = 'gj_employer';
        $post_types_to_delete[] = 'gj_candidate';
        $post_types_to_delete[] = 'gj_u_package';
        $post_types_to_delete[] = 'gj_order';

        if ($reassign) {
            unset($post_types_to_delete['job']);
            if (gj_option('keep_jobs_delete_user') == '2') {
                unset($post_types_to_delete['application']);
            }
        }

        $post_types_to_delete = array_values($post_types_to_delete);

        $post_types_to_delete = implode("', '", $post_types_to_delete);
        $post_ids = $wpdb->get_col($wpdb->prepare("SELECT ID FROM $wpdb->posts WHERE post_author = %d AND post_type IN ('$post_types_to_delete')", $user_id));
        if ($post_ids) {
            foreach ($post_ids as $post_id)
                wp_delete_post($post_id);
        }

        $sql = "SELECT ID FROM {$wpdb->prefix}gj_alerts WHERE user_id = %d";
        $alerts = $wpdb->get_results($wpdb->prepare($sql, $user_id));
        $alert_ids = array();
        if ($alerts) {
            foreach ($alerts as $alert) {
                $alert_ids[] = $alert->ID;
            }
        }
        if ($alert_ids) {
            $wpdb->query("DELETE FROM {$wpdb->prefix}gj_alerts WHERE ID IN(" . implode(',', $alert_ids) . ")");
            $wpdb->query("DELETE FROM {$wpdb->prefix}gj_alert_relationships WHERE alert_id IN(" . implode(',', $alert_ids) . ")");
        }

        $sql_review = "SELECT ID FROM {$wpdb->prefix}gj_reviews WHERE user_id = %d";
        $reviews = $wpdb->get_results($wpdb->prepare($sql_review, $user_id));
        $review_ids = array();
        if ($reviews) {
            foreach ($reviews as $review) {
                $review_ids[] = $review->ID;
            }
        }
        if ($review_ids) {
            $wpdb->query("DELETE FROM {$wpdb->prefix}gj_reviews WHERE ID IN(" . implode(',', $review_ids) . ")");
            $wpdb->query("DELETE FROM {$wpdb->prefix}gj_reviews_reply WHERE review_id IN(" . implode(',', $review_ids) . ")");
        }

        $wpdb->delete($wpdb->prefix . 'gj_follows', array('user_id' => $user_id), array('%d'));
        $wpdb->delete($wpdb->prefix . 'gj_save_jobs', array('user_id' => $user_id), array('%d'));
        $wpdb->delete($wpdb->prefix . 'gj_save_resums', array('user_id' => $user_id), array('%d'));
    }

    static function can_reset_password($user_name, $code) {
        $current_user = wp_get_current_user();
        $user = get_user_by('login', $user_name);
        if ($user && (!$current_user->ID || $current_user->user_login == $user_name)) {
            $reset_code = get_user_meta($user->ID, GJ_PREFIX . 'resetpass_code', true);
            if ($reset_code === $code) {
                return true;
            }
        }

        return false;
    }

    public function __construct($user) {
        $this->user = $user;
    }

    /**
     * @param null $user
     * @param bool $force
     * @return GJ_User
     */
    static function get_user($user = null, $force = false) {
        if ($user === null) {
            if (!function_exists('wp_get_current_user')) {
                include(ABSPATH . "wp-includes/pluggable.php");
            }
            $user = wp_get_current_user();
        }
        $user_id = 0;
        if (is_numeric($user)) {
            $user = get_userdata($user);
            if ($user && !is_wp_error($user)) {
                $user_id = $user->ID;
            }
        } elseif (is_object($user)) {
            $user_id = $user->ID;
        }

        if ($user_id) {
            if ($force) {
                clean_user_cache($user_id);
                $user = get_userdata($user_id);
            }

            if ($force || !isset(self::$cache[$user_id])) {
                self::$cache[$user_id] = new GJ_User($user);
            }

            return self::$cache[$user_id];
        }


        return null;
    }

    function get_id() {
        return $this->user->ID;
    }

    function get_display_name() {
        return $this->user->display_name;
    }

    function get_headline() {
        if ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_headline();
        } elseif ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_headline();
        } else {
            return false;
        }
    }

    function get_first_name() {
        return $this->user->user_firstname;
    }

    function get_last_name() {
        return $this->user->user_lastname;
    }

    function get_description() {
        if ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_description(true);
        } elseif ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_description(true);
        } else {
            return $this->user->description;
        }
    }

    function get_short_description() {
        if ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_short_description();
        } elseif ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_description();
        } else {
            return $this->user->description;
        }
    }

    function get_full_address() {
        if ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_full_address();
        } elseif ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_full_address();
        } else {
            return '';
        }
    }

    function get_address() {
        if ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_address();
        } elseif ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_address();
        } else {
            return '';
        }
    }

    function get_gallery() {
        if ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_gallery();
        } elseif ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_gallery();
        } else {
            return '';
        }
    }

    function get_map() {
        if ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_map();
        } elseif ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_map();
        } else {
            return '';
        }
    }

    function get_phone() {
        if ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->get_phone();
        } elseif ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->get_phone();
        } else {
            return '';
        }
    }

    function get_website() {
        return $this->user->user_url;
    }

    function get_roles() {
        return $this->user->roles;
    }

    function get_email() {
        return $this->user->user_email;
    }

    function get_login() {
        return $this->user->user_login;
    }

    function permalink() {
        if ($this->is_employer() && $employer = $this->get_first_employer()) {
            return $employer->permalink();
        } elseif ($this->is_candidate() && $candidate = $this->get_first_candidate()) {
            return $candidate->permalink();
        } else {
            return get_author_posts_url($this->get_id());
        }
    }

    static function pre_get_avatar($null, $id_or_email, $args) {
        if (is_numeric($id_or_email))
            $user_id = (int) $id_or_email;
        elseif (is_string($id_or_email) && ( $user = get_user_by('email', $id_or_email) ))
            $user_id = $user->ID;
        elseif (is_object($id_or_email) && !empty($id_or_email->user_id))
            $user_id = (int) $id_or_email->user_id;

        if (empty($user_id))
            return null;

        // fetch local avatar from meta and make sure it's properly ste
        $avatar = get_user_meta($user_id, GJ_PREFIX . 'avatar', true);

        if (empty($avatar))
            return null;

        $alt = $args['alt'];
        if (empty($alt))
            $alt = get_the_author_meta('display_name', $user_id);

        if (is_numeric($avatar)) {

            // generate a new size
            $avatar_url =  wp_get_attachment_image_src($avatar, 'thumbnail')[0];
            $avatar_url2x = wp_get_attachment_image_src($avatar, 'thumbnail')[0];
        }else {
            if ('http' != substr($avatar, 0, 4))
                $avatar = home_url($avatar);
            $avatar_url = $avatar_url2x = $avatar;
        }

        $author_class = is_author($user_id) ? ' current-author' : '';
        $avatar = "<img alt='" . esc_attr($alt) . "' src='" . ( $avatar_url ) . "' srcset='" . $avatar_url2x . " 2x' class='avatar avatar-70{$author_class} photo' height='70' width='70' />";

        return apply_filters('gj_avatar', $avatar);
    }

    static function get_avatar_url($url, $id_or_email, $args) {
        if (is_numeric($id_or_email))
            $user_id = (int) $id_or_email;
        elseif (is_string($id_or_email) && ( $user = get_user_by('email', $id_or_email) ))
            $user_id = $user->ID;
        elseif (is_object($id_or_email) && !empty($id_or_email->user_id))
            $user_id = (int) $id_or_email->user_id;

        if (empty($user_id))
            return $url;

        // fetch local avatar from meta and make sure it's properly ste
        $avatars = get_user_meta($user_id, GJ_PREFIX . 'avatar', true);

        if (empty($avatars))
            return $url;

        if (is_numeric($avatars)) {
            if (isset($args['img_size']) && $args['img_size']) {
                $avatars = wp_get_attachment_image_src($avatars, $args['img_size']);
            } else {
                $avatars = wp_get_attachment_image_src($avatars, 'thumbnail');
            }
            if (empty($avatars[0]))
                return $url;
            // generate a new size
            $avatar_url = $avatars[0];
        }else {
            $avatar_url = $avatars;
        }

        return $avatar_url;
    }

    function is_active_profile() {
        if ($this->is_employer()) {
            $employer = $this->get_first_employer();
            if ($employer && $employer->is_active()) {
                return true;
            }
        }

        if ($this->is_candidate()) {
            $candidate = $this->get_first_candidate();
            if ($candidate && $candidate->is_active()) {
                return true;
            }
        }

        return false;
    }

    function is_employer() {

        if (user_can($this->user, 'administrator') || user_can($this->user, 'gj_employer')) {
            return true;
        }

        return false;
    }

    function get_employer_id() {
        $first_employer = $this->get_first_employer();
        return $first_employer ? $first_employer->get_id() : null;
    }

    function get_employers() {
        $args = array(
            'post_type' => 'gj_employer',
            'posts_per_page' => -1,
            'post_status' => array('publish', 'pending', 'draft', 'private'),
            'author' => $this->get_id()
        );

        return get_posts($args);
    }

    function get_first_employer() {
        $employers = $this->get_employers();
        return $employers ? GJ_Employer::get_employer($employers[0]) : null;
    }

    function is_candidate() {
        if ($this->is_employer()) {
            return false;
        }

        if (user_can($this->user, 'gj_candidate')) {
            return true;
        }

        return false;
    }

    function get_candidate_id() {
        $first_candidate = $this->get_first_candidate();
        return $first_candidate ? $first_candidate->get_id() : null;
    }

    function get_candidates($status = array()) {
        if(!$status) $status = array('publish', 'pending', 'draft', 'private');
        $args = array(
            'post_type' => 'gj_candidate',
            'posts_per_page' => -1,
            'post_status' => $status,
            'author' => $this->get_id()
        );

        return get_posts($args);
    }

    function get_first_candidate() {
        $candidate = $this->get_candidates();
        return $candidate ? GJ_Candidate::get_candidate($candidate[0]) : null;
    }

    function get_orders($args = array()) {
        $default_args = array(
            'posts_per_page' => gj_option('dashboard_items_per_page', get_option('posts_per_page', 20)),
            'post_type' => 'gj_order',
            'post_status' => (isset($_GET['order_status']) && $_GET['order_status']) ? sanitize_text_field($_GET['order_status']) : array_keys(GJ_Order::get_status_array(false, false)),
            'paged' => isset($_GET['cpage']) ? intval($_GET['cpage']) : 1,
            'author' => $this->get_id(),
        );

        if (isset($_GET['search']) && $_GET['search']) {
            $default_args['s'] = sanitize_text_field($_GET['search']);
        }

        if (isset($_GET['order_type']) && $_GET['order_type']) {
            $default_args['meta_key'] = GJ_PREFIX . 'type';
            $default_args['meta_value'] = sanitize_text_field($_GET['order_type']);
            $default_args['meta_compare'] = '=';
        }

        $args = wp_parse_args($args, $default_args);

        return new WP_Query($args);
    }

    function get_jobs($args = array()) {
        $search = isset($_GET['search']) ? sanitize_text_field($_GET['search']) : '';
        $paged = isset($_GET['cpage']) ? intval($_GET['cpage']) : 1;
        $status = isset($_GET['status']) && $_GET['status'] ? sanitize_text_field($_GET['status']) : array_keys(GJ_Job::get_status_array());
        $orderby = isset($_GET['orderby']) ? sanitize_text_field($_GET['orderby']) : '';
        $default_args = array(
            'post_type' => 'gj_job',
            'post_parent' => 0,
            'post_status' => $status,
            'posts_per_page' => gj_option('dashboard_item_per_page', get_option('posts_per_page', 20)),
            'author' => $this->get_id(),
            'paged' => $paged,
            's' => $search,
        );

        if ($orderby) {
            $orderby = explode("_", $orderby);
            $default_args['orderby'] = $orderby[0];
            $default_args['order'] = strtoupper($orderby[1]);
        }

        $args = wp_parse_args($args, $default_args);

        return new WP_Query($args);
    }

    function get_job_ids() {
        global $wpdb;
        $sql = "SELECT ID FROM {$wpdb->posts} WHERE post_author = %d AND post_type = %s AND post_status NOT IN ('trash', 'revisions', 'auto-draft')";
        $sql = $wpdb->prepare($sql, $this->get_id(), 'gj_job');
        $jobs = $wpdb->get_results($sql);
        $job_ids = array();
        if ($jobs) {
            foreach ($jobs AS $job) {
                $job_ids[] = $job->ID;
            }
        }

        return $job_ids;
    }

    function count_total_views() {
        $job_ids = $this->get_job_ids();
        $view = 0;
        if (count($job_ids)) {
            foreach ($job_ids as $job_id) {
                $job = GJ_Job::get_job($job_id);
                $view += intval($job->get_views());
            }
        }

        return $view;
    }

    function count_total_applications($status = null){
            global $wpdb;
            if(!$status){
                $status = array_keys(GJ_Application::get_status_array());
            }
            $sql = "SELECT COUNT(1) FROM {$wpdb->posts} AS p join {$wpdb->postmeta} AS pm ON pm.post_id = p.ID WHERE 
                    p.post_type = %s AND post_status IN ('".implode("','", $status)."') AND pm.meta_key=%s AND pm.meta_value IN 
                    (SELECT ID FROM {$wpdb->posts} WHERE post_author = %d AND post_type = %s AND post_status NOT IN ('trash', 'revisions', 'auto-draft'))";

            $sql = $wpdb->prepare($sql, 'gj_application', GJ_PREFIX . 'job_id', $this->get_id(), 'gj_job');

            return $wpdb->get_var($sql);
    }

    function get_applications($job_id = null, $args = array()) {
        if($job_id){
            $ids = (array)$job_id;
        }else{
            $ids = $this->get_job_ids();
        }

        if ($ids) {
            $default_args = array(
                'posts_per_page' => gj_option('dashboard_items_per_page', get_option('posts_per_page', 20)),
                'post_type' => 'gj_application',
                'post_status' => isset($_GET['status']) && $_GET['status'] ? sanitize_text_field($_GET['status']) : array_keys(GJ_Application::get_status_array()),
                'paged' => isset($_GET['cpage']) ? intval($_GET['cpage']) : 1,
                's' => isset($_GET['search']) ? sanitize_text_field($_GET['search']) : '',
                'meta_query' => array(
                    array(
                        'key' => GJ_PREFIX . 'job_id',
                        'value' => $ids,
                        'compare' => 'IN'
                    )
                )
            );

            $args = wp_parse_args($args, $default_args);

            return new WP_Query($args);
        }

        return null;
    }

    function get_submited_applications($args = array()) {

        $default_args = array(
            'posts_per_page' => gj_option('dashboard_items_per_page', get_option('posts_per_page', 20)),
            'post_type' => 'gj_application',
            'post_status' => (isset($_GET['status']) && $_GET['status']) ? sanitize_text_field($_GET['status']) : array_keys(GJ_Application::get_status_array()),
            'author' => $this->get_id(),
            'paged' => isset($_GET['cpage']) ? intval($_GET['cpage']) : 1,
        );

        if (isset($_GET['search']) && $_GET['search']) {
            $posts = get_posts(array(
                'post_type' => 'gj_job',
                'post_status' => 'publish',
                'posts_per_page' => -1,
                's' => sanitize_text_field($_GET['search'])
            ));
            if ($posts) {
                $post_ids = array();
                foreach ($posts as $post) {
                    $post_ids[] = $post->ID;
                }

                $default_args['meta_query'] = array(
                    array(
                        'key' => GJ_PREFIX . 'job_id',
                        'value' => $post_ids,
                        'compare' => 'IN'
                    )
                );
            } else {
                return null;
            }
        }

        $args = wp_parse_args($args, $default_args);

        return new WP_Query($args);
    }

    function count_jobs($all = false, $expired_job = null) {
        if ($all) {
            global $wpdb;
            $sql = "SELECT COUNT(1) FROM {$wpdb->posts} WHERE post_author = %d AND post_type = %s AND post_status NOT IN ('trash', 'revisions', 'auto-draft')";
            $sql = $wpdb->prepare($sql, $this->get_id(), 'gj_job');
            $jobs = $wpdb->get_var($sql);
        } else {
            global $wpdb;
            $status = array('publish');
            if($expired_job){
                $status[] = 'gj-expired';
            }

            $sql = "SELECT COUNT(1) FROM {$wpdb->posts} WHERE post_author = %d AND post_type = %s AND post_status IN ('".implode(',', $status)."')";
            $sql = $wpdb->prepare($sql, $this->get_id(), 'gj_job');
            $jobs = $wpdb->get_var($sql);
        }

        return $jobs;
    }

    function count_jobs_with_status($status = '') {
        global $wpdb;
        if ($status == 'expired') {
            $sql = "SELECT COUNT(1) FROM {$wpdb->posts} WHERE post_author = %d AND post_type = %s AND post_status IN ('gj-expired')";
            $sql = $wpdb->prepare($sql, $this->get_id(), 'gj_job');
            $jobs = $wpdb->get_var($sql);
        } else if ($status == 'publish') {
            $sql = "SELECT COUNT(1) FROM {$wpdb->posts} WHERE post_author = %d AND post_type = %s AND post_status IN ('publish')";
            $sql = $wpdb->prepare($sql, $this->get_id(), 'gj_job');
            $jobs = $wpdb->get_var($sql);
        } else {
            $status = explode(",", $status);
            $jobs = 0;
            foreach ($status as $st) {
                $sql = "SELECT COUNT(1) FROM {$wpdb->posts} WHERE post_author = %d AND post_type = %s AND post_status IN (%s)";
                $sql = $wpdb->prepare($sql, $this->get_id(), 'gj_job', $st);
                $jobs += $wpdb->get_var($sql);
            }
        }

        return $jobs;
    }

    /**
     * @return GJ_Job[]
     */
    function get_open_jobs($args = array()) {
        $id = $this->get_id();
        $default_args = array(
            'posts_per_page' => -1,
            'post_type' => 'gj_job',
            'post_status' => 'publish',
            'post__not_in' => array($id),
            'author' => $this->get_id(),
        );

        if (!gj_option('show_expired_job')) {
            $default_args['meta_query'] = array(
                'relation' => 'OR',
                array(
                    'key' => GJ_PREFIX . 'expiry',
                    'value' => current_time('timestamp'),
                    'compare' => '>',
                ),
                array(
                    'key' => GJ_PREFIX . 'expiry',
                    'value' => '',
                    'compare' => '=',
                )
            );
        }

        $args = wp_parse_args($args, $default_args);
        $posts = get_posts($args);
        $employer_jobs = array();
        if ($posts) {
            foreach ($posts as $key => $post) {
                $employer_jobs[] = GJ_Job::get_job($post);
            }
        }

        return (array)$employer_jobs;
    }

    function get_follower_ids() {
        $employer_post_id = $this->get_employer_id();
        $user_ids = array();

        if ($employer_post_id) {
            global $wpdb;
            $sql = "SELECT user_id FROM {$wpdb->prefix}gj_follows WHERE post_id = %d";
            $records = $wpdb->get_results($wpdb->prepare($sql, $employer_post_id));
            if ($records) {
                foreach ($records as $record) {
                    $user_ids[] = $record->user_id;
                }
            }
        }

        return $user_ids;
    }

    function count_followers() {
        $employer_post_id = $this->get_employer_id();
        $total = 0;

        if ($employer_post_id) {
            global $wpdb;
            $sql = "SELECT COUNT(*) FROM {$wpdb->prefix}gj_follows WHERE post_id = %d";
            $total = $wpdb->get_var($wpdb->prepare($sql, $employer_post_id));
        }

        return $total;
    }

    function count_following() {
        global $wpdb;
        $sql = "SELECT COUNT(f.*) FROM {$wpdb->prefix}gj_follows AS f JOIN {$wpdb->posts} AS p ON f.post_id = p.ID WHERE f.user_id = %d AND p.post_status = 'publish'";
        $total = $wpdb->get_var($wpdb->prepare($sql, $this->get_id()));

        return $total;
    }

    function generate_resetpass_code() {
        $code = wp_generate_password(50, false);
        update_user_meta($this->get_id(), GJ_PREFIX . 'resetpass_code', $code);
        return $code;
    }

    function delete_resetpass_code() {
        return delete_user_meta($this->get_id(), GJ_PREFIX . 'resetpass_code');
    }

    function get_resetpass_url() {
        $url = gj_get_page_permalink('lostpass');
        $url = add_query_arg(array('user' => $this->get_login(), 'code' => get_user_meta($this->get_id(), GJ_PREFIX . 'resetpass_code', true)), $url);
        return $url;
    }

    public function get_follows($args = array()) {
        global $wpdb;

        $default_args = array(
            'posts_per_page' => gj_option('dashboard_items_per_page', get_option('posts_per_page', 20)),
            'search' => isset($_GET['search']) ? sanitize_text_field($_GET['search']) : '',
        );
        $args = wp_parse_args($args, $default_args);
        $query = "SELECT f.* FROM {$wpdb->prefix}gj_follows AS f JOIN {$wpdb->posts} AS p ON f.post_id = p.ID WHERE p.post_status = 'publish' AND f.user_id = '" . $this->get_id() . "'";
        if ($args['search']) {
            $query .= ' AND p.post_title LIKE "%' . $args['search'] . '%"';
        }
        $total_query = "SELECT COUNT(1) FROM (${query}) AS combined_table";
        $total = $wpdb->get_var($total_query);
        $items_per_page = $args['posts_per_page'];
        $page = isset($_GET['cpage']) ? abs((int) $_GET['cpage']) : 1;
        $offset = ( $page * $items_per_page ) - $items_per_page;
        $result = $wpdb->get_results($query . " ORDER BY f.ID DESC LIMIT ${offset}, ${items_per_page}");
        $total_page = ceil($total / $items_per_page);
        if ($total) {
            return array(
                'result' => $result,
                'total_page' => $total_page,
                'current_page' => $page,
            );
        } else {
            return null;
        }
    }

    public function get_save_jobs($args = array()) {
        global $wpdb;

        $default_args = array(
            'posts_per_page' => gj_option('dashboard_items_per_page', get_option('posts_per_page', 20)),
            'search' => isset($_GET['search']) ? sanitize_text_field($_GET['search']) : '',
        );
        $args = wp_parse_args($args, $default_args);
        if (gj_option('show_expired_job')) {
            $query = "SELECT DISTINCT s.* FROM {$wpdb->prefix}gj_save_jobs AS s JOIN {$wpdb->posts} AS p ON s.post_id = p.ID WHERE (p.post_status = 'publish' OR p.post_status = 'gj-expired') AND s.user_id = '" . $this->get_id() . "'";
        } else {
            $query = "SELECT DISTINCT s.* FROM {$wpdb->prefix}gj_save_jobs AS s JOIN {$wpdb->posts} AS p ON s.post_id = p.ID WHERE p.post_status = 'publish' AND s.user_id = '" . $this->get_id() . "'";
        }

        if ($args['search']) {
            $query .= ' AND p.post_title LIKE "%' . $args['search'] . '%"';
        }

        $total_query = "SELECT COUNT(1) FROM (${query}) AS combined_table";
        $total = $wpdb->get_var($total_query);
        $items_per_page = $args['posts_per_page'];
        $page = isset($_GET['cpage']) ? abs((int) $_GET['cpage']) : 1;
        $offset = ( $page * $items_per_page ) - $items_per_page;
        $result = $wpdb->get_results($query . " ORDER BY s.ID DESC LIMIT ${offset}, ${items_per_page}");
        $total_page = ceil($total / $items_per_page);
        if ($total) {
            return array(
                'result' => $result,
                'total_page' => $total_page,
                'current_page' => $page,
            );
        } else {
            return null;
        }
    }

    public function get_save_resumes($args = array()) {
        global $wpdb;

        $default_args = array(
            'posts_per_page' => gj_option('dashboard_items_per_page', get_option('posts_per_page', 20)),
            'search' => isset($_GET['search']) ? sanitize_text_field($_GET['search']) : '',
        );
        $args = wp_parse_args($args, $default_args);
        $query = "SELECT s.* FROM {$wpdb->prefix}gj_save_resums AS s JOIN {$wpdb->posts} AS p ON s.post_id = p.ID WHERE p.post_status = 'publish' AND s.user_id = '" . $this->get_id() . "'";
        if ($args['search']) {
            if (is_email($args['search'])) {
                $search_user = get_user_by('email', $args['search']);
                if ($search_user) {
                    $query .= ' AND p.post_author = "' . $search_user->ID . '"';
                } else {
                    $query .= ' AND p.post_author = "-1"';
                }
            } else {
                $query .= ' AND p.post_title LIKE "%' . $args['search'] . '%"';
            }
        }
        $total_query = "SELECT COUNT(1) FROM (${query}) AS combined_table";
        $total = $wpdb->get_var($total_query);
        $items_per_page = $args['posts_per_page'];
        $page = isset($_GET['cpage']) ? abs((int) $_GET['cpage']) : 1;
        $offset = ( $page * $items_per_page ) - $items_per_page;
        $result = $wpdb->get_results($query . " ORDER BY ID DESC LIMIT ${offset}, ${items_per_page}");
        $total_page = ceil($total / $items_per_page);
        if ($total) {
            return array(
                'result' => $result,
                'total_page' => $total_page,
                'current_page' => $page,
            );
        } else {
            return null;
        }
    }

    public function is_followed($id) {
        global $wpdb;
        $query = "SELECT COUNT(1) FROM {$wpdb->prefix}gj_follows WHERE post_id = %d AND user_id = %d";
        return $wpdb->get_var($wpdb->prepare($query, $id, $this->get_id()));
    }

    public function follow($id) {
        global $wpdb;
        if ($wpdb->insert($wpdb->prefix . 'gj_follows', array('post_id' => $id, 'user_id' => $this->get_id()), array('%d', '%d'))) {
            return $wpdb->insert_id;
        }

        return false;
    }

    public function unfollow($id) {
        global $wpdb;
        if ($wpdb->delete($wpdb->prefix . 'gj_follows', array('post_id' => $id, 'user_id' => $this->get_id()), array('%d', '%d'))) {
            return true;
        }

        return false;
    }

    public function is_saved_job($id) {
        global $wpdb;
        $query = "SELECT COUNT(1) FROM {$wpdb->prefix}gj_save_jobs WHERE post_id = %d AND user_id = %d";
        return $wpdb->get_var($wpdb->prepare($query, $id, $this->get_id()));
    }

    public function save_job($id) {
        global $wpdb;
        if ($wpdb->insert($wpdb->prefix . 'gj_save_jobs', array('post_id' => $id, 'user_id' => $this->get_id()), array('%d', '%d'))) {
            return $wpdb->insert_id;
        }

        return false;
    }

    public function undo_save_job($id) {
        global $wpdb;
        if ($wpdb->delete($wpdb->prefix . 'gj_save_jobs', array('post_id' => $id, 'user_id' => $this->get_id()), array('%d', '%d'))) {
            return true;
        }

        return false;
    }

    public function check_user_review($item_id) {
        global $wpdb;
        $query = "SELECT COUNT(1) FROM {$wpdb->prefix}gj_reviews WHERE item_id = %d AND user_id = %d";
        return $wpdb->get_var($wpdb->prepare($query, $item_id, $this->get_id()));
    }

    public function can_view_resum($id) {
        $post = get_post($id);
        if (gj_option('view_free_resum') || user_can($this->user, 'privilege_view_resum') || ($post->post_author == $this->get_id())
        ) {
            return true;
        }

        return false;
    }

    public function is_saved_resum($id) {
        global $wpdb;
        $query = "SELECT COUNT(1) FROM {$wpdb->prefix}gj_save_resums WHERE post_id = %d AND user_id = %d";
        return $wpdb->get_var($wpdb->prepare($query, $id, $this->get_id()));
    }

    public function save_resum($id) {
        global $wpdb;
        if ($wpdb->insert($wpdb->prefix . 'gj_save_resums', array('post_id' => $id, 'user_id' => $this->get_id()), array('%d', '%d'))) {
            return $wpdb->insert_id;
        }

        return false;
    }

    public function delete_save_resum($id) {
        global $wpdb;
        if ($wpdb->delete($wpdb->prefix . 'gj_save_resums', array('post_id' => $id, 'user_id' => $this->get_id()), array('%d', '%d'))) {
            return true;
        }

        return false;
    }

    public function undo_save_resum($id) {
        global $wpdb;
        if ($wpdb->delete($wpdb->prefix . 'gj_save_resums', array('post_id' => $id, 'user_id' => $this->get_id()), array('%d', '%d'))) {
            return true;
        }

        return false;
    }

    public function get_cv() {
        if ($this->is_candidate()) {
            $candidate = $this->get_first_candidate();
            if ($candidate) {
                return $candidate->get_cv();
            }
        }

        return false;
    }

    public function get_cover_letter() {
        if ($this->is_candidate()) {
            $candidate = $this->get_first_candidate();
            if ($candidate) {
                return $candidate->get_cover_letter();
            }
        }

        return false;
    }

    function is_verified() {
        $verify_code = get_user_meta($this->get_id(), GJ_PREFIX . 'verify_code', true);
        if (empty($verify_code)) {
            return true;
        }

        return false;
    }

    function get_activation_url($new_code = true) {
        if ($new_code) {
            $code = wp_generate_password(20, false);
            update_user_meta($this->get_id(), GJ_PREFIX . 'verify_code', $code);
        } else {
            $code = get_user_meta($this->get_id(), GJ_PREFIX . 'verify_code', true);
        }

        $verify_url = home_url('/');
        $verify_url = add_query_arg(array('verify_account' => $this->get_id(), 'verify_code' => $code), $verify_url);

        return $verify_url;
    }
	
	public function can_apply() {
        // Check user don't must employer permission
        $allow = true;
        if (!user_can($this->user, 'apply_job')) {
            $allow = false;
        }

        return apply_filters('gj_user_can_apply_job', $allow);
    }
}

GJ_User::init();
