<?php
/**
 * @class 		GJ_Field_Checklist
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Checklist extends GJ_Field_Text {

    protected $type = 'checklist';
    protected $name = 'Checklist';

    public $validationFieldConfig = false;

    public function JSInputFields(){

        $tab = parent::JSInputFields();
        $fields = $tab['fields'];

        foreach($fields as $fieldkey=>$field){
            if($field['model'] === 'showInput'){
                break;
            }
        }
        $leftFields = array_splice($fields,0, $fieldkey+1);

        $newFields =  array(
            array(
                "type" => "checkbox",
                "label" => esc_html__( "Use option key", "gj" ),
                "model" => "useKey",
                "tab" => "Input"
            ),
            array(
                "type" => "simpleArray",
                "label" => esc_html__( "Options", "gj" ),
                "model" => "options",
                "useKey" => "beginJSFunction(model){ return model.useKey === true}endJSFunction",
                "tab" => "Input"
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function defaultSettings(){
        $default = parent::defaultSettings();
        $default->useKey = false;
        return $default;
    }

    public function checklistSettings(){
        $selectOptions = new stdClass();
        if($this->getSetting('useKey') === 'true'){
            $selectOptions->value = 'key';
            $selectOptions->name = 'val';
        }

        return $selectOptions;
    }

    public function checklistOptions(){
        if($this->getSetting('useKey') === 'true') {
            $values = (array)$this->getSetting('options');
        }else{
            $values = array_map(array($this, 'splitOption'), (array)$this->getSetting('options'));
            //array("Vue.js", "JavaScript", "Ruby", "Sinatra");
        }

        return $values;
    }

    public function splitOption($option){
        return $option->val;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            'type' : '{$this->type}',
            'label' : ".($this->getSetting('showlabel') === 'true' ? "'".$this->clearn_text($this->getSetting('name'))."'" : 'null').",
            'model' : '".$this->getSetting('metakey')."',
            'default' : '".$this->clearn_text($this->getSetting('default'))."',
            ".($this->getSetting('useKey') === 'true' ? "checklistOptions : ".json_encode($this->checklistSettings())."," : "")."
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'values' : ".json_encode($this->checklistOptions()).",
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function save()
    {
        $postID = $this->postID;
        $value = $this->sanitize();

        if($value){
            if(is_array($value)){
                $value = array_values($value);
            }
        }

        update_post_meta($postID, $this->getSetting('metakey'), $value);
    }

    public function model(){
        if($this->postID){
            $data = $this->data();
            if($data){
                $data = array_values($data);
            }
        }else{
            $_data = explode(",", $this->getSetting('default'));
            $data = array();
            if($_data){
                foreach ((array)$this->getSetting('options') as $option){
					
                    if(isset($option->key) && in_array($option->key, $_data)){
                        $data[] = $option;
                    }
                }
            }
        }
        return "'{$this->settings->metakey}' : ".json_encode($data);
    }

    public function data(){
        if($this->isWpCoreField()){
            return $this->getWpCoreFieldData();
        }else{
            $data = array_filter((array)$this->rawData());

            return $data;
        }
    }

    public function outputValue(){

        $values = $this->data();
        if($values && $this->getSetting('useKey') === 'true'){
            $options = $this->checklistOptions();
            $_values = array();
            foreach ($options as $option){
                if(in_array($option->key, $values)){
                    $_values[] = $option->val;
                }
            }
            $values = $_values;
        }

        $value = implode($values, ", ");

        return $value;
    }

    public function searchOutputHtml($type)
    {
        if($this->isActive() && $this->getSetting('searchOutput')) {
            $placeholder = $this->getSetting('searchPlaceholder') ? $this->getSetting('searchPlaceholder') : sprintf(__('Choose %s', 'gj'), $this->getSetting('name'));
            $value = isset($_REQUEST[$this->getSetting($this->getSetting('metakey'))]) ? $this->getSetting($this->getSetting('metakey')) : '';
            ?>
            <div class="col-md-<?php echo $this->getSetting('searchColumWidth'); ?> filter-item">
                <select class="default-sorting gj-select-2 form-control" name="<?php echo $this->getSetting('metakey'); ?>" data-options="<?php echo esc_attr( wp_json_encode(array('minimumResultsForSearch' => 'Infinity'))); ?>">
                    <option value="" selected="selected"><?php echo $placeholder ?></option>
                    <?php
                    $options = (array)$this->getSetting('options');
                    foreach ($options as $option) {
                        if($this->getSetting('useKey') === 'true'){
                            echo '<option value="' . esc_attr($option->key) . '" ' . selected($value, $option->key, false) . '>' . esc_html($option->val) . '</option>';
                        }else{
                            echo '<option value="' . esc_attr($option->val) . '" ' . selected($value, $option->val, false) . '>' . esc_html($option->val) . '</option>';
                        }
                    } ?>
                </select>
            </div>
            <?php
        }
    }
}