<?php
/**
 * @class 		GJ_Field_CurriculumVitae
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_CurriculumVitae extends GJ_Field_Base {

    protected $type = 'curriculumVitae';
    protected $name = 'CV';

    public function getCVOptions(){

        $options = array();
        $user = GJ_User::get_user();
        if($user){
            $candidates = $user->get_candidates(array('publish'));
            if($candidates){
                foreach ($candidates as $candidate){
                    $candidate = GJ_Candidate::get_candidate($candidate);
                    $cv = $candidate->get_cv();
                    if($cv) $options[] = $cv;
                }
            }
        }

        return $options;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        if(!is_admin()){
            $cvs = $this->getCVOptions();
        }else{
            $cvs = null;
        }
        return "{
            'type' : '{$this->type}',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : {},
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'maxUploadFileSize' : ".(int)gj_max_upload_cv_size().",
            ".($cvs ? "cvs : ".json_encode($cvs)."," : "")."
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function save()
    {
        $postID = $this->postID;
        if(isset($_FILES[$this->settings->metakey])){
            $value = gj_upload_cv($_FILES[$this->settings->metakey]);
        }else{
            $value = $this->sanitize();
        }
		$oldID = $this->rawData();

        if($value){
            if($oldID && $oldID != $value['ID'] && current_user_can('delete_post', $oldID)){
                wp_delete_post($oldID);
            }

            update_post_meta($postID, $this->settings->metakey, $value['ID']);
        }else{
            if($oldID && current_user_can('delete_post', $oldID)){
                wp_delete_post($oldID);
            }
            update_post_meta($postID, $this->settings->metakey, '');
        }
    }

    public function model(){
        $value = array();
        if($this->postID) {
            $value = $this->data();
        }

        if(!$value && !is_admin()){
            $cvs = $this->getCVOptions();
            if($cvs){
                $value = $cvs[0];
            }
        }
        return "'{$this->settings->metakey}' : ".json_encode($value);
    }

    public function data(){
        if($this->isWpCoreField()){
            return $this->getWpCoreFieldData();
        }else{
            $raw = $this->rawData();
            $data = array();
            if($raw){
                $data['ID'] = $raw;
                $data['url'] = wp_get_attachment_url($raw);
                $data['name'] = get_the_title( $raw );
                $data['date'] = get_the_date($raw);
                $data['icon'] = wp_get_attachment_image($raw);

            }

            return $data;
        }
    }

    public function outputValue(){
        $cv = $this->data();
        $html = "";

        if($cv){
            $html = '<a href="'.esc_url($cv['url']).'" target="_blank">'.esc_html($cv['name']).'</a>';
        }

        return $html;
    }
}