<?php
/**
 * @class 		GJ_Field_Datetime
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Datetime extends GJ_Field_Text {

    protected $type = 'datetime';
    protected $name = 'Datetime';

    public $validationFieldConfig = false;

    public function enqueue(){
        wp_enqueue_style( 'datetimepicker');
        wp_enqueue_script( 'datetimepicker');
    }

    public function JSInputFields(){

        $tab = parent::JSInputFields();
        $fields = $tab['fields'];

        foreach($fields as $fieldkey=>$field){
            if($field['model'] === 'showInput'){
                break;
            }
        }
        $leftFields = array_splice($fields,0, $fieldkey+1);

        $newFields =  array(
            array(
                "type" => "input",
                "inputType" => "text",
                "label" => esc_html__( "Format", "gj" ),
                "model" => "format",
                "tab" => "Input"
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function splitOption($option){
        return $option->val;
    }

    public function getFormat(){
        $format = $this->getSetting('format');

        return $format ? $format : 'Y/m/d H:i:s';
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            'type' : 'dateTime',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'dateOptions' : {
                format : '".$this->clearn_text($this->getFormat())."',
                lang : '".$this->clearn_text(substr( get_locale(), 0, 2 ))."',
                timepicker : true,
                datepicker : true,
            },
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function model(){
        $data = $this->postID ? $this->data() : $this->getDefaultValue() ;
        $data = $data && is_numeric($data) ? date($this->getFormat(), $data) : '';
        return "'{$this->settings->metakey}' : '{$data}'";
    }

    public function save()
    {
        $postID = $this->postID;
        $value = $this->sanitize();
        if($value){
            $value = strtotime(str_replace('/', '-', $value));
        }
        update_post_meta($postID, $this->settings->metakey, $value);
    }

    public function data(){
        if($this->isWpCoreField()){
            return $this->getWpCoreFieldData();
        }else{
            $data = $this->rawData();
            return $data;
        }
    }

    public function outputValue(){
        $data = $this->data();
        $html = $data && is_numeric($data) ? date(get_option('date_format'), $data) : $data;

        return $html;
    }
}