<?php
/**
 * @class 		GJ_Field_Experience
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Experience extends GJ_Field_Repeater {

    protected $type = 'experience';
    protected $inputType = 'experience';
    protected $name = 'Experience';

    public function getRepeaterSchema(){
        $schemas = array("fields" => array(
            array(
                'label' => esc_html__('Title', 'gj'),
                'type' => 'input',
                'inputType' => 'text',
                'model' => 'title',
                'required' => true,
            ),
            array(
                'label' => esc_html__('Company', 'gj'),
                'type' => 'input',
                'inputType' => 'text',
                'model' => 'company',
                'required' => true,
            ),
            array(
                'label' => esc_html__('Date in-out', 'gj'),
                'type' => 'input',
                'inputType' => 'text',
                'model' => 'date',
                'required' => true,
            ),
            array(
                'label' => esc_html__('Description', 'gj'),
                'type' => 'textArea',
                'inputType' => 'text',
                'model' => 'description',
            )
        ));
        return json_encode($schemas);
    }

    public function itemContainerHeader(){
        return "function(model, schema, index) {
            var html = '<span class=\"company\"><strong>".esc_html__('Company', 'gj')."</strong>'+(model.company || index)+'</span>';
            html += '<span class=\"position\"><strong>".esc_html__('Position', 'gj')."</strong>'+(model.title || '')+'</span>';
            html += '<span class=\"date\"><strong>".esc_html__('Date', 'gj')."</strong>'+(model.date || '')+'</span>';
            
            return html;
        }";
    }

    public function newElementButtonLabel(){
        return $this->settings->newbuttonlabel ? $this->settings->newbuttonlabel : esc_html__('Add more experience', 'gj');
    }

    public function getStyleClasses(){
        return parent::getStyleClasses(). ' field-experience';
    }

    public function outputValue(){

        $data = $this->data();
        $html = '';
        if($data){
            $html .= '<ul class="gj-time-line">';
            foreach ($data as $row){
                $html .= '<li>';
                if ( !empty( $row['date'] ) || !empty($row['company']) ) {

                    $html .= '<div class="top">';
                    if ( !empty($row['date']) ) {
                        $html .= '<div class="date theme-second-color">' . $row['date'] . '</div>';
                    }
                    if ( !empty($row['company']) ) {
                        $html .= '<div class="company-name theme-second-color theme-border-second-color">' . $row['company'] . '</div>';
                    }
                    $html .= '</div>';

                }
                if( !empty($row['title']) ){
                    $html .= '<div class="position-company bottom">'.$row['title'].'</div>';
                }
                if( !empty($row['description']) ){
                    $html .= '<div class="desc">'.$row['description'].'</div>';
                }
                $html .= '</li>';
            }
            $html .= '</ul>';
        }

        return $html;
    }
}