<?php
/**
 * @class 		GJ_Field_Gallery
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Gallery extends GJ_Field_Base {

    protected $type = 'gallery';
    protected $name = 'Gallery';

    public function JSInputFields(){

        $tab = parent::JSInputFields();
        $fields = $tab['fields'];

        foreach($fields as $fieldkey=>$field){
            if($field['model'] === 'showInput'){
                break;
            }
        }
        $leftFields = array_splice($fields,0, $fieldkey+1);

        $newFields =  array(
            array(
                "type" => "checkbox",
                "label" => esc_html__( "Featured first image", "gj" ),
                "model" => "featuredfirstimage",
                "tab" => "Input"
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            'type' : '{$this->type}',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'imageUrl' : 'https://via.placeholder.com/150',
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function deletePost(){
        $images = $this->data();
        if($images){
            foreach ($images as $image){
                wp_delete_attachment( $image, true );
            }
        }

        if($this->getSetting('featuredfirstimage') === 'true'){
            $thubnail = get_post_thumbnail_id($this->postID);
            wp_delete_attachment( $thubnail, true );
        }
    }

    public function save()
    {
        $postID = $this->postID;
        $imageIDs = array();
        $removeImageIDs = array();
        $images = $this->sanitize();
        $oldImageIDs = (array)$this->data();
        if($images){
            foreach ($images as $image){
                $imageIDs[] = $image['id'];
            }

            if($oldImageIDs){
                $removeImageIDs = array_diff($oldImageIDs, $imageIDs);
            }
        }else{
            $removeImageIDs = $oldImageIDs;
        }

        if($this->getSetting('featuredfirstimage') === 'true'){
            if($imageIDs){
                set_post_thumbnail($postID, $imageIDs[0]);
                unset($imageIDs[0]);
            }else{
                delete_post_thumbnail($postID);
            }
        }

        update_post_meta($postID, $this->settings->metakey, $imageIDs);

        if($removeImageIDs){
            foreach ($removeImageIDs as $id){
                if(current_user_can('delete_post', $id)){
                    wp_delete_attachment($id, true);
                }
            }
        }
    }

    public function data(){
        $value = $this->rawData();
        return $value ? $value : array();
    }

    public function model(){
        $value = array();
        if($this->postID) {
            $images = $this->data();
            if($this->getSetting('featuredfirstimage') === 'true'){
                $thumbnail_id = get_post_thumbnail_id($this->postID);
                if($thumbnail_id){
                    array_unshift($images, $thumbnail_id);
                }
            }
            
            if($images){
                foreach ($images as $image){
                    $attached_file = get_attached_file( $image );
                    $file_path = get_attached_file( $image );
                    $file_size = file_exists($file_path) ? round(filesize( get_attached_file( $image ) ) / 1024) . " KB" : "";
                    if($attached_file){
                        $imageData = array();
                        $imageData['id'] = $image;
                        $imageData['name'] = basename($attached_file);
                        $FileNameArr = explode('.', $imageData['name']);
                        $imageData['type'] = end($FileNameArr);
                        $imageData['size'] = $file_size;
                        $imageData['url'] = wp_get_attachment_image_src( $image )[0];
                        $value[] = $imageData;
                    }
                }
            }
        }

        return "'{$this->settings->metakey}' : ".json_encode($value);
    }

    public function outputValue(){

        $images = $this->data();
        $video_url        =   get_post_meta( get_the_ID(), 'video_url', true );
        $html = "";
        if($images || $video_url){
            wp_enqueue_style('owl-carousel');
            wp_enqueue_style('owl-theme');
            wp_enqueue_style('owl-transitions');
            wp_enqueue_script('owl-carousel');
            wp_enqueue_style('jquery-fancybox');
            $data_plugin_options = array(
                "loop"       => false,
                "nav"        => false,
                "dots"       => true,
                "autoplay"   => false,
                "margin"   => 30,
                "items"      => 4,
                "responsive" => [
                    '0'    => array(
                        'items' => 2
                    ),
                    '568'  => array(
                        'items' => 4
                    ),
                ],
            );
            $html .= "<div class='gj-gallery'>";
            $html .= "<div class='Gj-owl-carousel owl-carousel' data-plugin-options='".htmlspecialchars( json_encode( $data_plugin_options ) )."'>";
            if ($images) {
                $i = 1;
                foreach ($images as $image){
                    if ($i == 1) {
                        if ($video_url) {
                            $html .= "<a rel='alternate' class='fancybox fancybox.iframe' href='" . $video_url . "'><img src='".wp_get_attachment_image_src( $image, "thumbnail" )[0]."' alt='".get_the_title($image)."'><i class=\"fa fa-play\"></i></a>";
                        } else {
                            $html .= "<a rel='alternate' href='" . wp_get_attachment_image_src( $image, "full" )[0] . "'><img src='".wp_get_attachment_image_src( $image, "thumbnail" )[0]."' alt='".get_the_title($image)."'></a>";
                        }
                    } else {
                        $html .= "<a rel='alternate' href='" . wp_get_attachment_image_src( $image, "full" )[0] . "'><img src='".wp_get_attachment_image_src( $image, "thumbnail" )[0]."' alt='".get_the_title($image)."'></a>";
                    }
                $i ++;}
            } elseif ($video_url) {
                $html .= '<a rel="alternate" class="fancybox fancybox.iframe" href="'.$video_url.'">';
                $html .= "<img src='".GJ_PLUGIN_URL."/assets/images/poster_video.jpg' alt=''>";
                $html .= '<i class="fa fa-play"></i>';
                $html .= '</a>';
            }
            $html .= "</div>";
            $html .= "</div>";
        }

        return $html;
    }
}