<?php
/**
 * @class 		GJ_Field_Avatar
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Image extends GJ_Field_Base {

    protected $type = 'image';
    protected $name = 'Image';

    public function JSInputFields(){

        $tab = parent::JSInputFields();
        $fields = $tab['fields'];

        foreach($fields as $fieldkey=>$field){
            if($field['model'] === 'showInput'){
                break;
            }
        }
        $leftFields = array_splice($fields,0, $fieldkey+1);

        $newFields =  array(
            array(
                "type" => "checkbox",
                "label" => esc_html__( "Image as post thumbnail", "gj" ),
                "model" => "is_post_thumbnail",
                "tab" => "Input"
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');
        
        return "{
            'type' : '{$this->type}',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->clearn_text($this->settings->metakey)}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function deletePost(){
        $image = $this->data();
        if($image){
            wp_delete_attachment( $image, true );
        }
    }

    public function save()
    {
        $postID = $this->postID;
        $value = $this->sanitize();
        if($this->getSetting('is_post_thumbnail') === 'true'){
            set_post_thumbnail($postID, $value['id']);
        }else{
            update_post_meta($postID, $this->settings->metakey, $value['id']);
        }
    }

    public function rawData(){
        if($this->getSetting('is_post_thumbnail') === 'true'){
            $value = get_post_thumbnail_id($this->postID);
        }else{
            $value = get_post_meta($this->postID, $this->settings->metakey, true);
        }

        return $value;
    }

    public function model(){
        $value = array();
        if($this->postID) {
            $image_id = $this->data();
            if($image_id){
                $value['id'] = $image_id;
                $value['url'] = wp_get_attachment_image_src( $image_id )[0];
            }
        }

        return "'{$this->settings->metakey}' : ".json_encode($value);
    }
}