<?php
/**
 * @class 		GJ_Field_Map
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Map extends GJ_Field_Base {

    protected $type = 'map';
    protected $name = 'Map';
    public $defaultFieldConfig = false;
    public $validationFieldConfig = false;

    public function enqueue(){
        wp_enqueue_script( 'google-maps', array('jquery'));
        wp_enqueue_script('vue-multiselect');
        wp_enqueue_style('vue-multiselect');
    }

    public function JSInputFields(){

        $tab = parent::JSInputFields();
        $fields = $tab['fields'];

        foreach($fields as $fieldkey=>$field){
            if($field['model'] === 'showInput'){
                break;
            }
        }

        $leftFields = array_splice($fields,0, $fieldkey+1);

        $newFields =  array(
            array(
                "type" => "checkbox",
                "label" => esc_html__( "Auto detect country/states/city", "gj" ),
                "model" => "autoDetectLocation",
                "tab" => "Input"
            ),
            array(
                "type" => "checkbox",
                "label" => esc_html__( "Show map", "gj" ),
                "model" => "showMap",
                "tab" => "Input"
            ),
            array(
                "type" => "input",
                "inputType" => "text",
                "label" => esc_html__( "Placeholder", "gj" ),
                "model" => "placeholder",
                "tab" => "Input",
                "visible" => "beginJSFunction(model) { return model && model.autoDetectLocation }endJSFunction",
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function JSOutputFields(){

        $tab = parent::JSOutputFields();
        $fields = $tab['fields'];

        foreach($fields as $fieldkey=>$field){
            if($field['model'] === 'showOutputLable'){
                break;
            }
        }

        $leftFields = array_splice($fields,0, $fieldkey+1);

        $newFields =  array(
            array(
                "type" => "checkbox",
                "label" => esc_html__( "Show map", "gj" ),
                "model" => "outputShowMap",
                "tab" => "Output"
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function JSFilterFields(){
        return array(
            'title' => esc_html__('Filter', 'gj'),
            'id' => 'filter',
            'fields' => array(
                array(
                    "type" => "checkbox",
                    "label" => esc_html__( "Filter output", "gj" ),
                    "model" => "filterOutput",
                    "default" => true,
                    "tab" => "Filter"
                ),
                array(
                    "type" => "checkbox",
                    "label" => esc_html__( "Default expand", "gj" ),
                    "model" => "defaultExpand",
                    "default" => true,
                    "tab" => "Filter"
                ),
                array(
                    "type" => "select",
                    "label" => esc_html__( "Order by", "gj" ),
                    "model" => "filterOrderby",
                    "default" => "name",
                    "tab" => "Filter",
                    "values" => array(
                        array("id" => "", "name" => "ID"),
                        array("id" => "once", "name" => "Count"),
                        array("id" => "name", "name" => "Name"),
                    )
                ),
                array(
                    "type" => "select",
                    "label" => esc_html__( "Order", "gj" ),
                    "model" => "filterOrder",
                    "default" => "ASC",
                    "tab" => "Filter",
                    "values" => array(
                        array("id" => "ASC", "name" => "ASC"),
                        array("id" => "DESC", "name" => "DESC"),
                    )
                ),
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Ordering", "gj" ),
                    "model" => "filterOrdering",
                    "default" => "",
                    "tab" => "Filter"
                ),
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Show maximum items", "gj" ),
                    "hin" => "leave blank to show all items",
                    "model" => "maxShow",
                    "default" => "",
                    "tab" => "Filter"
                ),
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Min radius", "gj" ),
                    "model" => "minRadius",
                    "default" => "10",
                    "tab" => "Filter"
                ),
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Max radius", "gj" ),
                    "model" => "maxRadius",
                    "default" => "100",
                    "tab" => "Filter"
                ),
            )
        );
    }

    public function JSRegisterFields(){
        $fields = parent::JSRegisterFields();
        $fields[] = $this->JSFilterFields();

        return $fields;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        $placeholder = $this->getSetting('placeholder');
        return "{
            'type' : '{$this->type}',
            'label' : ".($this->settings->showlabel === 'true' && $this->getSetting('autoDetectLocation') === 'true' ? "'".$this->clearn_text($this->settings->name)."'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->settings->default}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'autoDetectLocation' : ".($this->getSetting('autoDetectLocation') === 'true' ? 'true' : 'false').",
            'showMap' : ".($this->getSetting('showMap') === 'true' ? 'true' : 'false').",
            'selectOptions' : {
                noOptions : '".$this->clearn_text(esc_html__('No List Found','gj'))."',
                fetchingOptions : '".$this->clearn_text(esc_html__('Fetching data...', 'gj'))."',
                placeholders : {
                    country : '".$this->clearn_text(esc_html__('Select Country','gj'))."',
                    state : '".$this->clearn_text(esc_html__('Select State','gj'))."',
                    city : '".$this->clearn_text(esc_html__('Select City','gj'))."',
                }
            },
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
            ".($placeholder ? "placeholder : '{$this->clearn_text($placeholder)}'," : "")."
        }";
    }

    public function save()
    {
        $postID = $this->postID;
        $value = (array)$this->sanitize();
        if($value){
            $useLocation = true;
            $autoDetectLocation = $this->getSetting('autoDetectLocation');
            if($useLocation){
                if($autoDetectLocation === 'true'){
                    if(isset($value['state']) && is_array($value['state'])){
                        $state = $value['state']['name'];
                        $stateObj = get_term_by( 'name', $state, 'gj_state');
                        if(!$stateObj){
                            $stateObj = wp_insert_term($state, 'gj_state');
                            $stateID = $stateObj['term_id'];
                            $country = $value['country']['code'];
                            update_term_meta($stateID, 'country', $country);
                        }else{
                            $stateID = $stateObj->term_id;
                        }
                        wp_set_post_terms( $postID, array($stateID), 'gj_state' );
                    }else{
                        wp_set_post_terms( $postID, null, 'gj_state' );
                    }
                    if(isset($value['city']) && is_array($value['city'])){
                        $city = $value['city']['name'];
                        $cityObj = get_term_by( 'name', $city, 'gj_city');
                        if(!$cityObj){
                            $cityObj = wp_insert_term($city, 'gj_city');
                            $cityID = $cityObj['term_id'];
                            update_term_meta($cityID, 'state', $stateID);
                        }else{
                            $cityID = $cityObj->term_id;
                        }
                        wp_set_post_terms( $postID, array($cityID), 'gj_city' );
                    }else{
                        wp_set_post_terms( $postID, null, 'gj_city' );
                    }
                }else{
                    if(isset($value['state']) && is_array($value['state'])){
                        $state = (int)$value['state']['term_id'];
                        if(term_exists( $state, 'gj_state')){
                            wp_set_post_terms( $postID, array($state), 'gj_state' );
                        }
                    }else{
                        wp_set_post_terms( $postID, null, 'gj_state' );
                    }

                    if(isset($value['city']) && is_array($value['city'])){
                        $city = (int)$value['city']['term_id'];
                        if(term_exists( $city, 'gj_city')){
                            wp_set_post_terms( $postID, array($city), 'gj_city' );
                        }
                    }else{
                        wp_set_post_terms( $postID, null, 'gj_city' );
                    }
                }
            }

            $address =  isset($value['address']) ? sanitize_text_field($value['address']) : "";
            $lat =  isset($value['lat']) ? sanitize_text_field($value['lat']) : "";
            $lng =  isset($value['lng']) ? sanitize_text_field($value['lng']) : "";

            update_post_meta($postID, 'address', $address);
            update_post_meta($postID, 'lat', $lat);
            update_post_meta($postID, 'lng', $lng);
        }
    }

    public function rawData(){
        $values = array();
        $values['address'] = get_post_meta($this->postID, 'address', true);
        $values['lat'] = get_post_meta($this->postID, 'lat', true);
        $values['lng'] = get_post_meta($this->postID, 'lng', true);

        return $values;
    }

    public function model(){
        $model = array();
        if($this->postID){
            $useLocation = true;
            $model = $this->data();
            if($useLocation) {
                $state = get_the_terms($this->postID, 'gj_state');
                $state = $state ? $state[0] : null;
                $country = null;
                if($state){
                    $country = get_term_meta($state->term_id, 'country', true);
                    if($country){
                        $country = array('code' => $country, 'name' => gj_get_country_titles($country));
                        $model['country'] = $country;
                    }

                    $model['state'] = $state;
                }

                $city = get_the_terms($this->postID, 'gj_city');
                $city = $state ? $city[0] : null;
                $model['city'] = $city;
            }
        }

        return "'{$this->settings->metakey}' : ".json_encode($model);
    }

    public function outputValue(){
        $data = $this->data();
        $html = "";
        if($this->getSetting('outputShowMap')){
            if($data && (isset($data['lat']) && $data['lat']) || (isset($data['lng']) && $data['lng'])){
                $html .= "<div class='job-detail-map' data-lat='".esc_attr($data['lat'])."' data-lng='".esc_attr($data['lng'])."' data-zoom='".esc_attr(gj_option('map_zoom'))."' data-maker=''
						 data-address='".esc_attr($data['address'])."' style='height: 332px;'>
					</div>";
            }
        }else{
            $post = GJ_Post::get_post($this->postID);
            if($post){
                $html = $post->get_location();
            }
        }

        return $html;
    }

    public function getTerms($type = 'state', $slug = ''){

        $taxonomy = 'gj_'.$type;
        $hideEmpty = false;
        $orderby = $this->getSetting('filterOrderby');
        $order = $this->getSetting('filterOrder');
        $number = $this->getSetting('maxShow');
        $args = array(
            'hide_empty' => $hideEmpty,
            'taxonomy'  => $taxonomy,
            'orderby'  => $orderby,
            'order'  => $order,
            'number'  => $number,
            'slug' => $slug
        );

        return get_terms( $args );
    }

    public function totalTerms($type = 'state'){

        $taxonomy = 'gj_'.$type;
        $hideEmpty = false;

        $args = array(
            'hide_empty' => $hideEmpty,
        );

        return wp_count_terms($taxonomy,  $args );
    }

    public function filterOutputHtml($type){

        $html = apply_filters('gj_field_before_filter_output_html', null, $this, $type);
        if($html !== null){
            echo $html;
        }else{
            $defaultExpand = $this->getSetting('defaultExpand') === 'true' ? true : false;
            $style_collapse = $defaultExpand ? 'block' :  'none';

            switch ($type){
                case 'gj_candidate':
                    $filters = GJ_Candidate_Listing::instance()->get_data_filters();
                    break;
                case 'gj_employer':
                    $filters = GJ_Employer_Listing::instance()->get_data_filters();
                    break;
                default:
                    $filters = GJ_Job_Listing::instance()->get_data_filters();
                    break;
            }

            if($this->getSetting('filterOutput') === 'true'){
                $max_radius = $this->getSetting('maxRadius') ? $this->getSetting('maxRadius') :  '100';
                $min_radius = $this->getSetting('minRadius') ? $this->getSetting('minRadius') :  '10';
                $default_radius = gj_option('default_search_radius') ?  gj_option('default_search_radius') : 10;
                $unit = gj_option('search_unit');

                if ($filters && isset($filters['radius'])) {
                    $default_radius = $filters['radius'];
                }

                wp_enqueue_script( 'google-maps' );
                wp_enqueue_script( 'range-slide-js' );
                wp_enqueue_style( 'range-slide-css' );

                $data_radius = array(
                    'min_radius' => $min_radius,
                    'max_radius' => $max_radius,
                    'default_radius' => $default_radius,
                );

                $aside_location_class = array();
                if ($defaultExpand) {
                    $aside_location_class[] = 'no-compress';
                } else {
                    $aside_location_class[] = 'compress';
                }

                ob_start();
                ?>
                <aside class="widget gj-widget-collapse sidebar-jobs-item sidebar-location <?php echo esc_attr(implode(' ', $aside_location_class)); ?>">
                    <h3 class="widget-title gj-widget-title-collapse"><span><?php echo esc_html__('Location', 'gj'); ?></span></h3>
                    <div class="sidebar-job-1 gj-widget-content-collapse" style="display: <?php echo esc_attr($style_collapse); ?>;">
                        <form class="gj-form-filter gj-location-search-form">
                            <div class="gj-location-search">
                                <input id="gj-input-location" class="input-field" placeholder="<?php echo esc_html__('Enter location', 'gj'); ?>" name="location" type="text" value="<?php echo isset($filters['location']) ? sanitize_text_field($filters['location']) : ''; ?>">
                                <span id="gj-pinpoint-btn" class="pinpoint-btn"><i class="fa fa-dot-circle-o"></i></span>
                                <input type="hidden" name="lat" id="gj-input-lat" value="<?php echo isset($filters['lat']) ? floatval($filters['lat']) : ''; ?>">
                                <input type="hidden" name="lng" id="gj-input-lng" value="<?php echo isset($filters['lng']) ? floatval($filters['lng']) : ''; ?>">
                            </div>
                            <div class="slide-range" data-radius="<?php echo htmlspecialchars( json_encode( $data_radius ) ); ?>">
                                <div class="search-distance-label theme-second-color"><?php echo esc_html__('Radius: ', 'gj'); ?><span id="gj-text-distance" class="text-distance"><?php echo esc_html($default_radius); ?></span><?php echo ($unit == 'Km') ? esc_html__('Km', 'gj') : esc_html__(' miles', 'gj'); ?></div>
                                <div id="gj-range-radius" class="range-radius"></div>
                                <input type="hidden" name="radius" id="gj-input-radius" value="<?php echo isset($filters['radius']) ? intval($filters['radius']) : $default_radius; ?>">
                            </div>
                        </form>
                    </div>
                </aside>
                <?php
                $html = ob_get_contents();
                ob_end_clean();
            }
            echo apply_filters('gj_field_filter_output_html', $html, $this, $type);
        }
    }

    public function filteredOutputHtml($type){
        $html = apply_filters('gj_field_before_filtered_output_html', null, $this, $type);
        if($html !== null){
            echo $html;
        }else{
            if($this->getSetting('filterOutput') === 'true'){
                switch ($type){
                    case 'gj_candidate':
                        $filters = GJ_Candidate_Listing::instance()->get_data_filtered();
                        break;
                    case 'gj_employer':
                        $filters = GJ_Employer_Listing::instance()->get_data_filtered();
                        break;
                    default:
                        $filters = GJ_Job_Listing::instance()->get_data_filtered();
                        break;
                }

                if ((isset($data_filter['location']) && $filters['location']) || (isset($filters['radius']) && $filters['radius'])) {
                    $html = '<li data-search_type="radius" class="gj-filter-selected-item">
                        <label><i class="lnr lnr-location"></i> '.(isset($filters['location']) && $filters['location'] ? wp_trim_words($filters['location'], 5, '...') : $filters['radius']). '</label>
                        <a href="#" class="remove"><i class="lnr lnr-cross-circle"></i></a>
                        </li>';
                }

            }

            echo apply_filters('gj_field_filtered_output_html', $html, $this, $type);
        }
    }

    public function searchOutputHtml($type)
    {
        $min_radius = 26;
        $unit = 'KM';
        ?>
        <div class="col-md-<?php echo $this->getSetting('searchColumWidth'); ?> section-filter">
            <i class="lnr lnr-map-marker"></i>
            <input class="location" type="text" name="location" id="location" placeholder="<?php echo __('Enter Location', 'gj'); ?>">
            <span><?php echo esc_html__('Within: ', 'gj') ?><span><?php echo esc_html($min_radius.' '.$unit); ?></span><button class="btn-pinpoint"><i class="fa fa-dot-circle-o"></i></button></span>
            <input type="hidden" name="current_lat" class="gj_curent_lat">
            <input type="hidden" name="current_lng" class="gj_curent_lng">
        </div>
        <?php
    }
}