<?php
/**
 * @class 		GJ_Field_Post
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Post extends GJ_Field_SelectAdvanced {

    protected $type = 'post';
    protected $name = 'Post';

    public $defaultFieldConfig = false;
    public $validationFieldConfig = false;

    private function AllPostTypes(){
        return array_keys(get_post_types());
    }

    public function JSInputFields(){

        $tab = parent::JSInputFields();
        $fields = $tab['fields'];
        $fieldkey = 2;
        foreach ($fields as $key => $field){
            if($field['model'] == 'useKey' || $field['model'] == 'options'){
                unset($fields[$key]);
            }

            if($field['model'] === 'showInput'){
                $fieldkey = $key;
            }
        }

        $leftFields = array_splice($fields,0, $fieldkey+1);

        $newFields =  array(
            array(
                "type" => "select",
                "label" => esc_html__( "Asynchronous select", "gj" ),
                "model" => "asynchronous",
                "default" => "",
                "tab" => "Input",
                "values" => array(
                    array("id" => "", "name" => "None"),
                    array("id" => "once", "name" => "Once when focusing on it"),
                    array("id" => "every", "name" => "Every time after searching"),
                )
            ),
            array(
                "type" => "select",
                "label" => esc_html__( "Post", "gj" ),
                "model" => "postType",
                "default" => "",
                "tab" => "Input",
                "values" => $this->AllPostTypes()
            ),
            array(
                "type" => "select",
                "label" => esc_html__( "Order by", "gj" ),
                "model" => "orderby",
                "default" => "name",
                "tab" => "Input",
                "values" => array(
                    array("id" => "id", "name" => "id"),
                    array("id" => "count", "name" => "count"),
                    array("id" => "name", "name" => "name"),
                )
            ),
            array(
                "type" => "select",
                "label" => esc_html__( "Order", "gj" ),
                "model" => "order",
                "default" => "ASC",
                "tab" => "Input",
                "values" => array(
                    array("id" => "ASC", "name" => "ASC"),
                    array("id" => "DESC", "name" => "DESC"),
                )
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function defaultSettings(){
        $default = parent::defaultSettings();
        $default->searchable = false;
        $default->multiple = false;
        $default->asynchronous = false;
        $default->postType = '';
        $default->orderby = 'name';
        $default->order = 'ASC';
        return $default;
    }

    public function splitOption($option){
        return $option->val;
    }

    public function getPosts(){
        $args = array(
            'post_type' => $this->settings->postType,
            'orderby'  => $this->settings->orderby,
            'order'  => $this->settings->order,
            'posts_per_page' => -1,
        );

        $posts =  get_posts( $args );
        if($posts){
            $posts = array_map(function ($item){
                $newItem = new stdClass();
                $newItem->ID = $item->ID;
                $newItem->post_title = wp_specialchars_decode($item->post_title);

                return $newItem;
            }, $posts);
        }

        return $posts;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        $values = $this->settings->asynchronous === 'false' ? json_encode($this->getPosts()) : "[]";
        
        return "{
            'type' : 'post',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'placeholder' : '".$this->clearn_text(esc_html__('Type to search', 'gj'))."',
            'postType' : '{$this->clearn_text($this->settings->postType)}',
            'asynchronous' : '{$this->clearn_text($this->settings->asynchronous)}',
            'orderby' : '{$this->clearn_text($this->settings->orderby)}',
            'order' : '{$this->clearn_text($this->settings->order)}',
            'values' : {$values},
            'selectOptions' : {
                multiple : ".($this->getSetting('multiple') === 'true' ? 'true' : 'false').",
                noOptions : '".$this->clearn_text(esc_html__('No List Found','gj'))."',
                fetchingOptions : '".$this->clearn_text(esc_html__('Fetching data...', 'gj'))."',
            },
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function sanitize(){
        if($this->settings->multiple === 'true'){
            return (array)gj_clean($_POST[$this->settings->metakey]);
        }else{
            return sanitize_text_field($_POST[$this->settings->metakey]['ID']);
        }
    }

    public function save()
    {
        $postID = $this->postID;
        $value = $this->sanitize();
        update_post_meta($postID, $this->settings->metakey, $value);
    }

    public function model(){
        $value = null;

        if(!$this->postID){
            $model = $this->settings->multiple ? '[]' : '';
        }else{
            $post_type = $this->settings->postType;
            $value = $this->data();
            if($value){
                if($this->settings->multiple === 'true') {
                    $model = get_posts( array(
                        'post_type' => $post_type,
                        'include' => (array)$value,
                    ) );
                    if($model){
                        $model = array_map(function ($item){
                            $newItem = new stdClass();
                            $newItem->ID = $item->ID;
                            $newItem->post_title = $item->post_title;

                            return $newItem;
                        }, $model);
                    }
                }else{
                    $value = is_array($value) ? $value[0]: $value;
                    $post = get_post( $value);
                    if($post && !is_wp_error($post)){
                        $model = new stdClass();
                        $model->ID = $post->ID;
                        $model->post_title = $post->post_title;
                    }else{
                        $model = "";
                    }
                }
            }else{
                $model = $this->settings->multiple ? "[]" : "";
            }
        }

        return "'{$this->settings->metakey}' : ".($value ? json_encode($model) : ($this->settings->multiple ? $model : "'{$model}'"));
    }

    public function outputValue(){
        $values = $this->data();
        $html = "";
        if($values && $this->settings->multiple === 'true'){
            $_values = array();
            foreach ($values as $postID){
                $_values[] = get_the_title($postID);
            }

            $_values = array_filter($_values);
            $html = implode($_values, ", ");
        }elseif($values){
            $html = get_the_title($values);
        }

        return $html;
    }
}