<?php
/**
 * @class 		GJ_Field_Repeater
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Repeater extends GJ_Field_Base {

    protected $type = 'repeater';
    protected $inputType = 'repeater';
    protected $name = 'Repeater';

    public function JSInputFields(){
        $tab = parent::JSInputFields();
        $fields = $tab['fields'];
        $fields = array_merge(
            $fields,
            array(
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "New button label", "gj" ),
                    "model" => "newbuttonlabel",
                    "default" => "",
                    "tab" => "Input",
                ),
            )
        );
        $tab['fields'] = $fields;

        return $tab;
    }


    public function defaultSettings(){
        $default = parent::defaultSettings();
        $default->schema = '';
        $default->newbuttonlabel = '';
        return $default;
    }

    public function input(){
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            type : 'array',
            label : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            model : '{$this->settings->metakey}',
            itemContainerComponent : '".$this->itemContainerComponent()."',
            validateDebounceTime : 100,
            required : ".($this->settings->required === 'true' ? 'true' : 'false').",
            items: {
                type: 'object',
                default: {},
                schema: ".$this->getRepeaterSchema()."
            },
            styleClasses : '".$this->clearn_text($this->getStyleClasses())."',
            newElementButtonLabel : '".$this->clearn_text($this->newElementButtonLabel())."',
            itemContainerHeader: ".$this->itemContainerHeader().",
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function itemContainerComponent(){
        return "Container2";
    }

    public function newElementButtonLabel(){
        return $this->settings->newbuttonlabel ? $this->settings->newbuttonlabel : esc_html__('Add more', 'gj');
    }

    public function itemContainerHeader(){
        return "function(model, schema, index) {
            return model.title || 'Item '+ index;
        }";
    }

    public function getRepeaterSchema(){
        $settingSchema = $this->getSetting('schema');
        $schemas = array("fields" => array());
        if($settingSchema){
            $schemaLines = explode("||", $settingSchema);
            if($schemaLines){
                foreach ($schemaLines as $schemaLine){
                    $schemaLine = explode("|", $schemaLine);
                    if($schemaLine[0] === "text"){
                        $schema = array(
                            "type" => "input",
                            "inputType" => "text",
                        );
                    }else{
                        $schema = array(
                            "type" => $schemaLine[0]
                        );
                    }
                    $schema["model"] = $schemaLine[1];
                    $schema["label"] = $schemaLine[2];

                    $schemas["fields"][] = $schema;
                }
            }
        }

        return json_encode($schemas);
    }

    public function save()
    {
        $postID = $this->postID;
        $value = (array)$this->sanitize();
        update_post_meta($postID, $this->settings->metakey, $value);
    }

    public function rawData(){
        return get_post_meta($this->postID, $this->settings->metakey, true);
    }

    public function data(){
        $value = $this->rawData();
         return $value ? array_filter(array_values($value)) : array();
    }

    public function model(){
        $data = $this->postID ? $this->data() : array();
        return "'{$this->settings->metakey}' : ".($data ? json_encode($data) : '[]');
    }

    public function outputValue(){

        $data = $this->data();
        $html = $data ? json_encode($data) : "";

        return $html;
    }
}