<?php
/**
 * @class 		GJ_Field_Resume
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Resume extends GJ_Field_Base {

    protected $type = 'resume';
    protected $name = 'Resume';

    public function getResumeOptions(){

        $options = array(array(
            'ID' => '',
            'title' => esc_html__('Select Resume', 'gj'),
        ));
        $user = GJ_User::get_user();
        if($user){
            $candidates = $user->get_candidates(array('publish'));
            if($candidates){
                foreach ($candidates as $candidate){
                    $option = array();
                    $option['ID'] = $candidate->ID;
                    $option['title'] = $candidate->post_title;
                    $option['date'] = get_the_date($candidate->ID);
                    $options[] = $option;
                }
            }
        }
        
        return $options;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            'type' : '{$this->type}',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : {},
            'screen' : ".(is_admin() ? '"admin"' : '"frontend"').",
            'options' : ".json_encode($this->getResumeOptions()).",
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function save()
    {
        $postID = $this->postID;
		$value = $this->sanitize();
		update_post_meta($postID, $this->settings->metakey, $value);
    }

    public function model(){
        $value = null;
        if($this->postID) {
            $value = $this->data();
        }

        if(is_admin()){
            $new_value = array();
            if($value){
                    $new_value['ID'] = $value;
                    $new_value['url'] = get_the_permalink($value);
                    $new_value['title'] = get_the_title($value);
                    $new_value['date'] = get_the_date($value);
            }              

            return "'{$this->settings->metakey}' : ".json_encode($new_value);
        }else{
            if(!$value){
                $user = GJ_User::get_user();
                if($user){
                    $candidate = $user->get_first_candidate();
                    if($candidate){
                        $value = $candidate->get_id();
                    }
                }
            }
            return "'{$this->settings->metakey}' : ".($value ? (int)$value : "''");
        }
        
    }

    public function outputValue(){
        $resume_id = $this->data();
        $html = "";

        if($resume_id){
            $candidate = GJ_Candidate::get_candidate($resume_id);
            if($candidate){
                $html = '<a href="'.esc_url($candidate->permalink()).'" target="_blank">'.esc_html__('View resume', 'gj').'</a>';
            }
        }

        return $html;
    }
}