<?php
/**
 * @class 		GJ_Field_SelectAdvanced
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_SelectAdvanced extends GJ_Field_Checklist {

    protected $type = 'selectAdvanced';
    protected $name = 'Select Advanced';

    public function enqueue(){
        wp_enqueue_script('vue-multiselect');
        wp_enqueue_style('vue-multiselect');
    }

    public function JSInputFields(){
        $tab = parent::JSInputFields();
        $fields = $tab['fields'];

        foreach($fields as $fieldkey=>$field){
            if($field['model'] === 'useKey'){
                break;
            }
        }

        $leftFields = array_splice($fields,0, $fieldkey+1);
        $newFields =  array(
            array(
                "type" => "checkbox",
                "label" => esc_html__( "Multiple", "gj" ),
                "model" => "multiple",
                "tab" => "Input"
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function defaultSettings(){
        $default = parent::defaultSettings();
        $default->useKey = false;
        $default->multiple = false;
        return $default;
    }

    public function selectSettings(){
        $selectOptions = new stdClass();
        $selectOptions->multiple = $this->settings->multiple;
        $selectOptions->searchable = false;
        $selectOptions->closeOnSelect = true;
        if($this->settings->useKey){
            $selectOptions->key = 'key';
            $selectOptions->label = 'val';
            $selectOptions->trackBy = 'key';
        }
        $selectOptions->allowEmpty = true;
        $selectOptions->taggable = false;
        $selectOptions->clearOnSelect = false;
        $selectOptions->selectLabel = '';
        $selectOptions->selectedLabel = '';
        $selectOptions->deselectLabel = '';
        $selectOptions->deselectGroupLabel = '';

        return $selectOptions;
    }

    public function selectOptions(){
        if($this->settings->useKey) {
            $values = (array)$this->getSetting('options');
        }else{
            $values = array_map(array($this, 'splitOption'), (array)$this->getSetting('options'));
            //array("Vue.js", "JavaScript", "Ruby", "Sinatra");
        }

        return $values;
    }

    public function splitOption($option){
        return $option->val;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            'type' : 'vueMultiSelect',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'selectOptions' : ".json_encode($this->selectSettings()).",
            'values' : ".json_encode($this->selectOptions()).",
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function sanitize(){
        if($this->settings->useKey === 'true'){
            if($this->settings->multiple){
                return array_unique(array_map(array($this, 'splitValue'), (array)$_POST[$this->settings->metakey]));
            }else{
                return sanitize_text_field($_POST[$this->settings->metakey]['key']);
            }
        }else{
            if($this->settings->multiple === 'true'){
                return array_map("sanitize_text_field", (array)$_POST[$this->settings->metakey]);
            }else{
                return sanitize_text_field($_POST[$this->settings->metakey]);
            }
        }
    }

    public function splitValue($val){
        return sanitize_text_field($val['key']);
    }

    public function data(){
        $data = parent::data();
        if($this->settings->multiple === 'true'){
            $data = (array)$data;
        }else{
            if(is_array($data)){
                $data = $data ? $data[0] : '';
            }
        }
        return $data;
    }

    public function model(){
        if(!$this->postID){
            $value = 'null';
        }else{
            $value = array_filter($this->selectOptions(), function($option){
				if(isset($option->key)):
					return in_array($option->key, (array)$this->data());
				else:
					return in_array($option, (array)$this->data());
				endif;
            });
            if($value){
                if($this->settings->multiple === 'true'){
                    $value = json_encode(array_values($value));
                }else{
                    $value = json_encode(array_values($value)[0]);
                }
            }else{
                $value = 'null';
            }
        }

        return "'{$this->settings->metakey}' : {$value}";
    }

    public function outputValue(){

        $values = $this->data();
        $html = "";
        if($values && $this->settings->useKey === 'true'){
            $values = (array)$values;
            $_values = array();
            foreach ($this->selectOptions() as $option){
                if(in_array($option->key, $values)){
                    $_values[] = $option->val;
                }
            }
            $html = implode(", ",$_values);
        }

        return $html;
    }
}