<?php
/**
 * @class 		GJ_Field_Social
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Social extends GJ_Field_Base {

    protected $type = 'social';
    protected $name = 'Social';

    public function JSSocialFields(){
        return array(
            'title' => esc_html__('Social', 'gj'),
            'id' => 'social',
            'fields' => array(
                array(
                    "type" => "array",
                    "label" => esc_html__( "Social", "gj" ),
                    "model" => "social",
                    "default" => array(),
                    "tab" => "Input",
                    "itemContainerComponent" => "Container",
                    "itemContainerHeader" => "beginJSFunction(model, schema, index){return model && model.label || 'Item '+ index;}endJSFunction",
                    "items" => array(
                        "type" => "object",
                        "default" => "beginJSFunction () { return [] }endJSFunction",
                        "schema" => array(
                            "fields" => array(
                                array(
                                    "type" => "input",
                                    "inputType" => "text",
                                    "label" => esc_html__( "SocialID", "gj" ),
                                    "model" => "id",
                                ),
                                array(
                                    "type" => "input",
                                    "inputType" => "text",
                                    "label" => esc_html__( "Label", "gj" ),
                                    "model" => "label",
                                ),
                                array(
                                    "type" => "input",
                                    "inputType" => "text",
                                    "label" => esc_html__( "Icon Class", "gj" ),
                                    "model" => "iconClass",
                                ),
                            )
                        ),
                    ),
                )
            )
        );
    }
    public function JSRegisterFields(){
        $fields = parent::JSRegisterFields();
        $fields[] = $this->JSSocialFields();

        return $fields;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            'type' : 'object',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : {},
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            schema : {
                fields : ".json_encode($this->getItemsSchemaFields())."
            },
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function getItemsSchemaFields(){
        $fields = array();
        $socials = $this->getSetting('social');
        if($socials){
            foreach ($socials as $social){
                $field = new stdClass();
                $field->type = 'input';
                $field->inputType = 'text';
                $field->label = $social->label;
                $field->model = $social->id;
                $fields[] = $field;
            }
        }

        return $fields;
    }

    public function sanitize(){
        return isset($_POST[$this->settings->metakey]) ? (array)gj_clean($_POST[$this->settings->metakey]) : null;
    }

    public function data(){
        $value = $this->rawData();
        if($value){
            return array_filter( (array)$value);
        }

        return array();
    }

    public function rawData(){
        return get_post_meta($this->postID, $this->settings->metakey, true);
    }

    public function model(){
        if(!$this->postID){
            $value = null;
        }else{
            $value = $this->data();
        }

        return "'{$this->settings->metakey}' : ".($value ? json_encode($value) : 'null');
    }

    public function outputValue(){
        $values = $this->data();
        $html = '';

        if( $values ) {

            $html .= '<ul class="gj-field-social">';

            foreach ( $this->settings->social as $social ) {

                if( !empty( $values[$social->id] ) ) {

                    $html .= '<li class="'. $social->id .'">';
                    $html .= '<a href="'. esc_url( $values[$social->id] ) .'" title="'. esc_attr( $social->label ) .'">';
                    $html .= '<i class="'. esc_attr( $social->iconClass ) .'"></i>';
                    $html .= '</a>';
                    $html .= '</li>';

                }

            }

            $html .= '</ul>';
        }

        return $html;
    }
}