<?php
/**
 * @class 		GJ_Field_Taxonomy
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Taxonomy extends GJ_Field_SelectAdvanced {

    protected $type = 'taxonomy';
    protected $name = 'Taxonomy';

    private function Taxonomies(){
        return array_keys(get_taxonomies());
    }

    public function JSInputFields(){
        $tab = parent::JSInputFields();
        $fields = $tab['fields'];

        $fieldkey = 2;

        foreach ($fields as $key => $field){
            if($field['model'] == 'useKey' || $field['model'] == 'options'){
                unset($fields[$key]);
            }

            if($field['model'] === 'showInput'){
                $fieldkey = $key;
            }
        }

        $leftFields = array_splice($fields,0, $fieldkey+1);
        $newFields =  array(
            array(
                "type" => "select",
                "label" => esc_html__( "Asynchronous select", "gj" ),
                "model" => "asynchronous",
                "default" => "",
                "tab" => "Input",
                "values" => array(
                    array("id" => "", "name" => esc_html__( "None", "gj" )),
                    array("id" => "once", "name" => esc_html__( "Once when focusing on it", "gj" ) ),
                    array("id" => "every", "name" => esc_html__( "Every time after searching", "gj" ) ),
                )
            ),
            array(
                "type" => "select",
                "label" => esc_html__( "Taxonomy", "gj" ),
                "model" => "taxonomy",
                "default" => "",
                "tab" => "Input",
                "values" => $this->Taxonomies()
            ),
            array(
                "type" => "select",
                "label" => esc_html__( "Order by", "gj" ),
                "model" => "orderby",
                "default" => "name",
                "tab" => "Input",
                "values" => array(
                    array("id" => "", "name" => esc_html__( "ID", "gj" ) ),
                    array("id" => "once", "name" => esc_html__( "Count", "gj" ) ),
                    array("id" => "name", "name" => esc_html__( "Name", "gj" ) ),
                )
            ),
            array(
                "type" => "select",
                "label" => esc_html__( "Order", "gj" ),
                "model" => "order",
                "default" => "ASC",
                "tab" => "Input",
                "values" => array(
                    array("id" => "ASC", "name" => esc_html__( "ASC", "gj" ) ),
                    array("id" => "DESC", "name" => esc_html__( "DESC", "gj" ) ),
                )
            ),
        );

        $tab['fields'] = array_merge($leftFields, $newFields, $fields);

        return $tab;
    }

    public function JSFilterFields(){
        return array(
            'title' => esc_html__('Filter', 'gj'),
            'id' => 'filter',
            'fields' => array(
                array(
                    "type" => "checkbox",
                    "label" => esc_html__( "Filter output", "gj" ),
                    "model" => "filterOutput",
                    "default" => true,
                    "tab" => "Filter"
                ),
                array(
                    "type" => "checkbox",
                    "label" => esc_html__( "Multiple filter", "gj" ),
                    "model" => "multipleFilter",
                    "default" => true,
                    "tab" => "Filter"
                ),
                array(
                    "type" => "checkbox",
                    "label" => esc_html__( "Default expand", "gj" ),
                    "model" => "defaultExpand",
                    "default" => true,
                    "tab" => "Filter"
                ),
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Show maximum items", "gj" ),
                    "hin" => "leave blank to show all items",
                    "model" => "maxShow",
                    "default" => "",
                    "tab" => "Filter"
                ),
                array(
                    "type" => "select",
                    "label" => esc_html__( "Order by", "gj" ),
                    "model" => "filterOrderby",
                    "default" => "name",
                    "tab" => "Filter",
                    "values" => array(
                        array("id" => "", "name" => esc_html__( "ID", "gj" ) ),
                        array("id" => "once", "name" => esc_html__( "Count", "gj" ) ),
                        array("id" => "name", "name" => esc_html__( "Name", "gj" ) ),
                    )
                ),
                array(
                    "type" => "select",
                    "label" => esc_html__( "Order", "gj" ),
                    "model" => "filterOrder",
                    "default" => "ASC",
                    "tab" => "Filter",
                    "values" => array(
                        array("id" => "ASC", "name" => esc_html__( "ASC", "gj" ) ),
                        array("id" => "DESC", "name" => esc_html__( "DESC", "gj" ) ),
                    )
                ),
                array(
                    "type" => "select",
                    "label" => esc_html__( "Layout", "gj" ),
                    "model" => "filterLayout",
                    "default" => "ASC",
                    "tab" => "Filter",
                    "values" => array(
                        array("id" => "dropdown", "name" => esc_html__( "Dropdown", "gj" ) ),
                        array("id" => "list", "name" => esc_html__( "List", "gj" ) ),
                    )
                ),
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Label", "gj" ),
                    "model" => "filterLabel",
                    "default" => "",
                    "tab" => "Filter"
                ),
                array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Ordering", "gj" ),
                    "model" => "filterOrdering",
                    "default" => "",
                    "tab" => "Filter"
                ),
            )
        );
    }
    public function JSRegisterFields(){
        $fields = parent::JSRegisterFields();
        $fields[] = $this->JSFilterFields();
        return $fields;
    }

    public function defaultSettings(){
        $default = parent::defaultSettings();
        $default->taggable = 'false';
        $default->multiple = 'false';
        $default->asynchronous = '';
        $default->taxonomy = '';
        $default->orderby = 'name';
        $default->order = 'ASC';
        return $default;
    }

    public function splitOption($option){
        return $option->val;
    }

    public function getTerms($hideEmpty = null, $orderby = null, $order = null, $number = 0, $slug = ''){
        if(!$this->getSetting('taxonomy')){
            return array();
        }

        if(!$hideEmpty) $hideEmpty = false;
        if(!$orderby) $orderby = $this->getSetting('orderby');
        if(!$order) $order = $this->getSetting('order');

        $args = array(
            'hide_empty' => $hideEmpty,
            'taxonomy'  => $this->getSetting('taxonomy'),
            'orderby'  => $orderby,
            'order'  => $order,
            'number'  => $number,
            'slug' => $slug
        );

        if($this->getSetting('taxonomy') == 'gj_city'){
            $state_slug = gj_get_taxonomy_slug('gj_state');
            if(isset($_REQUEST[$state_slug]) && $_REQUEST[$state_slug]){
                $state = get_term_by('slug', $_REQUEST[$state_slug], 'gj_state');
                if($state){
                    $args['meta_query'] = array(
                        array(
                            'key'       => 'state',
                            'value'     => (int)$state->term_id,
                            'compare'   => '='
                        )
                    );
                }    
            }
        }
        
        $terms = get_terms( $args );

        return $terms;
    }

    public function totalTerms($hideEmpty = null){

        if(!$this->getSetting('taxonomy')){
            return 0;
        }

        if(!$hideEmpty) $hideEmpty = false;

        $args = array(
            'hide_empty' => $hideEmpty,
        );

        if($this->getSetting('taxonomy') == 'gj_city'){
            $state_slug = gj_get_taxonomy_slug('gj_state');
            if(isset($_REQUEST[$state_slug]) && $_REQUEST[$state_slug]){
                $state = get_term_by('slug', $_REQUEST[$state_slug], 'gj_state');
                if($state){
                    $args['meta_query'] = array(
                        array(
                            'key'       => 'state',
                            'value'     => (int)$state->term_id,
                            'compare'   => '='
                        )
                    );
                }    
            }
        }

        return wp_count_terms( $this->getSetting('taxonomy'), $args );
    }

    public function input(){
        if(!$this->settings->taxonomy){
            return null;
        }

        $_terms = $this->getTerms();
        $terms = array();
        if($_terms && !is_wp_error($_terms)){
            foreach ($_terms as $term){
                $terms[] = array(
                    'term_id' => $term->term_id,
                    'name' => wp_specialchars_decode($term->name),
                );
            }
        }

        $values = !$this->settings->asynchronous ? json_encode($terms) : "[]";

        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');
        
        return "{
            'type' : 'taxonomy',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'placeholder' : '".($this->settings->asynchronous ? $this->clearn_text(esc_html__('Type to search', 'gj')) : $this->clearn_text(esc_html__('Select option', 'gj')))."',
            'taxonomy' : '{$this->clearn_text($this->settings->taxonomy)}',
            'asynchronous' : '{$this->clearn_text($this->settings->asynchronous)}',
            'orderby' : '{$this->clearn_text($this->settings->orderby)}',
            'order' : '{$this->clearn_text($this->settings->order)}',
            'values' : {$values},
            'selectOptions' : {
                multiple : {$this->settings->multiple},
                taggable : {$this->settings->taggable},
            },
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function sanitize(){
        if($this->settings->multiple === 'true'){
            $rawvalues = isset($_POST[$this->settings->metakey]) ? (array)gj_clean($_POST[$this->settings->metakey]) : array();
            if($rawvalues && $this->taggable === 'true'){
                $restrict = gj_restrict_bad_terms();
                foreach ($rawvalues as $key=>$value){
                    if(isset($value['is_new']) && $value['is_new'] && $value['name'] && !in_array($value['name'], $restrict)){
                        $newTerm = wp_insert_term($value['name'], $this->settings->taxonomy);
                        if(!is_wp_error($newTerm)){
                            $rawvalues[$key]['term_id'] = $newTerm['term_id'];
                        }
                    }
                }
            }

            $value = array_values(array_unique(array_map(function($value){return intval($value['term_id']); }, $rawvalues)));
        }else{
            $value = isset($_POST[$this->settings->metakey]['term_id']) ? intval($_POST[$this->settings->metakey]['term_id']) : null;
        }

        return $value ? $value : null;
    }

    public function save()
    {
        $postID = $this->postID;
        $value = $this->sanitize();
        wp_set_object_terms( $postID, $value, $this->settings->taxonomy );
    }

    public function rawData(){
        $data = get_the_terms($this->postID, $this->settings->taxonomy);
        
        if($data && !is_wp_error($data)){
            return $data;
        }

        return null;
    }

    public function data(){
        return $this->rawData();
    }

    public function model(){
        if(!$this->settings->taxonomy){
            return null;
        }

        $value = null;

        if(!$this->postID){
            $model = $this->settings->multiple === 'true' ? '[]' : '';
        }else{
            $value = $this->data();
            if($value){
                if($this->settings->multiple === 'false'){
                    $model = is_array($value) ? $value[0]: $value;
                    $model->name = wp_specialchars_decode($model->name);
                }else{
                    $model = $value;
                    $model = array_map(function($term){
                        $term->name = wp_specialchars_decode($term->name);
                        return $term;
                    }, $model);
                }
            }else{
                $model = $this->settings->multiple === 'true' ? "[]" : "";
            }
        }

        return "'{$this->settings->metakey}' : ".($value ? json_encode($model) : ($this->settings->multiple === 'true' ? $model : "'{$model}'"));
    }

    public function outputValue(){
        $values = $this->data();
        $html = "";
        if($values && $this->settings->multiple === 'true'){
            $_values = array();
            foreach ($values as $term){

                if ( $term->taxonomy != 'gj_size' ) {
                    $_values[] = "<a href='".get_term_link($term->term_id)."'>".$term->name."</a>";
                }else {
                    $_values[] = $term->name;
                }

            }
            $html = implode(" ", $_values);
        }elseif($values){
            $value = is_array($values) ? $values[0] : $values;
            $color_type = '';

            if ( $value->taxonomy != 'gj_size' ) {
                if ($value->taxonomy == 'gj_type') {
                    $color_type =   get_term_meta( $value->term_taxonomy_id, GJ_PREFIX.'color', true );
                }
                if ($color_type != '') {
                    $html = $value ? "<a style='color: ".$color_type."' href='".get_term_link($value->term_id)."'>".$value->name."</a>" : null;
                } else {
                    $html = $value ? "<a href='".get_term_link($value->term_id)."'>".$value->name."</a>" : null;
                }
            } else {
                $html = $value->name;
            }

        }

        return $html;
    }

    public function filterOutputHtml($type){
        $html = apply_filters('gj_field_before_filter_output_html', null, $this, $type);
        if($html !== null){
            echo $html;
        }else{
            if($this->getSetting('filterOutput') === 'true'){
                $terms = $this->getTerms(
                    $this->getSetting('hideEmpty'),
                    $this->getSetting('filterOrderby'),
                    $this->getSetting('filterOrder'),
                    $this->getSetting('maxShow')
                );

                $totalTerms = $this->totalTerms($this->getSetting('hideEmpty'));
                $max_items_visible = apply_filters('gj_widget_filter_max_items_visible', 10);
                $multipleFilter = $this->getSetting('multipleFilter') === 'true' ? true : false;
                if($this->getSetting('taxonomy') == 'gj_state' || $this->getSetting('taxonomy') == 'gj_city'){
                    $multipleFilter = false;
                }
                $inputName = gj_get_taxonomy_slug($this->getSetting('taxonomy')) . ($multipleFilter ? '[]' :  '');
                $label = $this->getSetting('filterLabel') ? $this->getSetting('filterLabel') : $this->getSetting('name');
                $taxonomy = $this->getSetting('taxonomy');

                if($terms){
                    switch ($type){
                        case 'gj_candidate':
                            $filters = GJ_Candidate_Listing::instance()->get_data_filters();
                            break;
                        case 'gj_employer':
                            $filters = GJ_Employer_Listing::instance()->get_data_filters();
                            break;
                        default:
                            $filters = GJ_Job_Listing::instance()->get_data_filters();
                            break;
                    }

                    $term_ids = wp_list_pluck($terms, 'term_id');
                    $counts = gj_count_item_by_taxonomy($filters, $term_ids);
                    gj_map_terms_with_counter($terms, $counts);

                    $actived_ids = array();
                    $display_actived_ids = array();
                    if(isset($filters[$taxonomy]) && $filters[$taxonomy]){
                        $actived_ids = $filters[$taxonomy];
                    }
                }

                $inputType = $multipleFilter ? 'checkbox' :  'radio';
                $defaultExpand = $this->getSetting('defaultExpand') === 'true' ? true : false;
                $style_collapse = $defaultExpand ? 'block' :  'none';
                $aside_class = array();
                if ($defaultExpand) {
                    $aside_class[] = 'no-compress';
                } else {
                    $aside_class[] = 'compress';
                }
                if ($max_items_visible && ($max_items_visible < count($terms))) {
                    $aside_class[] = 'gj-aside-widget-scroll';
                    $style = 'style="max-height: '.(($max_items_visible * 26) - 10).'px; overflow: hidden;"';
                } else {
                    $style = 'style="max-height: none"';
                }

                ob_start();
                ?>
                <aside class="widget gj-widget-collapse sidebar-jobs-item sidebar-<?php echo esc_attr($this->getSetting('taxonomy')); ?> <?php echo esc_attr(implode(' ', $aside_class)); ?>" <?php echo !$terms ? 'style="display: none;"' : '';?>>
                    <h3 class="widget-title gj-widget-title-collapse"><span><?php echo esc_html($label); ?></span></h3>
                    <div class="sidebar-job-1 gj-widget-content-collapse" style="display: <?php echo esc_attr($style_collapse); ?>;">
                        <div class="gj-widget-scroll" <?php echo ($style); ?>>
                            <form name="<?php echo esc_attr($this->getSetting('taxonomy')); ?>"
                                  class="gj-form-filter"
                                  id="form-<?php echo esc_attr($this->getSetting('taxonomy')); ?>"
                                  data-orderby="<?php echo esc_attr($this->getSetting('filterOrderby')); ?>"
                                  data-order="<?php echo esc_attr($this->getSetting('filterOrder')); ?>"
                                  data-hide-empty="<?php echo esc_attr($this->getSetting('hideEmpty')); ?>"
                                  data-number="<?php echo esc_attr($this->getSetting('maxShow')); ?>"
                                  data-taxonomy="<?php echo esc_attr($taxonomy); ?>"
                                  data-input-type="<?php echo esc_attr($inputType); ?>"
                                  data-input-name="<?php echo esc_attr($inputName); ?>"
                                  data-more-text="<?php echo esc_attr__('More', 'gj'); ?>"
                            >
                                <?php if( $this->getSetting('filterLayout') === 'dropdown' ) : ?>

                                    <button class="btn dropdown-toggle" type="button" data-toggle="dropdown">
                                        <span class="name-tax" data-none-text="<?php echo esc_html__('All ', 'gj').$label; ?>">
                                           <?php
                                           if ( !empty( $actived_ids ) ) :
                                               $i = 1;
                                               foreach ( $actived_ids as $item ) :
                                                   $term = get_term_by('slug', $item, $taxonomy );

                                                   if ( $i > 1 && $i <= count( $actived_ids ) ):
                                                       echo wp_kses_post( '&sbquo;&nbsp;' );
                                                   endif;

                                                   echo esc_html( $term->name );

                                                   $i++;
                                               endforeach;

                                           else:
                                               echo esc_html__('All ', 'gj') . $label;
                                           endif;

                                           ?>
                                        </span>

                                        <i class="fa fa-angle-down" aria-hidden="true"></i>
                                    </button>

                                <?php endif;?>

                                <ul class="gj-list-<?php echo esc_attr($this->getSetting('taxonomy')) . esc_attr( $this->getSetting('filterLayout') === 'dropdown' ? ' dropdown-menu' : '' ); ?>">
                                    <?php
                                    if($terms){
                                        foreach ($terms as $term) :
                                            $id = 'gj-filter-cbx-'.$term->term_id;
                                            $checked = in_array($term->slug, $actived_ids);
                                            if($checked){
                                                $display_actived_ids[] = $term->slug;
                                            }
                                            ?>
                                            <li class="gj-input-<?php echo esc_attr(esc_attr($inputType)); ?> <?php echo esc_attr($id.' '.$this->getSetting('taxonomy')); ?> <?php echo ($checked == true) ? 'checked' : '';?>" >
                                                <div class="filter-name-item">
                                                    <input type="<?php echo esc_attr($inputType); ?>"
                                                        <?php echo ($checked == true) ? 'checked="checked"' : ''; ?>
                                                           name="<?php echo esc_attr($inputName); ?>"
                                                           id="<?php echo esc_attr($id); ?>"
                                                           class="gj-filter-cbx"
                                                           value="<?php echo esc_attr($term->slug); ?>"
                                                           data-id="<?php echo esc_attr($term->term_id); ?>"
                                                    >
                                                    <label for="<?php echo esc_attr($id); ?>"><?php echo esc_html($term->name); ?></label>
                                                </div>
                                                <span id="gj-count-<?php echo esc_attr($term->term_id); ?>" class="gj-count"><?php echo esc_attr($term->count); ?></span>
                                            </li>
                                        <?php endforeach; ?>

                                        <?php if ($terms && count($terms) < $totalTerms) : ?>
                                            <li class="gj-more-filter-btn <?php echo esc_attr($inputType); ?>">
                                                <button type="button" class="theme-color-hover"><?php echo esc_html__('Show More', 'gj'); ?></button>
                                            </li>
                                        <?php endif; ?>

                                        <?php
                                        $undisplay_actived_ids = array_diff($actived_ids, $display_actived_ids);
                                        if($undisplay_actived_ids){
                                            $undisplay_terms = $this->getTerms(
                                                $this->getSetting('hideEmpty'),
                                                $this->getSetting('filterOrderby'),
                                                $this->getSetting('filterOrder'),
                                                $this->getSetting('maxShow'),
                                                $undisplay_actived_ids
                                            );

                                            foreach ($undisplay_terms as $term){
                                                $id = 'gj-filter-cbx-'.$term->term_id;
                                                ?>
                                                <li
                                                        class="theme-color-hover gj-input-<?php echo esc_attr($inputType); ?> <?php echo esc_attr($id.' '.$this->getSetting('taxonomy')); ?> checked"
                                                        style="display: none">
                                                    <div class="filter-name-item">
                                                        <input type="<?php echo esc_attr($inputType); ?>"
                                                               checked="checked"
                                                               name="<?php echo esc_attr($inputName); ?>"
                                                               id="<?php echo esc_attr($id); ?>"
                                                               class="gj-filter-cbx"
                                                               value="<?php echo esc_attr($term->slug); ?>"
                                                        >
                                                    </div>
                                                </li>
                                                <?php
                                            }
                                        }
                                    }
                                    ?>
                                </ul>
                            </form>
                        </div>
                    </div>
                </aside>
                <?php
                $html = ob_get_contents();
                ob_end_clean();
            }

            echo apply_filters('gj_field_filter_output_html', $html, $this, $type);
        }
    }

    public function filteredOutputHtml($type){
        $html = apply_filters('gj_field_before_filtered_output_html', null, $this, $type);
        if($html !== null){
            echo $html;
        }else{
            if($this->getSetting('filterOutput') === 'true'){
                $actived_terms = array();
                $taxonomy = $this->getSetting('taxonomy');

                switch ($type){
                    case 'gj_candidate':
                        $filters = GJ_Candidate_Listing::instance()->get_data_filters();
                        break;
                    case 'gj_employer':
                        $filters = GJ_Employer_Listing::instance()->get_data_filters();
                        break;
                    default:
                        $filters = GJ_Job_Listing::instance()->get_data_filters();
                        break;
                }

                if(isset($filters[$taxonomy]) && $filters[$taxonomy]){
                    $actived_terms = get_terms( array(
                        'taxonomy' => $taxonomy,
                        'slug' => $filters[$taxonomy],
                        'hide_empty' => $this->getSetting('hideEmpty') === 'true' ? true : false
                    ));
                }

                if($actived_terms){
                    foreach ($actived_terms as $term){
                        $html .= '<li id="gj-filter-selected-item-'.esc_attr($term->term_id).'"
                            data-value="'.esc_attr($term->term_id).'"
                            class="gj-filter-selected-item">
                            <label>'.esc_html($term->name).'</label>
                            <a href="#" class="remove"><i class="lnr lnr-cross-circle"></i></a>
                        </li>';
                    }
                }
            }

            echo apply_filters('gj_field_filtered_output_html', $html, $this, $type);
        }
    }

    public function searchOutputHtml($type)
    {
        if($this->isActive() && $this->getSetting('searchOutput')) {
            switch ($type) {
                case 'gj_candidate':
                    $filters = GJ_Candidate_Listing::instance()->get_data_filters();
                    break;
                case 'gj_employer':
                    $filters = GJ_Employer_Listing::instance()->get_data_filters();
                    break;
                default:
                    $filters = GJ_Job_Listing::instance()->get_data_filters();
                    break;
            }

            $actived_ids = array();
            if (isset($filters[$this->getSetting('taxonomy')]) && $filters[$this->getSetting('taxonomy')]) {
                $actived_ids = $filters[$this->getSetting('taxonomy')];
            }

            $placeholder = $this->getSetting('searchPlaceholder') ? $this->getSetting('searchPlaceholder') : sprintf(__('Choose %s', 'gj'), $this->getSetting('name'));
            $inputName = gj_get_taxonomy_slug($this->getSetting('taxonomy'));
            ?>
            <div class="col-md-<?php echo $this->getSetting('searchColumWidth'); ?> filter-item">
                <select class="default-sorting gj-select-2 form-control" name="<?php echo $inputName; ?>" data-options="<?php echo esc_attr( wp_json_encode(array('minimumResultsForSearch' => 'Infinity'))); ?>">
                    <option value="" selected="selected"><?php echo $placeholder ?></option>
                    <?php
                    $terms = $this->getTerms(
                        $this->getSetting('hideEmpty'),
                        $this->getSetting('searchOrderby'),
                        $this->getSetting('searchOrder')
                    );
                    foreach ($terms as $term) {
                        echo '<option value="' . esc_attr($term->slug) . '" ' . (in_array($term->slug, $actived_ids) ? 'selected' : ''). '>' . esc_html($term->name) . '</option>';
                    } ?>
                </select>
            </div>
            <?php
        }
    }
}