<?php
/**
 * @class 		GJ_Field_Text
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_Text extends GJ_Field_Base {

    protected $type = 'text';
    protected $inputType = 'text';
    protected $name = 'Text';

    public $defaultFieldConfig = true;
    public $validationFieldConfig = true;

    public function JSInputFields(){

        $tab = parent::JSInputFields();

        if($this->defaultFieldConfig || $this->validationFieldConfig){
            $fields = $tab['fields'];
            $fieldkey = 2;
            foreach ($fields as $key => $field){
                if($field['model'] == 'useKey' || $field['model'] == 'options'){
                    unset($fields[$key]);
                }

                if($field['model'] === 'showInput'){
                    $fieldkey = $key;
                }
            }
            $leftFields = array_splice($fields,0, $fieldkey+1);

            $newFields = array();

            if($this->validationFieldConfig){
                $newFields[] = array(
                    "type" => "select",
                    "label" => esc_html__( "Validation", "gj" ),
                    "model" => "validation",
                    "default" => "",
                    "tab" => "Input",
                    "values" => array(
                        array("id" => "", "name" => esc_html__( "None", "gj" ) ),
                        array("id" => "number", "name" => esc_html__( "Number", "gj" ) ),
                        array("id" => "integer", "name" => esc_html__( "Integer", "gj" ) ),
                        array("id" => "double", "name" => esc_html__( "Double", "gj" ) ),
                        array("id" => "string", "name" => esc_html__( "String", "gj" ) ),
                        array("id" => "email", "name" => esc_html__( "Email", "gj" ) ),
                        array("id" => "url", "name" => esc_html__( "Url", "gj" ) ),
                        array("id" => "creditCard", "name" => esc_html__( "creditCard", "gj" ) ),
                        array("id" => "alpha", "name" => esc_html__( "Alpha", "gj" ) ),
                        array("id" => "alphaNumeric", "name" => esc_html__( "alphaNumeric", "gj" ) ),
                        array("id" => "regexp", "name" => esc_html__( "regexp", "gj" ) ),
                    )
                );
                $newFields[] = array(
                    "type" => "input",
                    "inputType" => "text",
                    "label" => esc_html__( "Regexp", "gj" ),
                    "model" => "regexp",
                    "default" => "",
                    "visible" => "beginJSFunction(model) { return model && model.validation == 'regexp';}endJSFunction",
                    "tab" => "Input"
                );
            }

            $tab['fields'] = array_merge($leftFields, $newFields, $fields);
        }

        return $tab;
    }

    public function get_prefix(){
        $prefix = $this->getSetting('prefix');
        return $prefix;
    }

    public function get_subfix(){
        $subfix = $this->getSetting('subfix');
        return $subfix;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        $prefix = $this->get_prefix();
        $subfix = $this->get_subfix();
        return "{
            'type' : 'input',
            'inputType' : '{$this->inputType}',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'validator' : '".$this->clearn_text($this->settings->validation)."',
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
            ".($prefix ? "prefix : '{$this->clearn_text($prefix)}'," : "")."
            ".($subfix ? "subfix : '{$this->clearn_text($subfix)}'," : "")."
        }";
    }

    public function searchOutputHtml($type)
    {
        if($this->isActive() && $this->getSetting('searchOutput')) {
            ?>
            <div class="col-md-<?php echo $this->getSetting('searchColumWidth'); ?> filter-item">
                <input type="text" name="<?php echo $this->getSetting('metakey'); ?>"
                       placeholder="<?php echo $this->getSetting('searchPlaceholder'); ?>">
            </div>
            <?php
        }
    }

}