<?php
/**
 * @class 		GJ_Field_User
 * @package		GJ/Field/Classes
 * @author 		InwaveThemes
 */

class GJ_Field_User extends GJ_Field_SelectAdvanced {

    protected $type = 'user';
    protected $name = 'User';

    public function JSInputFields()
    {
        $tab = parent::JSInputFields();
        $fields = $tab['fields'];
        foreach ($fields as $key => $field) {
            if ($field['model'] == 'useKey' || $field['model'] == 'options') {
                unset($fields[$key]);
            }
        }

        $tab['fields'] = $fields;

        return $tab;
    }

    public function defaultSettings(){
        $default = parent::defaultSettings();
        $default->searchable = false;
        $default->asynchronous = false;
        $default->user = '';
        return $default;
    }

    public function splitOption($option){
        return $option->val;
    }

    public function input(){
        $class = $this->getSetting('inputClass');
        $width = $this->getSetting('inputWith');
        $help = $this->getSetting('help');
        $hint = $this->getSetting('hint');

        return "{
            'type' : 'user',
            'label' : ".($this->settings->showlabel === 'true' ? "'{$this->clearn_text($this->settings->name)}'" : 'null').",
            'model' : '{$this->settings->metakey}',
            'default' : '{$this->clearn_text($this->settings->default)}',
            'required' : ".($this->settings->required === 'true' ? 'true' : 'false').",
            'asynchronous' : 'every',
            'placeholder' : '".$this->clearn_text(esc_html__("Type to search", "gj"))."',
            'values' : [],
            'selectOptions' : {
                multiple : ".($this->getSetting('multiple') === 'true' ? 'true' : 'false').",
                noOptions : '".$this->clearn_text(esc_html__('No List Found','gj'))."',
                fetchingOptions : '".$this->clearn_text(esc_html__('Fetching data...', 'gj'))."',
            },
            ".($class ? "styleClasses : '{$this->clearn_text($class)}'," : "")."
            ".($width ? "styleWidth : {$this->clearn_text($width)}," : "")."
            ".($help ? "help : '{$this->clearn_text($help)}'," : "")."
            ".($hint ? "hint : '{$this->clearn_text($hint)}'," : "")."
        }";
    }

    public function save()
    {
        $postID = $this->postID;
        $value = $this->sanitize();
        update_post_meta($postID, $this->settings->metakey, $value);
    }

    public function outputValue(){
        $html = "";
        $postID = $this->postID;
        if($this->getSetting('corefield') === 'post_author' && get_post_type($postID) === 'gj_job'){
            $job = GJ_Job::get_job($postID);
            $employer = $job->get_employer();
            if($employer && $employer->is_active()){
                $html = $employer->get_title();
            }else{
                $author = $job->get_author();
                $html = $author->get_display_name();
            }
        }else{
            $value = $this->data();
            if($value){
                $user_info = get_userdata($value);
                $html = $user_info ? $user_info->display_name : null;
            }
        }

        return $html;
    }
}