<?php
/**
 * @class 		GJ_Install
 * @package		GJ/Install
 * @author 		InwaveThemes
 */

class GJ_Install{
    static function install($networkwide = null){
        global $wpdb;

        $upload_dir = wp_upload_dir();
        $dir = $upload_dir['basedir'] . '/cv/';
        if (!is_dir($dir)) {
            mkdir($dir);
            WP_Filesystem();
            global $wp_filesystem;
            $file_path = $dir.'index.html';
            $wp_filesystem->put_contents($file_path, '<html></html>');
        }

        if (is_multisite() && $networkwide) {
                $old_blog =  $wpdb->blogid;
                //Get all blog ids
                $blogids =  $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
                foreach ( $blogids as $blog_id ) {
                    switch_to_blog($blog_id);
                    //Create database table if not exists
                    self::create_tables();
                    self::create_options();
                    self::create_fields();

                }
                switch_to_blog( $old_blog );
        }else{
            self::create_tables();
            self::create_options();
            self::create_fields();
        }

        self::create_roles();
        self::create_cron_jobs();

        update_option('gj_version', GJ()->version);

        GJ_Post_Types::register_post_types();

        // Flush rules after install
        flush_rewrite_rules();

        do_action( 'gj_installed' );
    }

    static function new_blog( $blog_id, $user_id, $domain, $path, $site_id, $meta ){
        if ( is_plugin_active_for_network( 'grand-job/gj.php' ) ) {
            switch_to_blog( $blog_id );
            self::create_tables();
            self::create_options();
            self::create_roles();
            self::create_cron_jobs();
            GJ_Post_Types::register_post_types();
            flush_rewrite_rules();

        restore_current_blog();
        }
    }

    static function create_tables(){
        global $wpdb;

        //Create Tables
        require_once(ABSPATH . '/wp-admin/includes/upgrade.php');

        $collate = '';

        if ( $wpdb->has_cap( 'collation' ) ) {
            $collate = $wpdb->get_charset_collate();
        }

        $sql = "CREATE TABLE IF NOT EXISTS  {$wpdb->prefix}gj_save_resums (
                  `ID` int(11) NOT NULL AUTO_INCREMENT,
                  `post_id` int(11) NOT NULL,
                  `user_id` int(11) NOT NULL,
                  PRIMARY KEY (`ID`),
                  KEY `Post ID` (`post_id`),
                  KEY `User ID` (`user_id`)
                ) $collate;";
        dbDelta($sql);

        $sql = "CREATE TABLE IF NOT EXISTS  {$wpdb->prefix}gj_save_jobs (
                  `ID` int(11) NOT NULL AUTO_INCREMENT,
                  `post_id` int(11) NOT NULL,
                  `user_id` int(11) NOT NULL,
                  PRIMARY KEY (`ID`),
                  KEY `Post ID` (`post_id`),
                  KEY `User ID` (`user_id`)
                ) $collate;";
        dbDelta($sql);

        $sql = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}gj_follows (
                  `ID` int(11) NOT NULL AUTO_INCREMENT,
                  `post_id` int(11) NOT NULL,
                  `user_id` int(11) NOT NULL,
                  PRIMARY KEY (`ID`),
                  KEY `Post ID` (`post_id`),
                  KEY `User ID` (`user_id`)
                ) $collate;";
        dbDelta($sql);

        $sql = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}gj_email_queue (
                  `ID` int(11) NOT NULL AUTO_INCREMENT,
                  `send_time` int(11) NOT NULL,
                  `priority` tinyint(3) NOT NULL,
                  `attemp` tinyint(3) NOT NULL,
                  `from_name` varchar(255) NOT NULL,
                  `from_address` varchar(255) NOT NULL,
                  `recipients` varchar(255) NOT NULL,
                  `subject` varchar(255) NOT NULL,
                  `content` text NOT NULL,
                  PRIMARY KEY (`ID`)
                ) $collate;";
        dbDelta($sql);
    }

    static function create_roles(){
        add_role( 'gj_employer', esc_html__('Employer', 'gj'),
            array(
                'read' => true,
                'level_1' => true,
                'upload_files' =>true,
                'edit_attachments' =>true,
                'delete_attachments' =>true,

                'edit_jobs' => true,
                'edit_published_jobs' => true,
                'delete_jobs' => true,
                'delete_published_jobs' => true,
                'create_jobs' => true,

                'edit_employers' => true,
                'edit_published_employers' => true,
                'delete_employers' => true,
                'delete_published_employers' => true,
                'create_employers' => true,

                'edit_posts' => true,
                'edit_posts_jobs' => true,
                'delete_posts' => true,
                'delete_published_posts' => true,
                'create_posts' => true,
            )
        );

        add_role( 'gj_candidate', esc_html__('Candidate', 'gj'),
            array(
                'read' => true,
                'level_1' => true,
                'upload_files' =>true,
                'edit_attachments' =>true,
                'delete_attachments' =>true,
                'apply_job' =>true,

                'edit_candidates' => true,
                'edit_published_candidates' => true,
                'delete_gj_candiates' => true,
                'delete_published_candidates' => true,
                'create_candidates' => true,

                'edit_posts' => true,
                'edit_posts_jobs' => true,
                'delete_posts' => true,
                'delete_published_posts' => true,
                'create_posts' => true,
            )
        );

        $roles = array( 'administrator');
        foreach ( $roles as $roleName ) {
            // Get role
            $role = get_role( $roleName );

            // Check role exists
            if ( is_null( $role) ) {
                continue;
            }

            $customCaps = array('privilege_view_resum');
            // Iterate through our custom capabilities, adding them
            // to this role if they are enabled
            foreach ( $customCaps as $capability ) {
                // Add capability
                $role->add_cap( $capability );
            }

            $job_caps = array(
                'create_jobs',
                'delete_jobs',
                'delete_private_jobs',
                'delete_published_jobs',
                'delete_others_jobs',
                'edit_jobs',
                'edit_others_jobs',
                'edit_published_jobs',
                'edit_private_jobs',
                '',
                'publish_jobs',

                'create_employers',
                'delete_employers',
                'delete_private_employers',
                'delete_published_employers',
                'delete_others_employers',
                'edit_employers',
                'edit_others_employers',
                'edit_published_employers',
                'edit_private_employers',
                'manage_employers',
                'publish_employers',

                'create_candidates',
                'delete_candidates',
                'delete_private_candidates',
                'delete_published_candidates',
                'delete_others_candidates',
                'edit_candidates',
                'edit_others_candidates',
                'edit_published_candidates',
                'edit_private_candidates',
                'manage_candidates',
                'publish_candidates'
            );

            foreach ( $job_caps as $capability ) {
                // Add capability
                $role->add_cap( $capability );
            }
        }
    }

    static function export_options(){
        WP_Filesystem();

        global $wp_filesystem;
        $file_path = GJ_PLUGIN_DIR.'/includes/admin/pre-data/settings.text';
        $settings = gj_option();
        foreach ($settings as $key => $value) {
            if(strpos($key, 'page_id') !== false){
                $settings[$key] = '';
            }
        }
        $wp_filesystem->put_contents($file_path, json_encode($settings));
    }

    static function create_options($force = false){
        if(!get_option('gj_settings')){
            WP_Filesystem();
            global $wp_filesystem;
            $file_path = GJ_PLUGIN_DIR.'/includes/admin/pre-data/settings.text';
            $content = $wp_filesystem->get_contents($file_path);
            $settings = json_decode($content,true);

            update_option('gj_settings',  $settings);
        }
    }

    static function export_fields(){
        $groups = get_posts(array(
            'post_type' => 'gj_field_groups',
            'posts_per_page' => -1,
            'post_status' => 'publish'
        ));

        $ignored_fields = array('filter', 'pinged', 'to_ping', 'ping_status', 'guid');

        foreach ($groups as $group){
            foreach ($ignored_fields as $ignored){
                if(isset($group->{$ignored})){
                    unset($group->{$ignored});
                }
            }
            $group->metadata = get_post_meta($group->ID);
            $fields = get_posts(array(
                'post_type' => 'gj_fields',
                'post_parent' => $group->ID,
                'posts_per_page' => -1,
                'post_status' => 'publish'
            ));
            foreach ($fields as $field){
                foreach ($ignored_fields as $ignored){
                    if(isset($field->{$ignored})){
                        unset($field->{$ignored});
                    }
                }
                $field->metadata = get_post_meta($field->ID);
            }
            $group->fields = $fields;
        }

        $group = new stdClass();
        $group->ID = '';

        $fields = get_posts(array(
            'post_type' => 'gj_fields',
            'post_parent' => 0,
            'posts_per_page' => -1,
            'post_status' => 'publish'
        ));

        foreach ($fields as $field){
            foreach ($ignored_fields as $ignored){
                if(isset($field->{$ignored})){
                    unset($field->{$ignored});
                }
            }
            $field->metadata = get_post_meta($field->ID);
        }

        $group->fields = $fields;
        $groups[] = $group;

        WP_Filesystem();

        global $wp_filesystem;
        $file_path = GJ_PLUGIN_DIR.'/includes/admin/pre-data/fields.json';
        $wp_filesystem->put_contents($file_path, json_encode($groups));
    }

    static function create_fields(){
        $created_fields = get_option('gj_created_fields');
        if(!$created_fields){
            WP_Filesystem();
            global $wp_filesystem;
            $file_path = GJ_PLUGIN_DIR.'/includes/admin/pre-data/fields.json';
            $fields_content = $wp_filesystem->get_contents($file_path);
            $groups = json_decode($fields_content);
            foreach ($groups as $group){
                if($group->ID){
                    unset($group->ID);
                    $group->ID = wp_insert_post($group);
                    if($group->metadata){
                        foreach($group->metadata as $meta_key => $meta_value){
                            if(is_array($meta_value)){
                                foreach($meta_value as $mvalue){
                                    add_post_meta($group->ID, $meta_key, $mvalue);
                                }
                            }else{
                                update_post_meta($group->ID, $meta_key, $meta_value);
                            }
                        }
                    }
                }
                
                if($group->fields){
                    foreach ($group->fields as $field){
                        unset($field->ID);
                        $field->post_parent = $group->ID;
                        $field->ID = wp_insert_post($field);
                        if($field->metadata){
                            foreach($field->metadata as $meta_key => $meta_value){
                                if(is_array($meta_value)){
                                    foreach($meta_value as $mvalue){
                                        add_post_meta($field->ID, $meta_key, $mvalue);
                                    }
                                }else{
                                    update_post_meta($field->ID, $meta_key, $mvalue);
                                }
                            }
                        }
                    }
                }
            }

            update_option('gj_created_fields', 1);
        }
    }

    static function register_widgets(){
        register_sidebar(array(
            'name' => esc_html__('Sidebar Job Detail', 'gj'),
            'id' => 'sidebar-job',
            'description' => '',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Sidebar Candidate Detail', 'gj'),
            'id' => 'sidebar-candidate',
            'description' => '',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Sidebar Employer Detail', 'gj'),
            'id' => 'sidebar-employer',
            'description' => '',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Sidebar Jobs', 'gj'),
            'id' => 'sidebar-jobs',
            'description' => '',
            'before_widget' => '<aside id="%1$s" class="widget sidebar-jobs %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Sidebar Candidates', 'gj'),
            'id' => 'sidebar-candidates',
            'description' => '',
            'before_widget' => '<aside id="%1$s" class="widget sidebar-candidate sidebar-jobs %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(array(
            'name' => esc_html__('Sidebar Employers', 'jobgrand'),
            'id' => 'sidebar-employers',
            'description' => '',
            'before_widget' => '<aside id="%1$s" class="widget sidebar-jobs %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
    }

    static function create_cron_jobs(){

	    wp_clear_scheduled_hook( 'gj_job_expired' );
	    wp_schedule_event( current_time( 'timestamp' ), 'daily', 'gj_job_expired');

        wp_clear_scheduled_hook( 'gj_delete_draft_job' );
        $held_duration = gj_option( 'delete_draft_job_hours', '24' );
        if ( $held_duration >= 1 ) {
            wp_schedule_single_event( time() + ( absint( $held_duration ) * 60 * 60), 'gj_delete_draft_job' );
        }

        wp_clear_scheduled_hook( 'gj_delete_pending_order' );
        $held_duration = gj_option( 'delete_pending_order_hours', '48' );
        if ( $held_duration >= 1 ) {
            wp_schedule_single_event( time() + ( absint( $held_duration ) * 60 * 60), 'gj_delete_pending_order' );
        }
		do_action('gj_create_cron_jobs');
    }

    static function deactive($networkwide){
        global $wpdb;

        if (is_multisite() && $networkwide) {
            $old_blog =  $wpdb->blogid;
            //Get all blog ids
            $blogids =  $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
            foreach ( $blogids as $blog_id ) {
                switch_to_blog($blog_id);
                self::clear_scheduled_hook();
            }
            switch_to_blog( $old_blog );
        }else{
            self::clear_scheduled_hook();
        }
    }

    static function delete_blog($blog_id, $drop){
        self::delete_tables();
    }

    static function uninstall(){
        self::clear_scheduled_hook();
        self::remove_role();
        self::delete_tables();
        return false;
        include_once( 'includes/helper.function.php' );
        $login_page_id = gj_get_page_id('login');
        if($login_page_id){
            wp_trash_post($login_page_id);
        }

        $register_page_id = gj_get_page_id('register');
        if($register_page_id){
            wp_trash_post($register_page_id);
        }

        $lostpass_page_id = gj_get_page_id('lostpass');
        if($lostpass_page_id){
            wp_trash_post($lostpass_page_id);
        }

        $dashboard_page_id = gj_get_page_id('dashboard');
        if($dashboard_page_id){
            wp_trash_post($dashboard_page_id);
        }

        $jobs_page_id = gj_get_page_id('jobs');
        if($jobs_page_id){
            wp_trash_post($jobs_page_id);
        }

        $employers_page_id = gj_get_page_id('employers');
        if($employers_page_id){
            wp_trash_post($employers_page_id);
        }

        $candidates_page_id = gj_get_page_id('candidates');
        if($candidates_page_id){
            wp_trash_post($candidates_page_id);
        }

        global $wpdb;

        // Delete options.
        $wpdb->query("DELETE FROM $wpdb->options WHERE option_name LIKE '_gj._%';");

        // Delete posts + data.
        $wpdb->query( "DELETE FROM {$wpdb->posts} WHERE post_type IN ( 'gj_job', 'gj_package', 'gj_ressum_package', 'gj_u_package' , 'gj_order', 'gj_application', 'gj_employer', 'gj_candidate' );" );
        $wpdb->query( "DELETE meta FROM {$wpdb->postmeta} meta LEFT JOIN {$wpdb->posts} posts ON posts.ID = meta.post_id WHERE posts.ID IS NULL;" );

        // Delete taxonomy.
        $wpdb->query( "DELETE FROM {$wpdb->term_taxonomy} WHERE taxonomy IN ( 'gj_cat', 'gj_type', 'gj_salary', 'gj_skill', 'gj_level', 'gj_keyword' );" );
        $wpdb->query( "DELETE terms FROM {$wpdb->terms} terms LEFT JOIN {$wpdb->term_taxonomy} term_taxonomy ON terms.term_id = term_taxonomy.term_id WHERE term_taxonomy.ID IS NULL;" );
        $wpdb->query( "DELETE meta FROM {$wpdb->termmeta} meta LEFT JOIN {$wpdb->term_taxonomy} term_taxonomy ON terms.term_id = meta.term_id WHERE term_taxonomy.term_id IS NULL;" );

        //Delete user meta
        $wpdb->query("DELETE FROM $wpdb->usermeta WHERE meta_key LIKE '_gj._%';");

    }

    static function remove_role(){
        remove_role( 'gj_employer');
        remove_role( 'gj_candidate');
    }

    static function clear_scheduled_hook(){
	    wp_clear_scheduled_hook( 'gj_job_expired' );
        wp_clear_scheduled_hook('gj_delete_draft_job');
		do_action('gj_clear_schedule_hook');
    }

    static function delete_tables(){
        global $wpdb;

        $wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}gj_save_resums" );
        $wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}gj_save_jobs" );
        $wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}gj_follows" );
        $wpdb->query( "DROP TABLE IF EXISTS {$wpdb->prefix}gj_email_queue" );
    }

    static function update(){
    }
}