<?php
/**
 * @class 		GJ_Admin_Jobs_Tools
 * @package		GJ/Admin/Classes
 * @author 		InwaveThemes
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class GJ_Admin_Jobs_Tools {
	static $fields = array();

	static function init() {
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'admin_load_scripts' ) );
		add_action( 'gj_jobs_tools_tab', array( __CLASS__, 'jobs_tools_tab' ), 1 );
		add_action( 'gj_jobs_tools_content', array( __CLASS__, 'jobs_tools_content' ), 1 );
	}

	static function admin_load_scripts() {
		if ( isset( $_REQUEST['page'] ) && sanitize_text_field($_REQUEST['page']) == 'gj-tools' ) {
			wp_enqueue_style( 'sweet-alert', GJ_PLUGIN_URL . '/assets/css/sweetalert.css', array() );
			wp_enqueue_script( 'icheck', GJ_PLUGIN_URL . '/assets/js/icheck.min.js', 'jquery', GJ_VERSION, true );
			wp_enqueue_script( 'sweet-alert', GJ_PLUGIN_URL . '/assets/js/sweetalert-dev.js', array( 'jquery' ), GJ_VERSION, true );
			wp_enqueue_script( 'admin-imports-exports', GJ_PLUGIN_URL . '/assets/js/admin_imports_exports.js', array( 'jquery' ), true );
		}
	}

	static function management_page() {
		global $active_tab;
		$active_tab = isset( $_GET['tab'] ) ? sanitize_text_field($_GET['tab']) : 'export'; ?>
		<h2 class="nav-tab-wrapper">
			<?php do_action( 'gj_jobs_tools_tab' ); ?>
		</h2>
		<div class="gj-tools-content-page">
			<?php do_action( 'gj_jobs_tools_content' ); ?>
		</div>
		<?php
	}

	static function jobs_tools_tab() {
		global $active_tab; ?>
		<a class="nav-tab <?php echo ($active_tab == 'export' || '') ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url(admin_url( 'edit.php?post_type=gj_job&page=gj-tools&tab=export' )); ?>"><?php echo esc_html__( 'Export', 'gj' ); ?> </a>
		<a class="nav-tab <?php echo ($active_tab == 'import') ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url(admin_url( 'edit.php?post_type=gj_job&page=gj-tools&tab=import' )); ?>"><?php echo esc_html__( 'Import', 'gj' ); ?> </a>
		<a class="nav-tab <?php echo ($active_tab == 'tools') ? 'nav-tab-active' : ''; ?>" href="<?php echo esc_url(admin_url( 'edit.php?post_type=gj_job&page=gj-tools&tab=tools' )); ?>"><?php echo esc_html__( 'Tools', 'gj' ); ?> </a>
		<?php
	}

	static function jobs_tools_content() {
		global $active_tab;

		if ( $active_tab == 'export' || $active_tab == '' ) {
			self::jobs_export_content_page();
		}elseif ( $active_tab == 'import' ) {
			self::jobs_import_content_page();
		}elseif ( $active_tab == 'tools' ) {
			self::jobs_tools_content_page();
		}
	}

	static function jobs_tools_content_page(){
	    ?>
        <table>
            <tr>
                <th>
                    <strong><?php esc_html_e('Create default page', 'gj'); ?></strong>
                    <p class="description"><?php esc_html_e('This tool will install all the missing GJ pages. Pages already defined and set up will not be replaced', 'gj'); ?></p>
                </th>
                <td><a href="#" class="button" id="gj-create-default-pages"><?php esc_html_e('Create pages', 'gj'); ?></a></td>
            </tr>
            <tr>
                <th>
                    <strong><?php esc_html_e('Reorder fields', 'gj'); ?></strong>
                    <p class="description"><?php esc_html_e('This tool will help order groups and fields in the manager page work correctly', 'gj'); ?></p>
                </th>
                <td><a href="#" class="button" id="gj-reorder-all-fields"><?php esc_html_e('Reorder', 'gj'); ?></a></td>
            </tr>
            <?php
            do_action('gj_tools_content_page');
            ?>
        </table>
        <?php
    }

	static function jobs_export_content_page() { ?>
		<form action="" method="post" class="gj-form-exports-job">
			<?php
                echo '<label for="export-post-types">'.esc_html__('Post types', 'gj').'</label>';
                echo '<select id="export-post-types" multiple="true">';
                    echo '<option value="gj_job">'.esc_html__('Jobs', 'gj').'</option>';
                    echo '<option value="gj_employer">'.esc_html__('Employers', 'gj').'</option>';
                    echo '<option value="gj_candidate">'.esc_html__('Candidates', 'gj').'</option>';
                echo '</select>';
            ?>
			<p class="submit">
				<button type="submit" class="button button-primary gj-button-export" name=""><?php echo esc_html__( 'Export', 'gj' ); ?></button>
			</p>
		</form>
		<div class="gj-loading-exports hidden">
			<img src="<?php echo GJ_PLUGIN_URL . '/assets/images/bx_loader.gif'; ?>" alt="<?php echo esc_html__( 'Loading', 'gj' ); ?>">
		</div>
		<div id="gj-download-link" class="hidden">
			<p class="gj-export-msg"></p>
			<a href="#"><?php echo esc_html__( 'Download', 'gj' ); ?></a>
		</div>
		<?php
	}

	static function jobs_import_content_page() {
		$step      = isset( $_REQUEST['step'] ) ? sanitize_text_field( $_REQUEST['step'] ) : '';
		switch ( $step ) {
			case 'import_file':
				self::form_import_file();
				break;
			case 'mapping_config':
				self::form_mapping_configuration();
				break;
			case 'confirm':
				self::form_ignite_import();
				break;
			default:
				self::form_import_file();
				break;
		}
	}

	static function form_import_file() { ?>
		<form class="form-horizontal" method="post" id="form_import_file" action="<?php echo esc_url( admin_url() . 'edit.php?post_type=gj_job&page=gj-tools&tab=import&step=mapping_config' ); ?>" enctype="multipart/form-data">
			<div id='gj_importjob_sec' class="col-md-12" style="display: none;">
				<div id="gj_displayname">
					<div id="gj_filename_display"></div>
				</div>
				<div class="">
					<div id="gj_progress-div">
						<div id="gj_progress-bar">
							<span class="progresslabel"></span>
						</div>
					</div>
					<div id="gj_targetLayer"></div>
				</div>
				<div class="clearfix"></div>
				<div class="form-group gj_mt10">
					<span class="import-if-duplicate"><label><?php echo esc_html__( 'If duplicate ID', 'gj' ); ?></label></span>
					<span>
						<label>
							<input type="radio" name="import_mode" value="ignore_items" checked="checked"><?php echo esc_html__( ' Ignore', 'gj' ); ?>
						</label>
						<label class="pl20">
							<input type="radio" name="import_mode" value="update_existing_items"><?php echo esc_html__( ' Update information', 'gj' ); ?>
						</label>
					</span>
				</div>
				<div id="gj_select_module" class="select_module">
					<span><label class="import-textnew"><?php echo esc_html__( 'Import as post type', 'gj' ); ?></label></span>
					<span class="select_box" style="width:200px;height:40px;">
						  <select class="search_dropdown selectpicker" id="search_dropdowns" data-size="5" name="posttype" style="width:200px;height:39px;">
							  <?php
							  $post_types = array(
								  'gj_job'       => esc_html__( 'Job', 'gj' ),
								  'gj_candidate' => esc_html__( 'Candidate', 'gj' ),
								  'gj_employer'  => esc_html__( 'Employer', 'gj' ),
							  );
							  foreach ( $post_types as $key_pt => $post_type ) { ?>
								  <option value="<?php echo esc_attr($key_pt); ?>"><?php echo esc_html($post_type); ?></option>
								  <?php
							  } ?>
						  </select>
					</span>
				</div>
				<div class=" gj_mt20">
					<input type="submit" class="smack-btn smack-btn-primary btn-radius ripple-effect continue-btn" disabled value="<?php echo esc_html__( 'Continue', 'gj' ) ?>">
				</div>
			</div>
			<div class="bhoechie-tab-content active" id="gj_division1">
				<div class="gj_file_upload">
					<input id="gj_upload_file" type="file" name="files[]" onchange="gj_upload_method()" />
					<div class="file-upload-icon">
						<span id="gj_fileupload" class="import-icon"> <img src="<?php echo GJ_PLUGIN_URL . '/assets/img/upload-123.png'; ?>" width="60" height="60" /></span>
						<span class="file-upload-text"><?php echo esc_html__( 'Click here to upload CSV from desktop', 'gj' ); ?></span>
					</div>
				</div>
			</div>
			<input type="hidden" id="uploaded_name" name="uploaded_name" value="">
			<input type="hidden" id="file_name" name="file_name" value="">
			<input type="hidden" id="file_extension" name="file_extension" value="">
			<input type="hidden" id="import_method" name="import_method" value="desktop">
			<input type="hidden" id="file_version" name="file_version" value="">
			<input type="hidden" id="upload_max" name="upload_max" value="<?php echo ini_get( 'upload_max_filesize' ); ?>">
		</form>
		<?php
	}

	static function form_mapping_configuration() {

        require_once GJ_PLUGIN_DIR . '/includes/libs/parsecsv/vendor/autoload.php';

		if ( $_POST ) {
			$_POST                  = filter_input_array( INPUT_POST, FILTER_SANITIZE_STRING );
			$records['import_file'] = $_POST;
			self::setPostValues( sanitize_key( $_REQUEST['eventkey'] ), $records );
		}
		$eventKey    = sanitize_key( $_REQUEST['eventkey'] );
		$get_records = self::getPostValues( $eventKey );
		$import_type = $get_records[ $eventKey ]['import_file']['posttype'];
		$file = GJ_IMPORT_DIR . '/' . $eventKey . '/' . $eventKey;
        $csv = new ParseCsv\Csv($file);
		$Headers        = $csv->titles;
		$backlink        = esc_url( admin_url() . 'edit.php?post_type=gj_job&page=gj-tools&tab=import&step=import_file' );
		$actionURL       = esc_url( admin_url() . 'edit.php?post_type=gj_job&page=gj-tools&tab=import&step=confirm&eventkey=' . $_REQUEST['eventkey'] ); ?>
		<div class="template_body whole_body">
			<div>
				<h3 class="csv-importer-heading"><?php echo esc_html__( 'Mapping Section', 'gj' ); ?></h3>
			</div>
			<form id="mapping_section" method="post" action="<?php echo esc_url($actionURL); ?>">
				<div id='wp_warning' style='display:none;' class='error'></div>
				<div class="mapping_table">
					<?php
					$integrations = array(
						0 => array('title' => 'Post Fields', 'input' => 'core'),
						1 => array('title' => 'Term Fields', 'input' => 'term'),
						2 => array('title' => 'Extra Fields', 'input' => 'extra'),
					);
					$widget_fields = self::get_widget_fields( $Headers, $import_type );
					foreach ( $integrations as $wkey => $widget ) {
						$widget_slug = strtolower( str_replace( ' ', '_', $widget['title'] ) );
						$fields      = $widget_fields[$wkey];
						?>
						<div class="panel-group" id='accordion_<?php echo esc_attr($widget['title']) ; ?>'>
							<div class='panel panel-default' data-target="#<?php echo esc_attr($widget_slug); ?>" data-parent="#accordion_<?php echo esc_attr($widget['title']) ; ?>">
								<div id='<?php echo esc_attr($widget_slug); ?>' class='panel-heading' onclick="gj_toggle_func('<?php echo esc_attr($widget_slug); ?>');">
									<div class="panel-title">
										<b><?php echo esc_html($widget['title']); ?></b>
										<span class='fa fa-minus-square-o' id='<?php echo 'icon' . $widget_slug ?>' style="float:right;"></span>
									</div>
								</div>
								<div id='<?php echo esc_attr($widget_slug); ?>toggle' style="height:auto;">
									<div class="grouptitlecontent">
										<table class='table table-mapping custom_table' id='<?php echo esc_attr($widget_slug); ?>_table'>
											<tbody>
											<tr>
												<td class='columnheader mappingtd_style'>
													<label class='groupfield'><?php echo esc_html__( 'Field Name', 'gj' ); ?></label>
												</td>
												<td class='columnheader mappingtd_style'>
													<label class='groupfield'><?php echo esc_html__( 'CSV Header', 'gj' ); ?></label>
												</td>
											</tr>
											<?php if ( ! empty( $fields ) ) {
												foreach ( $fields as $key => $value ) { ?>
													<tr id="gj-tr-<?php echo esc_attr( $widget_slug . $key ); ?>">
														<td class='left_align'>
                                                            <label class="wpfields"><?php echo '[Name: ' . $value . ']'; ?></label>
														</td>
														<td class="mappingtd_style">
															<div class="mapping-select-div">
																<select name="fields_mapping[<?php echo esc_attr($widget['input']); ?>][<?php echo esc_attr($value); ?>]" class="selectpicker">
																	<option value=""><?php echo esc_html__( 'Select field', 'gj' ); ?></option>
																	<?php
																	foreach ( $Headers as $csvkey => $csvheader ) {
																		$csvheader_entity = preg_replace("/\xEF\xBB\xBF/", "", $csvheader);?>
																		<option value="<?php echo esc_attr($csvheader_entity); ?>" <?php echo ($csvheader_entity == $value) ? 'selected' : ''; ?>><?php echo esc_html($csvheader_entity); ?></option>
																		<?php
																	} ?>
																</select>
															</div>
														</td>
													</tr>
													<?php
												}
											} ?>
											</tbody>
										</table>
									</div>
								</div>
							</div>
						</div>
						<?php
					}
                    ?>
				</div>
				<div class="gj_import_btn_ctn gj_mt20">
					<div class="pull-left">
						<a class="smack-btn btn-default btn-radius" href="<?php echo esc_url( $backlink ); ?>"><?php echo esc_html__( 'Back', 'gj' ) ?></a>
					</div>
					<div class="pull-right">
						<input type="submit" class="smack-btn smack-btn-primary btn-radius" value="<?php echo esc_attr__( 'Continue', 'gj' ); ?>" />
					</div>
				</div>
				<div class="gj_mb20"></div>
			</form>
		</div>
		<?php
	}

	static function form_ignite_import() {

        require_once GJ_PLUGIN_DIR . '/includes/libs/parsecsv/vendor/autoload.php';

		if ( $_POST ) {
			$_POST                     = filter_input_array( INPUT_POST, FILTER_SANITIZE_STRING );
			$records = $_POST;
			$post_values               = self::getPostValues( sanitize_key( $_REQUEST['eventkey'] ) );
			$result                    = array_merge( $post_values[ sanitize_key($_REQUEST['eventkey']) ], $records );
			self::setPostValues( sanitize_key( $_REQUEST['eventkey'] ), $result );
		}
		$get_screen_info = self::getPostValues( sanitize_key( $_REQUEST['eventkey'] ) );
		$eventkey        = sanitize_key( $_REQUEST['eventkey'] );
		$file            = GJ_IMPORT_DIR . '/' . $eventkey . '/' . $eventkey;
        $csv = new ParseCsv\Csv();
        $csv->load_data($file);
		$total_row_count = $csv->getTotalDataRowCount();

		$import_type     = $get_screen_info[ $eventkey ]['import_file']['posttype'];
		$import_mode     = $get_screen_info[ $eventkey ]['import_file']['import_mode']; ?>
		<div class="template_body whole_body">
			<form class="form-inline" method="post">
				<div class="clearfix"></div>
				<div id="gj_progress-div">
					<div id="gj_progress-bar">
						<span class="progresslabel"></span>
					</div>
				</div>
				<div class="clearfix"></div>
				<div class="event-summary">
					<span class="es-left"> <?php echo esc_html__( 'File Name:', 'gj' ); ?><?php echo esc_attr($get_screen_info[ $eventkey ]['import_file']['uploaded_name']); ?> </span>
					<span class="es-right"> <?php echo esc_html__( 'File Size:', 'gj' ); ?><?php echo self::getFileSize( $file ); ?> </span>
				</div>
				<div class="event-summary">
					<span class="es-left"> <?php echo esc_html__( 'Process: Import', 'gj' ); ?></span>
					<span class="es-right"> <?php echo esc_html__( 'Total no of records:', 'gj' ); ?><?php echo intval($total_row_count); ?> </span>
				</div>
				<div class="event-summary timer">
					<span class="es-left"> <?php echo esc_html__( 'Time Elapsed:', 'gj' ); ?> </span>
					<span class="es-left" style="padding-left: 10px;">
						<span class="hour">00</span>:<span class="minute">00</span>:<span class="second">00</span>
					</span>
                    <span class="es-right" id="gj_import_fail_records" style="padding-right:2px;color:red;"> <?php echo esc_html__( 'Fail Record(s):', 'gj' ); ?><span class="count">0/<?php echo intval($total_row_count);?></span></span>
					<span class="es-right" id="gj_import_success_records" style="padding-right:7px;color:green;"> <?php echo esc_html__( 'Success Record(s):', 'gj' ); ?><span class="count">0</span></span>
				</div>
				<div class="control" style="display: none;">
					<input type="button" id="gj_import_timer_start" onClick="timer.start(1000)" value="<?php echo esc_attr__( 'Start', 'gj' ); ?>" />
					<input type="button" id="gj_import_timer_stop" onClick="timer.stop()" value="<?php echo esc_attr__( 'Stop', 'gj' ); ?>" />
					<input type="button" id="gj_import_timer_reset" onClick="timer.reset(60)" value="<?php echo esc_attr__( 'Reset', 'gj' ); ?>" />
					<input type="button" id="gj_import_timer_count_up" onClick="timer.mode(1)" value="<?php echo esc_attr__( 'Count up', 'gj' ); ?>" />
					<input type="button" id="gj_import_timer_count_down" onClick="timer.mode(0)" value="<?php echo esc_attr__( 'Countdown', 'gj' ); ?>" />
				</div>
				<div id="logsection" class="seoadv_options">
					<div id="innerlog" class="logcontainer"></div>
				</div>
				<input type="hidden" id="eventkey" value="<?php echo sanitize_key( $_REQUEST['eventkey'] ); ?>">
				<input type="hidden" id="import_type" name="import_type" value="<?php echo esc_attr($import_type); ?>">
				<input type="hidden" id="import_mode" name="import_mode" value="<?php echo esc_attr($import_mode); ?>">
				<input type="hidden" id="currentlimit" name="currentlimit" value="1">
				<input type="hidden" id="importedSuccess" name="importedSuccess" value="0">
				<input type="hidden" id="limit" name="limit" value="1">
				<input type="hidden" id="inserted" value="0">
				<input type="hidden" id="totalcount" name="totalcount" value="<?php echo esc_attr($total_row_count); ?>">
				<input type="hidden" id="terminate_action" name="terminate_action" value="continue" />
			</form>
		</div>
		<script>
			jQuery(document).ready(function (e) {
				jQuery("#gj_import_timer_count_up").click();
				jQuery("#gj_import_timer_start").click();
			});
            gj_ignite_import();
		</script>
		<?php
	}

	static function coreFields( $type ) {
		$coreFields = array(
			'ID',
			'post_type',
			'post_author',
			'post_date',
			'post_date_gmt',
			'post_content',
			'post_title',
			'post_excerpt',
			'post_status',
			'post_name',
			'post_modified',
			'post_modified_gmt',
			'post_content_filtered',
			'post_parent',
			'guid',
			'menu_order',
			'post_mime_type',
			'comment_count',
            'comment_status',
            'ping_status',
            'post_password',
            'to_ping',
            'pinged',
            'filter'
		);

		return $coreFields;
	}

	static function extraFields( $headers, $core_fields, $term_fields, $import_type ) {
		$extra_fields = array();
		$_fields = array_merge($core_fields, $term_fields);
		foreach ($headers as $field) {
		    if(!in_array($field, $_fields)) {
                $extra_fields[] = $field;
		    }
        }

		return $extra_fields;
	}

	static function termFields( $type ) {
		switch ( $type ) {
			case 'gj_candidate':
				return gj_get_candidate_taxonomies();
			case 'gj_employer':
                return gj_get_employer_taxonomies();
            default :
                return gj_get_job_taxonomies();
		}
	}

	static function getFileSize( $file ) {
		$fileSize = filesize( $file );

		if ( $fileSize > 1024 && $fileSize < ( 1024 * 1024 ) ) {
			$fileSize = round( ( $fileSize / 1024 ), 2 ) . ' kb';
		} else if ( $fileSize > ( 1024 * 1024 ) ) {
			$fileSize = round( ( $fileSize / ( 1024 * 1024 ) ), 2 ) . ' mb';
		} else {
			$fileSize = $fileSize . ' bytes';
		}

		return $fileSize;
	}

	static function serverReq_data() {
		$record_arr          = array();
		$split_range         = array();
		$initial_recordcount = 1000;
		$minimum_record      = 0;
		$filesize            = 8000;
		//$tot_records = count($record_arr);
		$tot_records   = 10;
		$executiontime = ini_get( 'max_execution_time' );
		$memorysize    = ini_get( 'memory_limit' );
		if ( $tot_records < $initial_recordcount ) {
			$current_processtime = ( $tot_records / 20 ) * 60;
		} else {
			$current_processtime = ( ( $tot_records / 1000 ) * 5 ) * 60;
		}
		if ( $executiontime < $current_processtime ) {
			$time_in_minute = round( $executiontime / 60, 3 );
			if ( $executiontime > 300 ) {
				$server_req = 1000 * ( $time_in_minute / 5 ); // 1000 record takes 5 minutes i.e 300s
			} else {
				$server_req = 150 * $time_in_minute; // 150 record takes 1 minute.
			}
			$server_req = $server_req / 2;
		} else {
			$server_req = $tot_records / 2;
		}
		if ( $server_req != 0 ) {
			// convert to neareast 10.
			$quotient_val  = (int) $server_req / 10;
			$remainder_val = (int) $server_req % 10;
			if ( $remainder_val != 0 ) {
				$server_req = ( intval( $quotient_val ) + 1 ) * 10;
			}
			// Split the range
			$count = 0;
			for ( $i = $server_req; $count < 10; $i ++ ) {
				if ( $i > 20 ) {
					$split_range[] = $i - 20;
					$i             -= 20;
				} else {
					$split_range[] = $i;
					break;
				}
				$count ++;
			}
		}

		return $split_range;
	}

	static function setPostValues( $eventKey = null, $values = null ) {
		$uploadPath = GJ_IMPORT_DIR . '/' . $eventKey;
		if ( ! is_dir( $uploadPath ) ) {
			wp_mkdir_p( $uploadPath );
		}
		$filename = $uploadPath . '/screenInfo.txt';
		$post_values[ $eventKey ] = $values;
		$post_values              = serialize( $post_values );

        WP_Filesystem();
        global $wp_filesystem;
        $wp_filesystem->put_contents($filename, $post_values);

		$_SESSION[ $eventKey ] = $values;
	}

	static function getPostValues( $eventKey ) {
		$uploadPath       = GJ_IMPORT_DIR . '/' . $eventKey;
		$screen_info_file = $uploadPath . '/screenInfo.txt';
        WP_Filesystem();
        global $wp_filesystem;
        $str = $wp_filesystem->get_contents($screen_info_file);
        return @unserialize( $str );
	}

	static function get_widget_fields( $headers, $import_type ) {
        $core_fields = self::coreFields( $import_type );
        $term_fields = self::termFields( $import_type );
        $extra_fields = self::extraFields($headers, $core_fields, $term_fields, $import_type );
		$fields = array(
            0 => $core_fields,
            1 => $term_fields,
            2 => $extra_fields
        );
		return $fields;
	}

}

GJ_Admin_Jobs_Tools::init();