<?php
/**
 * @class 	GJ_Widget_Candidates
 * @package GJ/Widgets
 * @since 1.0.1
 */

class GJ_Widget_Candidates extends WP_Widget {

    public function __construct() {
        $widget_ops = array(
            'description' => esc_html__( 'Display Candidates list.', 'gj' ),
            'customize_selective_refresh' => true,
        );
        parent::__construct( 'gj_candidates', esc_html__( '[GJ] Candidates', 'gj' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $limit = isset($instance['limit']) ?  strip_tags($instance['limit']) : 12;
        $orderby = isset($instance['orderby']) ? esc_attr($instance['orderby']) : 'date';
        $order = isset($instance['order']) ? esc_attr($instance['order']) : 'DESC';
	    $show_featured_candidates = isset($instance['show_featured_candidates']) ?  strip_tags($instance['show_featured_candidates']) : '';

        $args_candidate = array(
            'posts_per_page' => $limit,
            'post_type' => 'gj_candidate',
            'orderby' => $orderby,
            'order' => $order,
        );
	    $args_company['meta_query'] = array(
		    'relation' => 'AND',
		);

	    if ( $show_featured_candidates ) {
		    $args_candidate['meta_query'][] =
			    array(
				    'key'   => '_gj_featured',
				    'value' => '1',
					'compare' => '='
			    );
	    }

	    $args_candidate['meta_query'][] = array(
		    'relation' => 'OR',
		    array(
			    'key' => GJ_PREFIX . 'public_account',
			    'compare' => 'NOT EXISTS' // doesn't work
		    ),
		    array(
			    'key'     => GJ_PREFIX . 'public_account',
			    'value'   => 1,
			    'compare' => '='
		    )
	    );

        $candidates = get_posts($args_candidate);

        $data = array(
            'args' => $args,
            'instance' => $instance,
            'widget_id' => $this->id_base,
            'parent' => $this,
            'candidates' => $candidates,
        );

        gj_get_template_part('widgets/candidates', $data);
    }

    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = sanitize_text_field( $new_instance['title'] );
        $instance['limit'] = strip_tags($new_instance['limit']);
        $instance['orderby'] = strip_tags($new_instance['orderby']);
        $instance['order'] = strip_tags($new_instance['order']);
	    $instance['show_featured_candidates'] = strip_tags($new_instance['show_featured_candidates']);
        return $instance;
    }

    public function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => esc_html__('Recent Resumes', 'gj'), 'limit' => '5', 'orderby' => 'date', 'order' => 'DESC' ) );
        $title = strip_tags($instance['title']);
        $limit = esc_attr($instance['limit']);
        $orderby = esc_attr($instance['orderby']);
        $order = esc_attr($instance['order']);
	    $show_featured_candidates = esc_attr($instance['show_featured_candidates']);
        ?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php echo esc_html__( 'Title:', 'gj'); ?></label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" />
        </p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('show_featured_candidates')); ?>"><?php esc_html_e('Show Candidates:', 'gj'); ?></label>
			<select class="widefat" id="<?php echo esc_attr($this->get_field_id('show_featured_candidates')); ?>" name="<?php echo esc_attr($this->get_field_name('show_featured_candidates')); ?>">
				<option value="" <?php selected($show_featured_candidates, 'any'); ?>><?php esc_html_e('Any', 'gj'); ?></option>
				<option value="featured" <?php selected($show_featured_candidates, 'featured'); ?>><?php esc_html_e('Featured', 'gj'); ?></option>
			</select>
		</p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('limit')); ?>"><?php esc_html_e('Limit:', 'gj'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('limit')); ?>" name="<?php echo esc_attr($this->get_field_name('limit')); ?>" type="text" value="<?php echo esc_attr($limit); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('orderby')); ?>"><?php esc_html_e('Order By:', 'gj'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('orderby')); ?>" name="<?php echo esc_attr($this->get_field_name('orderby')); ?>">
                <option value="ID" <?php selected($orderby, 'ID'); ?>><?php esc_html_e('ID', 'gj'); ?></option>
                <option value="date" <?php selected($orderby, 'date'); ?>><?php esc_html_e('Date', 'gj'); ?></option>
                <option value="modified" <?php selected($orderby, 'modified'); ?>><?php esc_html_e('modified', 'gj'); ?></option>
                <option value="title" <?php selected($orderby, 'title'); ?>><?php esc_html_e('title', 'gj'); ?></option>
                <option value="menu_order" <?php selected($orderby, 'menu_order'); ?>><?php esc_html_e('Ordering', 'gj'); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('order')); ?>"><?php esc_html_e('Order:', 'gj'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('order')); ?>" name="<?php echo esc_attr($this->get_field_name('order')); ?>">
                <option value="DESC" <?php selected($order, 'DESC'); ?>><?php esc_html_e('DESC', 'gj'); ?></option>
                <option value="ASC" <?php selected($order, 'ASC'); ?>><?php esc_html_e('ASC', 'gj'); ?></option>
            </select>
        </p>
        <?php
    }

}

function gj_widget_candidates() {
    register_widget('GJ_Widget_Candidates');
}
add_action('widgets_init', 'gj_widget_candidates');