<?php
/**
 * @class 	GJ_Widget_Employers
 * @package GJ/Widgets
 * @since 1.0.1
 */

class GJ_Widget_Employers extends WP_Widget {

    public function __construct() {
        $widget_ops = array(
            'description' => esc_html__( 'Display Employers Lists.', 'gj' ),
            'customize_selective_refresh' => true,
        );
        parent::__construct( 'gj_employers', esc_html__( '[GJ] Employers', 'gj' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $limit = isset($instance['limit']) ?  strip_tags($instance['limit']) : 12;
        $orderby = isset($instance['orderby']) ?  strip_tags($instance['orderby']) : 'date';
        $order = isset($instance['order']) ?  strip_tags($instance['order']) : 'DESC';
        $show_featured_employers = isset($instance['show_featured_employers']) ?  strip_tags($instance['show_featured_employers']) : '';

        if($orderby != 'total_jobs'){
            $args_company = array(
                'posts_per_page' => ($limit ? $limit : -1),
                'post_type' => 'gj_employer',
                'post_status' => 'publish',
                'orderby' => $orderby,
                'order' => $order,
            );
	        if ( $show_featured_employers ) {
		        $args_company['meta_query'] = array(
			        'relation' => 'AND',
			        array(
				        'key'   => '_gj_featured',
				        'value' => '1',
			        ),
		        );
	        }
            $employers = get_posts($args_company);
        }else{
            global $wpdb;
            $sql = "SELECT p.*, COUNT(p.ID) AS total_jobs
                    FROM {$wpdb->prefix}posts AS p
                    LEFT JOIN {$wpdb->prefix}posts AS p1 ON p.post_author = p1.post_author
                    ".($show_featured_employers ? " JOIN {$wpdb->postmeta} AS pm ON pm.post_id = p.ID" : "")."
                    WHERE p.post_type = 'gj_employer' AND p.post_status IN (".(gj_option('show_expired_job') ? "'publish','gj-expired'" : "'publish'").") AND p1.post_type = 'gj_job' AND p1.post_status = 'publish'
                    ".($show_featured_employers ? " AND (pm.meta_key = '".GJ_PREFIX."featured' AND pm.meta_value ='1')":"")."
                    GROUP BY p1.post_author
                    ORDER BY total_jobs {$order}
                    LIMIT 0, {$limit}
                    ";
            $employers = $wpdb->get_results($sql);
        }

        $data = array(
            'args' => $args,
            'instance' => $instance,
            'widget_id' => $this->id_base,
            'parent' => $this,
            'employers' => $employers
        );

        gj_get_template_part('widgets/employers', $data);
    }

    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = sanitize_text_field( $new_instance['title'] );
        $instance['ids'] = strip_tags( $new_instance['ids'] );
        $instance['limit'] = strip_tags($new_instance['limit']);
        $instance['orderby'] = strip_tags($new_instance['orderby']);
        $instance['order'] = strip_tags($new_instance['order']);
        $instance['show_featured_employers'] = strip_tags($new_instance['show_featured_employers']);
        return $instance;
    }

    public function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => esc_html__('Lastest Employers', 'gj'), 'ids' => '', 'limit' => '12', 'orderby' => 'date', 'order' => 'DESC' ) );
        $title_id = $this->get_field_id( 'title' );
        $title = strip_tags($instance['title']);
        $limit = esc_attr($instance['limit']);
        $orderby = esc_attr($instance['orderby']);
        $order = esc_attr($instance['order']);
        $show_featured_employers = esc_attr($instance['show_featured_employers']);
        ?>
        <p><label for="<?php echo esc_attr($title_id); ?>"><?php echo esc_html__( 'Title:', 'gj'); ?></label>
            <input type="text" class="widefat" id="<?php echo esc_attr($title_id); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" />
        </p>
		<p>
			<label for="<?php echo esc_attr($this->get_field_id('show_featured_employers')); ?>"><?php esc_html_e('Show Employers:', 'gj'); ?></label>
			<select class="widefat" id="<?php echo esc_attr($this->get_field_id('show_featured_employers')); ?>" name="<?php echo esc_attr($this->get_field_name('show_featured_employers')); ?>">
				<option value="" <?php selected($show_featured_employers, 'any'); ?>><?php esc_html__('Any', 'gj'); ?></option>
				<option value="featured" <?php selected($show_featured_employers, 'featured'); ?>><?php esc_html_e('Featured', 'gj'); ?></option>
			</select>
		</p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('limit')); ?>"><?php esc_html_e('Limit:', 'gj'); ?></label>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id('limit')); ?>" name="<?php echo esc_attr($this->get_field_name('limit')); ?>" type="text" value="<?php echo esc_attr($limit); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('orderby')); ?>"><?php esc_html_e('Order By:', 'gj'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('orderby')); ?>" name="<?php echo esc_attr($this->get_field_name('orderby')); ?>">
                <option value="ID" <?php selected($orderby, 'ID'); ?>><?php esc_html__('ID', 'gj'); ?></option>
                <option value="date" <?php selected($orderby, 'date'); ?>><?php esc_html__('Date', 'gj'); ?></option>
                <option value="modified" <?php selected($orderby, 'modified'); ?>><?php esc_html__('modified', 'gj'); ?></option>
                <option value="title" <?php selected($orderby, 'title'); ?>><?php esc_html__('title', 'gj'); ?></option>
                <option value="menu_order" <?php selected($orderby, 'menu_order'); ?>><?php esc_html__('Ordering', 'gj'); ?></option>
                <option value="total_jobs" <?php selected($orderby, 'total_jobs'); ?>><?php esc_html__('Total Jobs', 'gj'); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('order')); ?>"><?php esc_html_e('Order:', 'gj'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('order')); ?>" name="<?php echo esc_attr($this->get_field_name('order')); ?>">
                <option value="DESC" <?php selected($order, 'DESC'); ?>><?php esc_html__('DESC', 'gj'); ?></option>
                <option value="ASC" <?php selected($order, 'ASC'); ?>><?php esc_html__('ASC', 'gj'); ?></option>
            </select>
        </p>
        <?php
    }

}

function gj_widget_employers() {
    register_widget('GJ_Widget_Employers');
}
add_action('widgets_init', 'gj_widget_employers');