<?php
/**
 * @class 	GJ_Widget_Social_Share
 * @package GJ/Widgets
 * @since 1.0.1
 */

class GJ_Widget_Social_Share extends WP_Widget {

    public function __construct() {
        $widget_ops = array(
            'description' => esc_html__( 'Display Social Share, used only with sidebar details.', 'gj' ),
            'customize_selective_refresh' => true,
        );
        parent::__construct( 'gj_social_share', esc_html__( '[GJ] Social Share', 'gj' ), $widget_ops );
    }

    public function widget( $args, $instance ) {

        $data = array(
            'args' => $args,
            'instance' => $instance,
            'widget_id' => $this->id_base,
            'parent' => $this,
        );

        gj_get_template_part('widgets/social-share', $data);
    }

    public function update( $new_instance, $old_instance ) {
        $instance = array();
        $instance['title'] = sanitize_text_field( $new_instance['title'] );
        $instance['use_for'] = sanitize_text_field( $new_instance['use_for'] );
        return $instance;
    }
    public function form( $instance ) {
        $instance = wp_parse_args( (array) $instance, array( 'title' => '', 'use_for' => 'job') );
        $title = strip_tags($instance['title']);
        $use_for = strip_tags($instance['use_for']);
        ?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php echo esc_html__( 'Title:', 'gj'); ?></label>
            <input type="text" class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" value="<?php echo esc_attr($title); ?>" />
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('use_for')); ?>"><?php esc_html_e('Use for:', 'gj'); ?></label>
            <select class="widefat" id="<?php echo esc_attr($this->get_field_id('use_for')); ?>" name="<?php echo esc_attr($this->get_field_name('use_for')); ?>">
                <option value="job" <?php selected($use_for, 'job'); ?>><?php esc_html_e('Job', 'gj'); ?></option>
                <option value="employer" <?php selected($use_for, 'employer'); ?>><?php esc_html_e('Employer', 'gj'); ?></option>
                <option value="candidate" <?php selected($use_for, 'candidate'); ?>><?php esc_html_e('Candidate', 'gj'); ?></option>
            </select>
        </p>
        <?php
    }

}

function gj_widget_social_share() {
    register_widget('GJ_Widget_Social_Share');
}
add_action('widgets_init', 'gj_widget_social_share');