<?php
$paged = isset($_GET['cpage']) ? intval($_GET['cpage']) : 1;
$status = isset($_GET['status']) ? sanitize_text_field($_GET['status']) : '';
$search = isset($_GET['search']) ? sanitize_text_field($_GET['search']) : '';
$user = GJ_User::get_user();
$application_query = $user->get_submited_applications();
$url = gj_get_page_permalink('dashboard');
?>
<div class="gj-submited-applications">
    <div class="gj-search-form">
        <form action="<?php echo esc_url($url); ?>">
            <div class="row">
                <div class="col-md-3 col-sm-3 col-xs-12">
                    <label><?php echo esc_html__('Status:', 'gj'); ?></label>
                    <div class="gj-select-option">
                        <select class="search-select gj-jobs-status gj-select-2-wsearch" name="status">
                            <option value="" <?php selected($status, ''); ?>><?php echo esc_html__('Status', 'gj'); ?></option>
                            <?php
                            $job_status = GJ_Application::get_status_array(true, true);
                            foreach ($job_status as $key => $title) {
                                echo '<option value="' . $key . '" ' . selected($status, $key, false) . '>' . $title . '</option>';
                            }
                            ?>
                        </select>
                    </div>
                </div>
                <div class="col-md-9 col-sm-9 col-xs-12">
                    <div class="search-box">
                        <input type="text" class="search-text" placeholder="<?php echo esc_html__('Search by job', 'gj'); ?>" name="search" value="<?php echo esc_attr($search); ?>">
                        <button class="search-button" type="submit"><i class="fa fa-search"></i></button>
                    </div>
                </div>
            </div>
        </form>
    </div>
    <div class="gj-main-block">
        <div class="gj-submited-applications-table">
            <div class="gj-table-overflow-x">
                <table class="table">
                    <thead>
                        <tr>
                            <th style="width: 30%;"><?php echo esc_html__('Applied Job', 'gj'); ?></th>
                            <th style="width: 20%;"><?php echo esc_html__('Employer', 'gj'); ?></th>
                            <th style="width: 20%;"><?php echo esc_html__('Applied Date', 'gj'); ?></th>
                            <th style="width: 20%;"></th>
                            <th style="width: 10%;" class="text-center"></th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if ($application_query && $application_query->have_posts()) { ?>
                            <?php
                            while ($application_query->have_posts()) {
                                $application_query->the_post();
                                $post = get_post();
                                $application = GJ_Application::get_application($post);
                                $job = $application->get_job();
                                if ($job != null) {
                                    ?>
                                    <tr class="application-item application-<?php echo esc_attr($application->get_id()); ?>">
                                        <td class="application-job">
                                            <?php
                                            $job_link = $job->permalink();
                                            ?>
                                            <h3>
                                                <a href="<?php echo esc_url($job_link); ?>"><?php echo esc_html($job->get_title()); ?></a>
                                            </h3>
                                            <?php
                                            ?>
                                        </td>
                                        <td class="application-employer">
                                            <?php
                                            $employer = $job->get_employer('publish');
                                            ?>
                                            <h3>
                                                <?php if ($employer): ?>
                                                    <a href="<?php echo esc_url($employer->permalink()); ?>"><?php echo esc_html($employer->get_title()); ?></a>
                                                <?php else: ?>
                                                    <a class="dotted" href="#" data-toggle="tooltip" title="<?php echo esc_html__('Employer has been deleted or unpublish', 'gj');?>"><?php echo esc_html__('Unknown', 'gj'); ?></a>
                                                <?php endif; ?>
                                            </h3>
                                        </td>
                                        <td class="application-created"><?php echo esc_html($application->get_created()); ?></td>
                                        <td class="download-cv">
                                            <?php
                                            $cv = $application->get_cv();
                                            if (isset($cv['url']) && $cv['url'] != null) {
                                                ?>
                                                <a href="<?php echo esc_url($cv['url']); ?>" target="_blank" title="<?php echo esc_html__('Download CV', 'gj'); ?>"><span><?php echo esc_html__('Download CV', 'gj'); ?></span><i class="fa fa-download"></i></a>
                                            <?php } ?>
                                        </td>
                                        <td class="action text-center">
                                            <div>
                                                <a href="#" class="gj-view-application" data-id="<?php echo esc_attr($application->get_id()) ?>" data-remote="false" data-toggle="modal" data-target="#gj-application-view-modal"><i class="fa fa-eye"></i></a>
                                            </div>
                                        </td>
                                    </tr>
                                    <?php
                                }
                            }
                            wp_reset_postdata();
                        } else {
                            ?>
                            <tr class="gj-empty">
                                <td colspan="4"><?php echo esc_html__('No applications found.', 'gj'); ?></td>
                            </tr>
                        <?php } ?>
                    </tbody>
                </table>
            </div>
            <div class="modal fade gj-application-view-modal" id="gj-application-view-modal" tabindex="-1" role="dialog" data-loading="<?php echo esc_html__('Loading...', 'gj'); ?>">
                <div class="iw-vertical-alignment-helper">
                    <div class="iw-vertical-align-center">
                        <div class="modal-dialog" role="document">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h4 class="modal-title"><?php echo esc_html__('Application Details', 'gj'); ?></h4>
                                    <button type="button" class="close" data-dismiss="modal">&times;</button>
                                </div>
                                <div class="modal-body">
                                    <?php echo esc_html__('Loading...', 'gj'); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="clearfix"></div>
        <?php if ($application_query && $application_query->max_num_pages > 1) { ?>
            <div class="gj-pagination">
                <?php
                $big = 999999999; // need an unlikely integer
                echo paginate_links(array(
                    'base' => add_query_arg('cpage', '%#%'),
                    'format' => '',
                    'prev_text' => '&laquo;',
                    'next_text' => '&raquo;',
                    'current' => $paged,
                    'total' => $application_query->max_num_pages
                ));
                ?>
            </div>
            <div class="clearfix"></div>
        <?php } ?>
    </div>
</div>
