<?php
    $user = GJ_User::get_user();
    $follows = $user->get_follows();
    $search = isset($_GET['search']) ? sanitize_text_field($_GET['search']) : '';
    $url = gj_get_page_permalink('dashboard');
?>
<div class="gj-follows">
    <div class="gj-search-form">
        <form action="<?php echo esc_url($url); ?>">
			<div class="search-box">
                <input type="text" class="search-text" placeholder="<?php echo esc_html__('Search', 'gj'); ?>" name="search" value="<?php echo esc_attr($search); ?>">
                <button class="search-button" type="submit"><i class="fa fa-search"></i></button>
            </div>
        </form>
    </div>
    <div class="gj-main-block">
        <div class="gj-table-overflow-x">
            <table class="table">
                <thead>
                <tr>
                    <th style="width: 40%;"><?php echo esc_html__('Company', 'gj'); ?></th>
                    <th style="width: 40%;" class="text-center"><?php echo esc_html__('Opening Jobs', 'gj'); ?></th>
                    <th style="width: 15%;" class="text-center"></th>
                </tr>
                </thead>
                <tbody>
                <?php if($follows) {
                    if($follows['result']){
                        foreach ($follows['result'] as $item){
                            $employer = GJ_Employer::get_employer($item->post_id);
							$image = $employer->get_thumbnail('gje-thumbnail');
                            $author = $employer->get_author();
                            ?>
                            <tr class="follow-item" id="follow-<?php echo esc_attr($item->post_id); ?>">
                                <td>
                                    <div class="avatar">
                                        <a href="<?php echo esc_url($employer->permalink()); ?>"><?php echo (string)$image; ?></a>
                                    </div>
                                    <div class="follow-content">
                                        <h3><a href="<?php echo esc_url($employer->permalink()); ?>"><?php echo esc_html($employer->get_display_name()); ?></a></h3>
                                        <?php if($location = $employer->get_location()){ ?>
                                            <div class="location">
                                                <span class="meta-title"><i class="lnr lnr-location"></i></span>
                                                <span class="meta-value">
                                                    <?php echo esc_html($location); ?>
                                                </span>
                                            </div>
                                        <?php } ?>
                                        <div class="employer-meta-info">
                                            <?php if($category_links = $employer->get_categories_links()){ ?>
                                                <div class="categories">
                                                    <span class="meta-title"><i class="fa fa-suitcase"></i></span>
                                                <span class="meta-value">
                                                    <?php echo (string)$category_links; ?>
                                                </span>
                                                </div>
                                            <?php } ?>
                                        </div>
                                    </div>
                                <td class="text-center">
                                    <?php
                                    $opening_jobs = $employer->count_opening_jobs();
                                    if($opening_jobs){
                                        echo '<a href="'.esc_url($employer->permalink()).'">'.sprintf(_n('%d Open Position', '%d Open Positions', $opening_jobs, 'gj'), $opening_jobs).'</a>';
                                    }
                                    ?>
                                </td>
                                <td class="text-center action">
                                    <a href="#" class="gj-unfollow" data-id="<?php echo esc_attr($item->post_id); ?>"
                                       data-message="<?php printf(__('Are you sure you want to remove %s?', 'gj'), $employer->get_display_name()); ?>">
                                        <i class="lnr lnr-trash"></i>
                                    </a>
                                </td>
                            </tr>
                        <?php
                        }
                    }
                }else{ ?>
                    <tr class="gj-empty">
                        <td colspan="3"><?php echo esc_html__('No companies found', 'gj'); ?></td>
                    </tr>
                <?php } ?>
                </tbody>
            </table>
        </div>

        <div class="modal fade" id="gj-confirm-unfollow" role="dialog">
            <div class="iw-vertical-alignment-helper">
                <div class="iw-vertical-align-center">
                    <div class="modal-dialog">
                        <!-- Modal content-->
                        <div class="modal-content">
                            <div class="modal-header">
                                <h4 class="modal-title"><?php echo esc_html__('Confirm Delete', 'gj'); ?></h4>
                                <button type="button" class="close" data-dismiss="modal">&times;</button>
                            </div>
                            <div class="modal-body">
                                <p></p>
                            </div>
                            <div class="modal-footer">
                                <div class="gj-respon-msg"></div>
                                <div class="gj-button-loader">
                                    <button type="button" class="btn btn-primary gj-agree-unfollow"><?php echo esc_html__('Continue', 'gj'); ?></button>
                                    <button type="button" class="btn btn-default" data-dismiss="modal"><?php echo esc_html__('Close', 'gj'); ?></button>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <div class="clearfix"></div>
        <?php if($follows && $follows['total_page'] > 1){ ?>
            <div class="gj-pagination">
            <?php
            echo paginate_links( array(
                'base' => add_query_arg( 'cpage', '%#%' ),
                'format' => '',
                'prev_text' => '&laquo;',
                'next_text' => '&raquo;',
                'total' => $follows['total_page'],
                'current' => $follows['current_page']
                ));
            ?>
            </div>
            <div class="clearfix"></div>
        <?php } ?>
    </div>
</div>