<?php
/**
 * The Template for login page
 * @package GJ/Templates
 * @since 1.0.1
 */
?>

<div class="gj-login">
    <?php
    if(!is_user_logged_in()) {?>
        <form action="<?php echo esc_url(get_permalink()); ?>" method="post" class="gj-form gj-login-form">
            <div class="intro_login text-center">
                <?php
                if(isset($link_image) && $link_image){ ?>
                    <img src="<?php echo esc_url($link_image)?>" alt="login_logo">
                <?php } ?>
                <?php if(isset($pre_text) && $pre_text){ ?>
                    <div class="pre-text"><?php echo esc_html($pre_text); ?></div>
                <?php } ?>
                <?php if(isset($des_text) && $des_text){ ?>
                    <div class="des_text"><?php echo esc_html($des_text); ?></div>
                <?php } ?>
            </div>

            <div class="gj-respon-msg hide"></div>
            <div class="gj-field">
                <label><?php echo esc_html__('Email', 'gj'); ?></label>
                <div class="gj-input">
                    <input type="text" name="username" placeholder="<?php echo esc_html__('Enter Your Username or Email.', 'gj'); ?>">
                </div>
            </div>
            <div class="gj-field mb-0">
                <label><?php echo esc_html__('Password', 'gj'); ?></label>
                <div class="gj-input">
                    <input type="password" name="password" placeholder="<?php echo esc_html__('Enter Password.', 'gj'); ?>">
                </div>
            </div>
            <div class="text-right lost-password">
                <a href="<?php echo esc_url(gj_get_page_permalink('lostpass')); ?>"><?php echo esc_html__('Lost Password?', 'gj'); ?></a>
            </div>
            <div class="gj-button-loader">
               <button type="submit" name="login" class="gj-btn gj-btn-primary gj-btn-full gj-btn-large gj-login-btn"><?php echo esc_html__('Login', 'gj'); ?></button>
            </div>

            <?php
            $socials = GJ()->social_logins->get_available_socials();
            if($socials){ ?>
                <div class="gj-divider">
                    <span class="line"></span>
                    <span class="circle"><?php echo esc_html__('Or', 'gj');?></span>
                </div>
                <?php echo '<div class="social-login row">';
                foreach ($socials as $social){
                    if($social && $social->is_available()){
                        echo '<div class="col-md-12">
                            <a href="'.esc_url($social->get_login_url()).'" class="gj-btn gj-btn-primary gj-btn-full gj-btn-large gj-btn-icon social-login-'.$social->id.'"><i class="'.$social->get_fontawesome_icon().'"></i>'.$social->get_description().'</a>
                            </div>';
                    }
                }
                echo '</div>';
            }

            $disable_candidate_register = gj_option('disable_candidate_register');
            $disable_employer_register = gj_option('disable_employer_register');
            if(!$disable_candidate_register || !$disable_employer_register){
            ?>
            <div class="text-left register-account">
                <?php echo esc_html__('Do not you have an account? ','gj')?><a href="<?php echo esc_url(gj_get_page_permalink('register')); ?>"><?php echo esc_html__('Register', 'gj'); ?></a>
            </div>
            <?php } ?>
            <input type="hidden" name="redirect_to" value="<?php echo esc_url($redirect_to); ?>">
        </form>
    <?php }else{
        $user = GJ_User::get_user();
        ?>
        <div class="logged-in">
            <?php sprintf(__('You are login as %s, click <a href="%s">here</a> to go to dashboard manager', 'gj'), $user->get_display_name(), esc_url(gj_get_page_permalink('dashboard'))); ?>
        </div>
    <?php } ?>
</div>
