<?php
$employer = $job->get_employer();
$is_featured = $job->is_featured();
$type = $job->get_type();
$salary = $job->get_salary();
$salary_postfix = $job->get_salary_postfix();
$location = $job->get_location();
?>
<div class="job-detail default" itemscope itemtype="http://schema.org/JobPosting">
    <div class="job-page-heading">
        <div class="container">
            <div class="row flex">
                <div class="content-heading">
                    <div class="flex-middle">
                        <?php if ($employer || $job->get_thumbnail()) { ?>
                            <?php if($employer && $employer->get_thumbnail()){ ?>
                                <div class="company-logo">
                                    <a href="<?php echo esc_url($employer->permalink()); ?>" >
                                        <?php echo wp_kses_post($employer->get_thumbnail()); ?>
                                    </a>
                                </div>
                                <?php
                            } elseif ($job->get_thumbnail()) { ?>
                                <div class="company-logo">
                                    <?php echo wp_kses_post($job->get_thumbnail()); ?>
                                </div>
                            <?php }?>
                        <?php } ?>
                        <div class="job-meta">
                            <div class="job-meta-inner">
                                <?php if ($type != null) {?>
                                    <span class="job-type"><?php echo esc_html($type->name);?></span>
                                <?php } ?>
                                <h1 class="job-title" itemprop="title"><?php echo esc_html($job->get_title()); ?></h1>
                                <span class="posted">
                                <?php echo esc_html__('Posted ', 'gj').gj_time_ago($job->get_created());?>
                                </span>

                                <?php if ($location || $salary) :?>
                                    <ul class="meta">
                                        <?php if ($location) :?>
                                            <li class="location" itemprop="jobLocation" itemscope itemtype="http://schema.org/Place">
                                                <i class="fa fa-map-marker"></i><?php echo esc_html($location); ?>
                                                <meta itemprop="address" content="<?php echo esc_attr($location); ?>" />
                                            </li>
                                        <?php endif; ?>

                                        <?php if ($job->has_salary()) {
                                            ?>
                                            <li class="salary"><i class="far fa-money-bill-alt"></i><?php echo esc_html($salary); echo ($salary_postfix ? ' / '.$salary_postfix : ''); ?></li>
                                            <span itemprop="baseSalary" itemscope itemtype="http://schema.org/MonetaryAmount">
                                                <meta itemprop="currency" content="<?php echo esc_attr($job->get_currency()); ?>" />
                                                <meta itemprop="minValue" content="<?php echo esc_attr($job->get_salary_from()); ?>" />
                                                <meta itemprop="maxValue" content="<?php echo esc_attr($job->get_salary_to()); ?>" />
                                                <meta itemprop="unitText" content="<?php echo esc_attr($job->get_salary_postfix()); ?>" />
                                            </span>
                                        <?php } ?>
                                    </ul>
                                <?php endif; ?>
                                <?php if($employer){ ?>
                                    <span itemprop="hiringOrganization" itemscope itemtype="http://schema.org/Organization">
                                        <meta itemprop="name" content="<?php echo esc_attr($employer->get_title()); ?>" />
                                    </span>
                                <?php } ?>
                                <meta itemprop="datePosted" content="<?php echo get_the_date('Y-m-d'); ?>"/>
                                <?php if ($type){ ?>
                                    <meta itemprop="employmentType" content="<?php echo esc_attr($type->name); ?>" />
                                <?php } ?>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="action-button middle">
                    <div class="widget-item-sidebar">
                        <?php
                        $can_apply = $job->can_apply();
                        if($can_apply === 0) {
                                echo '<span class="job-expired"><i class="fa fa-exclamation-triangle"></i> ' . esc_html__('This job has expired.', 'gj') . '</span>';
                        }elseif ($user && !$user->can_apply()) {
							echo '<span class="job-expired">' . __('Employers do not have permission to apply to jobs', 'iwjob') . '</span>';
						}else {
                            if ($job->get_custom_apply_url()) {
                                ?>
                                <a href="<?php echo esc_url($job->get_custom_apply_url()); ?>" target="_blank" class="apply-job">
                                    <?php echo esc_html__('Apply now', 'gj'); ?><i class="fa fa-paper-plane"></i>
                                </a>
                                <?php
                            } else {
                                $applies = GJ()->applies->applies();
                                if ($applies) {
                                    foreach ($applies as $apply) {
                                        if ($apply->is_available() && $apply->id == 'form') {
                                            $apply->apply_button($job);
                                            break;
                                        }
                                    }
                                }
                            }
                        }
                        ?>

                        <?php
                        $can_save_job = gj_can_save_job();
                        if ($can_save_job === null) { ?>
                            <a href="#" class="save-job" data-toggle="modal" data-target="#gj-login-popup"><?php echo esc_html__('Save job', 'gj'); ?><i class="far fa-heart"></i></a>
                            <?php
                        } elseif ($can_save_job) {
                            $saved_job = $user && $user->is_saved_job(get_the_ID()) ? true : false;
                            $save_text = $saved_job ? esc_html__('Saved Job', 'gj') : esc_html__('Save Job', 'gj');
                            ?>
                            <a href="#" class="save-job gj-save-job <?php echo ($saved_job ? 'saved' : ''); ?>" data-toggle="tooltip" data-id="<?php echo esc_attr(get_the_ID()); ?>"><span class="text"><?php echo esc_html($save_text);?></span><i class="fa fa-heart"></i></a>
                        <?php } ?>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="content-wrap main-content">
        <div class="content-inner">
            <div class="container">
                <div class="row">
                    <div class="<?php echo esc_attr( gj_get_class( 'container', $job_sidebar, 'large' ) ) ?>">
                        <div class="job-detail">
                            <div class="job-detail-content">
                                <div id="job-detail-content">

                                    <?php
                                    $fields = gj_fields();
                                    foreach ($fields as $field){
                                        $block = $field->getSetting('outputPosition');
                                        if($block === 'main'){
                                            $field->outputHtml();
                                        }
                                    }

                                    do_action('gj_after_content');
                                    ?>

                                    <div class="post-social-share">
                                        <span class="job-share-title"><?php echo esc_html('Share: ')?></span>
                                        <?php
                                        gj_social_sharing(get_permalink(), gj_substrword($job->get_description(true), 10), get_the_title());
                                        ?>
                                    </div>

                                    <?php if (gj_option('show_print_job')) { ?>
                                        <div class="gj-print-job">
                                            <a href="javascript:void(0);" class="gj-button-print-job" data-title="<?php echo esc_attr($job->get_title()); ?>" data-author="<?php echo esc_attr($author->get_display_name()); ?>" data-author_avatar="<?php echo esc_url(get_avatar_url($author->get_id())); ?>">
                                                <span><?php echo esc_html__('Print: ', 'gj'); ?></span><i class="fa fa-print"></i>
                                            </a>
                                        </div>
                                    <?php } ?>
                                </div>
                            </div>
                        </div>


                        <?php
                        $related_jobs = $job->get_related();
                        if ($related_jobs) {
                            ?>
                            <div class="job-related">
                                    <h3 class="title"><?php echo esc_html__('Similar Jobs You May Like', 'gj'); ?></h3>
                                    <div class="jobs-list">
                                        <?php
                                        foreach ($related_jobs as $related_job) {
                                            $related_author = $related_job->get_author();
                                            $job_employer = $related_job->get_employer();
                                            $is_featured = $related_job->is_featured();
                                            $type = $related_job->get_type();
                                            $permalink = $related_job->permalink();
                                            $salary_job = $related_job->get_salary();
                                            ?>
                                            <div class="item job-page-heading">
                                                <div class="item-info flex-middle">
                                                    <?php if ($job->get_thumbnail()) {?>
                                                        <div class="company-logo">
                                                            <?php if($job_employer){ ?>
                                                                <a href="<?php echo esc_url($job_employer->permalink()); ?>" >
                                                                    <?php echo wp_kses_post($job_employer->get_thumbnail()); ?>
                                                                </a>
                                                                <?php
                                                            }else{
                                                                echo wp_kses_post($job->get_thumbnail());
                                                            }
                                                            ?>
                                                        </div>
                                                    <?php } ?>
                                                    <div class="job-meta">
                                                        <?php if($type){ ?>
                                                        <span class="job-type"><?php echo esc_html($type->name);?></span>
                                                        <?php } ?>
                                                        <h3 class="job-title">
                                                            <a href="<?php echo esc_url($permalink);?>"><?php echo esc_html($related_job->get_title()); ?></a>
                                                        </h3>
                                                        <ul class="meta">
                                                            <?php if ($related_job->get_location() ) :?>
                                                                <li class="location"><i class="fa fa-map-marker"></i><?php echo esc_html($related_job->get_location()); ?></li>
                                                            <?php endif;?>
                                                            <?php if ($salary_job) :?>
                                                                <li class="salary"><i class="far fa-money-bill-alt"></i><?php echo esc_html($salary_job); ?></li>
                                                            <?php endif; ?>
                                                        </ul>
                                                    </div>
                                                </div>
                                                <?php if ($is_featured) :?>
                                                    <span class="featured_label"><i class="gj-icon gj-icon-star"></i><?php echo esc_html__(' featured', 'gj');?></span>
                                                <?php endif; ?>
                                            </div>
                                            <?php
                                        }
                                        ?>
                                    </div>
                            </div>
                        <?php } ?>
                    </div>
                    <?php if ($job_sidebar && is_active_sidebar('sidebar-job')) : ?>
                        <div class="<?php echo( $job_sidebar_sticky ? 'gj-sidebar-sticky' : '' ); ?> job-sidebar gj-detail-sidebar <?php echo esc_attr(gj_get_class('sidebar', $job_sidebar)) ?>">
                            <?php dynamic_sidebar('sidebar-job'); ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<?php
$apply_cls = new GJ_Apply_Form();
gj_get_template_part('applies/form/popup', array('job' => $job, 'self' => $apply_cls));
?>
