<?php
/**
 * The Template for register page
 * @package GJ/Templates
 * @since 1.0.1
 */
?>
<div class="gj-register">
    <?php
    if (!is_user_logged_in()) {
        $active_tab = isset($_GET['role']) ? sanitize_text_field($_GET['role']) : 'candidate';
        $active_tab = apply_filters('gj_register_active_tab', $active_tab);
        $disable_candidate_register = gj_option('disable_candidate_register');
        $disable_employer_register = gj_option('disable_employer_register');
        if (!$disable_candidate_register || !$disable_employer_register) {
            ?>
            <form action="<?php echo esc_url(get_permalink()); ?>" method="post" class="gj-form gj-register-form">
                <div class="intro_register text-center">
                    <?php
                    if(isset($link_image) && $link_image){ ?>
                        <img src="<?php echo esc_url($link_image) ?>" alt="login_logo">
                    <?php } ?>
                    <?php if(isset($pre_text) && $pre_text){ ?>
                        <div class="pre-text"><?php echo esc_html($pre_text); ?></div>
                    <?php } ?>
                </div>
                <?php if (!$disable_candidate_register && !$disable_employer_register) { ?>
                    <div class="gj-tab-register-wrap">
                        <div class="gj-tab-register">
                            <span class="<?php echo 'employer' == $active_tab ? '' : 'active'; ?> gj-toggle gj-candidate-toggle"><?php echo esc_html__('Candidate', 'gj'); ?></span>
                            <span class="<?php echo 'employer' == $active_tab ? 'active' : ''; ?>gj-toggle gj-employer-toggle"><?php echo esc_html__('Employer', 'gj'); ?></span>
                        </div>
                    </div>
                <?php } ?>
                <div class="gj-field">
                    <label><?php echo esc_html__('User name', 'gj'); ?></label>
                    <div class="gj-input">
                        <input type="text" name="username" placeholder="<?php echo esc_html__('Enter Your Username.', 'gj'); ?>" required>
                    </div>
                </div>

                <div class="gj-field">
                    <label><?php echo esc_html__('Email', 'gj'); ?></label>
                    <div class="gj-input">
                        <input type="email" name="email" placeholder="<?php echo esc_html__('Enter Your Email Address.', 'gj'); ?>" required>
                    </div>
                </div>
                <?php if (!gj_option('registration_generate_password')) { ?>
                    <div class="flex-container">
                        <div class="gj-field">
                            <label><?php echo esc_html__('Password', 'gj'); ?></label>
                            <div class="gj-input">
                                <input type="password" name="password" placeholder="<?php echo esc_html__('Enter Your Password.', 'gj'); ?>" required>
                            </div>
                        </div>
                        <div class="gj-field">
                            <label>
                                <?php esc_html_e('Confirm Password', 'gj'); ?>
                            </label>
                            <div class="gj-input">
                                <input type="password" name="password_confirm" placeholder="<?php esc_attr_e('Confirm Password', 'gj'); ?>" required>
                            </div>
                        </div>
                    </div>

                <?php } ?>
	            <?php if (gj_option('terms_and_conditions') && (gj_option('terms_and_conditions_page') || gj_option('privacy_policy_page'))) { ?>
					<div class="register-account text-center">
			            <?php
			            $messages = gj_option( 'terms_and_conditions' );
			            $terms_and_conditions_url     = gj_option( 'terms_and_conditions_page' ) ? get_the_permalink( gj_option( 'terms_and_conditions_page' ) ) : '';
			            $privacy_policy_url           = gj_option( 'privacy_policy_page' ) ? get_the_permalink( gj_option( 'privacy_policy_page' ) ) : '';
			            $str_key                      = array(
				            '{link_terms_and_conditions_page}',
				            '{link_privacy_policy_page}'
			            );
			            $str_replaced                 = array( $terms_and_conditions_url, $privacy_policy_url );
			            $messages_replaced = str_replace( $str_key, $str_replaced, $messages);
			            echo wp_kses_post($messages_replaced);
			            ?>
					</div>
	            <?php } ?>
                <div class="gj-respon-msg gj-hide"></div>
                <?php
                $role = !$disable_candidate_register ? 'candidate' : 'employer';
                if ('employer' == $active_tab) {
                    $role = 'employer';
                }
                ?>
                <input type="hidden" name="role" value="<?php echo esc_attr($role); ?>">
                <button type="submit" name="register" class="gj-btn-primary"><?php echo esc_html__('Register', 'gj'); ?></button>
                <?php
                $socials = GJ()->social_logins->get_available_socials();
                if ($socials) { ?>
                    <div class="gj-divider">
                        <span class="line"></span>
                        <span class="circle"><?php echo esc_html__('Or', 'gj'); ?></span>
                    </div>
                    <?php echo '<div class="social-login row">';
                    foreach ($socials as $social) {
                        if ($social && $social->is_available()) {
                            echo '<div class="col-xs-12 col-sm-6 col-md-6 item-col">
                                <a href="' . esc_url($social->get_login_url()) . '" class="gj-btn gj-btn-primary gj-btn-medium gj-btn-full gj-btn-icon social-login-' . $social->id . '"><i class="' . $social->get_fontawesome_icon() . '"></i>' . $social->get_title() . '</a>
                                </div>';
                        }
                    }
                    echo '</div>';
                }
                ?>
                <input type="hidden" name="redirect_to" value="<?php echo esc_url($redirect_to); ?>">
                <div class="text-left register-account">
                    <?php echo esc_html__('Have a Account? ','gj')?><a href="<?php echo esc_url(gj_get_page_permalink('login')); ?>"><?php echo esc_html__('Sign In with Account?', 'gj'); ?></a>
                </div>
            </form>
            <?php
        } else {
            echo esc_html__('Sorry, the registration function is temporarily unavailable, please come back later', 'gj');
        }
        ?>
        <?php
    } else {
        $user = GJ_User::get_user();
        ?>
        <div class="logged-in">
            <?php sprintf(__('You are login as %s, click <a href="%s">here</a> to go to dashboard manager', 'gj'), $user->get_display_name(), esc_url(gj_get_page_permalink('dashboard'))); ?>
        </div>
    <?php } ?>
</div>
